@@ -30,7 +30,7 @@ apt-get install -y --no-install-recommends \
 echo "deb [arch=amd64] http://dl.google.com/linux/chrome/deb/ stable main" > /etc/apt/sources.list.d/google-chrome.list
 echo "deb [arch=amd64] https://download.docker.com/linux/ubuntu $(lsb_release -cs) stable" | tee -a /etc/apt/sources.list.d/google-cloud-sdk.list
 echo "deb [arch=amd64] https://apt.bell-sw.com/ stable main" | sudo tee /etc/apt/sources.list.d/bellsoft.list
-curl -sSL https://dl.google.com/linux/linux_signing_key.pub | apt-key add -
+curl -fsSL https://dl.google.com/linux/linux_signing_key.pub | apt-key add -
 curl -fsSL https://download.docker.com/linux/ubuntu/gpg | apt-key add -
 curl -fsSL https://download.bell-sw.com/pki/GPG-KEY-bellsoft | apt-key add -
 apt-get update
@@ -60,6 +60,7 @@ DEBIAN_FRONTEND=noninteractive apt-get install -y --no-install-recommends \
 cp -R /etc/alternatives /etc/keep-alternatives
 apt-get install -y --no-install-recommends \
     bellsoft-java11 \
+    bellsoft-java17 \
     bellsoft-java8
 rm -rf /etc/alternatives
 mv /etc/keep-alternatives /etc/alternatives
@@ -69,12 +70,12 @@ pip3 install setuptools
 pip3 install docker-compose
 
 pushd /tmp
-  curl -O https://dl.google.com/dl/cloudsdk/channels/rapid/downloads/google-cloud-sdk-${CLOUD_SDK_VERSION}-linux-x86_64.tar.gz
+  curl -fO https://dl.google.com/dl/cloudsdk/channels/rapid/downloads/google-cloud-sdk-${CLOUD_SDK_VERSION}-linux-x86_64.tar.gz
   tar xzf google-cloud-sdk-${CLOUD_SDK_VERSION}-linux-x86_64.tar.gz -C /
   rm google-cloud-sdk-${CLOUD_SDK_VERSION}-linux-x86_64.tar.gz
-  curl -sSO https://dl.google.com/cloudagents/install-monitoring-agent.sh
-  bash install-monitoring-agent.sh
-  rm install-monitoring-agent.sh
+  curl -fsSO https://dl.google.com/cloudagents/add-google-cloud-ops-agent-repo.sh
+  sudo bash  add-google-cloud-ops-agent-repo.sh --also-install
+  rm add-google-cloud-ops-agent-repo.sh
 popd
 export PATH=/google-cloud-sdk/bin:${PATH}
 gcloud config set core/disable_usage_reporting true
@@ -82,8 +83,7 @@ gcloud config set component_manager/disable_update_check true
 gcloud config set metrics/environment github_docker_image
 gcloud components install docker-credential-gcr --quiet
 gcloud auth configure-docker --quiet
-docker pull ${GEODE_DOCKER_IMAGE}
-curl -Lo /usr/local/bin/dunit-progress https://github.com/jdeppe-pivotal/progress-util/releases/download/0.2/progress.linux
+curl -fLo /usr/local/bin/dunit-progress https://github.com/jdeppe-pivotal/progress-util/releases/download/0.2/progress.linux
 chmod +x /usr/local/bin/dunit-progress
 wget --no-verbose -O /tmp/chromedriver_linux64.zip https://chromedriver.storage.googleapis.com/${CHROME_DRIVER_VERSION}/chromedriver_linux64.zip
 rm -rf /opt/selenium/chromedriver
@@ -98,3 +98,4 @@ echo "export PATH=/google-cloud-sdk/bin:${PATH}" > /etc/profile.d/google_sdk_pat
 apt-get remove -y unattended-upgrades && apt-get -y autoremove
 apt-get clean
 rm -rf /var/lib/apt/lists/*
+echo "kernel.pid_max=983040" > /etc/sysctl.d/99-geode.conf
