@@ -117,7 +117,7 @@ YML
   FLY_URL="${CONCOURSE_URL}/api/v1/cli?arch=amd64&platform=${platform}"
   FLY="${SCRIPTDIR}/fly"
   if [[ ! -e "${FLY}" ]]; then
-    curl -so ${FLY} ${FLY_URL}
+    curl -fso ${FLY} ${FLY_URL}
   fi
   chmod +x ${FLY}
   set +e
@@ -128,7 +128,6 @@ YML
     echo "Target ${FLY_TARGET} already exists."
   fi
 
-  FLY=${FLY:-$(which fly)}
 
   set -e
   if [[ "${UPSTREAM_FORK}" != "apache" ]]; then
@@ -301,9 +300,9 @@ if [[ "$GEODE_FORK" == "${UPSTREAM_FORK}" ]]; then
   if [[ "${PUBLIC}" == "true" ]]; then
     exposePipelines ${PIPELINE_PREFIX}main ${PIPELINE_PREFIX}images
     enableFeature examples
+    enableFeature pr
   fi
   if [[ "$GEODE_BRANCH" == "develop" ]]; then
-    enableFeature pr
     enableFeature mass-test-run
   fi
 fi
