@@ -37,11 +37,6 @@ fi
 . ${SCRIPTDIR}/shared_utilities.sh
 is_source_from_pr_testable "geode" "$(get_geode_pr_exclusion_dirs)" || exit 0
 
-if [ "${GRADLE_TASK}" = ":geode-apis-compatible-with-redis:redisAPITest" ] && ! grep -q redisAPITest geode/geode-apis-compatible-with-redis/build.gradle ; then
-  echo "redisAPITest is not applicable for 1.13 and earlier"
-  exit 0
-fi
-
 REPODIR=$(cd geode; git rev-parse --show-toplevel)
 
 if [[ ${PARALLEL_GRADLE:-"true"} == "true" ]]; then
@@ -64,7 +59,7 @@ scp ${SSH_OPTIONS} ${SCRIPTDIR}/capture-call-stacks.sh geode@${INSTANCE_IP_ADDRE
 if [[ -n "${PARALLEL_DUNIT}" && "${PARALLEL_DUNIT}" == "true" ]]; then
   PARALLEL_DUNIT="-PparallelDunit -PdunitDockerUser=geode -PdunitDockerImage=\$(docker images --format '{{.Repository}}:{{.Tag}}')"
   if [ -n "${DUNIT_PARALLEL_FORKS}" ]; then
-    DUNIT_PARALLEL_FORKS="-PdunitParallelForks=${DUNIT_PARALLEL_FORKS}"
+    DUNIT_PARALLEL_FORKS="--max-workers=${DUNIT_PARALLEL_FORKS} -PtestMaxParallelForks=${DUNIT_PARALLEL_FORKS} -PdunitParallelForks=${DUNIT_PARALLEL_FORKS}"
   fi
 else
   PARALLEL_DUNIT=""
@@ -77,12 +72,23 @@ case $ARTIFACT_SLUG in
     echo "Making environment adjustments for windows."
     JAVA_BUILD_PATH=C:/java${JAVA_BUILD_VERSION}
     JAVA_TEST_PATH=C:/java${JAVA_TEST_VERSION}
+    TEST_JAVA_8_HOME=C:/java8
+    TEST_JAVA_11_HOME=C:/java11
+    TEST_JAVA_17_HOME=C:/java17
     GRADLE_SKIP_TASK_OPTIONS="${GRADLE_SKIP_TASK_OPTIONS} -x docker"
     SEP=";"
+    OPTIONAL_KILL_ALL_CMD="${SEP} \
+      exit_code=\$? ${SEP} \
+      (taskkill //F //IM java.exe //T) ${SEP} \
+      exit \${exit_code}
+      "
     ;;
   *)
     JAVA_BUILD_PATH=/usr/lib/jvm/bellsoft-java${JAVA_BUILD_VERSION}-amd64
     JAVA_TEST_PATH=/usr/lib/jvm/bellsoft-java${JAVA_TEST_VERSION}-amd64
+    TEST_JAVA_8_HOME=/usr/lib/jvm/bellsoft-java8-amd64
+    TEST_JAVA_11_HOME=/usr/lib/jvm/bellsoft-java11-amd64
+    TEST_JAVA_17_HOME=/usr/lib/jvm/bellsoft-java17-amd64
     SEP="&&"
     ;;
 esac
@@ -98,6 +104,9 @@ GRADLE_ARGS=" \
     -PcompileJVMVer=${JAVA_BUILD_VERSION} \
     -PtestJVM=${JAVA_TEST_PATH} \
     -PtestJVMVer=${JAVA_TEST_VERSION} \
+    -PtestJava8Home=${TEST_JAVA_8_HOME} \
+    -PtestJava11Home=${TEST_JAVA_11_HOME} \
+    -PtestJava17Home=${TEST_JAVA_17_HOME} \
     ${PARALLEL_DUNIT} \
     ${DUNIT_PARALLEL_FORKS} \
     ${DEFAULT_GRADLE_TASK_OPTIONS} \
@@ -116,6 +125,9 @@ EXEC_COMMAND="bash -c 'echo Building with: $SEP \
   cd geode $SEP \
   cp gradlew gradlewStrict $SEP \
   sed -e 's/JAVA_HOME/GRADLE_JVM/g' -i.bak gradlewStrict $SEP \
-  GRADLE_JVM=${JAVA_BUILD_PATH} JAVA_TEST_PATH=${JAVA_TEST_PATH} ./gradlewStrict ${GRADLE_ARGS}'"
+  GRADLE_JVM=${JAVA_BUILD_PATH} JAVA_TEST_PATH=${JAVA_TEST_PATH} ./gradlewStrict ${GRADLE_ARGS} \
+  ${OPTIONAL_KILL_ALL_CMD}'"
+
 echo "${EXEC_COMMAND}"
 ssh ${SSH_OPTIONS} geode@${INSTANCE_IP_ADDRESS} "${EXEC_COMMAND}"
+
