@@ -17,7 +17,7 @@
 # limitations under the License.
 #
 
-set -e
+set -eu
 
 SOURCE="${BASH_SOURCE[0]}"
 while [[ -h "$SOURCE" ]]; do # resolve $SOURCE until the file is no longer a symlink
@@ -27,7 +27,7 @@ while [[ -h "$SOURCE" ]]; do # resolve $SOURCE until the file is no longer a sym
 done
 SCRIPTDIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"
 
-. ${SCRIPTDIR}/shared_utilities.sh
+. "${SCRIPTDIR}/shared_utilities.sh"
 
 is_source_from_pr_testable "geode" "$(get_geode_pr_exclusion_dirs)" || exit 0
 
@@ -39,10 +39,10 @@ function changes_for_path() {
                       jq -r -c '.[]| select(.name == "base_sha") | .value') || exit $?
 
     if [[ "${mergeBase}" == "" ]]; then
-      echo "Could not determine merge base. Exiting..."
+      >&2 echo "Could not determine merge base. Exiting..."
       exit 1
     fi
-    git diff --name-only ${mergeBase} -- $path
+    git diff --name-only --diff-filter=ACMR "${mergeBase}" -- $path
   popd >> /dev/null
 }
 
@@ -60,17 +60,17 @@ function create_gradle_test_targets() {
   echo $(${JAVA_HOME}/bin/java -cp $(cat /tmp/classpath.txt) org.apache.geode.test.util.StressNewTestHelper $@)
 }
 
-UNIT_TEST_CHANGES=$(changes_for_path '*/src/test/java') || exit $?
-INTEGRATION_TEST_CHANGES=$(changes_for_path '*/src/integrationTest/java') || exit $?
-DISTRIBUTED_TEST_CHANGES=$(changes_for_path '*/src/distributedTest/java') || exit $?
-ACCEPTANCE_TEST_CHANGES=$(changes_for_path '*/src/acceptanceTest/java') || exit $?
-UPGRADE_TEST_CHANGES=$(changes_for_path '*/src/upgradeTest/java') || exit $?
+UNIT_TEST_CHANGES=$(changes_for_path ':(glob)**/src/test/java/**') || exit $?
+INTEGRATION_TEST_CHANGES=$(changes_for_path ':(glob)**/src/integrationTest/java/**') || exit $?
+DISTRIBUTED_TEST_CHANGES=$(changes_for_path ':(glob)**/src/distributedTest/java/**') || exit $?
+ACCEPTANCE_TEST_CHANGES=$(changes_for_path ':(glob)**/src/acceptanceTest/java/**') || exit $?
+UPGRADE_TEST_CHANGES=$(changes_for_path ':(glob)**/src/upgradeTest/java/**') || exit $?
 
 CHANGED_FILES_ARRAY=( $UNIT_TEST_CHANGES $INTEGRATION_TEST_CHANGES $DISTRIBUTED_TEST_CHANGES $ACCEPTANCE_TEST_CHANGES $UPGRADE_TEST_CHANGES )
 NUM_CHANGED_FILES=${#CHANGED_FILES_ARRAY[@]}
 
 echo "${NUM_CHANGED_FILES} changed test files"
-for T in ${CHANGED_FILES_ARRAY[@]}; do
+for T in "${CHANGED_FILES_ARRAY[@]}"; do
   echo "  ${T}"
 done
 
@@ -82,8 +82,8 @@ fi
 
 save_classpath
 
-TEST_TARGETS=$(create_gradle_test_targets ${CHANGED_FILES_ARRAY[@]})
-TEST_COUNT=$(echo ${TEST_TARGETS} | sed -e 's/.*testCount=\([0-9]*\).*/\1/g')
+TEST_TARGETS=$(create_gradle_test_targets "${CHANGED_FILES_ARRAY[@]}")
+TEST_COUNT=$(echo "${TEST_TARGETS}" | sed -e 's/.*testCount=\([0-9]*\).*/\1/g')
 
 if [[ "${NUM_CHANGED_FILES}" -ne "${TEST_COUNT}" ]]
 then
@@ -103,5 +103,5 @@ export GRADLE_TASK_OPTIONS="-Prepeat=50 -PfailOnNoMatchingTests=false"
 echo "GRADLE_TASK_OPTIONS=${GRADLE_TASK_OPTIONS}"
 echo "GRADLE_TASK=${GRADLE_TASK}"
 
-${SCRIPTDIR}/execute_tests.sh
+"${SCRIPTDIR}/execute_tests.sh"
 
