@@ -33,6 +33,6 @@ public enum QueryCommand {
 
   UNKNOWN,
 
-  FUNCTION;
+  FUNCTION
 
 }
