@@ -16,6 +16,7 @@ package org.apache.geode.modules.session.bootstrap;
 
 import static org.apache.geode.distributed.ConfigurationProperties.CACHE_XML_FILE;
 import static org.apache.geode.distributed.ConfigurationProperties.LOG_FILE;
+import static org.apache.geode.distributed.ConfigurationProperties.SECURITY_PREFIX;
 import static org.apache.geode.distributed.ConfigurationProperties.STATISTIC_ARCHIVE_FILE;
 import static org.apache.geode.distributed.ConfigurationProperties.STATISTIC_SAMPLING_ENABLED;
 
@@ -80,7 +81,7 @@ public abstract class AbstractCache {
   protected static AbstractCache instance = null;
 
   AbstractCache() {
-    this.gemfireProperties = new ConcurrentHashMap<>();
+    gemfireProperties = new ConcurrentHashMap<>();
   }
 
   public void lifecycleEvent(LifecycleTypeAdapter eventType) {
@@ -118,7 +119,7 @@ public abstract class AbstractCache {
   }
 
   public GemFireCache getCache() {
-    return this.cache;
+    return cache;
   }
 
   private String getLogFileName() {
@@ -158,7 +159,7 @@ public abstract class AbstractCache {
   }
 
   public float getEvictionHeapPercentage() {
-    return this.evictionHeapPercentage;
+    return evictionHeapPercentage;
   }
 
   public void setEvictionHeapPercentage(String evictionHeapPercentage) {
@@ -166,7 +167,7 @@ public abstract class AbstractCache {
   }
 
   public float getCriticalHeapPercentage() {
-    return this.criticalHeapPercentage;
+    return criticalHeapPercentage;
   }
 
   public void setCriticalHeapPercentage(String criticalHeapPercentage) {
@@ -178,11 +179,11 @@ public abstract class AbstractCache {
   }
 
   public boolean getRebalance() {
-    return this.rebalance;
+    return rebalance;
   }
 
   private Map<String, String> getGemFireProperties() {
-    return this.gemfireProperties;
+    return gemfireProperties;
   }
 
   public void setProperty(String name, String value) {
@@ -191,20 +192,21 @@ public abstract class AbstractCache {
       return;
     }
 
-    // Determine the validity of the input property
-    boolean validProperty = false;
-    // TODO: AbstractDistributionConfig is internal and _getAttNames is designed for testing.
-    for (String gemfireProperty : AbstractDistributionConfig._getAttNames()) {
-      if (name.equals(gemfireProperty)) {
-        validProperty = true;
-        break;
+    // Determine the validity of the input property (all those that start with security-* are valid)
+    boolean validProperty = name.startsWith(SECURITY_PREFIX);
+    if (!validProperty) {
+      // TODO: AbstractDistributionConfig is internal and _getAttNames is designed for testing.
+      for (String gemfireProperty : AbstractDistributionConfig._getAttNames()) {
+        if (name.equals(gemfireProperty)) {
+          validProperty = true;
+          break;
+        }
       }
     }
 
-    // If it is a valid GemFire property, add it to the the GemFire properties.
-    // Otherwise, log a warning.
+    // If it is a valid GemFire property, add it to the GemFire properties, log a warning otherwise.
     if (validProperty) {
-      this.gemfireProperties.put(name, value);
+      gemfireProperties.put(name, value);
     } else {
       getLogger().warn("The input property named " + name
           + " is not a valid GemFire property. It is being ignored.");
@@ -219,9 +221,7 @@ public abstract class AbstractCache {
     Properties properties = new Properties();
 
     // Add any additional gemfire properties
-    for (Map.Entry<String, String> entry : this.gemfireProperties.entrySet()) {
-      properties.put(entry.getKey(), entry.getValue());
-    }
+    properties.putAll(gemfireProperties);
 
     // Replace the cache xml file in the properties
     File cacheXmlFile = getCacheXmlFile();
@@ -363,9 +363,8 @@ public abstract class AbstractCache {
       }
     }
 
-    // Validate java startup parameters (done after setting the eviction and
-    // critical heap percentages so that the CMSInitiatingOccupancyFraction can
-    // be compared against them.
+    // Validate java startup parameters after setting the eviction and
+    // critical heap percentages so that they can be compared against them.
     ResourceManagerValidator.validateJavaStartupParameters(getCache());
   }
 
@@ -383,7 +382,7 @@ public abstract class AbstractCache {
   @Override
   public String toString() {
     return getClass().getSimpleName() + "[" + "cache="
-        + this.cache + "]";
+        + cache + "]";
   }
 
   protected abstract void createOrRetrieveCache();
