@@ -21,12 +21,13 @@ import org.apache.catalina.util.LifecycleSupport;
  * @deprecated Tomcat 6 has reached its end of life and support for Tomcat 6 will be removed
  *             from a future Geode release.
  */
+@Deprecated
 public class Tomcat6DeltaSessionManager extends DeltaSessionManager<Tomcat6CommitSessionValve> {
 
   /**
    * The <code>LifecycleSupport</code> for this component.
    */
-  private LifecycleSupport lifecycle = new LifecycleSupport(this);
+  private final LifecycleSupport lifecycle = new LifecycleSupport(this);
 
   /**
    * Prepare for the beginning of active use of the public methods of this component. This method
@@ -39,10 +40,10 @@ public class Tomcat6DeltaSessionManager extends DeltaSessionManager<Tomcat6Commi
     if (getLogger().isDebugEnabled()) {
       getLogger().debug(this + ": Starting");
     }
-    if (this.started.get()) {
+    if (started.get()) {
       return;
     }
-    this.lifecycle.fireLifecycleEvent(START_EVENT, null);
+    lifecycle.fireLifecycleEvent(START_EVENT, null);
     try {
       init();
     } catch (Throwable t) {
@@ -62,7 +63,7 @@ public class Tomcat6DeltaSessionManager extends DeltaSessionManager<Tomcat6Commi
     // Create the timer and schedule tasks
     scheduleTimerTasks();
 
-    this.started.set(true);
+    started.set(true);
   }
 
   /**
@@ -75,17 +76,17 @@ public class Tomcat6DeltaSessionManager extends DeltaSessionManager<Tomcat6Commi
     if (getLogger().isDebugEnabled()) {
       getLogger().debug(this + ": Stopping");
     }
-    this.started.set(false);
-    this.lifecycle.fireLifecycleEvent(STOP_EVENT, null);
+    started.set(false);
+    lifecycle.fireLifecycleEvent(STOP_EVENT, null);
 
     // StandardManager expires all Sessions here.
     // All Sessions are not known by this Manager.
 
     // Require a new random number generator if we are restarted
-    this.random = null;
+    random = null;
 
     // Remove from RMI registry
-    if (this.initialized) {
+    if (initialized) {
       destroy();
     }
 
@@ -110,7 +111,7 @@ public class Tomcat6DeltaSessionManager extends DeltaSessionManager<Tomcat6Commi
    */
   @Override
   public void addLifecycleListener(LifecycleListener listener) {
-    this.lifecycle.addLifecycleListener(listener);
+    lifecycle.addLifecycleListener(listener);
   }
 
   /**
@@ -119,7 +120,7 @@ public class Tomcat6DeltaSessionManager extends DeltaSessionManager<Tomcat6Commi
    */
   @Override
   public LifecycleListener[] findLifecycleListeners() {
-    return this.lifecycle.findLifecycleListeners();
+    return lifecycle.findLifecycleListeners();
   }
 
   /**
@@ -129,7 +130,7 @@ public class Tomcat6DeltaSessionManager extends DeltaSessionManager<Tomcat6Commi
    */
   @Override
   public void removeLifecycleListener(LifecycleListener listener) {
-    this.lifecycle.removeLifecycleListener(listener);
+    lifecycle.removeLifecycleListener(listener);
   }
 
   @Override
