@@ -52,8 +52,8 @@ public abstract class AbstractSessionCacheTest {
 
 
   protected SessionManager sessionManager = mock(SessionManager.class);
-  @SuppressWarnings("unchecked")
-  protected Region<String, HttpSession> sessionRegion = mock(Region.class, RETURNS_DEEP_STUBS);
+  protected Region<String, HttpSession> sessionRegion =
+      uncheckedCast(mock(Region.class, RETURNS_DEEP_STUBS));
   protected DistributedSystem distributedSystem = mock(DistributedSystem.class);
   protected Log logger = mock(Log.class);
   protected Execution<Object, Object, List<Object>> emptyExecution =
