@@ -35,7 +35,7 @@ public class CommandServlet extends HttpServlet {
    */
   @Override
   public void init(ServletConfig config) {
-    this.context = config.getServletContext();
+    context = config.getServletContext();
   }
 
   /**
@@ -65,7 +65,7 @@ public class CommandServlet extends HttpServlet {
           break;
         case SET_MAX_INACTIVE:
           session = request.getSession();
-          session.setMaxInactiveInterval(Integer.valueOf(value));
+          session.setMaxInactiveInterval(Integer.parseInt(value));
           break;
         case GET:
           session = request.getSession();
@@ -94,7 +94,7 @@ public class CommandServlet extends HttpServlet {
           break;
       }
     } catch (Exception e) {
-      out.write("Error in servlet: " + e.toString());
+      out.write("Error in servlet: " + e);
     }
   }
 }
