@@ -45,9 +45,9 @@ public class AddFreeItemToOrders implements Function {
   @Override
   public void execute(FunctionContext context) {
     Region region = null;
-    List<Object> vals = new ArrayList<Object>();
-    List<Object> keys = new ArrayList<Object>();
-    List<Object> argsList = new ArrayList<Object>();
+    List<Object> vals = new ArrayList<>();
+    List<Object> keys = new ArrayList<>();
+    List<Object> argsList = new ArrayList<>();
     Object[] argsArray = null;
 
     if (context.getArguments() instanceof Boolean) {
@@ -76,7 +76,7 @@ public class AddFreeItemToOrders implements Function {
     String oql =
         "SELECT DISTINCT entry.key FROM " + SEPARATOR
             + "orders.entries entry WHERE entry.value.totalPrice > $1";
-    Object queryArgs[] = new Object[1];
+    Object[] queryArgs = new Object[1];
     queryArgs[0] = argsList.get(0);
 
     final Query query = cache.getQueryService().newQuery(oql);
