@@ -52,11 +52,11 @@ import org.apache.http.impl.client.HttpClients;
 public class GeodeDevRestClient {
   public static final String CONTEXT = "/geode/v1";
 
-  private String context;
-  private String bindAddress;
-  private int restPort;
-  private boolean useSsl;
-  private HttpHost host;
+  private final String context;
+  private final String bindAddress;
+  private final int restPort;
+  private final boolean useSsl;
+  private final HttpHost host;
 
 
   public GeodeDevRestClient(String bindAddress, int restPort) {
@@ -130,7 +130,7 @@ public class GeodeDevRestClient {
     return new HttpResponseAssert("Delete " + uri, doDelete(uri, null, null));
   }
 
-  /**
+  /*
    * this handles rest calls. each request creates a different httpClient object
    */
   public HttpResponse doRequest(HttpRequestBase request, String username, String password) {
