@@ -14,26 +14,27 @@
  */
 package org.apache.geode.launchers;
 
+import static java.nio.charset.Charset.defaultCharset;
+import static java.util.stream.Collectors.toList;
+import static org.apache.commons.io.FileUtils.readLines;
 import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.assertj.core.api.Assertions.assertThat;
 
-import java.io.IOException;
-import java.nio.file.Files;
 import java.nio.file.Path;
 import java.util.List;
 import java.util.function.Predicate;
 import java.util.regex.Pattern;
-import java.util.stream.Collectors;
 
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
 import org.junit.rules.TestName;
 
+import org.apache.geode.test.junit.rules.FolderRule;
+import org.apache.geode.test.junit.rules.gfsh.GfshExecution;
 import org.apache.geode.test.junit.rules.gfsh.GfshRule;
 
 public class ServerStartupRedundancyRecoveryNotificationTest {
@@ -42,13 +43,14 @@ public class ServerStartupRedundancyRecoveryNotificationTest {
   private static final String SERVER_2_NAME = "server2";
   private static final String LOCATOR_NAME = "locator";
 
-  @Rule
-  public GfshRule gfshRule = new GfshRule();
-  @Rule
-  public TemporaryFolder temporaryFolder = new TemporaryFolder();
+  @Rule(order = 0)
+  public FolderRule folderRule = new FolderRule();
+  @Rule(order = 1)
+  public GfshRule gfshRule = new GfshRule(folderRule::getFolder);
   @Rule
   public TestName testName = new TestName();
 
+  private Path rootFolder;
   private Path locatorFolder;
   private Path server1Folder;
   private Path server2Folder;
@@ -58,11 +60,11 @@ public class ServerStartupRedundancyRecoveryNotificationTest {
   private String regionNameTwo;
 
   @Before
-  public void redundantRegionThatRequiresRedundancyRecovery() throws IOException {
-    locatorFolder = temporaryFolder.newFolder(LOCATOR_NAME).toPath().toAbsolutePath();
-    server1Folder = temporaryFolder.newFolder(SERVER_1_NAME + "_before").toPath()
-        .toAbsolutePath();
-    server2Folder = temporaryFolder.newFolder(SERVER_2_NAME).toPath().toAbsolutePath();
+  public void redundantRegionThatRequiresRedundancyRecovery() {
+    rootFolder = folderRule.getFolder().toPath().toAbsolutePath();
+    locatorFolder = rootFolder.resolve(LOCATOR_NAME);
+    server1Folder = rootFolder.resolve(SERVER_1_NAME + "_before");
+    server2Folder = rootFolder.resolve(SERVER_2_NAME);
 
     locatorPort = getRandomAvailableTCPPort();
 
@@ -117,7 +119,8 @@ public class ServerStartupRedundancyRecoveryNotificationTest {
         createRegionCommand, createRegionTwoCommand, putCommand, putCommandInRegionTwo);
 
     String stopServer1Command = "stop server --dir=" + server1Folder;
-    gfshRule.execute(stopServer1Command);
+    GfshExecution execution = gfshRule.execute(stopServer1Command);
+    execution.serverStopper().awaitStop(server1Folder);
   }
 
   @After
@@ -125,14 +128,17 @@ public class ServerStartupRedundancyRecoveryNotificationTest {
     String stopServer1Command = "stop server --dir=" + server1Folder;
     String stopServer2Command = "stop server --dir=" + server2Folder;
     String stopLocatorCommand = "stop locator --dir=" + locatorFolder;
-    gfshRule.execute(stopServer1Command, stopServer2Command, stopLocatorCommand);
+    GfshExecution execution =
+        gfshRule.execute(stopServer1Command, stopServer2Command, stopLocatorCommand);
+    execution.serverStopper().awaitStop(server1Folder);
+    execution.serverStopper().awaitStop(server2Folder);
+    execution.locatorStopper().awaitStop(locatorFolder);
   }
 
   @Test
-  public void startupReportsOnlineOnlyAfterRedundancyRestored() throws IOException {
+  public void startupReportsOnlineOnlyAfterRedundancyRestored() {
     String connectCommand = "connect --locator=localhost[" + locatorPort + "]";
-    server1Folder =
-        temporaryFolder.newFolder(SERVER_1_NAME + "_test").toPath().toAbsolutePath();
+    server1Folder = rootFolder.resolve(SERVER_1_NAME + "_test");
     startServer1Command = String.join(" ",
         "start server",
         "--name=" + SERVER_1_NAME,
@@ -163,9 +169,9 @@ public class ServerStartupRedundancyRecoveryNotificationTest {
               .or(redundancyRestoredSecondRegionPattern.asPredicate())
               .or(serverOnlinePattern.asPredicate());
 
-          final List<String> foundPatterns =
-              Files.lines(logFile).filter(isRelevantLine)
-                  .collect(Collectors.toList());
+          final List<String> foundPatterns = readLines(logFile.toFile(), defaultCharset()).stream()
+              .filter(isRelevantLine)
+              .collect(toList());
 
           assertThat(foundPatterns)
               .as("Log file " + logFile + " includes one line matching each of "
