@@ -16,36 +16,47 @@
 package org.apache.geode.management.internal.cli.commands;
 
 import static org.apache.geode.cache.Region.SEPARATOR;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.File;
 import java.io.IOException;
 
+import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
 
 import org.apache.geode.test.compiler.JarBuilder;
+import org.apache.geode.test.junit.rules.FolderRule;
 import org.apache.geode.test.junit.rules.gfsh.GfshExecution;
 import org.apache.geode.test.junit.rules.gfsh.GfshRule;
 import org.apache.geode.test.junit.rules.gfsh.GfshScript;
 
-// GEODE-1897 Users should be able to configure eviction through gfsh
 public class ConfigureEvictionThroughGfsh {
 
-  @Rule
-  public GfshRule gfsh = new GfshRule();
+  private int locatorPort;
+
+  @Rule(order = 0)
+  public FolderRule folderRule = new FolderRule();
+  @Rule(order = 1)
+  public GfshRule gfshRule = new GfshRule(folderRule::getFolder);
+
+  @Before
+  public void setUp() {
+    locatorPort = getRandomAvailableTCPPort();
+  }
 
   @Test
-  public void configureEvictionByEntryCount() throws Exception {
-
+  public void configureEvictionByEntryCount() {
     GfshExecution execution = GfshScript
-        .of("start locator --name=locator", "start server --name=server --server-port=0",
+        .of("start locator --name=locator --port=" + locatorPort,
+            "start server --name=server --disable-default-server",
             "create region --name=region1 --eviction-action=local-destroy --eviction-entry-count=1000 --type=REPLICATE",
             "create region --name=region2 --eviction-action=overflow-to-disk --eviction-entry-count=1000 --type=REPLICATE",
             "create region --name=region3 --eviction-action=overflow-to-disk --eviction-entry-count=1000 --type=REPLICATE_PERSISTENT",
             "create region --name=region4 --eviction-action=local-destroy --eviction-entry-count=1000 --type=LOCAL",
             "create region --name=region5 --eviction-action=overflow-to-disk --eviction-entry-count=1000 --type=LOCAL")
-        .execute(gfsh);
+        .execute(gfshRule);
 
     assertThat(execution.getOutputText())
         .contains("Region \"" + SEPARATOR + "region1\" created on \"server\"");
@@ -59,54 +70,70 @@ public class ConfigureEvictionThroughGfsh {
         .contains("Region \"" + SEPARATOR + "region5\" created on \"server\"");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]",
+        .of("connect --locator=localhost[" + locatorPort + "]",
             "create region --name=region6 --eviction-action=local-destroy --eviction-entry-count=1000 --type=REPLICATE_PERSISTENT")
-        .expectFailure().execute(gfsh);
-    assertThat(execution.getOutputText()).contains(
-        "An Eviction Controller with local destroy eviction action is incompatible with");
+        .expectFailure()
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .contains("An Eviction Controller with local destroy eviction action is incompatible with");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region1").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region1")
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region1")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region1")
         .containsPattern("eviction-action\\s+| local-destroy")
         .containsPattern("eviction-maximum-value\\s+ | 1000");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region2").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region2")
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region2")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region2")
         .containsPattern("eviction-action\\s+| overflow-to-disk")
         .containsPattern("eviction-maximum-value\\s+ | 1000");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region3").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region3")
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region3")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region3")
         .containsPattern("eviction-action\\s+| overflow-to-disk")
         .containsPattern("eviction-maximum-value\\s+ | 1000");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region4").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region4")
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region4")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region4")
         .containsPattern("eviction-action\\s+| local-destroy")
         .containsPattern("eviction-maximum-value\\s+ | 1000");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region5").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region5")
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region5")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region5")
         .containsPattern("eviction-action\\s+| overflow-to-disk")
         .containsPattern("eviction-maximum-value\\s+ | 1000");
-
   }
 
   @Test
-  public void configureEvictionByMaxMemory() throws Exception {
+  public void configureEvictionByMaxMemory() {
     GfshExecution execution = GfshScript
-        .of("start locator --name=locator", "start server --name=server --server-port=0",
+        .of("start locator --name=locator --port=" + locatorPort,
+            "start server --name=server --disable-default-server",
             "create region --name=region1 --eviction-action=local-destroy --eviction-max-memory=1000 --type=REPLICATE",
             "create region --name=region2 --eviction-action=overflow-to-disk --eviction-max-memory=1000 --type=REPLICATE",
             "create region --name=region3 --eviction-action=overflow-to-disk --eviction-max-memory=1000 --type=REPLICATE_PERSISTENT",
             "create region --name=region4 --eviction-action=local-destroy --eviction-max-memory=1000 --type=LOCAL",
             "create region --name=region5 --eviction-action=overflow-to-disk --eviction-max-memory=1000 --type=LOCAL")
-        .execute(gfsh);
+        .execute(gfshRule);
     assertThat(execution.getOutputText())
         .contains("Region \"" + SEPARATOR + "region1\" created on \"server\"");
     assertThat(execution.getOutputText())
@@ -119,45 +146,141 @@ public class ConfigureEvictionThroughGfsh {
         .contains("Region \"" + SEPARATOR + "region5\" created on \"server\"");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]",
+        .of("connect --locator=localhost[" + locatorPort + "]",
             "create region --name=region6 --eviction-action=local-destroy --eviction-max-memory=1000 --type=REPLICATE_PERSISTENT")
-        .expectFailure().execute(gfsh);
-    assertThat(execution.getOutputText()).contains(
-        "An Eviction Controller with local destroy eviction action is incompatible with");
+        .expectFailure()
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .contains("An Eviction Controller with local destroy eviction action is incompatible with");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region1").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region1")
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region1")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region1")
         .containsPattern("eviction-action\\s+| local-destroy")
         .containsPattern("eviction-max-memory\\s+ | 1000");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region2").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region2")
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region2")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region2")
         .containsPattern("eviction-action\\s+| overflow-to-disk")
         .containsPattern("eviction-max-memory\\s+ | 1000");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region3").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region3")
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region3")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region3")
         .containsPattern("eviction-action\\s+| overflow-to-disk")
         .containsPattern("eviction-max-memory\\s+ | 1000");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region4").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region4")
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region4")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region4")
         .containsPattern("eviction-action\\s+| local-destroy")
         .containsPattern("eviction-max-memory\\s+ | 1000");
 
     execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region5").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region5")
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region5")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region5")
+        .containsPattern("eviction-action\\s+| overflow-to-disk")
+        .containsPattern("eviction-max-memory\\s+ | 1000");
+  }
+
+  @Test
+  public void configureEvictionByObjectSizer()
+      throws IOException {
+    GfshExecution execution = GfshScript
+        .of("start locator --name=locator --port=" + locatorPort,
+            "start server --name=server --disable-default-server",
+            "sleep --time=1",
+            "deploy --jar=" + createJar().getAbsolutePath(),
+            "create region --name=region1 --eviction-action=local-destroy --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=REPLICATE",
+            "create region --name=region2 --eviction-action=overflow-to-disk --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=REPLICATE",
+            "create region --name=region3 --eviction-action=overflow-to-disk --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=REPLICATE_PERSISTENT",
+            "create region --name=region4 --eviction-action=local-destroy --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=LOCAL",
+            "create region --name=region5 --eviction-action=overflow-to-disk --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=LOCAL")
+        .execute(gfshRule);
+
+    assertThat(execution.getOutputText())
+        .contains("Region \"" + SEPARATOR + "region1\" created on \"server\"");
+    assertThat(execution.getOutputText())
+        .contains("Region \"" + SEPARATOR + "region2\" created on \"server\"");
+    assertThat(execution.getOutputText())
+        .contains("Region \"" + SEPARATOR + "region3\" created on \"server\"");
+    assertThat(execution.getOutputText())
+        .contains("Region \"" + SEPARATOR + "region4\" created on \"server\"");
+    assertThat(execution.getOutputText())
+        .contains("Region \"" + SEPARATOR + "region5\" created on \"server\"");
+
+    execution = GfshScript
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "create region --name=region6 --eviction-action=local-destroy --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=REPLICATE_PERSISTENT")
+        .expectFailure()
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .contains("An Eviction Controller with local destroy eviction action is incompatible with");
+
+    execution = GfshScript
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region1")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region1")
+        .containsPattern("eviction-action\\s+| local-destroy")
+        .containsPattern("eviction-max-memory\\s+ | 1000");
+
+    execution = GfshScript
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region2")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region2")
+        .containsPattern("eviction-action\\s+| overflow-to-disk")
+        .containsPattern("eviction-max-memory\\s+ | 1000");
+
+    execution = GfshScript
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region3")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region3")
+        .containsPattern("eviction-action\\s+| overflow-to-disk")
+        .containsPattern("eviction-max-memory\\s+ | 1000");
+
+    execution = GfshScript
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region4")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region4")
+        .containsPattern("eviction-action\\s+| local-destroy")
+        .containsPattern("eviction-max-memory\\s+ | 1000");
+
+    execution = GfshScript
+        .of("connect --locator=localhost[" + locatorPort + "]",
+            "describe region --name=region5")
+        .execute(gfshRule);
+    assertThat(execution.getOutputText())
+        .containsPattern("region5")
         .containsPattern("eviction-action\\s+| overflow-to-disk")
         .containsPattern("eviction-max-memory\\s+ | 1000");
   }
 
   private File createJar() throws IOException {
-    File jarToDeploy = new File(gfsh.getTemporaryFolder().getRoot(), "ourJar.jar");
+    File jarToDeploy = folderRule.getFolder().toPath().resolve("ourJar.jar").toFile();
 
     String classContents =
         "import org.apache.geode.cache.util.ObjectSizer; import org.apache.geode.cache.Declarable;public class MySizer implements ObjectSizer, Declarable { public int sizeof(Object o) { return 10; } }";
@@ -167,67 +290,4 @@ public class ConfigureEvictionThroughGfsh {
 
     return jarToDeploy;
   }
-
-  @Test
-  public void configureEvictionByObjectSizer() throws Exception {
-    GfshExecution execution = GfshScript
-        .of("start locator --name=locator", "start server --name=server --server-port=0",
-            "sleep --time=1",
-            "deploy --jar=" + createJar().getAbsolutePath(),
-            "create region --name=region1 --eviction-action=local-destroy --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=REPLICATE",
-            "create region --name=region2 --eviction-action=overflow-to-disk --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=REPLICATE",
-            "create region --name=region3 --eviction-action=overflow-to-disk --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=REPLICATE_PERSISTENT",
-            "create region --name=region4 --eviction-action=local-destroy --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=LOCAL",
-            "create region --name=region5 --eviction-action=overflow-to-disk --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=LOCAL")
-        .execute(gfsh);
-
-    assertThat(execution.getOutputText())
-        .contains("Region \"" + SEPARATOR + "region1\" created on \"server\"");
-    assertThat(execution.getOutputText())
-        .contains("Region \"" + SEPARATOR + "region2\" created on \"server\"");
-    assertThat(execution.getOutputText())
-        .contains("Region \"" + SEPARATOR + "region3\" created on \"server\"");
-    assertThat(execution.getOutputText())
-        .contains("Region \"" + SEPARATOR + "region4\" created on \"server\"");
-    assertThat(execution.getOutputText())
-        .contains("Region \"" + SEPARATOR + "region5\" created on \"server\"");
-
-    execution = GfshScript
-        .of("connect --locator=localhost[10334]",
-            "create region --name=region6 --eviction-action=local-destroy --eviction-max-memory=1000 --eviction-object-sizer=MySizer --type=REPLICATE_PERSISTENT")
-        .expectFailure().execute(gfsh);
-    assertThat(execution.getOutputText()).contains(
-        "An Eviction Controller with local destroy eviction action is incompatible with");
-
-    execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region1").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region1")
-        .containsPattern("eviction-action\\s+| local-destroy")
-        .containsPattern("eviction-max-memory\\s+ | 1000");
-
-    execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region2").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region2")
-        .containsPattern("eviction-action\\s+| overflow-to-disk")
-        .containsPattern("eviction-max-memory\\s+ | 1000");
-
-    execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region3").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region3")
-        .containsPattern("eviction-action\\s+| overflow-to-disk")
-        .containsPattern("eviction-max-memory\\s+ | 1000");
-
-    execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region4").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region4")
-        .containsPattern("eviction-action\\s+| local-destroy")
-        .containsPattern("eviction-max-memory\\s+ | 1000");
-
-    execution = GfshScript
-        .of("connect --locator=localhost[10334]", "describe region --name=region5").execute(gfsh);
-    assertThat(execution.getOutputText()).containsPattern("region5")
-        .containsPattern("eviction-action\\s+| overflow-to-disk")
-        .containsPattern("eviction-max-memory\\s+ | 1000");
-
-  }
 }
