@@ -17,25 +17,28 @@ package org.apache.geode.management.internal.cli.commands;
 import static org.apache.geode.distributed.ConfigurationProperties.LOG_LEVEL;
 import static org.apache.geode.distributed.ConfigurationProperties.SECURITY_MANAGER;
 import static org.apache.geode.examples.security.ExampleSecurityManager.SECURITY_JSON;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.apache.geode.test.util.ResourceUtils.createFileFromResource;
 import static org.apache.geode.test.util.ResourceUtils.getResource;
 import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.File;
 import java.io.FileOutputStream;
+import java.io.IOException;
+import java.nio.file.Path;
 import java.util.Properties;
 
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
-import org.junit.rules.TemporaryFolder;
 
 import org.apache.geode.examples.security.ExampleSecurityManager;
 import org.apache.geode.management.internal.cli.util.CommandStringBuilder;
 import org.apache.geode.test.assertj.LogFileAssert;
 import org.apache.geode.test.junit.categories.LoggingTest;
 import org.apache.geode.test.junit.categories.SecurityTest;
+import org.apache.geode.test.junit.rules.FolderRule;
 import org.apache.geode.test.junit.rules.RequiresGeodeHome;
 import org.apache.geode.test.junit.rules.gfsh.GfshExecution;
 import org.apache.geode.test.junit.rules.gfsh.GfshRule;
@@ -54,25 +57,29 @@ public class LogsAndDescribeConfigAreFullyRedactedAcceptanceTest {
 
   private static final String PASSWORD = "abcdefg";
 
-  @Rule
+  private int locatorPort;
+
+  @Rule(order = 0)
   public RequiresGeodeHome geodeHome = new RequiresGeodeHome();
-  @Rule
-  public GfshRule gfsh = new GfshRule();
-  @Rule
-  public TemporaryFolder temporaryFolder = new TemporaryFolder();
+  @Rule(order = 1)
+  public FolderRule folderRule = new FolderRule();
+  @Rule(order = 2)
+  public GfshRule gfshRule = new GfshRule(folderRule::getFolder);
 
   @Before
-  public void createDirectoriesAndFiles() throws Exception {
-    File geodePropertiesFile = temporaryFolder.newFile("geode.properties");
-    File securityPropertiesFile = temporaryFolder.newFile("security.properties");
+  public void createDirectoriesAndFiles() throws IOException {
+    Path rootFolder = folderRule.getFolder().toPath().toAbsolutePath();
+
+    Path geodePropertiesFile = rootFolder.resolve("geode.properties");
+    Path securityPropertiesFile = rootFolder.resolve("security.properties");
 
     Properties geodeProperties = new Properties();
     geodeProperties.setProperty(LOG_LEVEL, "debug");
     geodeProperties.setProperty("security-username", "propertyFileUser");
     geodeProperties.setProperty("security-password", PASSWORD + "-propertyFile");
 
-    try (FileOutputStream fileOutputStream = new FileOutputStream(geodePropertiesFile)) {
-      geodeProperties.store(fileOutputStream, null);
+    try (FileOutputStream fos = new FileOutputStream(geodePropertiesFile.toFile())) {
+      geodeProperties.store(fos, null);
     }
 
     Properties securityProperties = new Properties();
@@ -81,41 +88,46 @@ public class LogsAndDescribeConfigAreFullyRedactedAcceptanceTest {
     securityProperties.setProperty("security-file-username", "securityPropertyFileUser");
     securityProperties.setProperty("security-file-password", PASSWORD + "-securityPropertyFile");
 
-    try (FileOutputStream fileOutputStream = new FileOutputStream(securityPropertiesFile)) {
-      securityProperties.store(fileOutputStream, null);
+    try (FileOutputStream fos = new FileOutputStream(securityPropertiesFile.toFile())) {
+      securityProperties.store(fos, null);
     }
 
     // The json is in the root resource directory.
-    createFileFromResource(getResource("/security.json"), temporaryFolder.getRoot(),
+    createFileFromResource(getResource("/security.json"), rootFolder.toFile(),
         "security.json");
 
+    locatorPort = getRandomAvailableTCPPort();
+
     String startLocatorCmd = new CommandStringBuilder("start locator")
         .addOption("name", "test-locator")
-        .addOption("properties-file", geodePropertiesFile.getAbsolutePath())
-        .addOption("security-properties-file", securityPropertiesFile.getAbsolutePath())
+        .addOption("port", String.valueOf(locatorPort))
+        .addOption("properties-file", geodePropertiesFile.toString())
+        .addOption("security-properties-file", securityPropertiesFile.toString())
         .addOption("J", "-Dsecure-username-jd=user-jd")
         .addOption("J", "-Dsecure-password-jd=password-jd")
-        .addOption("classpath", temporaryFolder.getRoot().getAbsolutePath())
+        .addOption("classpath", rootFolder.toString())
         .getCommandString();
 
     String startServerCmd = new CommandStringBuilder("start server")
         .addOption("name", "test-server")
+        .addOption("locators", "localhost[" + locatorPort + "]")
+        .addOption("disable-default-server", "true")
         .addOption("user", "viaStartMemberOptions")
         .addOption("password", PASSWORD + "-viaStartMemberOptions")
-        .addOption("properties-file", geodePropertiesFile.getAbsolutePath())
-        .addOption("security-properties-file", securityPropertiesFile.getAbsolutePath())
+        .addOption("properties-file", geodePropertiesFile.toString())
+        .addOption("security-properties-file", securityPropertiesFile.toString())
         .addOption("J", "-Dsecure-username-jd=user-jd")
         .addOption("J", "-Dsecure-password-jd=" + PASSWORD + "-password-jd")
-        .addOption("server-port", "0")
-        .addOption("classpath", temporaryFolder.getRoot().getAbsolutePath())
+        .addOption("classpath", rootFolder.toString())
         .getCommandString();
 
-    gfsh.execute(startLocatorCmd, startServerCmd);
+    gfshRule.execute(startLocatorCmd, startServerCmd);
   }
 
   @Test
   public void logsDoNotContainStringThatShouldBeRedacted() {
-    File dir = gfsh.getTemporaryFolder().getRoot();
+    Path rootFolder = folderRule.getFolder().toPath();
+    File dir = rootFolder.toFile();
     File[] logFiles = dir.listFiles((d, name) -> name.endsWith(".log"));
 
     for (File logFile : logFiles) {
@@ -126,17 +138,24 @@ public class LogsAndDescribeConfigAreFullyRedactedAcceptanceTest {
   @Test
   public void describeConfigRedactsJvmArguments() {
     String connectCommand = new CommandStringBuilder("connect")
+        .addOption("locator", "localhost[" + locatorPort + "]")
         .addOption("user", "viaStartMemberOptions")
-        .addOption("password", PASSWORD + "-viaStartMemberOptions").getCommandString();
+        .addOption("password", PASSWORD + "-viaStartMemberOptions")
+        .getCommandString();
 
     String describeLocatorConfigCommand = new CommandStringBuilder("describe config")
-        .addOption("hide-defaults", "false").addOption("member", "test-locator").getCommandString();
+        .addOption("hide-defaults", "false")
+        .addOption("member", "test-locator")
+        .getCommandString();
 
     String describeServerConfigCommand = new CommandStringBuilder("describe config")
-        .addOption("hide-defaults", "false").addOption("member", "test-server").getCommandString();
+        .addOption("hide-defaults", "false")
+        .addOption("member", "test-server")
+        .getCommandString();
 
     GfshExecution execution =
-        gfsh.execute(connectCommand, describeLocatorConfigCommand, describeServerConfigCommand);
+        gfshRule.execute(connectCommand, describeLocatorConfigCommand,
+            describeServerConfigCommand);
     assertThat(execution.getOutputText()).doesNotContain(PASSWORD);
   }
 }
