@@ -21,6 +21,7 @@ import static org.apache.geode.cache.execute.FunctionService.onServer;
 import static org.apache.geode.distributed.ConfigurationProperties.SECURITY_MANAGER;
 import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPorts;
 import static org.apache.geode.test.compiler.ClassBuilder.writeJarFromClasses;
+import static org.apache.geode.util.internal.UncheckedUtils.uncheckedCast;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.catchThrowable;
 
@@ -35,9 +36,9 @@ import java.util.Properties;
 
 import io.micrometer.core.instrument.Timer;
 import org.junit.After;
+import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
 
 import org.apache.geode.cache.Region;
 import org.apache.geode.cache.client.ClientCache;
@@ -51,23 +52,29 @@ import org.apache.geode.security.AuthInitialize;
 import org.apache.geode.security.AuthenticationFailedException;
 import org.apache.geode.security.NotAuthorizedException;
 import org.apache.geode.security.ResourcePermission;
+import org.apache.geode.test.junit.rules.FolderRule;
 import org.apache.geode.test.junit.rules.gfsh.GfshRule;
 
 public class CacheGetsTimerTest {
+
   private int locatorPort;
   private ClientCache clientCache;
   private Region<Object, Object> replicateRegion;
   private Region<Object, Object> partitionRegion;
+  private Path rootFolder;
 
-  @Rule
-  public GfshRule gfshRule = new GfshRule();
-
-  @Rule
-  public TemporaryFolder temporaryFolder = new TemporaryFolder();
-
+  @Rule(order = 0)
+  public FolderRule folderRule = new FolderRule();
+  @Rule(order = 1)
+  public GfshRule gfshRule = new GfshRule(folderRule::getFolder);
   @Rule
   public ServiceJarRule serviceJarRule = new ServiceJarRule();
 
+  @Before
+  public void setUp() {
+    rootFolder = folderRule.getFolder().toPath();
+  }
+
   @After
   public void tearDown() {
     if (clientCache != null) {
@@ -324,15 +331,14 @@ public class CacheGetsTimerTest {
     Path serviceJarPath = serviceJarRule.createJarFor("metrics-publishing-service.jar",
         MetricsPublishingService.class, SimpleMetricsPublishingService.class);
 
-    Path helpersJarPath = temporaryFolder.getRoot().toPath()
-        .resolve("helpers.jar").toAbsolutePath();
+    Path helpersJarPath = rootFolder.resolve("helpers.jar");
     writeJarFromClasses(helpersJarPath.toFile(), TimerValue.class,
         FetchCacheGetsTimerValues.class, DenyAllDataRead.class, ClientSecurityConfig.class);
 
     String startLocatorCommand = String.join(" ",
         "start locator",
         "--name=" + "locator",
-        "--dir=" + temporaryFolder.newFolder("locator").getAbsolutePath(),
+        "--dir=" + rootFolder.resolve("locator"),
         "--port=" + locatorPort,
         "--http-service-port=0",
         "--J=-Dgemfire.jmx-manager-port=" + locatorJmxPort,
@@ -342,7 +348,7 @@ public class CacheGetsTimerTest {
     String startServerCommand = String.join(" ",
         "start server",
         "--name=" + serverName,
-        "--dir=" + temporaryFolder.newFolder(serverName).getAbsolutePath(),
+        "--dir=" + rootFolder.resolve(serverName),
         "--server-port=" + serverPort,
         "--locators=localhost[" + locatorPort + "]",
         "--classpath=" + serviceJarPath + pathSeparatorChar + helpersJarPath);
@@ -394,7 +400,7 @@ public class CacheGetsTimerTest {
 
   private File createSecurityPropertiesFile() throws IOException {
     Properties securityProperties = ClientSecurityConfig.securityProperties();
-    File securityPropertiesFile = gfshRule.getTemporaryFolder().newFile("security.properties");
+    File securityPropertiesFile = rootFolder.resolve("security.properties").toFile();
     securityProperties.store(new FileOutputStream(securityPropertiesFile), null);
     return securityPropertiesFile;
   }
@@ -420,11 +426,9 @@ public class CacheGetsTimerTest {
   }
 
   private List<TimerValue> allTimerValuesForRegion(Region<?, ?> region) {
-    @SuppressWarnings("unchecked")
-    List<List<TimerValue>> timerValuesFromAllServers =
-        (List<List<TimerValue>>) onServer(clientCache)
-            .execute(new FetchCacheGetsTimerValues())
-            .getResult();
+    List<List<TimerValue>> timerValuesFromAllServers = uncheckedCast(onServer(clientCache)
+        .execute(new FetchCacheGetsTimerValues())
+        .getResult());
 
     assertThat(timerValuesFromAllServers)
         .hasSize(1);
@@ -435,10 +439,10 @@ public class CacheGetsTimerTest {
   }
 
   static class TimerValue implements Serializable {
-    final long count;
-    final double totalTime;
-    final String region;
-    final String result;
+    private final long count;
+    private final double totalTime;
+    private final String region;
+    private final String result;
 
     TimerValue(long count, double totalTime, String region, String result) {
       this.count = count;
@@ -519,7 +523,7 @@ public class CacheGetsTimerTest {
       return securityProperties();
     }
 
-    static Properties securityProperties() {
+    private static Properties securityProperties() {
       Properties securityProperties = new Properties();
       securityProperties.setProperty(SECURITY_MANAGER, DenyAllDataRead.class.getName());
       securityProperties.setProperty("security-username", "user");
