@@ -32,7 +32,7 @@ import org.apache.geode.management.api.ClusterManagementResult;
 import org.apache.geode.management.api.ClusterManagementService;
 import org.apache.geode.management.api.RealizationResult;
 import org.apache.geode.management.builder.GeodeClusterManagementServiceBuilder;
-import org.apache.geode.management.client.ClusterManagementServiceBuilder;
+import org.apache.geode.management.cluster.client.ClusterManagementServiceBuilder;
 import org.apache.geode.management.configuration.Region;
 import org.apache.geode.management.configuration.RegionType;
 import org.apache.geode.test.dunit.rules.ClientVM;
@@ -49,7 +49,7 @@ public class ClientClusterManagementServiceDunitTest {
   private static MemberVM server;
   private static ClientVM client;
 
-  private static String groupA = "group-a";
+  private static final String groupA = "group-a";
   private static ClusterManagementService cmsClient;
 
   @BeforeClass
