@@ -33,7 +33,7 @@ import org.apache.geode.examples.SimpleSecurityManager;
 import org.apache.geode.management.api.ClusterManagementGetResult;
 import org.apache.geode.management.api.ClusterManagementListResult;
 import org.apache.geode.management.api.ClusterManagementService;
-import org.apache.geode.management.client.ClusterManagementServiceBuilder;
+import org.apache.geode.management.cluster.client.ClusterManagementServiceBuilder;
 import org.apache.geode.management.configuration.Deployment;
 import org.apache.geode.management.runtime.DeploymentInfo;
 import org.apache.geode.test.compiler.JarBuilder;
@@ -101,8 +101,9 @@ public class DeploymentManagementDUnitTest {
         assertManagementListResult(list).isSuccessful();
     resultAssert.hasConfigurations().extracting(Deployment::getFileName)
         .containsExactlyInAnyOrder("group1.jar", "group2.jar", "cluster.jar");
-    resultAssert.hasRuntimeInfos().extracting(DeploymentInfo::getJarLocation).extracting(
-        FilenameUtils::getName)
+    resultAssert.hasRuntimeInfos()
+        .extracting(DeploymentInfo::getJarLocation).extracting(
+            FilenameUtils::getName)
         .containsExactlyInAnyOrder("group1.v1.jar", "group2.v1.jar", "cluster.v1.jar",
             "cluster.v1.jar");
   }
@@ -116,8 +117,10 @@ public class DeploymentManagementDUnitTest {
         assertManagementListResult(list).isSuccessful();
     resultAssert.hasConfigurations().extracting(Deployment::getFileName)
         .containsExactlyInAnyOrder("group1.jar");
-    resultAssert.hasRuntimeInfos().extracting(DeploymentInfo::getJarLocation).extracting(
-        FilenameUtils::getName).containsExactlyInAnyOrder("group1.v1.jar");
+    resultAssert.hasRuntimeInfos()
+        .extracting(DeploymentInfo::getJarLocation).extracting(
+            FilenameUtils::getName)
+        .containsExactlyInAnyOrder("group1.v1.jar");
   }
 
   @Test
@@ -151,8 +154,11 @@ public class DeploymentManagementDUnitTest {
     ClusterManagementGetResult<Deployment, DeploymentInfo> result = client.get(filter);
     ClusterManagementGetResultAssert<Deployment, DeploymentInfo> resultAssert =
         assertManagementGetResult(result).isSuccessful();
-    resultAssert.hasConfiguration().extracting(Deployment::getFileName).isEqualTo("cluster.jar");
-    resultAssert.hasRuntimeInfos().extracting(DeploymentInfo::getJarLocation).extracting(
-        FilenameUtils::getName).containsExactlyInAnyOrder("cluster.v1.jar", "cluster.v1.jar");
+    resultAssert.hasConfiguration().extracting(Deployment::getFileName)
+        .isEqualTo("cluster.jar");
+    resultAssert.hasRuntimeInfos()
+        .extracting(DeploymentInfo::getJarLocation).extracting(
+            FilenameUtils::getName)
+        .containsExactlyInAnyOrder("cluster.v1.jar", "cluster.v1.jar");
   }
 }
