@@ -51,7 +51,7 @@ import org.apache.geode.test.junit.categories.SessionTest;
 @Category({SessionTest.class})
 public abstract class CargoTestBase {
   private final UniquePortSupplier portSupplier = new UniquePortSupplier();
-  private static Logger logger = LogService.getLogger();
+  private static final Logger logger = LogService.getLogger();
 
   @Rule
   public TestName testName = new TestName();
@@ -106,15 +106,14 @@ public abstract class CargoTestBase {
   public void stop() throws IOException {
     try {
       manager.stopAllActiveContainers();
+    } catch (Exception exception) {
+      manager.dumpLogs();
+      throw exception;
     } finally {
       try {
-        manager.dumpLogs();
+        manager.cleanUp();
       } finally {
-        try {
-          manager.cleanUp();
-        } finally {
-          announceTest("END");
-        }
+        announceTest("END");
       }
     }
   }
@@ -170,6 +169,10 @@ public abstract class CargoTestBase {
   @Test
   public void containersShouldReplicateCookies() throws IOException, URISyntaxException {
     manager.startAllInactiveContainers();
+    await().until(() -> {
+      ServerContainer container = manager.getContainer(0);
+      return container.getState().isStarted();
+    });
 
     client.setPort(Integer.parseInt(manager.getContainerPort(0)));
     Client.Response resp = client.get(null);
@@ -183,6 +186,10 @@ public abstract class CargoTestBase {
   @Test
   public void containersShouldHavePersistentSessionData() throws IOException, URISyntaxException {
     manager.startAllInactiveContainers();
+    await().until(() -> {
+      ServerContainer container = manager.getContainer(0);
+      return container.getState().isStarted();
+    });
 
     String key = "value_testSessionPersists";
     String value = "Foo";
@@ -200,6 +207,10 @@ public abstract class CargoTestBase {
   public void failureShouldStillAllowOtherContainersDataAccess()
       throws IOException, URISyntaxException {
     manager.startAllInactiveContainers();
+    await().until(() -> {
+      ServerContainer container = manager.getContainer(0);
+      return container.getState().isStarted();
+    });
 
     String key = "value_testSessionPersists";
     String value = "Foo";
@@ -220,6 +231,10 @@ public abstract class CargoTestBase {
   @Test
   public void invalidationShouldRemoveValueAccessForAllContainers() throws Exception {
     manager.startAllInactiveContainers();
+    await().until(() -> {
+      ServerContainer container = manager.getContainer(0);
+      return container.getState().isStarted();
+    });
 
     String key = "value_testInvalidate";
     String value = "Foo";
@@ -246,6 +261,10 @@ public abstract class CargoTestBase {
   public void containersShouldExpireInSetTimeframe()
       throws IOException, URISyntaxException, InterruptedException {
     manager.startAllInactiveContainers();
+    await().until(() -> {
+      ServerContainer container = manager.getContainer(0);
+      return container.getState().isStarted();
+    });
 
     String key = "value_testSessionExpiration";
     String value = "Foo";
@@ -272,6 +291,10 @@ public abstract class CargoTestBase {
   public void sessionPicksUpSessionTimeoutConfiguredInWebXml()
       throws IOException, URISyntaxException {
     manager.startAllInactiveContainers();
+    await().until(() -> {
+      ServerContainer container = manager.getContainer(0);
+      return container.getState().isStarted();
+    });
 
     String key = "value_testSessionExpiration";
     String value = "Foo";
@@ -310,6 +333,10 @@ public abstract class CargoTestBase {
   public void containersShouldShareSessionExpirationReset()
       throws URISyntaxException, IOException {
     manager.startAllInactiveContainers();
+    await().until(() -> {
+      ServerContainer container = manager.getContainer(0);
+      return container.getState().isStarted();
+    });
 
     int timeToExp = 30;
     String key = "value_testSessionExpiration";
@@ -348,6 +375,11 @@ public abstract class CargoTestBase {
   @Test
   public void containersShouldShareDataRemovals() throws IOException, URISyntaxException {
     manager.startAllInactiveContainers();
+    await().until(() -> {
+      ServerContainer container = manager.getContainer(0);
+      return container.getState().isStarted();
+    });
+
     String key = "value_testSessionRemove";
     String value = "Foo";
     client.setPort(Integer.parseInt(manager.getContainerPort(0)));
@@ -368,6 +400,10 @@ public abstract class CargoTestBase {
   @Test
   public void newContainersShouldShareDataAccess() throws Exception {
     manager.startAllInactiveContainers();
+    await().until(() -> {
+      ServerContainer container = manager.getContainer(0);
+      return container.getState().isStarted();
+    });
 
     String key = "value_testSessionAdd";
     String value = "Foo";
@@ -390,6 +426,11 @@ public abstract class CargoTestBase {
   @Test
   public void attributesCanBeReplaced() throws IOException, URISyntaxException {
     manager.startAllInactiveContainers();
+    await().until(() -> {
+      ServerContainer container = manager.getContainer(0);
+      return container.getState().isStarted();
+    });
+
     String key = "value_testSessionUpdate";
     String value = "Foo";
     String updateValue = "Bar";
@@ -407,7 +448,7 @@ public abstract class CargoTestBase {
 
   private void checkLogs() {
     for (int i = 0; i < manager.numContainers(); i++) {
-      File cargo_dir = manager.getContainer(i).cargoLogDir;
+      File cargo_dir = manager.getContainer(i).cargoLogDir.toFile();
       LogChecker.checkLogs(cargo_dir);
     }
   }
