@@ -55,9 +55,9 @@ public class SwaggerManagementVerificationIntegrationTest {
 
     // Check the JSON
     JsonNode json =
-        assertResponse(client.get("/management/v1/api-docs")).hasStatusCode(200)
+        assertResponse(client.get("/management/v3/api-docs")).hasStatusCode(200)
             .getJsonObject();
-    assertThat(json.get("swagger").asText(), is("2.0"));
+    assertThat(json.get("openapi").asText(), is("3.0.1"));
 
     JsonNode info = json.get("info");
     assertThat(info.get("description").asText(),
