@@ -16,7 +16,7 @@ package org.apache.geode.connectors.jdbc.internal.cli;
 
 import org.apache.geode.annotations.Experimental;
 import org.apache.geode.cache.execute.FunctionContext;
-import org.apache.geode.internal.util.DriverJarUtil;
+import org.apache.geode.internal.util.DriverJarUtils;
 import org.apache.geode.management.cli.CliFunction;
 import org.apache.geode.management.internal.functions.CliFunctionResult;
 
@@ -36,7 +36,7 @@ public class DeregisterDriverFunction extends CliFunction<Object[]> {
   public CliFunctionResult executeFunction(FunctionContext<Object[]> context) {
     try {
       String driverClassName = (String) context.getArguments()[0];
-      DriverJarUtil util = getDriverJarUtil();
+      DriverJarUtils util = getDriverJarUtil();
       util.deregisterDriver(driverClassName);
       return new CliFunctionResult(context.getMemberName(), CliFunctionResult.StatusState.OK,
           driverClassName + " was successfully deregistered.");
@@ -46,7 +46,7 @@ public class DeregisterDriverFunction extends CliFunction<Object[]> {
     }
   }
 
-  DriverJarUtil getDriverJarUtil() {
-    return new DriverJarUtil();
+  DriverJarUtils getDriverJarUtil() {
+    return new DriverJarUtils();
   }
 }
