@@ -28,13 +28,13 @@ import org.junit.Test;
 
 import org.apache.geode.cache.execute.FunctionContext;
 import org.apache.geode.internal.cache.execute.FunctionContextImpl;
-import org.apache.geode.internal.util.DriverJarUtil;
+import org.apache.geode.internal.util.DriverJarUtils;
 import org.apache.geode.management.internal.functions.CliFunctionResult;
 
 public class RegisterDriverFunctionTest {
   private RegisterDriverFunction function;
   private FunctionContext<Object[]> context;
-  private DriverJarUtil util;
+  private DriverJarUtils util;
   private static final String DRIVER_CLASS_NAME = "Test.Driver.Name";
   private static final String MEMBER_NAME = "Test Member Name";
 
@@ -45,7 +45,7 @@ public class RegisterDriverFunctionTest {
     function = spy(new RegisterDriverFunction());
     when(context.getArguments()).thenReturn(new Object[] {DRIVER_CLASS_NAME});
     when(context.getMemberName()).thenReturn(MEMBER_NAME);
-    util = mock(DriverJarUtil.class);
+    util = mock(DriverJarUtils.class);
     doReturn(util).when(function).getDriverJarUtil();
   }
 
