@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.dunit;
 
+import static java.lang.System.lineSeparator;
 import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.CACHE_XML_FILE;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
@@ -115,9 +116,9 @@ public class QueryIndexUsingXMLDUnitTest extends JUnit4CacheTestCase {
     URL url = getClass().getResource(CACHE_XML_FILE_NAME);
     assertThat(url).isNotNull(); // precondition
 
-    this.cacheXmlFile = this.temporaryFolder.newFile(CACHE_XML_FILE_NAME);
-    FileUtils.copyURLToFile(url, this.cacheXmlFile);
-    assertThat(this.cacheXmlFile).exists(); // precondition
+    cacheXmlFile = temporaryFolder.newFile(CACHE_XML_FILE_NAME);
+    FileUtils.copyURLToFile(url, cacheXmlFile);
+    assertThat(cacheXmlFile).exists(); // precondition
   }
 
   @After
@@ -315,7 +316,7 @@ public class QueryIndexUsingXMLDUnitTest extends JUnit4CacheTestCase {
 
     // close one vm cache
     vm1.invoke(resetTestHook());
-    vm1.invoke(() -> closeCache());
+    vm1.invoke(JUnit4CacheTestCase::closeCache);
 
     // restart
     vm1.invoke(setTestHook());
@@ -507,8 +508,8 @@ public class QueryIndexUsingXMLDUnitTest extends JUnit4CacheTestCase {
     vm1.invoke(prIndexCreationCheck(PERSISTENT_REG_NAME, "secIndex", 50));
     vm1.invoke(indexCreationCheck(REP_REG_NAME, "secIndex"));
 
-    vm0.invoke(() -> validateIndexSize());
-    vm1.invoke(() -> validateIndexSize());
+    vm0.invoke(this::validateIndexSize);
+    vm1.invoke(this::validateIndexSize);
 
 
     // Execute query and verify index usage
@@ -722,9 +723,9 @@ public class QueryIndexUsingXMLDUnitTest extends JUnit4CacheTestCase {
             }
 
             // compare.
-            getLogWriter().info("Execute query : " + System.getProperty("line.separator")
+            getLogWriter().info("Execute query : " + lineSeparator()
                 + " QUERY_STR with index: " + queryStrings[0] + " "
-                + System.getProperty("line.separator") + " QUERY_STR without index: "
+                + lineSeparator() + " QUERY_STR without index: "
                 + queryStrings[1]);
             resultsSet.CompareQueryResultsWithoutAndWithIndexes(selectResults, 1, queryStrings);
           }
@@ -752,13 +753,13 @@ public class QueryIndexUsingXMLDUnitTest extends JUnit4CacheTestCase {
 
     @Override
     public void beforeIndexLookup(Index index, int oper, Object key) {
-      this.indexesUsed.add(index.getName());
+      indexesUsed.add(index.getName());
     }
 
     @Override
     public void afterIndexLookup(Collection results) {
       if (results != null) {
-        this.isIndexesUsed = true;
+        isIndexesUsed = true;
       }
     }
   }
