@@ -113,8 +113,8 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
       InternalResourceManager irm = getCache().getInternalResourceManager();
       // Reset CRITICAL_UP by informing all that heap usage is now 1 byte (0 would disable).
       irm.getHeapMonitor().updateStateAndSendEvent(NORMAL_HEAP_USED, "test");
-      Set<ResourceListener> listeners = irm.getResourceListeners(ResourceType.HEAP_MEMORY);
-      for (ResourceListener l : listeners) {
+      Set<ResourceListener<?>> listeners = irm.getResourceListeners(ResourceType.HEAP_MEMORY);
+      for (ResourceListener<?> l : listeners) {
         if (l instanceof TestMemoryThresholdListener) {
           ((TestMemoryThresholdListener) l).resetThresholdCalls();
         }
@@ -921,7 +921,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
   private void stopServer(VM server) {
     server.invoke(() -> {
       GemFireCacheImpl cache = (GemFireCacheImpl) getCache();
-      cache.MAX_QUERY_EXECUTION_TIME = -1;
+      GemFireCacheImpl.MAX_QUERY_EXECUTION_TIME = -1;
       return null;
     });
   }
@@ -944,7 +944,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
 
       GemFireCacheImpl cache = (GemFireCacheImpl) getCache();
 
-      cache.MAX_QUERY_EXECUTION_TIME = queryTimeout;
+      GemFireCacheImpl.MAX_QUERY_EXECUTION_TIME = queryTimeout;
 
       InternalResourceManager resourceManager =
           (InternalResourceManager) cache.getResourceManager();
@@ -1105,7 +1105,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
 
     CancelDuringGatherHook(VM vmToCallback) {
       super();
-      this.hitCriticalThreshold = true;
+      hitCriticalThreshold = true;
       callbackVM = vmToCallback;
     }
 
