@@ -32,7 +32,6 @@ import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 import java.util.stream.Stream;
 
-import junitparams.JUnitParamsRunner;
 import junitparams.Parameters;
 import junitparams.naming.TestCaseName;
 import org.assertj.core.api.ThrowableAssert;
@@ -66,8 +65,9 @@ import org.apache.geode.test.junit.categories.OQLQueryTest;
 import org.apache.geode.test.junit.categories.SecurityTest;
 import org.apache.geode.test.junit.rules.serializable.SerializableTemporaryFolder;
 import org.apache.geode.test.junit.rules.serializable.SerializableTestName;
+import org.apache.geode.test.junit.runners.GeodeParamsRunner;
 
-@RunWith(JUnitParamsRunner.class)
+@RunWith(GeodeParamsRunner.class)
 @Category({OQLQueryTest.class, SecurityTest.class})
 public class QueryConfigurationServiceConstraintsDistributedTest implements Serializable {
   private static final int ENTRIES = 500;
@@ -578,8 +578,8 @@ public class QueryConfigurationServiceConstraintsDistributedTest implements Seri
 
     @Override
     public void initialize(Cache cache, Set<String> parameters) {
-      this.authorizedMethods = parameters;
-      this.restrictedMethodAuthorizer = new RestrictedMethodAuthorizer(cache);
+      authorizedMethods = parameters;
+      restrictedMethodAuthorizer = new RestrictedMethodAuthorizer(cache);
     }
 
     @Override
