@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.internal.index;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
@@ -118,7 +119,8 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
             // Create Indexes
             try {
               Index index =
-                  cache.getQueryService().createIndex("statusIndex", "p.ID", "/" + name + " p");
+                  cache.getQueryService().createIndex("statusIndex", "p.ID",
+                      SEPARATOR + name + " p");
               assertNotNull(index);
             } catch (Exception e1) {
               e1.printStackTrace();
@@ -161,7 +163,7 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
             Cache cache = getCache();
 
             Query statusQuery = getCache().getQueryService()
-                .newQuery("select * from /" + name + " p where p.ID > -1");
+                .newQuery("select * from " + SEPARATOR + name + " p where p.ID > -1");
 
             while (!hooked) {
               Wait.pause(100);
@@ -222,7 +224,8 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
             // Create Indexes
             try {
               Index index =
-                  cache.getQueryService().createIndex("statusIndex", "p.ID", "/" + name + " p");
+                  cache.getQueryService().createIndex("statusIndex", "p.ID",
+                      SEPARATOR + name + " p");
               assertNotNull(index);
             } catch (Exception e1) {
               e1.printStackTrace();
@@ -265,7 +268,7 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
             Cache cache = getCache();
 
             Query statusQuery = getCache().getQueryService()
-                .newQuery("select * from /" + name + " p where p.ID > -1");
+                .newQuery("select * from " + SEPARATOR + name + " p where p.ID > -1");
 
             while (!hooked) {
               Wait.pause(100);
@@ -326,7 +329,8 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
             // Create Indexes
             try {
               Index index =
-                  cache.getQueryService().createIndex("statusIndex", "p.ID", "/" + name + " p");
+                  cache.getQueryService().createIndex("statusIndex", "p.ID",
+                      SEPARATOR + name + " p");
               assertNotNull(index);
             } catch (Exception e1) {
               e1.printStackTrace();
@@ -366,7 +370,7 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
           @Override
           public void run2() throws CacheException {
             Query statusQuery = getCache().getQueryService()
-                .newQuery("select * from /" + name + " p where p.ID > -1");
+                .newQuery("select * from " + SEPARATOR + name + " p where p.ID > -1");
 
             while (!hooked) {
               Wait.pause(100);
@@ -427,7 +431,8 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
             // Create Indexes
             try {
               Index index =
-                  cache.getQueryService().createIndex("statusIndex", "p.ID", "/" + name + " p");
+                  cache.getQueryService().createIndex("statusIndex", "p.ID",
+                      SEPARATOR + name + " p");
               assertNotNull(index);
             } catch (Exception e1) {
               e1.printStackTrace();
@@ -467,7 +472,7 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
           @Override
           public void run2() throws CacheException {
             Query statusQuery = getCache().getQueryService()
-                .newQuery("select * from /" + name + " p where p.ID > -1");
+                .newQuery("select * from " + SEPARATOR + name + " p where p.ID > -1");
 
             while (!hooked) {
               Wait.pause(100);
@@ -519,7 +524,8 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
             // Create Indexes
             try {
               Index index =
-                  cache.getQueryService().createIndex("statusIndex", "p.ID", "/" + name + " p");
+                  cache.getQueryService().createIndex("statusIndex", "p.ID",
+                      SEPARATOR + name + " p");
               assertNotNull(index);
             } catch (Exception e1) {
               e1.printStackTrace();
@@ -562,7 +568,7 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
             Cache cache = getCache();
 
             Query statusQuery = getCache().getQueryService()
-                .newQuery("select * from /" + name + " p where p.ID > -1");
+                .newQuery("select * from " + SEPARATOR + name + " p where p.ID > -1");
 
             while (!hooked) {
               Wait.pause(10);
@@ -614,7 +620,8 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
             // Create Indexes
             try {
               Index index =
-                  cache.getQueryService().createIndex("statusIndex", "p.ID", "/" + name + " p");
+                  cache.getQueryService().createIndex("statusIndex", "p.ID",
+                      SEPARATOR + name + " p");
               assertNotNull(index);
             } catch (Exception e1) {
               e1.printStackTrace();
@@ -653,7 +660,7 @@ public class ConcurrentIndexOperationsOnOverflowRegionDUnitTest extends JUnit4Ca
           @Override
           public void run2() throws CacheException {
             Query statusQuery = getCache().getQueryService()
-                .newQuery("select * from /" + name + " p where p.ID > -1");
+                .newQuery("select * from " + SEPARATOR + name + " p where p.ID > -1");
 
             while (!hooked) {
               Wait.pause(10);
