@@ -45,6 +45,7 @@ import org.apache.geode.test.dunit.ThreadUtils;
 import org.apache.geode.test.dunit.VM;
 import org.apache.geode.test.dunit.Wait;
 import org.apache.geode.test.dunit.cache.internal.JUnit4CacheTestCase;
+import org.apache.geode.test.dunit.internal.JUnit4DistributedTestCase;
 import org.apache.geode.test.junit.categories.OQLIndexTest;
 
 @Category({OQLIndexTest.class})
@@ -118,9 +119,9 @@ public class MultiIndexCreationDUnitTest extends JUnit4CacheTestCase {
         });
 
         SelectResults sr = null;
-        for (int i = 0; i < queries.length; i++) {
+        for (final String query : queries) {
           try {
-            sr = (SelectResults) getCache().getQueryService().newQuery(queries[i]).execute();
+            sr = (SelectResults) getCache().getQueryService().newQuery(query).execute();
           } catch (Exception e) {
             fail("QueryExecution failed, " + e);
           }
@@ -164,9 +165,9 @@ public class MultiIndexCreationDUnitTest extends JUnit4CacheTestCase {
         });
 
         SelectResults sr = null;
-        for (int i = 0; i < queries.length; i++) {
+        for (final String query : queries) {
           try {
-            sr = (SelectResults) getCache().getQueryService().newQuery(queries[i]).execute();
+            sr = (SelectResults) getCache().getQueryService().newQuery(query).execute();
           } catch (Exception e) {
             fail("QueryExecution failed, " + e);
           }
@@ -181,12 +182,12 @@ public class MultiIndexCreationDUnitTest extends JUnit4CacheTestCase {
   @Override
   public final void preTearDownCacheTestCase() throws Exception {
     hooked = false;
-    Invoke.invokeInEveryVM(() -> disconnectFromDS());
+    Invoke.invokeInEveryVM(JUnit4DistributedTestCase::disconnectFromDS);
   }
 
   @Override
   public final void postTearDownCacheTestCase() throws Exception {
-    Invoke.invokeInEveryVM(() -> QueryObserverHolder.reset());
+    Invoke.invokeInEveryVM(QueryObserverHolder::reset);
   }
 
   private static class MultiIndexCreationTestHook implements TestHook {
