@@ -72,8 +72,8 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     Host host = Host.getHost(0);
     VM vm0 = host.getVM(0);
     VM vm1 = host.getVM(1);
-    vm0.invoke(() -> DistAckMapMethodsDUnitTest.createCache());
-    vm1.invoke(() -> DistAckMapMethodsDUnitTest.createCache());
+    vm0.invoke(DistAckMapMethodsDUnitTest::createCache);
+    vm1.invoke(DistAckMapMethodsDUnitTest::createCache);
   }
 
   @Override
@@ -81,8 +81,8 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     Host host = Host.getHost(0);
     VM vm0 = host.getVM(0);
     VM vm1 = host.getVM(1);
-    vm0.invoke(() -> DistAckMapMethodsDUnitTest.closeCache());
-    vm1.invoke(() -> DistAckMapMethodsDUnitTest.closeCache());
+    vm0.invoke(DistAckMapMethodsDUnitTest::closeCache);
+    vm1.invoke(DistAckMapMethodsDUnitTest::closeCache);
     cache = null;
     Invoke.invokeInEveryVM(new SerializableRunnable() {
       @Override
@@ -188,7 +188,7 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     boolean ret;
     // put from one and get from other
     int i = 1;
-    Object objArr[] = new Object[1];
+    Object[] objArr = new Object[1];
     objArr[0] = "" + i;
     // Integer in = new Integer(i);
     // objArr[0] = (Object) in;
@@ -222,20 +222,20 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     VM vm0 = host.getVM(0);
     VM vm1 = host.getVM(1);
 
-    vm0.invoke(() -> DistAckMapMethodsDUnitTest.createRegionToTestRemove());
-    vm1.invoke(() -> DistAckMapMethodsDUnitTest.createRegionToTestRemove());
+    vm0.invoke(DistAckMapMethodsDUnitTest::createRegionToTestRemove);
+    vm1.invoke(DistAckMapMethodsDUnitTest::createRegionToTestRemove);
 
-    vm0.invoke(() -> DistAckMapMethodsDUnitTest.removeMethodDetails());
+    vm0.invoke(DistAckMapMethodsDUnitTest::removeMethodDetails);
     vm1.invoke(new CacheSerializableRunnable("testRemoveMethodDetails") {
       @Override
       public void run2() throws CacheException {
-        Object ob1 = remRegion.get(new Integer(1));
+        Object ob1 = remRegion.get(1);
         assertEquals("beforeDestroy", ob1.toString());
         // wait till listeber switches afterDestroy to true
         // while(!afterDestroy){
         // //wait
         // }
-        assertEquals("afterDestroy", remRegion.get(new Integer(3)).toString());
+        assertEquals("afterDestroy", remRegion.get(3).toString());
       }
     });
   }// end of testRemoveMethodDetails
@@ -248,18 +248,18 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     // boolean ret;
     // put from one and get from other
     int i = 1;
-    Object objArr[] = new Object[1];
+    Object[] objArr = new Object[1];
     objArr[0] = "" + i;
     // Integer in = new Integer(i);
     // objArr[0] = (Object) in;
     vm0.invoke(DistAckMapMethodsDUnitTest.class, "putMethod", objArr);
-    boolean val = vm1.invoke(() -> DistAckMapMethodsDUnitTest.isEmptyMethod());
+    boolean val = vm1.invoke(DistAckMapMethodsDUnitTest::isEmptyMethod);
     if (!val) {// val should be true
       fail("Failed in region.isEmpty");
     }
 
     vm1.invoke(DistAckMapMethodsDUnitTest.class, "getMethod", objArr);
-    boolean val1 = vm1.invoke(() -> DistAckMapMethodsDUnitTest.isEmptyMethod());
+    boolean val1 = vm1.invoke(DistAckMapMethodsDUnitTest::isEmptyMethod);
     if (val1) {
       fail("Failed in region.isEmpty");
     }
@@ -273,7 +273,7 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     // boolean ret;
     // put from one and get from other
     int i = 1;
-    Object objArr[] = new Object[1];
+    Object[] objArr = new Object[1];
     objArr[0] = "" + i;
     // Integer in = new Integer(i);
     // objArr[0] = (Object) in;
@@ -297,28 +297,28 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     VM vm1 = host.getVM(1);
 
     int i = 1;
-    Object objArr[] = new Object[1];
+    Object[] objArr = new Object[1];
     objArr[0] = "" + i;
     // Integer in = new Integer(i);
     // objArr[0] = (Object) in;
     vm0.invoke(DistAckMapMethodsDUnitTest.class, "putMethod", objArr);
-    int temp = vm1.invoke(() -> DistAckMapMethodsDUnitTest.keySetMethod());
+    int temp = vm1.invoke(DistAckMapMethodsDUnitTest::keySetMethod);
     if (temp != 0) {
       fail("failed in keySetMethodtest method");
     }
 
     vm1.invoke(DistAckMapMethodsDUnitTest.class, "getMethod", objArr);// to make sure that vm1
                                                                       // region has the entry
-    temp = vm1.invoke(() -> DistAckMapMethodsDUnitTest.keySetMethod());
+    temp = vm1.invoke(DistAckMapMethodsDUnitTest::keySetMethod);
     if (temp == 0) {
       fail("failed in keySetMethodtest method");
     }
     // in the above scenarion we can test this for mirrorred region scenarion as well
     temp = 0;
-    vm0.invoke(() -> DistAckMapMethodsDUnitTest.createMirroredRegion());
-    vm1.invoke(() -> DistAckMapMethodsDUnitTest.createMirroredRegion());
+    vm0.invoke(DistAckMapMethodsDUnitTest::createMirroredRegion);
+    vm1.invoke(DistAckMapMethodsDUnitTest::createMirroredRegion);
     vm0.invoke(DistAckMapMethodsDUnitTest.class, "putMethod", objArr);
-    temp = vm1.invoke(() -> DistAckMapMethodsDUnitTest.keySetMethod());
+    temp = vm1.invoke(DistAckMapMethodsDUnitTest::keySetMethod);
     if (temp == 0) {
       fail("failed in keySetMethodtest method");
     }
@@ -332,28 +332,28 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     VM vm1 = host.getVM(1);
 
     int i = 1;
-    Object objArr[] = new Object[1];
+    Object[] objArr = new Object[1];
     objArr[0] = "" + i;
     // Integer in = new Integer(i);
     // objArr[0] = (Object) in;
     vm0.invoke(DistAckMapMethodsDUnitTest.class, "putMethod", objArr);
-    int temp = vm1.invoke(() -> DistAckMapMethodsDUnitTest.entrySetMethod());
+    int temp = vm1.invoke(DistAckMapMethodsDUnitTest::entrySetMethod);
     if (temp != 0) {
       fail("failed in entrySetMethodtest method");
     }
 
     vm1.invoke(DistAckMapMethodsDUnitTest.class, "getMethod", objArr);// to make sure that vm1
                                                                       // region has the entry
-    temp = vm1.invoke(() -> DistAckMapMethodsDUnitTest.entrySetMethod());
+    temp = vm1.invoke(DistAckMapMethodsDUnitTest::entrySetMethod);
     if (temp == 0) {
       fail("failed in entrySetMethodtest method");
     }
     // in the above scenarion we can test this for mirrorred region scenarion as well
     temp = 0;
-    vm0.invoke(() -> DistAckMapMethodsDUnitTest.createMirroredRegion());
-    vm1.invoke(() -> DistAckMapMethodsDUnitTest.createMirroredRegion());
+    vm0.invoke(DistAckMapMethodsDUnitTest::createMirroredRegion);
+    vm1.invoke(DistAckMapMethodsDUnitTest::createMirroredRegion);
     vm0.invoke(DistAckMapMethodsDUnitTest.class, "putOnMirroredRegion", objArr);
-    temp = vm1.invoke(() -> DistAckMapMethodsDUnitTest.entrySetMethod());
+    temp = vm1.invoke(DistAckMapMethodsDUnitTest::entrySetMethod);
     if (temp == 0) {
       fail("failed in entrySetMethodtest method");
     }
@@ -366,19 +366,19 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     VM vm1 = host.getVM(1);
 
     int i = 1, j = 0;
-    Object objArr[] = new Object[1];
+    Object[] objArr = new Object[1];
     objArr[0] = "" + i;
     // Integer in = new Integer(i);
     // objArr[0] = (Object) in;
     vm0.invoke(DistAckMapMethodsDUnitTest.class, "putMethod", objArr);
-    j = vm1.invoke(() -> DistAckMapMethodsDUnitTest.sizeMethod());
+    j = vm1.invoke(DistAckMapMethodsDUnitTest::sizeMethod);
     if (j != 0) {
       fail("failed in region.size method");
     }
 
     vm1.invoke(DistAckMapMethodsDUnitTest.class, "getMethod", objArr);// to make sure that vm1
                                                                       // region has the entry
-    j = vm1.invoke(() -> DistAckMapMethodsDUnitTest.sizeMethod());
+    j = vm1.invoke(DistAckMapMethodsDUnitTest::sizeMethod);
     if (j == 0) {
       fail("failed in region.size method");
     }
@@ -388,7 +388,7 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
   public void testallMethodsArgs() {
     Host host = Host.getHost(0);
     VM vm0 = host.getVM(0);
-    vm0.invoke(() -> DistAckMapMethodsDUnitTest.allMethodsArgs());
+    vm0.invoke(DistAckMapMethodsDUnitTest::allMethodsArgs);
   }
 
 
@@ -522,7 +522,7 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
   public static void removeMethodDetails() {
     Object ob1;
     // Object ob2;
-    Integer inOb1 = new Integer(1);
+    Integer inOb1 = 1;
     try {
       region.put(inOb1, "first");
       ob1 = region.remove(inOb1);
@@ -533,7 +533,7 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
 
     // to test EntryNotFoundException
     try {
-      region.remove(new Integer(2));
+      region.remove(2);
       // fail("Should have thrown EntryNotFoundException");
     } // catch (EntryNotFoundException e){
     catch (Exception e) {
@@ -543,7 +543,7 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
 
     // to test NullPointerException
     try {
-      Integer inOb2 = new Integer(2);
+      Integer inOb2 = 2;
       region.put(inOb2, "second");
       inOb2 = null;
       region.remove(inOb2);
@@ -555,19 +555,19 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     // to test the cache writers and listeners
     try {
       // createRegionToTestRemove();
-      Integer inOb2 = new Integer(2);
+      Integer inOb2 = 2;
       remRegion.put(inOb2, "second");
       remRegion.remove(inOb2);
 
       // to test cacheWriter
-      inOb2 = new Integer(1);
+      inOb2 = 1;
       assertEquals("beforeDestroy", remRegion.get(inOb2).toString());
 
       // wait till listeber switches afterDestroy to true
       while (!afterDestroy) {
       }
       // to test cacheListener
-      inOb2 = new Integer(3);
+      inOb2 = 3;
       assertEquals("afterDestroy", remRegion.get(inOb2).toString());
 
       // verify that entryEventvalue is correct for listener
@@ -583,25 +583,25 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
   public static void allMethodsArgs() {
     // testing args for put method
     try {
-      region.put(new Integer(1), new String("first"));
-      region.put(new Integer(2), new String("second"));
-      region.put(new Integer(3), new String("third"));
+      region.put(1, "first");
+      region.put(2, "second");
+      region.put(3, "third");
 
       // test args for get method
-      Object ob1 = region.get(new Integer(1));
+      Object ob1 = region.get(1);
       assertEquals("first", ob1.toString());
 
       // test args for containsKey method
-      boolean val1 = region.containsKey(new Integer(2));
+      boolean val1 = region.containsKey(2);
       assertEquals(true, val1);
 
       // test args for containsKey method
-      boolean val2 = region.containsValue(new String("second"));
+      boolean val2 = region.containsValue("second");
       // assertIndexDetailsEquals(true, val2);
 
       // test args for remove method
       try {
-        region.remove(new Integer(3));
+        region.remove(3);
       } // catch (EntryNotFoundException ex){
       catch (Exception ex) {
         ex.printStackTrace();
@@ -628,8 +628,8 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
       }
 
       // RegionDestroyedException
-      key = new Integer(5);
-      value = new String("fifth");
+      key = 5;
+      value = "fifth";
 
       region.localDestroyRegion();
       // test put method
@@ -694,7 +694,7 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     @Override
     public void beforeDestroy(EntryEvent entryEvent)
         throws org.apache.geode.cache.CacheWriterException {
-      Integer o1 = new Integer(1);
+      Integer o1 = 1;
       remRegion.put(o1, "beforeDestroy");
     }
 
@@ -706,7 +706,7 @@ public class DistAckMapMethodsDUnitTest extends JUnit4DistributedTestCase { // T
     @Override
     public void afterDestroy(EntryEvent entryEvent)
         throws org.apache.geode.cache.CacheWriterException {
-      Integer o1 = new Integer(3);
+      Integer o1 = 3;
       remRegion.put(o1, "afterDestroy");
 
       afterDestroyObj = entryEvent.getKey();
