@@ -92,7 +92,7 @@ import org.apache.geode.test.dunit.cache.internal.JUnit4CacheTestCase;
 public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
 
   protected <K, V> RegionAttributes<K, V> getRegionAttributes() {
-    return this.getRegionAttributes(Scope.DISTRIBUTED_ACK);
+    return getRegionAttributes(Scope.DISTRIBUTED_ACK);
   }
 
   protected <K, V> RegionAttributes<K, V> getRegionAttributes(Scope scope) {
@@ -110,7 +110,7 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
   @Test
   public void testRemoteGrantor() throws Exception {
     IgnoredException.addIgnoredException("killing members ds");
-    final CacheTransactionManager txMgr = this.getCache().getCacheTransactionManager();
+    final CacheTransactionManager txMgr = getCache().getCacheTransactionManager();
     final String rgnName = getUniqueName();
     Region rgn = getCache().createRegion(rgnName, getRegionAttributes());
     rgn.create("key", null);
@@ -213,7 +213,7 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
    */
   @Test
   public void testInternalCallbacks() throws Exception {
-    final CacheTransactionManager txMgr = this.getCache().getCacheTransactionManager();
+    final CacheTransactionManager txMgr = getCache().getCacheTransactionManager();
     final String rgnName1 = getUniqueName() + "_1";
     final String rgnName2 = getUniqueName() + "_2";
     final String rgnName3 = getUniqueName() + "_3";
@@ -260,7 +260,7 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
     vm1.invoke(checkRgn1);
 
     {
-      final byte cbSensors[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};
+      final byte[] cbSensors = {0, 0, 0, 0, 0, 0, 0, 0, 0};
       txMgr.begin();
       ((TXStateProxyImpl) ((TXManagerImpl) txMgr).getTXState()).forceLocalBootstrap();
       setInternalCallbacks(((TXManagerImpl) txMgr).getTXState(), cbSensors);
@@ -310,7 +310,7 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
     vm1.invoke(checkRgn12);
 
     {
-      final byte cbSensors[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};
+      final byte[] cbSensors = {0, 0, 0, 0, 0, 0, 0, 0, 0};
       txMgr.begin();
       ((TXStateProxyImpl) ((TXManagerImpl) txMgr).getTXState()).forceLocalBootstrap();
       setInternalCallbacks(((TXManagerImpl) txMgr).getTXState(), cbSensors);
@@ -369,7 +369,7 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
     vm1.invoke(checkRgn123);
 
     {
-      final byte cbSensors[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};
+      final byte[] cbSensors = {0, 0, 0, 0, 0, 0, 0, 0, 0};
       txMgr.begin();
       ((TXStateProxyImpl) ((TXManagerImpl) txMgr).getTXState()).forceLocalBootstrap();
       setInternalCallbacks(((TXManagerImpl) txMgr).getTXState(), cbSensors);
@@ -415,60 +415,15 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
     ((TXStateProxyImpl) txp).forceLocalBootstrap();
     TXState tx = (TXState) ((TXStateProxyImpl) txp).getRealDeal(null, null);
     assertEquals(9, cbSensors.length);
-    tx.setAfterReservation(new Runnable() {
-      @Override
-      public void run() {
-        cbSensors[0]++;
-      }
-    });
-    tx.setAfterConflictCheck(new Runnable() {
-      @Override
-      public void run() {
-        cbSensors[1]++;
-      }
-    });
-    tx.setAfterApplyChanges(new Runnable() {
-      @Override
-      public void run() {
-        cbSensors[2]++;
-      }
-    });
-    tx.setAfterReleaseLocalLocks(new Runnable() {
-      @Override
-      public void run() {
-        cbSensors[3]++;
-      }
-    });
-    tx.setAfterIndividualSend(new Runnable() {
-      @Override
-      public void run() {
-        cbSensors[4]++;
-      }
-    });
-    tx.setAfterIndividualCommitProcess(new Runnable() {
-      @Override
-      public void run() {
-        cbSensors[5]++;
-      }
-    });
-    tx.setAfterSend(new Runnable() {
-      @Override
-      public void run() {
-        cbSensors[6]++;
-      }
-    });
-    tx.setDuringIndividualSend(new Runnable() {
-      @Override
-      public void run() {
-        cbSensors[7]++;
-      }
-    });
-    tx.setDuringIndividualCommitProcess(new Runnable() {
-      @Override
-      public void run() {
-        cbSensors[8]++;
-      }
-    });
+    tx.setAfterReservation(() -> cbSensors[0]++);
+    tx.setAfterConflictCheck(() -> cbSensors[1]++);
+    tx.setAfterApplyChanges(() -> cbSensors[2]++);
+    tx.setAfterReleaseLocalLocks(() -> cbSensors[3]++);
+    tx.setAfterIndividualSend(() -> cbSensors[4]++);
+    tx.setAfterIndividualCommitProcess(() -> cbSensors[5]++);
+    tx.setAfterSend(() -> cbSensors[6]++);
+    tx.setDuringIndividualSend(() -> cbSensors[7]++);
+    tx.setDuringIndividualCommitProcess(() -> cbSensors[8]++);
   }
 
   /**
@@ -476,7 +431,7 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
    */
   @Test
   public void testDACKLoadedMessage() throws Exception {
-    final CacheTransactionManager txMgr = this.getCache().getCacheTransactionManager();
+    final CacheTransactionManager txMgr = getCache().getCacheTransactionManager();
     final String rgnName = getUniqueName();
     AttributesFactory factory = new AttributesFactory();
     factory.setScope(Scope.DISTRIBUTED_ACK);
@@ -525,7 +480,7 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
 
     // Confirm loaded value case
     txMgr.begin();
-    rgn.get("key2", new Integer(2));
+    rgn.get("key2", 2);
     txMgr.commit();
     assertEquals("val2", rgn.getEntry("key2").getValue());
 
@@ -541,7 +496,7 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
     // This should use the ack w/ the lockid
     txMgr.begin();
     rgn.put("key3", "val3");
-    rgn.get("key4", new Integer(4));
+    rgn.get("key4", 4);
     txMgr.commit();
 
     Invoke
@@ -1069,50 +1024,44 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
     public Object value = null;
 
     public boolean getIsRunning() {
-      return this.isRunning;
+      return isRunning;
     }
 
     @Override
     public void run() {
-      Region rgn = this.myCache.getRegion(this.rgnName);
-      final CacheTransactionManager txMgr = this.myCache.getCacheTransactionManager();
+      Region rgn = myCache.getRegion(rgnName);
+      final CacheTransactionManager txMgr = myCache.getCacheTransactionManager();
       txMgr.begin();
       ((TXStateProxyImpl) ((TXManagerImpl) txMgr).getTXState()).forceLocalBootstrap();
       TXState txState = (TXState) ((TXStateProxyImpl) ((TXManagerImpl) txMgr).getTXState())
           .getRealDeal(null, null);
-      txState.setAfterReservation(new Runnable() {
-        @Override
-        public void run() {
-          try {
-            synchronized (PausibleTX.class) {
-              PausibleTX.this.isRunning = true;
-              // Notify the thread that created this, that we are ready
-              PausibleTX.class.notifyAll();
-              // Wait for the controller to start a GII and let us proceed
-              PausibleTX.class.wait();
-            }
-          } catch (InterruptedException ie) {
-            // PausibleTX.this.myCache.getLogger().info("Why was I interrupted? " + ie);
-            fail("interrupted");
+      txState.setAfterReservation(() -> {
+        try {
+          synchronized (PausibleTX.class) {
+            isRunning = true;
+            // Notify the thread that created this, that we are ready
+            PausibleTX.class.notifyAll();
+            // Wait for the controller to start a GII and let us proceed
+            PausibleTX.class.wait();
           }
+        } catch (InterruptedException ie) {
+          // PausibleTX.this.myCache.getLogger().info("Why was I interrupted? " + ie);
+          fail("interrupted");
         }
       });
-      txState.setAfterSend(new Runnable() {
-        @Override
-        public void run() {
-          try {
-            synchronized (PausibleTX.class) {
-              // Notify the controller that we have sent the TX data (and the
-              // update)
-              PausibleTX.class.notifyAll();
-              // Wait until the controller has determined in fact the update
-              // took place
-              PausibleTX.class.wait();
-            }
-          } catch (InterruptedException ie) {
-            // PausibleTX.this.myCache.getLogger().info("Why was I interrupted? " + ie);
-            fail("interrupted");
+      txState.setAfterSend(() -> {
+        try {
+          synchronized (PausibleTX.class) {
+            // Notify the controller that we have sent the TX data (and the
+            // update)
+            PausibleTX.class.notifyAll();
+            // Wait until the controller has determined in fact the update
+            // took place
+            PausibleTX.class.wait();
           }
+        } catch (InterruptedException ie) {
+          // PausibleTX.this.myCache.getLogger().info("Why was I interrupted? " + ie);
+          fail("interrupted");
         }
       });
       try {
@@ -1224,13 +1173,13 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
     // Build sets of System Ids and set them up on VM0 for future batch member checks
     HashSet txMembers = new HashSet(4);
     txMembers.add(getSystemId());
-    txMembers.add(vm0.invoke(() -> TXDistributedDUnitTest.getSystemId()));
+    txMembers.add(vm0.invoke(TXDistributedDUnitTest::getSystemId));
     vm0.invoke(() -> TXDistributedDUnitTest.setPreTXSystemIds(txMembers));
-    txMembers.add(vm2.invoke(() -> TXDistributedDUnitTest.getSystemId()));
+    txMembers.add(vm2.invoke(TXDistributedDUnitTest::getSystemId));
     vm0.invoke(() -> TXDistributedDUnitTest.setPostTXSystemIds(txMembers));
 
     // Don't include the tx host in the batch member set(s)
-    Serializable vm1HostId = (Serializable) vm1.invoke(() -> TXDistributedDUnitTest.getSystemId());
+    Serializable vm1HostId = vm1.invoke(TXDistributedDUnitTest::getSystemId);
     vm0.invoke(() -> TXDistributedDUnitTest.setTXHostSystemId(vm1HostId));
 
     // Create a TX on VM1 (such that it will ask for locks on VM0) that uses the callbacks
@@ -1395,7 +1344,7 @@ public class TXDistributedDUnitTest extends JUnit4CacheTestCase {
     }
 
     public void unblockShutdown() {
-      this.latch.countDown();
+      latch.countDown();
     }
   }
 
