@@ -36,6 +36,7 @@ import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableUD
 import static org.apache.geode.internal.inet.LocalHostUtil.getLocalHost;
 import static org.apache.geode.test.dunit.DistributedTestUtils.getDUnitLocatorPort;
 import static org.apache.geode.test.dunit.LogWriterUtils.getLogWriter;
+import static org.apache.geode.util.internal.GeodeGlossary.GEMFIRE_PREFIX;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
@@ -51,8 +52,10 @@ import java.util.Properties;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
+import org.junit.Rule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
+import org.junit.rules.TestRule;
 
 import org.apache.geode.CancelException;
 import org.apache.geode.GemFireConfigException;
@@ -74,6 +77,7 @@ import org.apache.geode.distributed.internal.membership.InternalDistributedMembe
 import org.apache.geode.test.dunit.IgnoredException;
 import org.apache.geode.test.dunit.VM;
 import org.apache.geode.test.dunit.internal.JUnit4DistributedTestCase;
+import org.apache.geode.test.dunit.rules.DistributedRestoreSystemProperties;
 import org.apache.geode.test.junit.categories.MembershipTest;
 
 /**
@@ -81,7 +85,8 @@ import org.apache.geode.test.junit.categories.MembershipTest;
  */
 @Category({MembershipTest.class})
 public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
-
+  @Rule
+  public TestRule restoreSystemProperties = new DistributedRestoreSystemProperties();
   private int mcastPort;
   private int locatorPort;
   private int tcpPort;
@@ -92,13 +97,13 @@ public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
   public void before() throws Exception {
     disconnectAllFromDS();
 
-    this.mcastPort = getRandomAvailableUDPPort();
-    this.locatorPort = getRandomAvailableTCPPort();
-    this.tcpPort = getRandomAvailableTCPPort();
+    mcastPort = getRandomAvailableUDPPort();
+    locatorPort = getRandomAvailableTCPPort();
+    tcpPort = getRandomAvailableTCPPort();
 
-    int[] portRange = getRandomAvailableTCPPortRange(3, true);
-    this.lowerBoundOfPortRange = portRange[0];
-    this.upperBoundOfPortRange = portRange[portRange.length - 1];
+    int[] portRange = getRandomAvailableTCPPortRange(3);
+    lowerBoundOfPortRange = portRange[0];
+    upperBoundOfPortRange = portRange[portRange.length - 1];
   }
 
   @After
@@ -114,7 +119,7 @@ public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
   public void testWaitForDeparture() throws Exception {
     Properties config = new Properties();
     config.put(LOCATORS, "");
-    config.put(START_LOCATOR, "localhost[" + this.locatorPort + "]");
+    config.put(START_LOCATOR, "localhost[" + locatorPort + "]");
     config.put(DISABLE_TCP, "true");
 
     InternalDistributedSystem system =
@@ -234,13 +239,13 @@ public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
   public void testSpecificTcpPort() throws Exception {
     Properties config = new Properties();
     config.put(LOCATORS, "localhost[" + getDUnitLocatorPort() + "]");
-    config.setProperty(TCP_PORT, String.valueOf(this.tcpPort));
+    config.setProperty(TCP_PORT, String.valueOf(tcpPort));
 
     InternalDistributedSystem system = getSystem(config);
 
     ClusterDistributionManager dm = (ClusterDistributionManager) system.getDistributionManager();
     Distribution mgr = dm.getDistribution();
-    assertThat(mgr.getLocalMember().getDirectChannelPort()).isEqualTo(this.tcpPort);
+    assertThat(mgr.getLocalMember().getDirectChannelPort()).isEqualTo(tcpPort);
   }
 
   /**
@@ -268,34 +273,43 @@ public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
   public void testPortRange() throws Exception {
     Properties config = new Properties();
     config.put(LOCATORS, "localhost[" + getDUnitLocatorPort() + "]");
+    System.clearProperty(GEMFIRE_PREFIX + MEMBERSHIP_PORT_RANGE);
     config.setProperty(MEMBERSHIP_PORT_RANGE,
-        this.lowerBoundOfPortRange + "-" + this.upperBoundOfPortRange);
+        lowerBoundOfPortRange + "-" + upperBoundOfPortRange);
 
     InternalDistributedSystem system = getSystem(config);
     ClusterDistributionManager dm = (ClusterDistributionManager) system.getDistributionManager();
     InternalDistributedMember member = dm.getDistributionManagerId();
 
-    verifyMembershipPortsInRange(member, this.lowerBoundOfPortRange, this.upperBoundOfPortRange);
+    verifyMembershipPortsInRange(member, lowerBoundOfPortRange, upperBoundOfPortRange);
   }
 
   @Test
   public void testConflictingUDPPort() {
     Properties config = new Properties();
-    config.setProperty(MCAST_PORT, String.valueOf(this.mcastPort));
-    config.setProperty(START_LOCATOR, "localhost[" + this.locatorPort + "]");
+    config.setProperty(MCAST_PORT, String.valueOf(mcastPort));
+    config.setProperty(START_LOCATOR, "localhost[" + locatorPort + "]");
+    System.clearProperty(GEMFIRE_PREFIX + MEMBERSHIP_PORT_RANGE);
     config.setProperty(MEMBERSHIP_PORT_RANGE,
-        this.lowerBoundOfPortRange + "-" + this.upperBoundOfPortRange);
+        lowerBoundOfPortRange + "-" + upperBoundOfPortRange);
 
     DistributedSystem.connect(config);
 
     IgnoredException.addIgnoredException("SystemConnectException", VM.getVM(1));
     VM.getVM(1).invoke(() -> {
+      String oldMembershipPortRange = System.clearProperty(GEMFIRE_PREFIX + MEMBERSHIP_PORT_RANGE);
       String locators = (String) config.remove(START_LOCATOR);
 
       config.put(LOCATORS, locators);
 
-      assertThatThrownBy(() -> DistributedSystem.connect(config))
-          .isInstanceOfAny(GemFireConfigException.class, SystemConnectException.class);
+      try {
+        assertThatThrownBy(() -> DistributedSystem.connect(config))
+            .isInstanceOfAny(GemFireConfigException.class, SystemConnectException.class);
+      } finally {
+        if (oldMembershipPortRange != null) {
+          System.setProperty(GEMFIRE_PREFIX + MEMBERSHIP_PORT_RANGE, oldMembershipPortRange);
+        }
+      }
     });
   }
 
@@ -330,7 +344,6 @@ public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
     VM vm0 = VM.getVM(0);
     VM vm1 = VM.getVM(1);
 
-
     // Install a membership listener which will send a message to
     // any new member that joins. The message will fail to deserialize, triggering
     // a failure reply
@@ -388,10 +401,12 @@ public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
 
   private void verifyMembershipPortsInRange(final InternalDistributedMember member,
       final int lowerBound, final int upperBound) {
-    assertThat(member.getMembershipPort()).isGreaterThanOrEqualTo(lowerBound);
-    assertThat(member.getMembershipPort()).isLessThanOrEqualTo(upperBound);
-    assertThat(member.getDirectChannelPort()).isGreaterThanOrEqualTo(lowerBound);
-    assertThat(member.getDirectChannelPort()).isLessThanOrEqualTo(upperBound);
+    assertThat(member.getMembershipPort())
+        .as("membership port")
+        .isBetween(lowerBound, upperBound);
+    assertThat(member.getDirectChannelPort())
+        .as("direct channel port")
+        .isBetween(lowerBound, upperBound);
   }
 
   private InetAddress getLoopback() throws SocketException, UnknownHostException {
@@ -420,7 +435,7 @@ public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
    * NullPointerException.
    */
   private static class FakeMessage extends SerialDistributionMessage {
-    private volatile boolean[] blocked; // always null
+    private final boolean[] blocked; // always null
     private volatile boolean processed; // unused
 
     FakeMessage(boolean[] blocked) { // null is always passed in
@@ -428,14 +443,14 @@ public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
     }
 
     public void doAction(ClusterDistributionManager dm, boolean block) {
-      this.processed = true;
+      processed = true;
       if (block) {
-        synchronized (this.blocked) { // throws NullPointerException here
-          this.blocked[0] = true;
-          this.blocked.notify();
+        synchronized (blocked) { // throws NullPointerException here
+          blocked[0] = true;
+          blocked.notify();
           try {
-            this.blocked.wait(60000);
-          } catch (InterruptedException e) {
+            blocked.wait(60000);
+          } catch (InterruptedException ignored) {
           }
         }
       }
@@ -453,7 +468,7 @@ public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
 
     @Override
     public String toString() {
-      return "FakeMessage(blocking=" + (this.blocked != null) + ")";
+      return "FakeMessage(blocking=" + (blocked != null) + ")";
     }
   }
 }
