@@ -49,7 +49,7 @@ public class LocatorUDPSecurityDUnitTest extends LocatorDUnitTest {
       system = getConnectedDistributedSystem(props);
       fail("Should not have reached this line, it should have caught the exception.");
     } catch (GemFireConfigException e) {
-      assertThat(e.getMessage()).contains("Rejecting findCoordinatorRequest");
+      assertThat(e.getCause().getMessage()).contains("Rejecting findCoordinatorRequest");
     }
   }
 }
