@@ -73,6 +73,7 @@ import org.apache.geode.test.dunit.SerializableRunnable;
 import org.apache.geode.test.dunit.VM;
 import org.apache.geode.test.dunit.WaitCriterion;
 import org.apache.geode.test.dunit.cache.internal.JUnit4CacheTestCase;
+import org.apache.geode.test.dunit.internal.JUnit4DistributedTestCase;
 import org.apache.geode.test.dunit.rules.DistributedRestoreSystemProperties;
 import org.apache.geode.util.internal.GeodeGlossary;
 
@@ -113,7 +114,7 @@ public class ConcurrentMapOpsDUnitTest extends JUnit4CacheTestCase {
 
   @After
   public void teardown() {
-    VM.getVM(4).invoke(() -> disconnectFromDS());
+    VM.getVM(4).invoke(JUnit4DistributedTestCase::disconnectFromDS);
   }
 
   @Override
@@ -1245,7 +1246,7 @@ public class ConcurrentMapOpsDUnitTest extends JUnit4CacheTestCase {
     final InternalDistributedMember server1ID = (InternalDistributedMember) server1.invoke(getID);
     final InternalDistributedMember server2ID = (InternalDistributedMember) server2.invoke(getID);
 
-    Set<IgnoredException> exceptions = new HashSet<IgnoredException>();
+    Set<IgnoredException> exceptions = new HashSet<>();
     exceptions.add(IgnoredException.addIgnoredException("Membership: requesting removal", server1));
     exceptions.add(IgnoredException.addIgnoredException("Membership: requesting removal", server2));
     exceptions.add(IgnoredException
@@ -1382,8 +1383,8 @@ public class ConcurrentMapOpsDUnitTest extends JUnit4CacheTestCase {
     public CustomerDelta() {}
 
     public CustomerDelta(CustomerDelta o) {
-      this.address = o.address;
-      this.name = o.name;
+      address = o.address;
+      name = o.name;
     }
 
     public CustomerDelta(String name, String address) {
@@ -1411,11 +1412,11 @@ public class ConcurrentMapOpsDUnitTest extends JUnit4CacheTestCase {
     public void fromDelta(DataInput in) throws IOException, InvalidDeltaException {
       boolean nameC = in.readBoolean();
       if (nameC) {
-        this.name = in.readUTF();
+        name = in.readUTF();
       }
       boolean addressC = in.readBoolean();
       if (addressC) {
-        this.address = in.readUTF();
+        address = in.readUTF();
       }
     }
 
@@ -1426,18 +1427,18 @@ public class ConcurrentMapOpsDUnitTest extends JUnit4CacheTestCase {
 
     @Override
     public void toDelta(DataOutput out) throws IOException {
-      if (this.nameChanged) {
+      if (nameChanged) {
         out.writeBoolean(nameChanged);
         out.writeUTF(name);
       }
-      if (this.addressChanged) {
+      if (addressChanged) {
         out.writeBoolean(addressChanged);
         out.writeUTF(address);
       }
     }
 
     public void setName(String name) {
-      this.nameChanged = true;
+      nameChanged = true;
       this.name = name;
     }
 
@@ -1446,7 +1447,7 @@ public class ConcurrentMapOpsDUnitTest extends JUnit4CacheTestCase {
     }
 
     public void setAddress(String address) {
-      this.addressChanged = true;
+      addressChanged = true;
       this.address = address;
     }
 
@@ -1460,12 +1461,12 @@ public class ConcurrentMapOpsDUnitTest extends JUnit4CacheTestCase {
         return false;
       }
       CustomerDelta other = (CustomerDelta) obj;
-      return this.name.equals(other.name) && this.address.equals(other.address);
+      return name.equals(other.name) && address.equals(other.address);
     }
 
     @Override
     public int hashCode() {
-      return this.address.hashCode() + this.name.hashCode();
+      return address.hashCode() + name.hashCode();
     }
 
   }
