@@ -29,7 +29,7 @@ import static org.apache.geode.distributed.internal.DistributionConfig.CLIENT_CO
 import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.apache.geode.internal.cache.CacheServerImpl.generateNameForClientMsgsRegion;
 import static org.apache.geode.internal.cache.tier.sockets.CacheClientProxyFactory.INTERNAL_FACTORY_PROPERTY;
-import static org.apache.geode.internal.lang.SystemPropertyHelper.GEMFIRE_PREFIX;
+import static org.apache.geode.internal.lang.SystemProperty.GEMFIRE_PREFIX;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.getTimeout;
 import static org.apache.geode.test.dunit.VM.getController;
@@ -48,10 +48,12 @@ import java.io.Serializable;
 import java.io.UncheckedIOException;
 import java.net.Socket;
 import java.util.Properties;
+import java.util.Random;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicReference;
+import java.util.function.Consumer;
 
 import org.apache.shiro.subject.Subject;
 import org.junit.After;
@@ -94,7 +96,10 @@ import org.apache.geode.internal.cache.tier.sockets.CacheClientNotifier;
 import org.apache.geode.internal.cache.tier.sockets.CacheClientProxy;
 import org.apache.geode.internal.cache.tier.sockets.CacheClientProxyFactory.InternalCacheClientProxyFactory;
 import org.apache.geode.internal.cache.tier.sockets.ClientProxyMembershipID;
+import org.apache.geode.internal.cache.tier.sockets.ClientUserAuths;
 import org.apache.geode.internal.cache.tier.sockets.MessageDispatcher;
+import org.apache.geode.internal.cache.tier.sockets.RandomSubjectIdGenerator;
+import org.apache.geode.internal.cache.tier.sockets.SubjectIdGenerator;
 import org.apache.geode.internal.security.SecurityService;
 import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.internal.statistics.StatisticsClock;
@@ -212,7 +217,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     });
 
     for (VM vm : toArray(serverVM, clientVM)) {
-      vm.invoke(() -> prepareDeltas());
+      vm.invoke(this::prepareDeltas);
     }
 
     serverVM.invoke(() -> {
@@ -224,10 +229,10 @@ public class DeltaPropagationDUnitTest implements Serializable {
       region.put(LAST_KEY, "");
     });
 
-    clientVM.invoke(() -> await().until(() -> LAST_KEY_RECEIVED.get()));
+    clientVM.invoke(() -> await().until(LAST_KEY_RECEIVED::get));
 
-    long toDeltas = serverVM.invoke(() -> DeltaTestImpl.getToDeltaInvokations());
-    long fromDeltas = clientVM.invoke(() -> DeltaTestImpl.getFromDeltaInvokations());
+    long toDeltas = serverVM.invoke(DeltaTestImpl::getToDeltaInvokations);
+    long fromDeltas = clientVM.invoke(DeltaTestImpl::getFromDeltaInvokations);
 
     assertThat(toDeltas).isEqualTo(EVENTS_SIZE - 1);
     assertThat(fromDeltas).isEqualTo(EVENTS_SIZE - 1);
@@ -259,7 +264,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     });
 
     for (VM vm : toArray(serverVM, clientVM)) {
-      vm.invoke(() -> prepareDeltas());
+      vm.invoke(this::prepareDeltas);
     }
 
     serverVM.invoke(() -> {
@@ -271,10 +276,10 @@ public class DeltaPropagationDUnitTest implements Serializable {
       region.put(LAST_KEY, "");
     });
 
-    clientVM.invoke(() -> await().until(() -> LAST_KEY_RECEIVED.get()));
+    clientVM.invoke(() -> await().until(LAST_KEY_RECEIVED::get));
 
-    long toDeltas = serverVM.invoke(() -> DeltaTestImpl.getToDeltaInvokations());
-    long fromDeltas = clientVM.invoke(() -> DeltaTestImpl.getFromDeltaInvokations());
+    long toDeltas = serverVM.invoke(DeltaTestImpl::getToDeltaInvokations);
+    long fromDeltas = clientVM.invoke(DeltaTestImpl::getFromDeltaInvokations);
 
     assertThat(toDeltas).isEqualTo(EVENTS_SIZE - 1);
     assertThat(fromDeltas).isEqualTo(EVENTS_SIZE - 1);
@@ -306,7 +311,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     });
 
     for (VM vm : toArray(serverVM, clientVM)) {
-      vm.invoke(() -> prepareErroneousDeltasForToDelta());
+      vm.invoke(this::prepareErroneousDeltasForToDelta);
     }
 
     serverVM.invoke(() -> {
@@ -324,11 +329,11 @@ public class DeltaPropagationDUnitTest implements Serializable {
       region.put(LAST_KEY, "");
     });
 
-    clientVM.invoke(() -> await().until(() -> LAST_KEY_RECEIVED.get()));
+    clientVM.invoke(() -> await().until(LAST_KEY_RECEIVED::get));
 
-    long toDeltas = serverVM.invoke(() -> DeltaTestImpl.getToDeltaInvokations());
-    long fromDeltas = clientVM.invoke(() -> DeltaTestImpl.getFromDeltaInvokations());
-    long toDeltaFailures = serverVM.invoke(() -> DeltaTestImpl.getToDeltaFailures());
+    long toDeltas = serverVM.invoke(DeltaTestImpl::getToDeltaInvokations);
+    long fromDeltas = clientVM.invoke(DeltaTestImpl::getFromDeltaInvokations);
+    long toDeltaFailures = serverVM.invoke(DeltaTestImpl::getToDeltaFailures);
 
     assertThat(toDeltas).isEqualTo(EVENTS_SIZE - 1);
     // -1 below is because the one failed in toDelta will be sent as full
@@ -364,7 +369,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     });
 
     for (VM vm : toArray(serverVM, clientVM)) {
-      vm.invoke(() -> prepareErroneousDeltasForFromDelta());
+      vm.invoke(this::prepareErroneousDeltasForFromDelta);
     }
 
     serverVM.invoke(() -> {
@@ -376,11 +381,11 @@ public class DeltaPropagationDUnitTest implements Serializable {
       region.put(LAST_KEY, "");
     });
 
-    clientVM.invoke(() -> await().until(() -> LAST_KEY_RECEIVED.get()));
+    clientVM.invoke(() -> await().until(LAST_KEY_RECEIVED::get));
 
-    long toDeltas = serverVM.invoke(() -> DeltaTestImpl.getToDeltaInvokations());
-    long fromDeltas = clientVM.invoke(() -> DeltaTestImpl.getFromDeltaInvokations());
-    long fromDeltaFailures = clientVM.invoke(() -> DeltaTestImpl.getFromDeltaFailures());
+    long toDeltas = serverVM.invoke(DeltaTestImpl::getToDeltaInvokations);
+    long fromDeltas = clientVM.invoke(DeltaTestImpl::getFromDeltaInvokations);
+    long fromDeltaFailures = clientVM.invoke(DeltaTestImpl::getFromDeltaFailures);
 
     assertThat(toDeltas).isEqualTo(EVENTS_SIZE - 1);
     assertThat(fromDeltas).isEqualTo(EVENTS_SIZE - 1);
@@ -414,7 +419,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     });
 
     for (VM vm : toArray(serverVM, clientVM)) {
-      vm.invoke(() -> prepareDeltas());
+      vm.invoke(this::prepareDeltas);
     }
 
     serverVM.invoke(() -> {
@@ -436,10 +441,10 @@ public class DeltaPropagationDUnitTest implements Serializable {
       region.put(LAST_KEY, "");
     });
 
-    clientVM.invoke(() -> await().until(() -> LAST_KEY_RECEIVED.get()));
+    clientVM.invoke(() -> await().until(LAST_KEY_RECEIVED::get));
 
-    long toDeltas = serverVM.invoke(() -> DeltaTestImpl.getToDeltaInvokations());
-    long fromDeltas = clientVM.invoke(() -> DeltaTestImpl.getFromDeltaInvokations());
+    long toDeltas = serverVM.invoke(DeltaTestImpl::getToDeltaInvokations);
+    long fromDeltas = clientVM.invoke(DeltaTestImpl::getFromDeltaInvokations);
 
     assertThat(toDeltas).isEqualTo(EVENTS_SIZE - 1);
     assertThat(fromDeltas).isEqualTo(EVENTS_SIZE - 1);
@@ -472,7 +477,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     });
 
     for (VM vm : toArray(serverVM, clientVM)) {
-      vm.invoke(() -> prepareDeltas());
+      vm.invoke(this::prepareDeltas);
     }
 
     serverVM.invoke(() -> {
@@ -494,10 +499,10 @@ public class DeltaPropagationDUnitTest implements Serializable {
       region.put(LAST_KEY, "");
     });
 
-    clientVM.invoke(() -> await().until(() -> LAST_KEY_RECEIVED.get()));
+    clientVM.invoke(() -> await().until(LAST_KEY_RECEIVED::get));
 
-    long toDeltas = serverVM.invoke(() -> DeltaTestImpl.getToDeltaInvokations());
-    long fromDeltas = clientVM.invoke(() -> DeltaTestImpl.getFromDeltaInvokations());
+    long toDeltas = serverVM.invoke(DeltaTestImpl::getToDeltaInvokations);
+    long fromDeltas = clientVM.invoke(DeltaTestImpl::getFromDeltaInvokations);
 
     assertThat(toDeltas).isEqualTo(EVENTS_SIZE - 1);
     assertThat(fromDeltas).isEqualTo(EVENTS_SIZE - 1 - 1);
@@ -529,7 +534,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     });
 
     for (VM vm : toArray(serverVM, clientVM)) {
-      vm.invoke(() -> prepareDeltas());
+      vm.invoke(this::prepareDeltas);
     }
 
     serverVM.invoke(() -> {
@@ -542,10 +547,10 @@ public class DeltaPropagationDUnitTest implements Serializable {
       region.put(LAST_KEY, "");
     });
 
-    clientVM.invoke(() -> await().until(() -> LAST_KEY_RECEIVED.get()));
+    clientVM.invoke(() -> await().until(LAST_KEY_RECEIVED::get));
 
-    long toDeltas = serverVM.invoke(() -> DeltaTestImpl.getToDeltaInvokations());
-    long fromDeltas = clientVM.invoke(() -> DeltaTestImpl.getFromDeltaInvokations());
+    long toDeltas = serverVM.invoke(DeltaTestImpl::getToDeltaInvokations);
+    long fromDeltas = clientVM.invoke(DeltaTestImpl::getFromDeltaInvokations);
 
     assertThat(toDeltas).isEqualTo(EVENTS_SIZE - 1);
     assertThat(fromDeltas).isEqualTo(EVENTS_SIZE - 1 - 1);
@@ -588,7 +593,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     });
 
     clientVM.invoke(() -> {
-      await().until(() -> LAST_KEY_RECEIVED.get());
+      await().until(LAST_KEY_RECEIVED::get);
 
       assertThat(DeltaTestImpl.getFromDeltaInvokations()).isZero();
     });
@@ -635,7 +640,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     });
 
     for (VM clientVM : toArray(client1VM, client2VM)) {
-      clientVM.invoke(() -> await().until(() -> LAST_KEY_RECEIVED.get()));
+      clientVM.invoke(() -> await().until(LAST_KEY_RECEIVED::get));
     }
 
     client1VM.invoke(() -> {
@@ -675,7 +680,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
       region.create(LAST_KEY, "");
     });
 
-    clientVM.invoke(() -> await().until(() -> LAST_KEY_RECEIVED.get()));
+    clientVM.invoke(() -> await().until(LAST_KEY_RECEIVED::get));
 
     serverVM.invoke(() -> {
       assertThat(DeltaTestImpl.getToDeltaInvokations()).isZero();
@@ -698,7 +703,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     VM server2VM = vm1;
 
     for (VM vm : toArray(clientVM, server1VM, server2VM)) {
-      vm.invoke(() -> prepareDeltas());
+      vm.invoke(this::prepareDeltas);
     }
 
     int serverPort = server1VM.invoke(() -> {
@@ -776,7 +781,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     VM server2VM = vm1;
 
     for (VM vm : toArray(clientVM, server1VM, server2VM)) {
-      vm.invoke(() -> prepareDeltas());
+      vm.invoke(this::prepareDeltas);
     }
 
     for (VM vm : toArray(server1VM, server2VM)) {
@@ -829,11 +834,11 @@ public class DeltaPropagationDUnitTest implements Serializable {
     });
 
     clientVM.invoke(() -> {
-      await().until(() -> LAST_KEY_RECEIVED.get());
+      await().until(LAST_KEY_RECEIVED::get);
 
-      long toDeltasOnServer1 = server1VM.invoke(() -> DeltaTestImpl.getToDeltaInvokations());
-      long fromDeltasOnServer2 = server2VM.invoke(() -> DeltaTestImpl.getFromDeltaInvokations());
-      long toDeltasOnServer2 = server2VM.invoke(() -> DeltaTestImpl.getToDeltaInvokations());
+      long toDeltasOnServer1 = server1VM.invoke(DeltaTestImpl::getToDeltaInvokations);
+      long fromDeltasOnServer2 = server2VM.invoke(DeltaTestImpl::getFromDeltaInvokations);
+      long toDeltasOnServer2 = server2VM.invoke(DeltaTestImpl::getToDeltaInvokations);
       long fromDeltasOnClient = DeltaTestImpl.getFromDeltaInvokations();
 
       assertThat(toDeltasOnServer1).isEqualTo(EVENTS_SIZE - 1);
@@ -851,7 +856,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     VM server3VM = vm2;
 
     for (VM vm : toArray(clientVM, server1VM, server2VM, server3VM)) {
-      vm.invoke(() -> prepareDeltas());
+      vm.invoke(this::prepareDeltas);
     }
 
     // Do puts after slowing the dispatcher.
@@ -897,7 +902,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
         closeCache();
       });
 
-      await().until(() -> LAST_KEY_RECEIVED.get());
+      await().until(LAST_KEY_RECEIVED::get);
 
       VM primaryServer2VM = pool.getPrimaryPort() == serverPort1 ? server1VM
           : pool.getPrimaryPort() == serverPort2 ? server2VM : server3VM;
@@ -906,7 +911,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
         vm.invoke(() -> LATCH.get().countDown());
       }
 
-      primaryServer2VM.invoke(() -> closeCache());
+      primaryServer2VM.invoke(this::closeCache);
 
       long fromDeltasOnClient = DeltaTestImpl.getFromDeltaInvokations();
       assertThat(fromDeltasOnClient).isEqualTo(EVENTS_SIZE - 1);
@@ -944,7 +949,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
     });
 
     for (VM vm : toArray(clientVM, serverVM)) {
-      vm.invoke(() -> prepareDeltas());
+      vm.invoke(this::prepareDeltas);
     }
 
     String durableClientId = getName() + "_client";
@@ -1076,7 +1081,7 @@ public class DeltaPropagationDUnitTest implements Serializable {
 
     // Step 0
     for (VM vm : toArray(getController(), server1VM, server2VM)) {
-      vm.invoke(() -> prepareDeltas());
+      vm.invoke(this::prepareDeltas);
     }
 
     // Step 1
@@ -1149,13 +1154,13 @@ public class DeltaPropagationDUnitTest implements Serializable {
       InternalPool pool = (InternalPool) PoolManager.getAll().values().stream().findFirst().get();
       VM primaryVM = pool.getPrimaryPort() == serverPort1 ? server1VM : server2VM;
 
-      await().until(() -> MARKER_RECEIVED.get());
+      await().until(MARKER_RECEIVED::get);
 
       // Step 6
-      primaryVM.invoke(() -> closeCache());
+      primaryVM.invoke(this::closeCache);
 
       // Step 7
-      await().until(() -> LAST_KEY_RECEIVED.get());
+      await().until(LAST_KEY_RECEIVED::get);
 
       // Step 8
       long fromDeltasOnClient = DeltaTestImpl.getFromDeltaInvokations();
@@ -1612,7 +1617,14 @@ public class DeltaPropagationDUnitTest implements Serializable {
           clientVersion, acceptorId, notifyBySubscription, securityService, subject,
           statisticsClock,
           notifier.getCache().getInternalDistributedSystem().getStatisticsManager(),
-          DEFAULT_CACHECLIENTPROXYSTATSFACTORY, CustomMessageDispatcher::new);
+          DEFAULT_CACHECLIENTPROXYSTATSFACTORY, CustomMessageDispatcher::new,
+          new ClientUserAuths(subjectIdGeneratorFor(proxyId)));
+    }
+
+    private static SubjectIdGenerator subjectIdGeneratorFor(ClientProxyMembershipID proxyId) {
+      int proxyIdHashCode = proxyId.hashCode();
+      Consumer<Random> initializer = r -> r.setSeed(proxyIdHashCode + System.currentTimeMillis());
+      return new RandomSubjectIdGenerator(new Random(), initializer);
     }
   }
 
