@@ -17,7 +17,6 @@ package org.apache.geode.internal.cache.control;
 import static java.util.concurrent.TimeUnit.SECONDS;
 import static org.apache.geode.distributed.ConfigurationProperties.REDUNDANCY_ZONE;
 import static org.apache.geode.internal.lang.SystemPropertyHelper.DEFAULT_DISK_DIRS_PROPERTY;
-import static org.apache.geode.internal.lang.SystemPropertyHelper.GEODE_PREFIX;
 import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.File;
@@ -31,7 +30,6 @@ import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.stream.Stream;
 
-import junitparams.JUnitParamsRunner;
 import junitparams.Parameters;
 import org.apache.commons.io.FileUtils;
 import org.apache.logging.log4j.Logger;
@@ -45,19 +43,21 @@ import org.apache.geode.cache.Region;
 import org.apache.geode.cache.client.ClientCache;
 import org.apache.geode.cache.control.ResourceManager;
 import org.apache.geode.internal.cache.PartitionedRegion;
+import org.apache.geode.internal.lang.SystemProperty;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.test.awaitility.GeodeAwaitility;
 import org.apache.geode.test.dunit.VM;
 import org.apache.geode.test.dunit.rules.ClientVM;
 import org.apache.geode.test.dunit.rules.ClusterStartupRule;
 import org.apache.geode.test.dunit.rules.MemberVM;
+import org.apache.geode.test.junit.runners.GeodeParamsRunner;
 
 /**
  * The purpose of RebalanceOperationComplexDistributedTest is to test rebalances
  * across zones and to ensure that enforceUniqueZone behavior of redundancy zones
  * is working correctly.
  */
-@RunWith(JUnitParamsRunner.class)
+@RunWith(GeodeParamsRunner.class)
 public class RebalanceOperationComplexDistributedTest implements Serializable {
   public static final int EXPECTED_BUCKET_COUNT = 113;
   public static final long TIMEOUT_SECONDS = GeodeAwaitility.getTimeout().getSeconds();
@@ -69,27 +69,20 @@ public class RebalanceOperationComplexDistributedTest implements Serializable {
 
   public static final String ZONE_A = "zoneA";
   public static final String ZONE_B = "zoneB";
+  private static final String ZONE_C = "zoneC";
+
   public int locatorPort;
   public static final AtomicInteger runID = new AtomicInteger(0);
   public String workingDir;
 
   // 6 servers distributed evenly across 2 zones
-  public static final Map<Integer, String> SERVER_ZONE_MAP = new HashMap<Integer, String>() {
-    {
-      put(1, ZONE_A);
-      put(2, ZONE_A);
-      put(3, ZONE_A);
-      put(4, ZONE_B);
-      put(5, ZONE_B);
-      put(6, ZONE_B);
-    }
-  };
+  public static Map<Integer, String> SERVER_ZONE_MAP;
 
   @Rule
   public ClusterStartupRule clusterStartupRule = new ClusterStartupRule(8);
 
   @Before
-  public void setup() throws Exception {
+  public void setup() {
     // Start the locator
     MemberVM locatorVM = clusterStartupRule.startLocatorVM(0);
     locatorPort = locatorVM.getPort();
@@ -97,16 +90,6 @@ public class RebalanceOperationComplexDistributedTest implements Serializable {
     workingDir = clusterStartupRule.getWorkingDirRoot().getAbsolutePath();
 
     runID.incrementAndGet();
-    cleanOutServerDirectories();
-
-    // Startup the servers
-    for (Map.Entry<Integer, String> entry : SERVER_ZONE_MAP.entrySet()) {
-      startServerInRedundancyZone(entry.getKey(), entry.getValue());
-    }
-
-    // Put data in the server regions
-    clientPopulateServers();
-
   }
 
   @After
@@ -124,9 +107,26 @@ public class RebalanceOperationComplexDistributedTest implements Serializable {
   @Test
   @Parameters({"1,2", "1,4", "4,1", "5,6"})
   public void testEnforceZoneWithSixServersAndTwoZones(int rebalanceServer,
-      int serverToBeShutdownAndRestarted) {
+      int serverToBeShutdownAndRestarted) throws Exception {
+    SERVER_ZONE_MAP = new HashMap<>();
+    SERVER_ZONE_MAP.put(1, ZONE_A);
+    SERVER_ZONE_MAP.put(2, ZONE_A);
+    SERVER_ZONE_MAP.put(3, ZONE_A);
+    SERVER_ZONE_MAP.put(4, ZONE_B);
+    SERVER_ZONE_MAP.put(5, ZONE_B);
+    SERVER_ZONE_MAP.put(6, ZONE_B);
 
-    // Rebalance Server VM will initiate all of the rebalances in this test
+    cleanOutServerDirectories();
+
+    // Startup the servers
+    for (Map.Entry<Integer, String> entry : SERVER_ZONE_MAP.entrySet()) {
+      startServerInRedundancyZone(entry.getKey(), entry.getValue());
+    }
+
+    // Put data in the server regions
+    clientPopulateServers();
+
+    // Rebalance Server VM will initiate the rebalances in this test
     VM rebalanceServerVM = clusterStartupRule.getVM(rebalanceServer);
 
     // Baseline rebalance with everything up
@@ -152,6 +152,78 @@ public class RebalanceOperationComplexDistributedTest implements Serializable {
     compareZoneBucketCounts(REGION_NAME);
   }
 
+
+  /**
+   * This test tests the case that we don't accidentally leave extra copies in a
+   * redundancy zone after a server recovers.
+   *
+   */
+  @Test
+  public void testThreeZonesHaveTwoCopiesAfterRebalance() throws Exception {
+    SERVER_ZONE_MAP = new HashMap<Integer, String>() {
+      {
+        put(1, ZONE_A);
+        put(2, ZONE_B);
+        put(3, ZONE_C);
+      }
+    };
+
+    cleanOutServerDirectories();
+
+    // Startup the servers
+    for (Map.Entry<Integer, String> entry : SERVER_ZONE_MAP.entrySet()) {
+      startServerInRedundancyZone(entry.getKey(), entry.getValue());
+    }
+
+    // Put data in the server regions
+    clientPopulateServers();
+
+    // Rebalance Server VM will initiate the rebalances in this test
+    VM server2 = clusterStartupRule.getVM(2);
+
+    // Baseline rebalance with everything up
+    server2.invoke(() -> doRebalance(ClusterStartupRule.getCache().getResourceManager()));
+
+    // Take the server 1 offline
+    clusterStartupRule.stop(1, false);
+
+    // Rebalance so that now all the buckets are on the other two servers.
+    // Zone b servers should not be touched.
+    server2.invoke(() -> doRebalance(ClusterStartupRule.getCache().getResourceManager()));
+
+    // Restart server 1
+    startServerInRedundancyZone(1, SERVER_ZONE_MAP.get(1));
+    // Rebalance so that now all the buckets are on the other two servers.
+    // Zone b servers should not be touched.
+
+    server2.invoke(() -> doRebalance(ClusterStartupRule.getCache().getResourceManager()));
+
+    int zoneABucketCount = getBucketCount(1);
+    int zoneBBucketCount = getBucketCount(2);
+    int zoneCBucketCount = getBucketCount(3);
+    final int LOWER_BOUND = (EXPECTED_BUCKET_COUNT * 2) / 3;
+    final int UPPER_BOUND = 1 + (EXPECTED_BUCKET_COUNT * 2) / 3;
+    assertThat(zoneABucketCount).isGreaterThanOrEqualTo(LOWER_BOUND)
+        .isLessThanOrEqualTo(UPPER_BOUND);
+    assertThat(zoneBBucketCount).isGreaterThanOrEqualTo(LOWER_BOUND)
+        .isLessThanOrEqualTo(UPPER_BOUND);
+    assertThat(zoneCBucketCount).isGreaterThanOrEqualTo(LOWER_BOUND)
+        .isLessThanOrEqualTo(UPPER_BOUND);
+
+    assertThat(zoneABucketCount + zoneBBucketCount + zoneCBucketCount)
+        .isEqualTo(2 * EXPECTED_BUCKET_COUNT);
+  }
+
+
+  private int getBucketCount(int server) {
+    return clusterStartupRule.getVM(server).invoke(() -> {
+      PartitionedRegion region =
+          (PartitionedRegion) ClusterStartupRule.getCache().getRegion(REGION_NAME);
+      return region.getLocalBucketsListTestOnly().size();
+    });
+  }
+
+
   private void stopServersAndDeleteDirectories() {
     for (Map.Entry<Integer, String> entry : SERVER_ZONE_MAP.entrySet()) {
       clusterStartupRule.stop(entry.getKey(), true);
@@ -217,7 +289,7 @@ public class RebalanceOperationComplexDistributedTest implements Serializable {
       if (!temporaryDirectory.exists()) {
         Files.createDirectory(temporaryDirectory.toPath());
       }
-      System.setProperty(GEODE_PREFIX + DEFAULT_DISK_DIRS_PROPERTY, path);
+      System.setProperty(SystemProperty.DEFAULT_PREFIX + DEFAULT_DISK_DIRS_PROPERTY, path);
     });
 
     clusterStartupRule.startServerVM(index, s -> s.withProperty("cache-xml-file",
@@ -259,12 +331,7 @@ public class RebalanceOperationComplexDistributedTest implements Serializable {
     int bucketCount = 0;
     for (Map.Entry<Integer, String> entry : SERVER_ZONE_MAP.entrySet()) {
       if (entry.getValue().compareTo(zoneName) == 0) {
-        bucketCount +=
-            clusterStartupRule.getVM(entry.getKey()).invoke(() -> {
-              PartitionedRegion region =
-                  (PartitionedRegion) ClusterStartupRule.getCache().getRegion(regionName);
-              return region.getLocalBucketsListTestOnly().size();
-            });
+        bucketCount += getBucketCount(entry.getKey());
       }
     }
     return bucketCount;
