@@ -19,7 +19,6 @@ import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 
 import java.io.File;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.Properties;
 
@@ -199,16 +198,17 @@ public class EvictionStatsDUnitTest extends CacheTestCase {
     createCache();
     createPartitionedRegion(true, EvictionAlgorithm.LRU_ENTRY, "PR1", 2, 1, 10000);
     for (int counter = 1; counter <= maxEntries; counter++) {
-      region.put(new Integer(counter), new byte[(1 * 1024 * 1024) - 2]);
+      region.put(counter, new byte[(1 * 1024 * 1024) - 2]);
     }
     PartitionedRegion pr = (PartitionedRegion) region;
     long sizeOfPRegion = pr.getEvictionCounter();
 
     assertEquals(sizeOfPRegion, 20);
     long bucketSize = 0;
-    for (final Iterator i =
-        ((PartitionedRegion) region).getDataStore().getAllLocalBuckets().iterator(); i.hasNext();) {
-      final Map.Entry entry = (Map.Entry) i.next();
+    for (final Map.Entry<Integer, BucketRegion> regionEntry : ((PartitionedRegion) region)
+        .getDataStore()
+        .getAllLocalBuckets()) {
+      final Map.Entry entry = (Map.Entry) regionEntry;
       final BucketRegion bucketRegion = (BucketRegion) entry.getValue();
       if (bucketRegion == null) {
         continue;
@@ -222,12 +222,13 @@ public class EvictionStatsDUnitTest extends CacheTestCase {
     bucketSize = 0;
     final int extraEnteries = 4;
     for (int counter = 1; counter <= extraEnteries; counter++) {
-      region.put(new Integer(counter), new byte[(1 * 1024 * 1024) - 2]);
+      region.put(counter, new byte[(1 * 1024 * 1024) - 2]);
     }
     sizeOfPRegion = pr.getEvictionCounter();
     assertEquals(sizeOfPRegion, 20);
-    for (final Iterator i = pr.getDataStore().getAllLocalBuckets().iterator(); i.hasNext();) {
-      final Map.Entry entry = (Map.Entry) i.next();
+    for (final Map.Entry<Integer, BucketRegion> bucketRegionEntry : pr.getDataStore()
+        .getAllLocalBuckets()) {
+      final Map.Entry entry = (Map.Entry) bucketRegionEntry;
       final BucketRegion bucketRegion = (BucketRegion) entry.getValue();
       if (bucketRegion == null) {
         continue;
@@ -238,8 +239,9 @@ public class EvictionStatsDUnitTest extends CacheTestCase {
     assertEquals(sizeOfPRegion, bucketSize);
 
     // Clear one bucket
-    for (final Iterator i = pr.getDataStore().getAllLocalBuckets().iterator(); i.hasNext();) {
-      final Map.Entry entry = (Map.Entry) i.next();
+    for (final Map.Entry<Integer, BucketRegion> integerBucketRegionEntry : pr.getDataStore()
+        .getAllLocalBuckets()) {
+      final Map.Entry entry = (Map.Entry) integerBucketRegionEntry;
       final BucketRegion bucketRegion = (BucketRegion) entry.getValue();
       if (bucketRegion == null) {
         continue;
@@ -456,7 +458,7 @@ public class EvictionStatsDUnitTest extends CacheTestCase {
       public void run2() throws CacheException {
         final Region pr = cache.getRegion(regionName);
         for (int counter = 1; counter <= noOfElememts; counter++) {
-          pr.put(new Integer(counter), new byte[1 * 1024 * 1024]);
+          pr.put(counter, new byte[1 * 1024 * 1024]);
           // getLogWriter().info("Deep put data element no->" + counter);
         }
       }
@@ -466,9 +468,9 @@ public class EvictionStatsDUnitTest extends CacheTestCase {
   private long getPRCounter(String prRegionName) {
     final long ONE_MEG = 1024L * 1024L;
     long sizeOfPR = 0;
-    sizeOfPR = sizeOfPR + (Long) dataStore1
+    sizeOfPR = sizeOfPR + dataStore1
         .invoke(() -> EvictionStatsDUnitTest.getPartionRegionCounter(prRegionName));
-    sizeOfPR = sizeOfPR + (Long) dataStore2
+    sizeOfPR = sizeOfPR + dataStore2
         .invoke(() -> EvictionStatsDUnitTest.getPartionRegionCounter(prRegionName));
     return sizeOfPR / ONE_MEG;
   }
@@ -482,9 +484,9 @@ public class EvictionStatsDUnitTest extends CacheTestCase {
     final long ONE_MEG = 1024L * 1024L;
     long totalBucketSize = 0;
     totalBucketSize = totalBucketSize
-        + (Long) dataStore1.invoke(() -> EvictionStatsDUnitTest.getCounterForBuckets(prRegionName));
+        + dataStore1.invoke(() -> EvictionStatsDUnitTest.getCounterForBuckets(prRegionName));
     totalBucketSize = totalBucketSize
-        + (Long) dataStore2.invoke(() -> EvictionStatsDUnitTest.getCounterForBuckets(prRegionName));
+        + dataStore2.invoke(() -> EvictionStatsDUnitTest.getCounterForBuckets(prRegionName));
     return totalBucketSize / ONE_MEG;
 
   }
@@ -492,8 +494,9 @@ public class EvictionStatsDUnitTest extends CacheTestCase {
   public static long getCounterForBuckets(String prRegionName) {
     long bucketSize = 0;
     final PartitionedRegion pr = (PartitionedRegion) cache.getRegion(prRegionName);
-    for (final Iterator i = pr.getDataStore().getAllLocalBuckets().iterator(); i.hasNext();) {
-      final Map.Entry entry = (Map.Entry) i.next();
+    for (final Map.Entry<Integer, BucketRegion> integerBucketRegionEntry : pr.getDataStore()
+        .getAllLocalBuckets()) {
+      final Map.Entry entry = (Map.Entry) integerBucketRegionEntry;
       final BucketRegion bucketRegion = (BucketRegion) entry.getValue();
       if (bucketRegion == null) {
         continue;
