@@ -17,11 +17,9 @@ package org.apache.geode.internal.cache.execute;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatNoException;
 
-import java.io.IOException;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -46,6 +44,7 @@ import org.apache.geode.cache.Region;
 import org.apache.geode.cache.RegionAttributes;
 import org.apache.geode.cache.Scope;
 import org.apache.geode.cache.client.Pool;
+import org.apache.geode.cache.client.PoolFactory;
 import org.apache.geode.cache.client.PoolManager;
 import org.apache.geode.cache.client.internal.PoolImpl;
 import org.apache.geode.cache.execute.Function;
@@ -57,8 +56,6 @@ import org.apache.geode.distributed.DistributedSystem;
 import org.apache.geode.internal.cache.functions.TestFunction;
 import org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil;
 import org.apache.geode.logging.internal.log4j.api.LogService;
-import org.apache.geode.test.dunit.Assert;
-import org.apache.geode.test.dunit.Host;
 import org.apache.geode.test.dunit.NetworkUtils;
 import org.apache.geode.test.dunit.SerializableCallableIF;
 import org.apache.geode.test.dunit.SerializableRunnable;
@@ -79,6 +76,8 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
 
   protected static Cache cache = null;
 
+  protected String hostName;
+
   static String PartitionedRegionName = "TestPartitionedRegion"; // default name
 
   protected static String regionName = "TestRegion"; // default name
@@ -93,15 +92,15 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
 
   @Override
   public final void postSetUp() throws Exception {
-    Host host = Host.getHost(0);
-    server1 = host.getVM(0);
-    server2 = host.getVM(1);
-    server3 = host.getVM(2);
-    client = host.getVM(3);
+    server1 = VM.getVM(0);
+    server2 = VM.getVM(1);
+    server3 = VM.getVM(2);
+    client = VM.getVM(3);
+    hostName = NetworkUtils.getServerHostName();
     postSetUpPRClientServerTestBase();
   }
 
-  protected void postSetUpPRClientServerTestBase() throws Exception {}
+  protected void postSetUpPRClientServerTestBase() {}
 
   private enum ExecuteFunctionMethod {
     ExecuteFunctionByObject, ExecuteFunctionById
@@ -119,7 +118,8 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
     return ExecuteFunctionMethod.ExecuteFunctionByObject == functionExecutionType;
   }
 
-  ArrayList createCommonServerAttributes(String regionName, PartitionResolver pr, int red,
+  ArrayList<Object> createCommonServerAttributes(String regionName, PartitionResolver<?, ?> pr,
+      int red,
       String colocatedWithRegion) {
     ArrayList<Object> commonAttributes = new ArrayList<>();
     commonAttributes.add(regionName); // 0
@@ -130,123 +130,111 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
     return commonAttributes;
   }
 
-  public static Integer createCacheServer(ArrayList commonAttributes, Integer localMaxMemory) {
-    AttributesFactory factory = new AttributesFactory();
-    PartitionAttributesFactory paf = new PartitionAttributesFactory();
+  public static Integer createCacheServer(ArrayList<Object> commonAttributes,
+      Integer localMaxMemory) {
+    return createCacheServer(commonAttributes, localMaxMemory, -1);
+  }
 
-    paf.setPartitionResolver((PartitionResolver) commonAttributes.get(1));
+  public static Integer createCacheServer(ArrayList<Object> commonAttributes,
+      Integer localMaxMemory,
+      int maxThreads) {
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
+    PartitionAttributesFactory<Object, Object> paf = new PartitionAttributesFactory<>();
+
+    paf.setPartitionResolver((PartitionResolver<Object, Object>) commonAttributes.get(1));
     paf.setRedundantCopies((Integer) commonAttributes.get(2));
     paf.setTotalNumBuckets((Integer) commonAttributes.get(3));
     paf.setColocatedWith((String) commonAttributes.get(4));
     paf.setLocalMaxMemory(localMaxMemory);
-    PartitionAttributes partitionAttributes = paf.create();
+    PartitionAttributes<?, ?> partitionAttributes = paf.create();
     factory.setDataPolicy(DataPolicy.PARTITION);
     factory.setPartitionAttributes(partitionAttributes);
-    RegionAttributes attrs = factory.create();
+    RegionAttributes<Object, Object> attrs = factory.create();
 
-    Region region = cache.createRegion((String) commonAttributes.get(0), attrs);
-    assertNotNull(region);
+    Region<Object, Object> region = cache.createRegion((String) commonAttributes.get(0), attrs);
+    assertThat(region).isNotNull();
     CacheServer server1 = cache.addCacheServer();
-    assertNotNull(server1);
+    assertThat(server1).isNotNull();
     int port = getRandomAvailableTCPPort();
     server1.setPort(port);
-    try {
-      server1.start();
-    } catch (IOException e) {
-      Assert.fail("Failed to start the Server", e);
+    if (maxThreads > 0) {
+      server1.setMaxThreads(maxThreads);
     }
-    assertTrue(server1.isRunning());
+    assertThatNoException().isThrownBy(server1::start);
+    assertThat(server1.isRunning()).isTrue();
 
     return server1.getPort();
   }
 
-  private static Integer createSelectorCacheServer(ArrayList commonAttributes,
+  private static Integer createSelectorCacheServer(ArrayList<Object> commonAttributes,
       Integer localMaxMemory) throws Exception {
-    AttributesFactory factory = new AttributesFactory();
-    PartitionAttributesFactory paf = new PartitionAttributesFactory();
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
+    PartitionAttributesFactory<Object, Object> paf = new PartitionAttributesFactory<>();
 
-    paf.setPartitionResolver((PartitionResolver) commonAttributes.get(1));
+    paf.setPartitionResolver((PartitionResolver<Object, Object>) commonAttributes.get(1));
     paf.setRedundantCopies((Integer) commonAttributes.get(2));
     paf.setTotalNumBuckets((Integer) commonAttributes.get(3));
     paf.setColocatedWith((String) commonAttributes.get(4));
     paf.setLocalMaxMemory(localMaxMemory);
-    PartitionAttributes partitionAttributes = paf.create();
+    PartitionAttributes<?, ?> partitionAttributes = paf.create();
     factory.setDataPolicy(DataPolicy.PARTITION);
     factory.setPartitionAttributes(partitionAttributes);
-    RegionAttributes attrs = factory.create();
+    RegionAttributes<Object, Object> attrs = factory.create();
 
-    Region region = cache.createRegion((String) commonAttributes.get(0), attrs);
-    assertNotNull(region);
+    Region<Object, Object> region = cache.createRegion((String) commonAttributes.get(0), attrs);
+    assertThat(region).isNotNull();
     CacheServer server1 = cache.addCacheServer();
-    assertNotNull(server1);
+    assertThat(server1).isNotNull();
     int port = getRandomAvailableTCPPort();
     server1.setPort(port);
     server1.setMaxThreads(16);
     server1.start();
-    assertTrue(server1.isRunning());
+    assertThat(server1.isRunning()).isTrue();
 
     return server1.getPort();
   }
 
-  private static Integer createCacheServerWith2Regions(ArrayList commonAttributes,
+  private static Integer createCacheServerWith2Regions(ArrayList<Object> commonAttributes,
       Integer localMaxMemory) throws Exception {
-    AttributesFactory factory = new AttributesFactory();
-    PartitionAttributesFactory paf = new PartitionAttributesFactory();
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
+    PartitionAttributesFactory<Object, Object> paf = new PartitionAttributesFactory<>();
 
-    paf.setPartitionResolver((PartitionResolver) commonAttributes.get(1));
+    paf.setPartitionResolver((PartitionResolver<Object, Object>) commonAttributes.get(1));
     paf.setRedundantCopies((Integer) commonAttributes.get(2));
     paf.setTotalNumBuckets((Integer) commonAttributes.get(3));
     paf.setColocatedWith((String) commonAttributes.get(4));
     paf.setLocalMaxMemory(localMaxMemory);
-    PartitionAttributes partitionAttributes = paf.create();
+    PartitionAttributes<?, ?> partitionAttributes = paf.create();
     factory.setDataPolicy(DataPolicy.PARTITION);
     factory.setPartitionAttributes(partitionAttributes);
-    RegionAttributes attrs = factory.create();
+    RegionAttributes<Object, Object> attrs = factory.create();
 
-    Region region1 = cache.createRegion(PartitionedRegionName + "1", attrs);
-    assertNotNull(region1);
-    Region region2 = cache.createRegion(PartitionedRegionName + "2", attrs);
-    assertNotNull(region2);
+    Region<Object, Object> region1 = cache.createRegion(PartitionedRegionName + "1", attrs);
+    assertThat(region1).isNotNull();
+    Region<Object, Object> region2 = cache.createRegion(PartitionedRegionName + "2", attrs);
+    assertThat(region2).isNotNull();
     CacheServer server1 = cache.addCacheServer();
-    assertNotNull(server1);
+    assertThat(server1).isNotNull();
     int port = getRandomAvailableTCPPort();
     server1.setPort(port);
     server1.start();
-    assertTrue(server1.isRunning());
+    assertThat(server1.isRunning()).isTrue();
 
     return server1.getPort();
   }
 
   public static Integer createCacheServer() throws Exception {
     CacheServer server1 = cache.addCacheServer();
-    assertNotNull(server1);
+    assertThat(server1).isNotNull();
     int port = getRandomAvailableTCPPort();
     server1.setPort(port);
     server1.start();
-    assertTrue(server1.isRunning());
+    assertThat(server1.isRunning()).isTrue();
 
     return server1.getPort();
   }
 
-  private static Integer createCacheServerWithDR() throws Exception {
-    AttributesFactory factory = new AttributesFactory();
-    factory.setScope(Scope.DISTRIBUTED_ACK);
-    factory.setDataPolicy(DataPolicy.REPLICATE);
-    assertNotNull(cache);
-    Region region = cache.createRegion(regionName, factory.create());
-    assertNotNull(region);
-
-    CacheServer server1 = cache.addCacheServer();
-    assertNotNull(server1);
-    int port = getRandomAvailableTCPPort();
-    server1.setPort(port);
-    server1.start();
-    assertTrue(server1.isRunning());
-
-    return server1.getPort();
-  }
-
-  public static void createCacheClient(String host, Integer port1, Integer port2, Integer port3) {
+  public static void createCacheClient(String host, int port1, int port2, int port3) {
     CacheServerTestUtil.disableShufflingOfEndpoints();
     Pool p;
 
@@ -260,16 +248,16 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
       CacheServerTestUtil.enableShufflingOfEndpoints();
     }
     pool = (PoolImpl) p;
-    AttributesFactory factory = new AttributesFactory();
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
     factory.setScope(Scope.LOCAL);
     factory.setDataPolicy(DataPolicy.EMPTY);
     factory.setPoolName(p.getName());
-    RegionAttributes attrs = factory.create();
-    Region region = cache.createRegion(PartitionedRegionName, attrs);
-    assertNotNull(region);
+    RegionAttributes<Object, Object> attrs = factory.create();
+    Region<Object, Object> region = cache.createRegion(PartitionedRegionName, attrs);
+    assertThat(region).isNotNull();
   }
 
-  private static void createCacheClient_SingleConnection(String host, Integer port1) {
+  private static void createCacheClient_SingleConnection(String host, int port1) {
     CacheServerTestUtil.disableShufflingOfEndpoints();
     Pool p;
 
@@ -282,17 +270,17 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
       CacheServerTestUtil.enableShufflingOfEndpoints();
     }
     pool = (PoolImpl) p;
-    AttributesFactory factory = new AttributesFactory();
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
     factory.setScope(Scope.LOCAL);
     factory.setDataPolicy(DataPolicy.EMPTY);
     factory.setPoolName(p.getName());
-    RegionAttributes attrs = factory.create();
-    Region region = cache.createRegion(PartitionedRegionName, attrs);
-    assertNotNull(region);
+    RegionAttributes<Object, Object> attrs = factory.create();
+    Region<Object, Object> region = cache.createRegion(PartitionedRegionName, attrs);
+    assertThat(region).isNotNull();
   }
 
-  private static void createCacheClientWith2Regions(String host, Integer port1, Integer port2,
-      Integer port3) {
+  private static void createCacheClientWith2Regions(String host, int port1, int port2,
+      int port3) {
     CacheServerTestUtil.disableShufflingOfEndpoints();
     Pool p;
 
@@ -306,22 +294,22 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
       CacheServerTestUtil.enableShufflingOfEndpoints();
     }
     pool = (PoolImpl) p;
-    AttributesFactory factory = new AttributesFactory();
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
     factory.setDataPolicy(DataPolicy.EMPTY);
     factory.setPoolName(p.getName());
-    RegionAttributes attrs = factory.create();
-    Region region1 = cache.createRegion(PartitionedRegionName + "1", attrs);
-    assertNotNull(region1);
+    RegionAttributes<Object, Object> attrs = factory.create();
+    Region<Object, Object> region1 = cache.createRegion(PartitionedRegionName + "1", attrs);
+    assertThat(region1).isNotNull();
 
-    factory = new AttributesFactory();
+    factory = new AttributesFactory<>();
     factory.setDataPolicy(DataPolicy.EMPTY);
     attrs = factory.create();
-    Region region2 = cache.createRegion(PartitionedRegionName + "2", attrs);
-    assertNotNull(region2);
+    Region<Object, Object> region2 = cache.createRegion(PartitionedRegionName + "2", attrs);
+    assertThat(region2).isNotNull();
   }
 
-  private static void createSingleHopCacheClient(String host, Integer port1, Integer port2,
-      Integer port3) {
+  private static void createSingleHopCacheClient(String host, int port1, int port2,
+      int port3) {
     CacheServerTestUtil.disableShufflingOfEndpoints();
 
     Pool p;
@@ -335,17 +323,17 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
       CacheServerTestUtil.enableShufflingOfEndpoints();
     }
     pool = (PoolImpl) p;
-    AttributesFactory factory = new AttributesFactory();
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
     factory.setScope(Scope.LOCAL);
     factory.setDataPolicy(DataPolicy.EMPTY);
     factory.setPoolName(p.getName());
-    RegionAttributes attrs = factory.create();
-    Region region = cache.createRegion(PartitionedRegionName, attrs);
-    assertNotNull(region);
+    RegionAttributes<Object, Object> attrs = factory.create();
+    Region<Object, Object> region = cache.createRegion(PartitionedRegionName, attrs);
+    assertThat(region).isNotNull();
   }
 
-  private static void createNoSingleHopCacheClient(String host, Integer port1, Integer port2,
-      Integer port3) {
+  private static void createNoSingleHopCacheClient(String host, int port1, int port2,
+      int port3) {
     CacheServerTestUtil.disableShufflingOfEndpoints();
 
     Pool p;
@@ -359,17 +347,44 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
       CacheServerTestUtil.enableShufflingOfEndpoints();
     }
     pool = (PoolImpl) p;
-    AttributesFactory factory = new AttributesFactory();
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
     factory.setScope(Scope.LOCAL);
     factory.setDataPolicy(DataPolicy.EMPTY);
     factory.setPoolName(p.getName());
-    RegionAttributes attrs = factory.create();
-    Region region = cache.createRegion(PartitionedRegionName, attrs);
-    assertNotNull(region);
+    RegionAttributes<Object, Object> attrs = factory.create();
+    Region<Object, Object> region = cache.createRegion(PartitionedRegionName, attrs);
+    assertThat(region).isNotNull();
   }
 
-  private static void createCacheClientWithoutRegion(String host, Integer port1, Integer port2,
-      Integer port3) {
+  private static void createNoSingleHopCacheClient(String host,
+      int port1, int port2, int port3, int connectTimeout) {
+    CacheServerTestUtil.disableShufflingOfEndpoints();
+
+    Pool p;
+    try {
+      PoolFactory factory = PoolManager.createFactory().addServer(host, port1)
+          .addServer(host, port2).addServer(host, port3).setPingInterval(2000)
+          .setSubscriptionEnabled(true).setReadTimeout(2000)
+          .setSocketBufferSize(1000).setRetryAttempts(0)
+          .setSocketConnectTimeout(connectTimeout)
+          .setPRSingleHopEnabled(false);
+
+      p = factory.create("PRClientServerTestBase");
+    } finally {
+      CacheServerTestUtil.enableShufflingOfEndpoints();
+    }
+    pool = (PoolImpl) p;
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
+    factory.setScope(Scope.LOCAL);
+    factory.setDataPolicy(DataPolicy.EMPTY);
+    factory.setPoolName(p.getName());
+    RegionAttributes<Object, Object> attrs = factory.create();
+    Region<Object, Object> region = cache.createRegion(PartitionedRegionName, attrs);
+    assertThat(region).isNotNull();
+  }
+
+  private static void createCacheClientWithoutRegion(String host, int port1, int port2,
+      int port3) {
     CacheServerTestUtil.disableShufflingOfEndpoints();
     logger
         .info("PRClientServerTestBase#createCacheClientWithoutRegion : creating pool");
@@ -387,81 +402,56 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
     pool = (PoolImpl) p;
   }
 
-  private static void createCacheClientWithDistributedRegion(String host, Integer port1,
-      Integer port2, Integer port3) throws Exception {
-    CacheServerTestUtil.disableShufflingOfEndpoints();
-    logger
-        .info("PRClientServerTestBase#createCacheClientWithoutRegion : creating pool");
-
-    Pool p;
-    try {
-      p = PoolManager.createFactory().addServer(host, port1)
-          .addServer(host, port2).addServer(host, port3).setPingInterval(250)
-          .setSubscriptionEnabled(true).setSubscriptionRedundancy(-1).setReadTimeout(2000)
-          .setSocketBufferSize(1000).setMinConnections(6).setMaxConnections(10).setRetryAttempts(0)
-          .create("PRClientServerTestBaseWithoutRegion");
-    } finally {
-      CacheServerTestUtil.enableShufflingOfEndpoints();
-    }
-    pool = (PoolImpl) p;
-    AttributesFactory factory = new AttributesFactory();
-    factory.setScope(Scope.DISTRIBUTED_ACK);
-    factory.setDataPolicy(DataPolicy.REPLICATE);
-    assertNotNull(cache);
-    Region region = cache.createRegion(regionName, factory.create());
-    assertNotNull(region);
-  }
-
-  void createClientServerScenarion(ArrayList commonAttributes, int localMaxMemoryServer1,
+  void createClientServerScenarion(ArrayList<Object> commonAttributes, int localMaxMemoryServer1,
       int localMaxMemoryServer2, int localMaxMemoryServer3) {
     createCacheInClientServer();
-    Integer port1 = server1.invoke(() -> PRClientServerTestBase
+    int port1 = server1.invoke(() -> PRClientServerTestBase
         .createCacheServer(commonAttributes, localMaxMemoryServer1));
-    Integer port2 = server2.invoke(() -> PRClientServerTestBase
+    int port2 = server2.invoke(() -> PRClientServerTestBase
         .createCacheServer(commonAttributes, localMaxMemoryServer2));
-    Integer port3 = server3.invoke(() -> PRClientServerTestBase
+    int port3 = server3.invoke(() -> PRClientServerTestBase
         .createCacheServer(commonAttributes, localMaxMemoryServer3));
     client.invoke(() -> PRClientServerTestBase
-        .createCacheClient(NetworkUtils.getServerHostName(server1.getHost()), port1, port2, port3));
+        .createCacheClient(hostName, port1, port2, port3));
   }
 
-  void createClientServerScenarion_SingleConnection(ArrayList commonAttributes,
+  void createClientServerScenarion_SingleConnection(ArrayList<Object> commonAttributes,
       int localMaxMemoryServer1,
       int localMaxMemoryServer2) {
     createCacheInClientServer();
-    Integer port1 = server1.invoke(() -> PRClientServerTestBase
+    int port1 = server1.invoke(() -> PRClientServerTestBase
         .createCacheServer(commonAttributes, localMaxMemoryServer1));
     server2.invoke(() -> PRClientServerTestBase.createCacheServer(commonAttributes,
         localMaxMemoryServer2));
     client.invoke(() -> PRClientServerTestBase.createCacheClient_SingleConnection(
-        NetworkUtils.getServerHostName(server1.getHost()), port1));
+        hostName, port1));
   }
 
 
 
-  void createClientServerScenarionWith2Regions(ArrayList commonAttributes,
+  void createClientServerScenarionWith2Regions(ArrayList<Object> commonAttributes,
       int localMaxMemoryServer1, int localMaxMemoryServer2,
       int localMaxMemoryServer3) {
     createCacheInClientServer();
-    Integer port1 = server1.invoke(() -> PRClientServerTestBase
+    int port1 = server1.invoke(() -> PRClientServerTestBase
         .createCacheServerWith2Regions(commonAttributes, localMaxMemoryServer1));
-    Integer port2 = server2.invoke(() -> PRClientServerTestBase
+    int port2 = server2.invoke(() -> PRClientServerTestBase
         .createCacheServerWith2Regions(commonAttributes, localMaxMemoryServer2));
-    Integer port3 = server3.invoke(() -> PRClientServerTestBase
+    int port3 = server3.invoke(() -> PRClientServerTestBase
         .createCacheServerWith2Regions(commonAttributes, localMaxMemoryServer3));
     client.invoke(() -> PRClientServerTestBase.createCacheClientWith2Regions(
-        NetworkUtils.getServerHostName(server1.getHost()), port1, port2, port3));
+        hostName, port1, port2, port3));
   }
 
-  void createClientServerScenarioSingleHop(ArrayList commonAttributes,
+  void createClientServerScenarioSingleHop(ArrayList<Object> commonAttributes,
       int localMaxMemoryServer1, int localMaxMemoryServer2,
       int localMaxMemoryServer3) {
     createCacheInClientServer();
-    Integer port1 = server1.invoke(() -> PRClientServerTestBase
+    int port1 = server1.invoke(() -> PRClientServerTestBase
         .createCacheServer(commonAttributes, localMaxMemoryServer1));
-    Integer port2 = server2.invoke(() -> PRClientServerTestBase
+    int port2 = server2.invoke(() -> PRClientServerTestBase
         .createCacheServer(commonAttributes, localMaxMemoryServer2));
-    Integer port3 = server3.invoke(() -> PRClientServerTestBase
+    int port3 = server3.invoke(() -> PRClientServerTestBase
         .createCacheServer(commonAttributes, localMaxMemoryServer3));
     // Workaround for the issue that hostnames returned by the client metadata may
     // not match those configured by the pool, leading to multiple copies
@@ -475,33 +465,49 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
     return cache.getDistributedSystem().getDistributedMember().getHost();
   }
 
-  void createClientServerScenarioNoSingleHop(ArrayList commonAttributes,
+  void createClientServerScenarioNoSingleHop(ArrayList<Object> commonAttributes,
       int localMaxMemoryServer1, int localMaxMemoryServer2,
       int localMaxMemoryServer3) {
     createCacheInClientServer();
-    Integer port1 = server1.invoke(() -> PRClientServerTestBase
+    int port1 = server1.invoke(() -> PRClientServerTestBase
         .createCacheServer(commonAttributes, localMaxMemoryServer1));
-    Integer port2 = server2.invoke(() -> PRClientServerTestBase
+    int port2 = server2.invoke(() -> PRClientServerTestBase
         .createCacheServer(commonAttributes, localMaxMemoryServer2));
-    Integer port3 = server3.invoke(() -> PRClientServerTestBase
+    int port3 = server3.invoke(() -> PRClientServerTestBase
         .createCacheServer(commonAttributes, localMaxMemoryServer3));
     client.invoke(() -> PRClientServerTestBase.createNoSingleHopCacheClient(
-        NetworkUtils.getServerHostName(server1.getHost()), port1, port2, port3));
+        hostName, port1, port2, port3));
   }
 
-  void createClientServerScenarioSelectorNoSingleHop(ArrayList commonAttributes,
+  void createClientServerScenarioNoSingleHop(ArrayList<Object> commonAttributes,
+      int localMaxMemoryServer1, int localMaxMemoryServer2,
+      int localMaxMemoryServer3,
+      int maxThreads,
+      int connectTimeout) {
+    createCacheInClientServer();
+    int port1 = server1.invoke(() -> PRClientServerTestBase
+        .createCacheServer(commonAttributes, localMaxMemoryServer1, maxThreads));
+    int port2 = server2.invoke(() -> PRClientServerTestBase
+        .createCacheServer(commonAttributes, localMaxMemoryServer2, maxThreads));
+    int port3 = server3.invoke(() -> PRClientServerTestBase
+        .createCacheServer(commonAttributes, localMaxMemoryServer3, maxThreads));
+    client.invoke(() -> PRClientServerTestBase.createNoSingleHopCacheClient(
+        hostName, port1, port2, port3, connectTimeout));
+  }
+
+  void createClientServerScenarioSelectorNoSingleHop(ArrayList<Object> commonAttributes,
       int localMaxMemoryServer1,
       int localMaxMemoryServer2,
       int localMaxMemoryServer3) {
     createCacheInClientServer();
-    Integer port1 = server1.invoke(() -> PRClientServerTestBase
+    int port1 = server1.invoke(() -> PRClientServerTestBase
         .createSelectorCacheServer(commonAttributes, localMaxMemoryServer1));
-    Integer port2 = server2.invoke(() -> PRClientServerTestBase
+    int port2 = server2.invoke(() -> PRClientServerTestBase
         .createSelectorCacheServer(commonAttributes, localMaxMemoryServer2));
-    Integer port3 = server3.invoke(() -> PRClientServerTestBase
+    int port3 = server3.invoke(() -> PRClientServerTestBase
         .createSelectorCacheServer(commonAttributes, localMaxMemoryServer3));
     client.invoke(() -> PRClientServerTestBase.createNoSingleHopCacheClient(
-        NetworkUtils.getServerHostName(server1.getHost()), port1, port2, port3));
+        hostName, port1, port2, port3));
   }
 
 
@@ -509,15 +515,15 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
     logger.info(
         "PRClientServerTestBase#createClientServerScenarionWithoutRegion : creating client server");
     createCacheInClientServer();
-    Integer port1 = server1.invoke(
+    int port1 = server1.invoke(
         (SerializableCallableIF<Integer>) PRClientServerTestBase::createCacheServer);
-    Integer port2 = server2.invoke(
+    int port2 = server2.invoke(
         (SerializableCallableIF<Integer>) PRClientServerTestBase::createCacheServer);
-    Integer port3 = server3.invoke(
+    int port3 = server3.invoke(
         (SerializableCallableIF<Integer>) PRClientServerTestBase::createCacheServer);
 
     client.invoke(() -> PRClientServerTestBase.createCacheClientWithoutRegion(
-        NetworkUtils.getServerHostName(server1.getHost()), port1, port2, port3));
+        hostName, port1, port2, port3));
   }
 
   void runOnAllServers(SerializableRunnable runnable) {
@@ -526,7 +532,7 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
     server3.invoke(runnable);
   }
 
-  void registerFunctionAtServer(Function function) {
+  void registerFunctionAtServer(Function<?> function) {
     server1.invoke(PRClientServerTestBase.class, "registerFunction", new Object[] {function});
 
     server2.invoke(PRClientServerTestBase.class, "registerFunction", new Object[] {function});
@@ -534,7 +540,7 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
     server3.invoke(PRClientServerTestBase.class, "registerFunction", new Object[] {function});
   }
 
-  public static void registerFunction(Function function) {
+  public static void registerFunction(Function<?> function) {
     FunctionService.registerFunction(function);
   }
 
@@ -559,24 +565,20 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
   }
 
   private void createCache(Properties props) {
-    try {
-      DistributedSystem ds = getSystem(props);
-      assertNotNull(ds);
-      ds.disconnect();
-      ds = getSystem(props);
-      cache = CacheFactory.create(ds);
-      assertNotNull(cache);
-    } catch (Exception e) {
-      Assert.fail("Failed while creating the cache", e);
-    }
+    DistributedSystem ds = getSystem(props);
+    assertThat(ds).isNotNull();
+    ds.disconnect();
+    ds = getSystem(props);
+    cache = CacheFactory.create(ds);
+    assertThat(cache).isNotNull();
   }
 
   static void startServerHA() throws Exception {
     Wait.pause(2000);
-    Collection bridgeServers = cache.getCacheServers();
+    Collection<?> bridgeServers = cache.getCacheServers();
     logger
         .info("Start Server cache servers list : " + bridgeServers.size());
-    Iterator bridgeIterator = bridgeServers.iterator();
+    Iterator<?> bridgeIterator = bridgeServers.iterator();
     CacheServer bridgeServer = (CacheServer) bridgeIterator.next();
     logger.info("start Server cache server" + bridgeServer);
     bridgeServer.start();
@@ -584,7 +586,7 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
 
   static void stopServerHA() {
     Wait.pause(1000);
-    Iterator iter = cache.getCacheServers().iterator();
+    Iterator<?> iter = cache.getCacheServers().iterator();
     if (iter.hasNext()) {
       CacheServer server = (CacheServer) iter.next();
       server.stop();
@@ -616,13 +618,13 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
 
   void serverBucketFilterExecution(Set<Integer> bucketFilterSet) {
     Region<Integer, Integer> region = cache.getRegion(PartitionedRegionName);
-    assertNotNull(region);
+    assertThat(region).isNotNull();
     final HashSet<Integer> testKeysSet = new HashSet<>();
     for (int i = 150; i > 0; i--) {
       testKeysSet.add(i);
     }
     DistributedSystem.setThreadsSocketPolicy(false);
-    Function function = new TestFunction(true, TestFunction.TEST_FUNCTION_BUCKET_FILTER);
+    Function<?> function = new TestFunction<>(true, TestFunction.TEST_FUNCTION_BUCKET_FILTER);
     if (shouldRegisterFunctionsOnClient()) {
       FunctionService.registerFunction(function);
     }
@@ -636,24 +638,24 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
     ResultCollector<Integer, List<Integer>> rc =
         dataSet.withBucketFilter(bucketFilterSet).execute(function.getId());
     List<Integer> results = rc.getResult();
-    assertEquals(bucketFilterSet.size(), results.size());
+    assertThat(results.size()).isEqualTo(bucketFilterSet.size());
     for (Integer bucket : results) {
       bucketFilterSet.remove(bucket);
     }
-    assertTrue(bucketFilterSet.isEmpty());
+    assertThat(bucketFilterSet).isEmpty();
   }
 
   void serverBucketFilterOverrideExecution(Set<Integer> bucketFilterSet,
       Set<Integer> ketFilterSet) {
 
     Region<Integer, Integer> region = cache.getRegion(PartitionedRegionName);
-    assertNotNull(region);
+    assertThat(region).isNotNull();
     final HashSet<Integer> testKeysSet = new HashSet<>();
     for (int i = 150; i > 0; i--) {
       testKeysSet.add(i);
     }
     DistributedSystem.setThreadsSocketPolicy(false);
-    Function function = new TestFunction(true, TestFunction.TEST_FUNCTION_BUCKET_FILTER);
+    Function<?> function = new TestFunction<>(true, TestFunction.TEST_FUNCTION_BUCKET_FILTER);
     if (shouldRegisterFunctionsOnClient()) {
       FunctionService.registerFunction(function);
     }
@@ -671,20 +673,21 @@ public class PRClientServerTestBase extends JUnit4CacheTestCase {
     ResultCollector<Integer, List<Integer>> rc = dataSet.withBucketFilter(bucketFilterSet)
         .withFilter(ketFilterSet).execute(function.getId());
     List<Integer> results = rc.getResult();
-    assertEquals(expectedBucketSet.size(), results.size());
+    assertThat(results.size()).isEqualTo(expectedBucketSet.size());
     for (Integer bucket : results) {
       expectedBucketSet.remove(bucket);
     }
-    assertTrue(expectedBucketSet.isEmpty());
+    assertThat(expectedBucketSet).isEmpty();
   }
 
-  public static class BucketFilterPRResolver implements PartitionResolver, Serializable {
+  public static class BucketFilterPRResolver
+      implements PartitionResolver<Object, Object>, Serializable {
 
     @Override
     public void close() {}
 
     @Override
-    public Object getRoutingObject(EntryOperation opDetails) {
+    public Object getRoutingObject(EntryOperation<Object, Object> opDetails) {
       Object key = opDetails.getKey();
       return getBucketID(key);
     }
