@@ -24,7 +24,6 @@ import static org.apache.geode.test.dunit.Assert.assertTrue;
 import static org.apache.geode.test.dunit.Assert.fail;
 import static org.apache.geode.test.dunit.LogWriterUtils.getLogWriter;
 
-import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.Map;
 import java.util.Properties;
@@ -96,16 +95,16 @@ public class HAEventIdPropagationDUnitTest extends JUnit4DistributedTestCase {
   public final void postSetUp() throws Exception {
     final Host host = Host.getHost(0);
     server1 = host.getVM(0);
-    server1.invoke(() -> ConflationDUnitTestHelper.unsetIsSlowStart());
+    server1.invoke(ConflationDUnitTestHelper::unsetIsSlowStart);
     client1 = host.getVM(2);
   }
 
   /** close the caches* */
   @Override
   public final void preTearDown() throws Exception {
-    client1.invoke(() -> HAEventIdPropagationDUnitTest.closeCache());
+    client1.invoke(HAEventIdPropagationDUnitTest::closeCache);
     // close server
-    server1.invoke(() -> HAEventIdPropagationDUnitTest.closeCache());
+    server1.invoke(HAEventIdPropagationDUnitTest::closeCache);
   }
 
   /** stops the server * */
@@ -125,10 +124,9 @@ public class HAEventIdPropagationDUnitTest extends JUnit4DistributedTestCase {
   /** function to create a server and a client * */
   private void createClientServerConfiguration() {
 
-    int PORT1 = ((Integer) server1.invoke(() -> HAEventIdPropagationDUnitTest.createServerCache()))
-        .intValue();
+    int PORT1 = server1.invoke(HAEventIdPropagationDUnitTest::createServerCache);
     client1.invoke(() -> HAEventIdPropagationDUnitTest
-        .createClientCache(NetworkUtils.getServerHostName(server1.getHost()), new Integer(PORT1)));
+        .createClientCache(NetworkUtils.getServerHostName(server1.getHost()), PORT1));
   }
 
   /** create the server * */
@@ -147,7 +145,7 @@ public class HAEventIdPropagationDUnitTest extends JUnit4DistributedTestCase {
     server.setPort(port);
     server.setNotifyBySubscription(true);
     server.start();
-    return new Integer(server.getPort());
+    return server.getPort();
   }
 
   /** function to create cache * */
@@ -164,7 +162,7 @@ public class HAEventIdPropagationDUnitTest extends JUnit4DistributedTestCase {
 
   /** function to create client cache * */
   public static void createClientCache(String hostName, Integer port1) throws Exception {
-    int PORT1 = port1.intValue();
+    int PORT1 = port1;
     Properties props = new Properties();
     props.setProperty(MCAST_PORT, "0");
     props.setProperty(LOCATORS, "");
@@ -180,7 +178,7 @@ public class HAEventIdPropagationDUnitTest extends JUnit4DistributedTestCase {
     Region region = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(region);
     region.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
-    System.out.println("KKKKKK:[" + pi.getName() + "]");;
+    System.out.println("KKKKKK:[" + pi.getName() + "]");
     PoolImpl p2 = (PoolImpl) PoolManager.find("testPool");
     System.out.println("QQQQ:" + p2);
     pool = pi;
@@ -236,9 +234,8 @@ public class HAEventIdPropagationDUnitTest extends JUnit4DistributedTestCase {
 
     // Set the entry to the last entry
     Map.Entry entry = null;
-    for (Iterator threadIdToSequenceIdMapIterator =
-        map.entrySet().iterator(); threadIdToSequenceIdMapIterator.hasNext();) {
-      entry = (Map.Entry) threadIdToSequenceIdMapIterator.next();
+    for (final Object o : map.entrySet()) {
+      entry = (Map.Entry) o;
     }
 
     ThreadIdentifier tid = (ThreadIdentifier) entry.getKey();
@@ -309,56 +306,56 @@ public class HAEventIdPropagationDUnitTest extends JUnit4DistributedTestCase {
   public void testEventIDPropagation() throws Exception {
     try {
       createClientServerConfiguration();
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.setReceivedOperationToFalse());
+      client1.invoke(HAEventIdPropagationDUnitTest::setReceivedOperationToFalse);
       client1.invoke(
-          () -> HAEventIdPropagationDUnitTest.assertThreadIdToSequenceIdMapisNotNullButEmpty());
-      Object eventId1 = server1.invoke(() -> HAEventIdPropagationDUnitTest.putKey1Val1());
+          HAEventIdPropagationDUnitTest::assertThreadIdToSequenceIdMapisNotNullButEmpty);
+      Object eventId1 = server1.invoke(HAEventIdPropagationDUnitTest::putKey1Val1);
       assertNotNull(eventId1);
       // wait for key to propagate till client
       // assert map not null on client
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.waitTillOperationReceived());
+      client1.invoke(HAEventIdPropagationDUnitTest::waitTillOperationReceived);
       Object eventId2 = client1
-          .invoke(() -> HAEventIdPropagationDUnitTest.assertThreadIdToSequenceIdMapHasEntryId());
+          .invoke(HAEventIdPropagationDUnitTest::assertThreadIdToSequenceIdMapHasEntryId);
       assertNotNull(eventId2);
       if (!eventId1.equals(eventId2)) {
         fail("Test failed as the eventIds are not equal");
       }
 
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.setReceivedOperationToFalse());
-      eventId1 = server1.invoke(() -> HAEventIdPropagationDUnitTest.updateKey1());
+      client1.invoke(HAEventIdPropagationDUnitTest::setReceivedOperationToFalse);
+      eventId1 = server1.invoke(HAEventIdPropagationDUnitTest::updateKey1);
       assertNotNull(eventId1);
       // wait for key to propagate till client
       // assert map not null on client
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.waitTillOperationReceived());
+      client1.invoke(HAEventIdPropagationDUnitTest::waitTillOperationReceived);
       eventId2 = client1
-          .invoke(() -> HAEventIdPropagationDUnitTest.assertThreadIdToSequenceIdMapHasEntryId());
+          .invoke(HAEventIdPropagationDUnitTest::assertThreadIdToSequenceIdMapHasEntryId);
       assertNotNull(eventId2);
       if (!eventId1.equals(eventId2)) {
         fail("Test failed as the eventIds are not equal");
       }
 
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.setReceivedOperationToFalse());
-      eventId1 = server1.invoke(() -> HAEventIdPropagationDUnitTest.invalidateKey1());
+      client1.invoke(HAEventIdPropagationDUnitTest::setReceivedOperationToFalse);
+      eventId1 = server1.invoke(HAEventIdPropagationDUnitTest::invalidateKey1);
       assertNotNull(eventId1);
       // wait for key to propagate till client
       // assert map not null on client
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.waitTillOperationReceived());
+      client1.invoke(HAEventIdPropagationDUnitTest::waitTillOperationReceived);
       eventId2 = client1
-          .invoke(() -> HAEventIdPropagationDUnitTest.assertThreadIdToSequenceIdMapHasEntryId());
+          .invoke(HAEventIdPropagationDUnitTest::assertThreadIdToSequenceIdMapHasEntryId);
       assertNotNull(eventId2);
       if (!eventId1.equals(eventId2)) {
         fail("Test failed as the eventIds are not equal");
       }
 
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.setReceivedOperationToFalse());
+      client1.invoke(HAEventIdPropagationDUnitTest::setReceivedOperationToFalse);
       EventID[] eventIds1 =
-          (EventID[]) server1.invoke(() -> HAEventIdPropagationDUnitTest.putAll());
+          (EventID[]) server1.invoke(HAEventIdPropagationDUnitTest::putAll);
       assertNotNull(eventIds1);
       // wait for key to propagate till client
       // assert map not null on client
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.waitTillOperationReceived());
+      client1.invoke(HAEventIdPropagationDUnitTest::waitTillOperationReceived);
       EventID[] eventIds2 = (EventID[]) client1
-          .invoke(() -> HAEventIdPropagationDUnitTest.assertThreadIdToSequenceIdMapHasEntryIds());
+          .invoke(HAEventIdPropagationDUnitTest::assertThreadIdToSequenceIdMapHasEntryIds);
       assertNotNull(eventIds2);
       for (int i = 0; i < 5; i++) {
         assertNotNull(eventIds1[i]);
@@ -368,27 +365,27 @@ public class HAEventIdPropagationDUnitTest extends JUnit4DistributedTestCase {
         }
       }
 
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.setReceivedOperationToFalse());
-      eventId1 = server1.invoke(() -> HAEventIdPropagationDUnitTest.removePUTALL_KEY1());
+      client1.invoke(HAEventIdPropagationDUnitTest::setReceivedOperationToFalse);
+      eventId1 = server1.invoke(HAEventIdPropagationDUnitTest::removePUTALL_KEY1);
       assertNotNull(eventId1);
       // wait for key to propagate till client
       // assert map not null on client
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.waitTillOperationReceived());
+      client1.invoke(HAEventIdPropagationDUnitTest::waitTillOperationReceived);
       eventId2 = client1
-          .invoke(() -> HAEventIdPropagationDUnitTest.assertThreadIdToSequenceIdMapHasEntryId());
+          .invoke(HAEventIdPropagationDUnitTest::assertThreadIdToSequenceIdMapHasEntryId);
       assertNotNull(eventId2);
       if (!eventId1.equals(eventId2)) {
         fail("Test failed as the eventIds are not equal");
       }
 
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.setReceivedOperationToFalse());
-      eventId1 = server1.invoke(() -> HAEventIdPropagationDUnitTest.destroyKey1());
+      client1.invoke(HAEventIdPropagationDUnitTest::setReceivedOperationToFalse);
+      eventId1 = server1.invoke(HAEventIdPropagationDUnitTest::destroyKey1);
       assertNotNull(eventId1);
       // wait for key to propagate till client
       // assert map not null on client
-      client1.invoke(() -> HAEventIdPropagationDUnitTest.waitTillOperationReceived());
+      client1.invoke(HAEventIdPropagationDUnitTest::waitTillOperationReceived);
       eventId2 = client1
-          .invoke(() -> HAEventIdPropagationDUnitTest.assertThreadIdToSequenceIdMapHasEntryId());
+          .invoke(HAEventIdPropagationDUnitTest::assertThreadIdToSequenceIdMapHasEntryId);
       assertNotNull(eventId2);
       if (!eventId1.equals(eventId2)) {
         fail("Test failed as the eventIds are not equal");
@@ -403,16 +400,16 @@ public class HAEventIdPropagationDUnitTest extends JUnit4DistributedTestCase {
   @Test
   public void testEventIDPropagationForClear() throws Exception {
     createClientServerConfiguration();
-    client1.invoke(() -> HAEventIdPropagationDUnitTest.setReceivedOperationToFalse());
+    client1.invoke(HAEventIdPropagationDUnitTest::setReceivedOperationToFalse);
     client1.invoke(
-        () -> HAEventIdPropagationDUnitTest.assertThreadIdToSequenceIdMapisNotNullButEmpty());
-    Object eventId1 = server1.invoke(() -> HAEventIdPropagationDUnitTest.clearRg());
+        HAEventIdPropagationDUnitTest::assertThreadIdToSequenceIdMapisNotNullButEmpty);
+    Object eventId1 = server1.invoke(HAEventIdPropagationDUnitTest::clearRg);
     assertNotNull(eventId1);
     // wait for key to propagate till client
     // assert map not null on client
-    client1.invoke(() -> HAEventIdPropagationDUnitTest.waitTillOperationReceived());
+    client1.invoke(HAEventIdPropagationDUnitTest::waitTillOperationReceived);
     Object eventId2 = client1
-        .invoke(() -> HAEventIdPropagationDUnitTest.assertThreadIdToSequenceIdMapHasEntryId());
+        .invoke(HAEventIdPropagationDUnitTest::assertThreadIdToSequenceIdMapHasEntryId);
     assertNotNull(eventId2);
     if (!eventId1.equals(eventId2)) {
       fail("Test failed as the clear eventIds are not equal");
@@ -423,14 +420,14 @@ public class HAEventIdPropagationDUnitTest extends JUnit4DistributedTestCase {
   @Test
   public void testEventIDPropagationForDestroyRegion() throws Exception {
     createClientServerConfiguration();
-    client1.invoke(() -> HAEventIdPropagationDUnitTest.setReceivedOperationToFalse());
-    Object eventId1 = server1.invoke(() -> HAEventIdPropagationDUnitTest.destroyRegion());
+    client1.invoke(HAEventIdPropagationDUnitTest::setReceivedOperationToFalse);
+    Object eventId1 = server1.invoke(HAEventIdPropagationDUnitTest::destroyRegion);
     assertNotNull(eventId1);
     // wait for key to propagate till client
     // assert map not null on client
-    client1.invoke(() -> HAEventIdPropagationDUnitTest.waitTillOperationReceived());
+    client1.invoke(HAEventIdPropagationDUnitTest::waitTillOperationReceived);
     Object eventId2 = client1
-        .invoke(() -> HAEventIdPropagationDUnitTest.assertThreadIdToSequenceIdMapHasEntryId());
+        .invoke(HAEventIdPropagationDUnitTest::assertThreadIdToSequenceIdMapHasEntryId);
     assertNotNull(eventId2);
     if (!eventId1.equals(eventId2)) {
       fail("Test failed as the eventIds are not equal");
