@@ -95,10 +95,10 @@ public class HAExpiryDUnitTest extends JUnit4DistributedTestCase {
 
   @Override
   public final void preTearDown() throws Exception {
-    vm0.invoke(() -> HAExpiryDUnitTest.closeCache());
-    vm1.invoke(() -> HAExpiryDUnitTest.closeCache());
-    vm2.invoke(() -> HAExpiryDUnitTest.closeCache());
-    vm3.invoke(() -> HAExpiryDUnitTest.closeCache());
+    vm0.invoke(HAExpiryDUnitTest::closeCache);
+    vm1.invoke(HAExpiryDUnitTest::closeCache);
+    vm2.invoke(HAExpiryDUnitTest::closeCache);
+    vm3.invoke(HAExpiryDUnitTest::closeCache);
     cache = null;
     Invoke.invokeInEveryVM(new SerializableRunnable() {
       @Override
@@ -110,10 +110,10 @@ public class HAExpiryDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testExpiryPeriod() throws Exception {
-    vm0.invoke(() -> HAExpiryDUnitTest.createRegionQueue(new Boolean(false)));
-    vm1.invoke(() -> HAExpiryDUnitTest.createRegionQueue(new Boolean(false)));
-    vm2.invoke(() -> HAExpiryDUnitTest.createRegionQueue(new Boolean(false)));
-    vm3.invoke(() -> HAExpiryDUnitTest.createRegionQueue(new Boolean(false)));
+    vm0.invoke(() -> HAExpiryDUnitTest.createRegionQueue(Boolean.FALSE));
+    vm1.invoke(() -> HAExpiryDUnitTest.createRegionQueue(Boolean.FALSE));
+    vm2.invoke(() -> HAExpiryDUnitTest.createRegionQueue(Boolean.FALSE));
+    vm3.invoke(() -> HAExpiryDUnitTest.createRegionQueue(Boolean.FALSE));
 
     vm0.invoke(new CacheSerializableRunnable("putFromVm") {
 
@@ -124,25 +124,25 @@ public class HAExpiryDUnitTest extends JUnit4DistributedTestCase {
       }
     });
 
-    vm0.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
-    vm1.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
-    vm2.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
-    vm3.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
+    vm0.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
+    vm1.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
+    vm2.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
+    vm3.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
 
     // Thread.sleep(7 * 1000);
 
-    vm0.invoke(() -> HAExpiryDUnitTest.checkSizeAfterExpiration());
-    vm1.invoke(() -> HAExpiryDUnitTest.checkSizeAfterExpiration());
-    vm2.invoke(() -> HAExpiryDUnitTest.checkSizeAfterExpiration());
-    vm3.invoke(() -> HAExpiryDUnitTest.checkSizeAfterExpiration());
+    vm0.invoke(HAExpiryDUnitTest::checkSizeAfterExpiration);
+    vm1.invoke(HAExpiryDUnitTest::checkSizeAfterExpiration);
+    vm2.invoke(HAExpiryDUnitTest::checkSizeAfterExpiration);
+    vm3.invoke(HAExpiryDUnitTest::checkSizeAfterExpiration);
   }
 
   @Test
   public void testDurableExpiryPeriod() throws Exception {
-    vm0.invoke(() -> HAExpiryDUnitTest.createRegionQueue(new Boolean(true)));
-    vm1.invoke(() -> HAExpiryDUnitTest.createRegionQueue(new Boolean(true)));
-    vm2.invoke(() -> HAExpiryDUnitTest.createRegionQueue(new Boolean(true)));
-    vm3.invoke(() -> HAExpiryDUnitTest.createRegionQueue(new Boolean(true)));
+    vm0.invoke(() -> HAExpiryDUnitTest.createRegionQueue(Boolean.TRUE));
+    vm1.invoke(() -> HAExpiryDUnitTest.createRegionQueue(Boolean.TRUE));
+    vm2.invoke(() -> HAExpiryDUnitTest.createRegionQueue(Boolean.TRUE));
+    vm3.invoke(() -> HAExpiryDUnitTest.createRegionQueue(Boolean.TRUE));
 
     vm0.invoke(new CacheSerializableRunnable("putFromVm") {
 
@@ -153,19 +153,19 @@ public class HAExpiryDUnitTest extends JUnit4DistributedTestCase {
       }
     });
 
-    vm0.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
-    vm1.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
-    vm2.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
-    vm3.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
+    vm0.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
+    vm1.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
+    vm2.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
+    vm3.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
 
     Wait.pause(5000); // wait for some time to make sure that we give sufficient time
     // to expiry
     // in spite of giving time the events should not expire, and queue should be
     // same as before expiration
-    vm0.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
-    vm1.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
-    vm2.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
-    vm3.invoke(() -> HAExpiryDUnitTest.checkSizeBeforeExpiration());
+    vm0.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
+    vm1.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
+    vm2.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
+    vm3.invoke(HAExpiryDUnitTest::checkSizeBeforeExpiration);
 
   }
 
@@ -240,7 +240,7 @@ public class HAExpiryDUnitTest extends JUnit4DistributedTestCase {
     // setting expiry time for the regionqueue.
     hattr.setExpiryTime(4);
     RegionQueue regionqueue = HARegionQueue.getHARegionQueueInstance(regionQueueName, cache, hattr,
-        HARegionQueue.NON_BLOCKING_HA_QUEUE, isDurable.booleanValue(), disabledClock());
+        HARegionQueue.NON_BLOCKING_HA_QUEUE, isDurable, disabledClock());
     assertNotNull(regionqueue);
     AttributesFactory factory = new AttributesFactory();
     factory.setScope(Scope.DISTRIBUTED_ACK);
