@@ -81,12 +81,10 @@ public class OperationsPropagationDUnitTest extends JUnit4DistributedTestCase {
     // Client 1 VM
     client1 = host.getVM(2);
 
-    PORT1 = ((Integer) server1.invoke(() -> OperationsPropagationDUnitTest.createServerCache()))
-        .intValue();
-    PORT2 = ((Integer) server2.invoke(() -> OperationsPropagationDUnitTest.createServerCache()))
-        .intValue();
+    PORT1 = server1.invoke(OperationsPropagationDUnitTest::createServerCache);
+    PORT2 = server2.invoke(OperationsPropagationDUnitTest::createServerCache);
     client1.invoke(() -> OperationsPropagationDUnitTest
-        .createClientCache(NetworkUtils.getServerHostName(host), new Integer(PORT2)));
+        .createClientCache(NetworkUtils.getServerHostName(host), PORT2));
   }
 
   /**
@@ -94,9 +92,9 @@ public class OperationsPropagationDUnitTest extends JUnit4DistributedTestCase {
    */
   @Override
   public final void preTearDown() throws Exception {
-    client1.invoke(() -> OperationsPropagationDUnitTest.closeCache());
-    server1.invoke(() -> OperationsPropagationDUnitTest.closeCache());
-    server2.invoke(() -> OperationsPropagationDUnitTest.closeCache());
+    client1.invoke(OperationsPropagationDUnitTest::closeCache);
+    server1.invoke(OperationsPropagationDUnitTest::closeCache);
+    server2.invoke(OperationsPropagationDUnitTest::closeCache);
   }
 
   /**
@@ -143,14 +141,14 @@ public class OperationsPropagationDUnitTest extends JUnit4DistributedTestCase {
     server.setPort(port);
     server.setNotifyBySubscription(true);
     server.start();
-    return new Integer(server.getPort());
+    return server.getPort();
   }
 
   /**
    * create the client and connect it to the server with the given port
    */
   public static void createClientCache(String host, Integer port2) throws Exception {
-    int PORT2 = port2.intValue();
+    int PORT2 = port2;
     Properties props = new Properties();
     props.setProperty(MCAST_PORT, "0");
     props.setProperty(LOCATORS, "");
@@ -208,12 +206,12 @@ public class OperationsPropagationDUnitTest extends JUnit4DistributedTestCase {
    */
   @Test
   public void testOperationsPropagation() throws Exception {
-    server1.invoke(() -> OperationsPropagationDUnitTest.initialPutKeyValue());
-    client1.invoke(() -> OperationsPropagationDUnitTest.assertKeyValuePresent());
-    server1.invoke(() -> OperationsPropagationDUnitTest.doOperations());
-    client1.invoke(() -> OperationsPropagationDUnitTest.assertOperationsSucceeded());
-    server1.invoke(() -> OperationsPropagationDUnitTest.doRemoveAll());
-    client1.invoke(() -> OperationsPropagationDUnitTest.assertRemoveAllSucceeded());
+    server1.invoke(OperationsPropagationDUnitTest::initialPutKeyValue);
+    client1.invoke(OperationsPropagationDUnitTest::assertKeyValuePresent);
+    server1.invoke(OperationsPropagationDUnitTest::doOperations);
+    client1.invoke(OperationsPropagationDUnitTest::assertOperationsSucceeded);
+    server1.invoke(OperationsPropagationDUnitTest::doRemoveAll);
+    client1.invoke(OperationsPropagationDUnitTest::assertRemoveAllSucceeded);
   }
 
   /**
