@@ -49,7 +49,6 @@ import java.util.TreeSet;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
-import junitparams.JUnitParamsRunner;
 import junitparams.Parameters;
 import junitparams.naming.TestCaseName;
 import org.junit.After;
@@ -102,11 +101,12 @@ import org.apache.geode.test.dunit.rules.CacheRule;
 import org.apache.geode.test.dunit.rules.DistributedDiskDirRule;
 import org.apache.geode.test.dunit.rules.DistributedRule;
 import org.apache.geode.test.junit.rules.serializable.SerializableTestName;
+import org.apache.geode.test.junit.runners.GeodeParamsRunner;
 
 /**
  * Tests the basic use cases for PR persistence.
  */
-@RunWith(JUnitParamsRunner.class)
+@RunWith(GeodeParamsRunner.class)
 @SuppressWarnings("serial,unused")
 public class PersistentPartitionedRegionDistributedTest implements Serializable {
 
@@ -1681,8 +1681,9 @@ public class PersistentPartitionedRegionDistributedTest implements Serializable
 
   private boolean thrownByDiskRecoveryDueToConflictingPersistentDataException(
       Throwable expectedException) {
-    return expectedException instanceof CacheClosedException
-        && expectedException.getCause() instanceof ConflictingPersistentDataException;
+    return expectedException instanceof DistributedSystemDisconnectedException
+        || (expectedException instanceof CacheClosedException
+            && expectedException.getCause() instanceof ConflictingPersistentDataException);
   }
 
   private boolean thrownByAsyncFlusherThreadDueToConflictingPersistentDataException(
