@@ -98,9 +98,9 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
     IgnoredException.addIgnoredException("SocketException");
 
     // start servers first
-    PORT1 = ((Integer) server1.invoke(() -> HAStartupAndFailoverDUnitTest.createServerCache()));
-    PORT2 = ((Integer) server2.invoke(() -> HAStartupAndFailoverDUnitTest.createServerCache()));
-    PORT3 = ((Integer) server3.invoke(() -> HAStartupAndFailoverDUnitTest.createServerCache()));
+    PORT1 = server1.invoke(HAStartupAndFailoverDUnitTest::createServerCache);
+    PORT2 = server2.invoke(HAStartupAndFailoverDUnitTest::createServerCache);
+    PORT3 = server3.invoke(HAStartupAndFailoverDUnitTest::createServerCache);
     CacheServerTestUtil.disableShufflingOfEndpoints();
   }
 
@@ -110,42 +110,42 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
   @Test
   public void testPrimaryFailover() throws Exception {
 
-    createClientCache(this.getName(), NetworkUtils.getServerHostName(server1.getHost()));
+    createClientCache(getName(), NetworkUtils.getServerHostName(server1.getHost()));
     // primary
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
+    server1.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
 
     // secondaries
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
+    server2.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
 
     setClientServerObserver();
 
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server1.invoke(HAStartupAndFailoverDUnitTest::stopServer);
 
     waitForPrimaryIdentification();
     // primary
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
+    server2.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
     unSetClientServerObserver();
     // secondary
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
 
     setClientServerObserver();
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server2.invoke(HAStartupAndFailoverDUnitTest::stopServer);
     // primary
     waitForPrimaryIdentification();
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
     unSetClientServerObserver();
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server3.invoke(HAStartupAndFailoverDUnitTest::stopServer);
     // All servers are dead at this point , no primary in the system.
     verifyDeadAndLiveServers(3, 0);
 
     // now start one of the servers
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.startServer());
+    server3.invoke(HAStartupAndFailoverDUnitTest::startServer);
     // make sure that the server3 which was started recenty was marked live.
     verifyDeadAndLiveServers(2, 1);
 
     // verify that is it primary , and dispatche is running
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
   }
 
 
@@ -157,24 +157,24 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
   @Test
   public void testExceptionWhileMakingPrimary() throws Exception {
 
-    createClientCacheWithIncorrectPrimary(this.getName(),
+    createClientCacheWithIncorrectPrimary(getName(),
         NetworkUtils.getServerHostName(server1.getHost()));
     // failed primary due to incorect host name of the server
 
     // new primary
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
+    server2.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
     // secondary
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
 
     setClientServerObserver();
 
     // stop new primary
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server2.invoke(HAStartupAndFailoverDUnitTest::stopServer);
 
     waitForPrimaryIdentification();
 
     // newly selectd primary
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
 
     unSetClientServerObserver();
   }
@@ -187,25 +187,25 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
   @Test
   public void testTwoPrimaryFailedOneAfterTheAnother() throws Exception {
 
-    createClientCacheWithLargeRetryInterval(this.getName(),
+    createClientCacheWithLargeRetryInterval(getName(),
         NetworkUtils.getServerHostName(server1.getHost()));
     // primary
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
+    server1.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
 
     // secondaries
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
+    server2.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
     setClientServerObserver();
 
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server1.invoke(HAStartupAndFailoverDUnitTest::stopServer);
     // stop ProbablePrimary
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server2.invoke(HAStartupAndFailoverDUnitTest::stopServer);
     // processException();
 
 
     waitForPrimaryIdentification();
     // new primary
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
     unSetClientServerObserver();
 
   }
@@ -216,11 +216,11 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
   @Test
   public void testPrimaryShouldBeNullAndEPListShouldBeEmptyWhenAllServersAreDead()
       throws Exception {
-    createClientCache(this.getName(), NetworkUtils.getServerHostName(server1.getHost()));
+    createClientCache(getName(), NetworkUtils.getServerHostName(server1.getHost()));
     verifyPrimaryShouldNotBeNullAndEPListShouldNotBeEmpty();
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server1.invoke(HAStartupAndFailoverDUnitTest::stopServer);
+    server2.invoke(HAStartupAndFailoverDUnitTest::stopServer);
+    server3.invoke(HAStartupAndFailoverDUnitTest::stopServer);
     verifyDeadAndLiveServers(3, 0);
     verifyPrimaryShouldBeNullAndEPListShouldBeEmpty();
   }
@@ -230,17 +230,17 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
    */
   @Test
   public void testCacheClientUpdatersInitiatesFailoverOnPrimaryFailure() throws Exception {
-    createClientCacheWithLargeRetryInterval(this.getName(),
+    createClientCacheWithLargeRetryInterval(getName(),
         NetworkUtils.getServerHostName(server1.getHost()));
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
+    server1.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
+    server2.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
     setClientServerObserver();
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server1.invoke(HAStartupAndFailoverDUnitTest::stopServer);
     waitForPrimaryIdentification();
     unSetClientServerObserver();
     verifyDeadAndLiveServers(1, 2);
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
+    server2.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
   }
 
   /**
@@ -248,15 +248,15 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
    */
   @Test
   public void testCacheClientUpdaterInitiatesFailoverOnSecondaryFailure() throws Exception {
-    createClientCacheWithLargeRetryInterval(this.getName(),
+    createClientCacheWithLargeRetryInterval(getName(),
         NetworkUtils.getServerHostName(server1.getHost()));
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server1.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
+    server2.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
+    server2.invoke(HAStartupAndFailoverDUnitTest::stopServer);
     verifyDeadAndLiveServers(1, 2);
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
+    server1.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
 
   }
 
@@ -269,15 +269,15 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
   public void testCacheClientUpdaterInitiatesFailoverOnBothPrimaryAndSecondaryFailure()
       throws Exception {
 
-    createClientCacheWithLargeRetryInterval(this.getName(),
+    createClientCacheWithLargeRetryInterval(getName(),
         NetworkUtils.getServerHostName(server1.getHost()));
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server1.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
+    server2.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
+    server1.invoke(HAStartupAndFailoverDUnitTest::stopServer);
+    server2.invoke(HAStartupAndFailoverDUnitTest::stopServer);
     verifyDeadAndLiveServers(2, 1);
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
 
 
   }
@@ -289,14 +289,14 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
   public void testCacheClientUpdaterInitiatesFailoverOnBothPrimaryAndSecondaryFailureWithServerMonitors()
       throws Exception {
 
-    createClientCache(this.getName(), NetworkUtils.getServerHostName(server1.getHost()));
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsNotAlive());
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    createClientCache(getName(), NetworkUtils.getServerHostName(server1.getHost()));
+    server1.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
+    server2.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsNotAlive);
+    server1.invoke(HAStartupAndFailoverDUnitTest::stopServer);
+    server2.invoke(HAStartupAndFailoverDUnitTest::stopServer);
     verifyDeadAndLiveServers(2, 1);
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.verifyDispatcherIsAlive());
+    server3.invoke(HAStartupAndFailoverDUnitTest::verifyDispatcherIsAlive);
   }
 
   /**
@@ -305,12 +305,12 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
   @Test
   public void testInitiateFailoverByCacheOperationThreads_Secondary() throws Exception {
     // Stop the 3rd server to guarantee the client put will go to the first server
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server3.invoke(HAStartupAndFailoverDUnitTest::stopServer);
     // create a client with no client updater thread
     // so that only cache operation can detect a server failure and should initiate failover
-    createClientCacheWithLargeRetryIntervalAndWithoutCallbackConnection(this.getName(),
+    createClientCacheWithLargeRetryIntervalAndWithoutCallbackConnection(getName(),
         NetworkUtils.getServerHostName(server1.getHost()));
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.stopServer());
+    server2.invoke(HAStartupAndFailoverDUnitTest::stopServer);
     put();
     verifyDeadAndLiveServers(1, 1);
   }
@@ -547,8 +547,8 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
     props.setProperty(MCAST_PORT, "0");
     props.setProperty(LOCATORS, "");
     new HAStartupAndFailoverDUnitTest().createCache(props);
-    PoolImpl p = (PoolImpl) PoolManager.createFactory().addServer(host, PORT1.intValue())
-        .addServer(host, PORT2.intValue()).addServer(host, PORT3.intValue())
+    PoolImpl p = (PoolImpl) PoolManager.createFactory().addServer(host, PORT1)
+        .addServer(host, PORT2).addServer(host, PORT3)
         .setSubscriptionEnabled(true).setSubscriptionRedundancy(-1).setReadTimeout(10000)
         // .setRetryInterval(2000)
         .create("HAStartupAndFailoverDUnitTestPool");
@@ -571,8 +571,8 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
     props.setProperty(MCAST_PORT, "0");
     props.setProperty(LOCATORS, "");
     new HAStartupAndFailoverDUnitTest().createCache(props);
-    PoolImpl p = (PoolImpl) PoolManager.createFactory().addServer(host, PORT1.intValue())
-        .addServer(host, PORT2.intValue()).addServer(host, PORT3.intValue())
+    PoolImpl p = (PoolImpl) PoolManager.createFactory().addServer(host, PORT1)
+        .addServer(host, PORT2).addServer(host, PORT3)
         .setSubscriptionEnabled(true).setSubscriptionRedundancy(-1).setReadTimeout(10000)
         // .setRetryInterval(2000000)
         .create("HAStartupAndFailoverDUnitTestPool");
@@ -599,8 +599,8 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
     CacheServerTestUtil.disableShufflingOfEndpoints();
     PoolImpl p;
     try {
-      p = (PoolImpl) PoolManager.createFactory().addServer(host, PORT1.intValue())
-          .addServer(host, PORT2.intValue()).addServer(host, PORT3.intValue()).setPingInterval(500)
+      p = (PoolImpl) PoolManager.createFactory().addServer(host, PORT1)
+          .addServer(host, PORT2).addServer(host, PORT3).setPingInterval(500)
           // .setRetryInterval(200000)
           .create("HAStartupAndFailoverDUnitTestPool");
     } finally {
@@ -632,7 +632,7 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
     new HAStartupAndFailoverDUnitTest().createCache(props);
     final int INCORRECT_PORT = 1;
     PoolImpl p = (PoolImpl) PoolManager.createFactory().addServer(host, INCORRECT_PORT)
-        .addServer(host, PORT2.intValue()).addServer(host, PORT3.intValue())
+        .addServer(host, PORT2).addServer(host, PORT3)
         .setSubscriptionEnabled(true).setSubscriptionRedundancy(-1).setReadTimeout(10000)
         // .setRetryInterval(10000)
         .create("HAStartupAndFailoverDUnitTestPool");
@@ -665,7 +665,7 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
     server1.setNotifyBySubscription(true);
     server1.setMaximumTimeBetweenPings(180000);
     server1.start();
-    return new Integer(server1.getPort());
+    return server1.getPort();
   }
 
   @Override
@@ -674,9 +674,9 @@ public class HAStartupAndFailoverDUnitTest extends JUnit4DistributedTestCase {
     closeCache();
 
     // then close the servers
-    server1.invoke(() -> HAStartupAndFailoverDUnitTest.closeCache());
-    server2.invoke(() -> HAStartupAndFailoverDUnitTest.closeCache());
-    server3.invoke(() -> HAStartupAndFailoverDUnitTest.closeCache());
+    server1.invoke(HAStartupAndFailoverDUnitTest::closeCache);
+    server2.invoke(HAStartupAndFailoverDUnitTest::closeCache);
+    server3.invoke(HAStartupAndFailoverDUnitTest::closeCache);
     CacheServerTestUtil.resetDisableShufflingOfEndpointsFlag();
   }
 
