@@ -18,7 +18,7 @@ import static java.util.concurrent.TimeUnit.MILLISECONDS;
 import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
-import static org.apache.geode.internal.lang.SystemPropertyHelper.GEMFIRE_PREFIX;
+import static org.apache.geode.internal.lang.SystemProperty.GEMFIRE_PREFIX;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.apache.geode.test.dunit.Disconnect.disconnectAllFromDS;
 import static org.apache.geode.test.dunit.VM.getController;
@@ -85,7 +85,7 @@ public class RedundancyLevelPart1DUnitTest implements Serializable {
   private static String server2;
   private static String server3;
   private static PoolImpl pool = null;
-  private static AtomicBoolean failOverDetectionByCCU = new AtomicBoolean(false);
+  private static final AtomicBoolean failOverDetectionByCCU = new AtomicBoolean(false);
   private static ClientServerObserver clientServerObserver = null;
   private static InternalCache cache;
   private static String hostname;
