@@ -97,10 +97,10 @@ public class RegisterInterestBeforeRegionCreationDUnitTest extends JUnit4Distrib
    */
   @Override
   public final void preTearDown() throws Exception {
-    client1.invoke(() -> RegisterInterestBeforeRegionCreationDUnitTest.closeCache());
-    client2.invoke(() -> RegisterInterestBeforeRegionCreationDUnitTest.closeCache());
-    server1.invoke(() -> RegisterInterestBeforeRegionCreationDUnitTest.closeCache());
-    server2.invoke(() -> RegisterInterestBeforeRegionCreationDUnitTest.closeCache());
+    client1.invoke(RegisterInterestBeforeRegionCreationDUnitTest::closeCache);
+    client2.invoke(RegisterInterestBeforeRegionCreationDUnitTest::closeCache);
+    server1.invoke(RegisterInterestBeforeRegionCreationDUnitTest::closeCache);
+    server2.invoke(RegisterInterestBeforeRegionCreationDUnitTest::closeCache);
   }
 
   /**
@@ -177,27 +177,25 @@ public class RegisterInterestBeforeRegionCreationDUnitTest extends JUnit4Distrib
   // function to create 2servers and 2 clients
   private void createClientServerConfigurationForClearTest() throws Exception {
     // create server and region
-    PORT1 = ((Integer) server1.invoke(
-        () -> RegisterInterestBeforeRegionCreationDUnitTest.createServer(new Boolean(true))))
-            .intValue();
+    PORT1 = server1.invoke(
+        () -> RegisterInterestBeforeRegionCreationDUnitTest.createServer(Boolean.TRUE));
 
     // only create server, no region
-    PORT2 = ((Integer) server2.invoke(
-        () -> RegisterInterestBeforeRegionCreationDUnitTest.createServer(new Boolean(false))))
-            .intValue();
+    PORT2 = server2.invoke(
+        () -> RegisterInterestBeforeRegionCreationDUnitTest.createServer(Boolean.FALSE));
 
     // client1 connected to server1
     client1.invoke(() -> RegisterInterestBeforeRegionCreationDUnitTest
-        .createClient(NetworkUtils.getServerHostName(server1.getHost()), new Integer(PORT1)));
+        .createClient(NetworkUtils.getServerHostName(server1.getHost()), PORT1));
 
     // client2 connected to server2
     client2.invoke(() -> RegisterInterestBeforeRegionCreationDUnitTest
-        .createClient(NetworkUtils.getServerHostName(server1.getHost()), new Integer(PORT2)));
+        .createClient(NetworkUtils.getServerHostName(server1.getHost()), PORT2));
   }
 
   public static Integer createServer(Boolean createRegion) throws Exception {
     new RegisterInterestBeforeRegionCreationDUnitTest().createCache(new Properties());
-    boolean isCreateRegion = createRegion.booleanValue();
+    boolean isCreateRegion = createRegion;
     if (isCreateRegion) {
       AttributesFactory factory = new AttributesFactory();
       factory.setScope(Scope.DISTRIBUTED_ACK);
@@ -211,7 +209,7 @@ public class RegisterInterestBeforeRegionCreationDUnitTest extends JUnit4Distrib
     server.setPort(port);
     server.setNotifyBySubscription(true);
     server.start();
-    return new Integer(server.getPort());
+    return server.getPort();
   }
 
   private void createCache(Properties props) throws Exception {
@@ -224,7 +222,7 @@ public class RegisterInterestBeforeRegionCreationDUnitTest extends JUnit4Distrib
   }
 
   public static void createClient(String host, Integer port1) throws Exception {
-    PORT1 = port1.intValue();
+    PORT1 = port1;
     Properties props = new Properties();
     props.setProperty(MCAST_PORT, "0");
     props.setProperty(LOCATORS, "");
