@@ -105,13 +105,13 @@ public class RegisterInterestKeysDUnitTest extends JUnit4DistributedTestCase {
 
     LogWriterUtils.getLogWriter().info("implementation class is " + impl.getClass());
 
-    PORT1 = ((Integer) server1.invoke(() -> impl.createServerCache())).intValue();
-    PORT2 = ((Integer) server2.invoke(() -> impl.createServerCache())).intValue();
+    PORT1 = server1.invoke(RegisterInterestKeysDUnitTest::createServerCache);
+    PORT2 = server2.invoke(RegisterInterestKeysDUnitTest::createServerCache);
 
-    client1.invoke(() -> impl.createClientCache(NetworkUtils.getServerHostName(server1.getHost()),
-        new Integer(PORT1), new Integer(PORT2)));
-    client2.invoke(() -> impl.createClientCache(NetworkUtils.getServerHostName(server1.getHost()),
-        new Integer(PORT1), new Integer(PORT2)));
+    client1.invoke(() -> createClientCache(NetworkUtils.getServerHostName(server1.getHost()),
+        PORT1, PORT2));
+    client2.invoke(() -> createClientCache(NetworkUtils.getServerHostName(server1.getHost()),
+        PORT1, PORT2));
   }
 
   /** subclass support */
@@ -134,8 +134,8 @@ public class RegisterInterestKeysDUnitTest extends JUnit4DistributedTestCase {
   @Test
   public void testRegisterCreatesInvalidEntry() {
     // First create entries on both servers via the two client
-    client1.invoke(() -> impl.createEntriesK1());
-    client2.invoke(() -> impl.registerKeysK1());
+    client1.invoke(RegisterInterestKeysDUnitTest::createEntriesK1);
+    client2.invoke(RegisterInterestKeysDUnitTest::registerKeysK1);
   }
 
 
@@ -155,8 +155,8 @@ public class RegisterInterestKeysDUnitTest extends JUnit4DistributedTestCase {
   }
 
   public static void createClientCache(String host, Integer port1, Integer port2) throws Exception {
-    int PORT1 = port1.intValue();
-    int PORT2 = port2.intValue();
+    int PORT1 = port1;
+    int PORT2 = port2;
     Properties props = new Properties();
     props.setProperty(MCAST_PORT, "0");
     props.setProperty(LOCATORS, "");
@@ -192,7 +192,7 @@ public class RegisterInterestKeysDUnitTest extends JUnit4DistributedTestCase {
     server.setPort(port);
     server.setNotifyBySubscription(true);
     server.start();
-    return new Integer(server.getPort());
+    return server.getPort();
   }
 
   protected RegionAttributes createServerCacheAttributes() {
@@ -235,10 +235,10 @@ public class RegisterInterestKeysDUnitTest extends JUnit4DistributedTestCase {
   @Override
   public final void preTearDown() throws Exception {
     // close client
-    client1.invoke(() -> impl.closeCache());
-    client2.invoke(() -> impl.closeCache());
+    client1.invoke(RegisterInterestKeysDUnitTest::closeCache);
+    client2.invoke(RegisterInterestKeysDUnitTest::closeCache);
     // close server
-    server1.invoke(() -> impl.closeCache());
-    server2.invoke(() -> impl.closeCache());
+    server1.invoke(RegisterInterestKeysDUnitTest::closeCache);
+    server2.invoke(RegisterInterestKeysDUnitTest::closeCache);
   }
 }
