@@ -66,11 +66,6 @@ public class CompressionStatsDUnitTest extends JUnit4CacheTestCase {
       "1234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890"
           .getBytes();
 
-  /**
-   * Creates a new CompressionStatsDUnitTest.
-   *
-   * @param name test name.
-   */
   public CompressionStatsDUnitTest() {
     super();
   }
@@ -257,7 +252,7 @@ public class CompressionStatsDUnitTest extends JUnit4CacheTestCase {
     assertEquals(0, stats.region2TotalDecompressions);
 
     stats.vmTotalPostCompressedBytes = getTotalPostCompressedBytesOnVm(vm, null);
-    assertEquals(10000, stats.vmTotalPostCompressedBytes);;
+    assertEquals(10000, stats.vmTotalPostCompressedBytes);
 
     stats.region1TotalPostCompressedBytes = getTotalPostCompressedBytesOnVm(vm, REGION_NAME);
     assertEquals(5000, stats.region1TotalPostCompressedBytes);
