@@ -88,7 +88,7 @@ public class DistributedSystemMXBeanDistributedTest implements Serializable {
     memberVM2 = getVM(2);
     memberVM3 = getVM(3);
 
-    managerVM.invoke(() -> createManager());
+    managerVM.invoke(this::createManager);
 
     for (VM memberVM : toArray(memberVM1, memberVM2, memberVM3)) {
       memberVM.invoke(() -> createMember(memberVM.getId()));
