@@ -24,6 +24,7 @@ import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.fail;
 
+import java.io.Serializable;
 import java.lang.management.ManagementFactory;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -91,7 +92,7 @@ public class OffHeapManagementDUnitTest extends CacheTestCase {
   /**
    * Half of expected memory total.
    */
-  private static final int HALF_TOTAL_MEMORY = (int) (TOTAL_MEMORY / 2);
+  private static final int HALF_TOTAL_MEMORY = TOTAL_MEMORY / 2;
 
   /**
    * An arbitrary array size.
@@ -144,7 +145,7 @@ public class OffHeapManagementDUnitTest extends CacheTestCase {
   /**
    * Local MBeanServer.
    */
-  private static MBeanServer mbeanServer = ManagementFactory.getPlatformMBeanServer();
+  private static final MBeanServer mbeanServer = ManagementFactory.getPlatformMBeanServer();
 
   private VM vm;
 
@@ -244,7 +245,7 @@ public class OffHeapManagementDUnitTest extends CacheTestCase {
 
     // After allocating large chunk (equal to total memory)
     // we should still have no fragmentation
-    int largeChunk = (int) TOTAL_MEMORY - OffHeapStoredObject.HEADER_SIZE;
+    int largeChunk = TOTAL_MEMORY - OffHeapStoredObject.HEADER_SIZE;
     doPutOnVm(vm, KEY, new byte[largeChunk], OFF_HEAP_REGION_NAME, false);
     // No compaction has run, so fragmentation should be zero
     assertFragmentationStatOnVm(vm, 0, ASSERT_OP.EQUAL);
@@ -508,7 +509,7 @@ public class OffHeapManagementDUnitTest extends CacheTestCase {
       while (stopwatch.elapsed(MINUTES) < 2) {
         doPut("KEY" + (i++), new byte[allocationSize], OFF_HEAP_REGION_NAME, false);
       }
-    } catch (OutOfOffHeapMemoryException e) {
+    } catch (OutOfOffHeapMemoryException ignored) {
     }
 
     return i;
@@ -603,7 +604,7 @@ public class OffHeapManagementDUnitTest extends CacheTestCase {
    * @param vm a virtual machine.
    */
   private void doCleanupOnVm(final VM vm) {
-    vm.invoke(() -> cleanup());
+    vm.invoke(this::cleanup);
   }
 
   /**
@@ -627,7 +628,7 @@ public class OffHeapManagementDUnitTest extends CacheTestCase {
    * Asserts that the off heap region data is available and enabled for a VM.
    */
   private void assertOffHeapRegionAttributesOnVm(final VM vm) {
-    vm.invoke(() -> assertOffHeapRegionAttributes());
+    vm.invoke(this::assertOffHeapRegionAttributes);
   }
 
   /**
@@ -863,16 +864,16 @@ public class OffHeapManagementDUnitTest extends CacheTestCase {
    * @param vm a virtual machine.
    */
   private void clearNotificationListenerOnVm(final VM vm) {
-    vm.invoke(() -> notificationListener.clear());
+    vm.invoke(notificationListener::clear);
   }
 
   /**
    * Collects MBean Notifications.
    */
-  private static class OffHeapNotificationListener implements NotificationListener {
+  private static class OffHeapNotificationListener implements NotificationListener, Serializable {
 
-    private List<Notification> notificationList =
-        Collections.synchronizedList(new ArrayList<Notification>());
+    private final List<Notification> notificationList =
+        Collections.synchronizedList(new ArrayList<>());
 
     @Override
     public void handleNotification(final Notification notification, final Object handback) {
