@@ -85,7 +85,7 @@ public class PdxSerializableDUnitTest extends JUnit4CacheTestCase {
     vm3.invoke(createRegion);
 
     vm1.invoke(() -> doSimplePut(false));
-    vm2.invoke(() -> verifySimplePut());
+    vm2.invoke(this::verifySimplePut);
 
     vm3.invoke(new SerializableCallable("check for PDX") {
 
@@ -99,7 +99,7 @@ public class PdxSerializableDUnitTest extends JUnit4CacheTestCase {
 
   private void createPR() {
     getCache().createRegionFactory(RegionShortcut.PARTITION)
-        .setPartitionAttributes(new PartitionAttributesFactory<Integer, Object>().create())
+        .setPartitionAttributes(new PartitionAttributesFactory<>().create())
         .create(TEST_REGION_NAME);
   }
 
@@ -110,12 +110,12 @@ public class PdxSerializableDUnitTest extends JUnit4CacheTestCase {
     VM vm2 = host.getVM(1);
     VM vm3 = host.getVM(2);
 
-    vm1.invoke(() -> createPR());
-    vm2.invoke(() -> createPR());
-    vm3.invoke(() -> createPR());
+    vm1.invoke(this::createPR);
+    vm2.invoke(this::createPR);
+    vm3.invoke(this::createPR);
     vm1.invoke(() -> doSimplePut(true));
 
-    vm2.invoke(() -> verifySimplePut());
+    vm2.invoke(this::verifySimplePut);
 
     vm3.invoke(() -> {
       assertNotNull(getRootRegion(PeerTypeRegistration.REGION_NAME));
@@ -143,7 +143,7 @@ public class PdxSerializableDUnitTest extends JUnit4CacheTestCase {
     vm1.invoke(createRegionAndAddPoisonedListener);
     vm2.invoke(createRegionAndAddPoisonedListener);
     vm1.invoke(() -> doSimplePut(true));
-    vm2.invoke(() -> verifySimplePut());
+    vm2.invoke(this::verifySimplePut);
   }
 
   @Test
@@ -383,12 +383,10 @@ public class PdxSerializableDUnitTest extends JUnit4CacheTestCase {
     public int intVar;
     public double floatVar;
 
-    public static enum AnEnum {
+    public enum AnEnum {
       ONE, TWO
     }
 
-    ;
-
     public AnEnum enumVar;
 
     public TestPdxObject() {}
@@ -403,7 +401,7 @@ public class PdxSerializableDUnitTest extends JUnit4CacheTestCase {
     @Override
     public void toData(final PdxWriter writer) {
       writer.writeString("stringVar", stringVar).writeInt("intVar", intVar)
-          .writeDouble("floatVar", floatVar).writeObject("enumVar", this.enumVar);
+          .writeDouble("floatVar", floatVar).writeObject("enumVar", enumVar);
     }
 
     @Override
