@@ -29,7 +29,6 @@ import org.apache.geode.internal.AvailablePortHelper;
 /**
  * Tests {@link org.apache.geode.admin.internal.AdminDistributedSystemImpl}.
  *
- * @created August 30, 2004
  * @since GemFire 3.5
  */
 @SuppressWarnings("deprecation")
@@ -42,10 +41,10 @@ public class BindDistributedSystemJUnitTest {
 
   @After
   public void tearDown() {
-    if (this.system != null) {
-      this.system.disconnect();
+    if (system != null) {
+      system.disconnect();
     }
-    this.system = null;
+    system = null;
   }
 
   // public void testBindToAddressNull() throws Exception {
@@ -66,12 +65,12 @@ public class BindDistributedSystemJUnitTest {
     props.setProperty(BIND_ADDRESS, bindTo);
     props.setProperty(START_LOCATOR,
         "localhost[" + AvailablePortHelper.getRandomAvailableTCPPort() + "]");
-    this.system = org.apache.geode.distributed.DistributedSystem.connect(props);
+    system = org.apache.geode.distributed.DistributedSystem.connect(props);
 
-    assertEquals(true, this.system.isConnected());
+    assertEquals(true, system.isConnected());
 
     // Because of fix for bug 31409
-    this.system.disconnect();
+    system.disconnect();
 
   }
 
