@@ -38,6 +38,7 @@ import org.apache.geode.CancelCriterion;
 import org.apache.geode.InternalGemFireException;
 import org.apache.geode.cache.client.AllConnectionsInUseException;
 import org.apache.geode.cache.client.NoAvailableServersException;
+import org.apache.geode.cache.client.ServerConnectivityException;
 import org.apache.geode.cache.client.internal.Connection;
 import org.apache.geode.cache.client.internal.ConnectionFactory;
 import org.apache.geode.cache.client.internal.Endpoint;
@@ -150,7 +151,7 @@ public class ConnectionManagerImplTest {
 
     PooledConnection heldConnection =
         (PooledConnection) connectionManager.borrowConnection(timeout);
-    assertThatThrownBy(() -> heldConnection.activate()).isInstanceOf(InternalGemFireException.class)
+    assertThatThrownBy(heldConnection::activate).isInstanceOf(InternalGemFireException.class)
         .hasMessageContaining("Connection already active");
 
     connectionManager.close(false);
@@ -521,4 +522,17 @@ public class ConnectionManagerImplTest {
 
     connectionManager.close(false);
   }
+
+  @Test
+  public void borrowConnectionOnSpecificServerDoesNotIncrementConnectionCountWhenUnableToCreateConnection() {
+    ServerLocation serverLocation = mock(ServerLocation.class);
+    connectionManager = createDefaultConnectionManager();
+    connectionManager.start(backgroundProcessor);
+    assertThat(connectionManager.getConnectionCount()).isEqualTo(0);
+    assertThatThrownBy(() -> connectionManager.borrowConnection(serverLocation, timeout, false))
+        .isInstanceOf(ServerConnectivityException.class);
+    verify(connectionFactory, times(1)).createClientToServerConnection(serverLocation, false);
+    assertThat(connectionManager.getConnectionCount()).isEqualTo(0);
+    connectionManager.close(false);
+  }
 }
