@@ -45,11 +45,11 @@ public class TypedIteratorJUnitTest {
   public void testUntyped() throws QueryException {
     // one untyped iterator is now resolved fine
     Query q =
-        this.qs.newQuery("SELECT DISTINCT * " + "FROM " + SEPARATOR + "pos " + "WHERE ID = 3 ");
+        qs.newQuery("SELECT DISTINCT * " + "FROM " + SEPARATOR + "pos " + "WHERE ID = 3 ");
     q.execute();
 
     // if there are two untyped iterators, then it's a problem, see bug 32251 and BugTest
-    q = this.qs.newQuery("SELECT DISTINCT * FROM " + SEPARATOR + "pos, positions WHERE ID = 3");
+    q = qs.newQuery("SELECT DISTINCT * FROM " + SEPARATOR + "pos, positions WHERE ID = 3");
     try {
       q.execute();
       fail("Expected a TypeMismatchException");
@@ -60,13 +60,13 @@ public class TypedIteratorJUnitTest {
 
   @Test
   public void testTyped() throws QueryException {
-    Query q = this.qs.newQuery( // must quote "query" because it is a reserved word
+    Query q = qs.newQuery( // must quote "query" because it is a reserved word
         "IMPORT org.apache.geode.cache.\"query\".data.Portfolio;\n" + "SELECT DISTINCT *\n"
             + "FROM " + SEPARATOR + "pos TYPE Portfolio\n" + "WHERE ID = 3  ");
     Object r = q.execute();
 
 
-    q = this.qs.newQuery( // must quote "query" because it is a reserved word
+    q = qs.newQuery( // must quote "query" because it is a reserved word
         "IMPORT org.apache.geode.cache.\"query\".data.Portfolio;\n" + "SELECT DISTINCT *\n"
             + "FROM " + SEPARATOR + "pos ptfo TYPE Portfolio\n" + "WHERE ID = 3  ");
     r = q.execute();
@@ -75,12 +75,12 @@ public class TypedIteratorJUnitTest {
 
   @Test
   public void testTypeCasted() throws QueryException {
-    Query q = this.qs.newQuery( // must quote "query" because it is a reserved word
+    Query q = qs.newQuery( // must quote "query" because it is a reserved word
         "IMPORT org.apache.geode.cache.\"query\".data.Portfolio;\n" + "SELECT DISTINCT *\n"
             + "FROM (collection<Portfolio>)" + SEPARATOR + "pos\n" + "WHERE ID = 3  ");
     Object r = q.execute();
 
-    q = this.qs.newQuery( // must quote "query" because it is a reserved word
+    q = qs.newQuery( // must quote "query" because it is a reserved word
         "IMPORT org.apache.geode.cache.\"query\".data.Position;\n" + "SELECT DISTINCT *\n"
             + "FROM " + SEPARATOR + "pos p, (collection<Position>)p.positions.values\n"
             + "WHERE secId = 'IBM'");
