@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.functional;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.junit.Assert.assertEquals;
 
 import java.util.ArrayList;
@@ -50,12 +51,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testProjectionEvaluationDuringIndexResults() throws QueryException {
     QueryService qs = CacheUtils.getQueryService();
-    String[] queries = new String[] {"select  p.status from /pos p where p.ID > 0 ",
-        "select  p.status from /pos p, p.positions pos where p.ID > 0 ",
-        "select  p.status from /pos p  where p.ID > 0 and p.createTime > 0",
-        "select  p.status as sts, p as pos from /pos p  where p.ID > 0 and p.createTime > 0",
-        "select  p.status as sts, p as pos from /pos p  where p.ID IN  SET( 0,1,2,3) and p.createTime > 0",
-        "select  p.status as sts, p as pos from /pos p  where ( p.ID IN  SET( 0,1,2,3) and p.createTime > 0L) OR (p.ID IN  SET( 2,3) and p.createTime > 5L)"
+    String[] queries = new String[] {"select  p.status from " + SEPARATOR + "pos p where p.ID > 0 ",
+        "select  p.status from " + SEPARATOR + "pos p, p.positions pos where p.ID > 0 ",
+        "select  p.status from " + SEPARATOR + "pos p  where p.ID > 0 and p.createTime > 0",
+        "select  p.status as sts, p as pos from " + SEPARATOR
+            + "pos p  where p.ID > 0 and p.createTime > 0",
+        "select  p.status as sts, p as pos from " + SEPARATOR
+            + "pos p  where p.ID IN  SET( 0,1,2,3) and p.createTime > 0",
+        "select  p.status as sts, p as pos from " + SEPARATOR
+            + "pos p  where ( p.ID IN  SET( 0,1,2,3) and p.createTime > 0L) OR (p.ID IN  SET( 2,3) and p.createTime > 5L)"
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -65,7 +69,7 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
 
 
     ObjectType[] expectedTypes = new ObjectType[] {new ObjectTypeImpl(String.class),
@@ -113,9 +117,11 @@ public class CustomerOptimizationsJUnitTest {
   public void testProjectionEvaluationDuringIndexResults_UNIMPLEMENTED() throws QueryException {
     QueryService qs = CacheUtils.getQueryService();
     String[] queries = new String[] {
-        "select  p.status from /pos p, p.positions pos where p.ID > 0 ",
-        "select  p.status as sts, p as pos from /pos p  where ( p.ID IN  SET( 0,1,2,3) and p.createTime > 0L) OR (p.ID IN  SET( 2,3) and p.createTime > 5L)",
-        "select  p.status as sts, p as pos from /pos p  where  p.ID IN  SET( 0,1,2,3) and p.createTime > 0L"};
+        "select  p.status from " + SEPARATOR + "pos p, p.positions pos where p.ID > 0 ",
+        "select  p.status as sts, p as pos from " + SEPARATOR
+            + "pos p  where ( p.ID IN  SET( 0,1,2,3) and p.createTime > 0L) OR (p.ID IN  SET( 2,3) and p.createTime > 5L)",
+        "select  p.status as sts, p as pos from " + SEPARATOR
+            + "pos p  where  p.ID IN  SET( 0,1,2,3) and p.createTime > 0L"};
     SelectResults[][] sr = new SelectResults[queries.length][2];
 
     for (int i = 0; i < queries.length; ++i) {
@@ -123,8 +129,8 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
 
 
     ObjectType[] expectedTypes = new ObjectType[] {new ObjectTypeImpl(String.class),
@@ -163,15 +169,17 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testUnionDuringIndexEvaluationForIN() throws QueryException {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 200; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  p.status as sts, p as pos from /pos p  where  p.ID IN  SET( 0,1,2,3,4,5) ",
-        "select  p.status as sts, p as pos from /pos p  where  p.ID IN  SET( 0,1,2,3,4,5,101,102,103,104,105) AND p.createTime > 9l"};
+        "select  p.status as sts, p as pos from " + SEPARATOR
+            + "pos p  where  p.ID IN  SET( 0,1,2,3,4,5) ",
+        "select  p.status as sts, p as pos from " + SEPARATOR
+            + "pos p  where  p.ID IN  SET( 0,1,2,3,4,5,101,102,103,104,105) AND p.createTime > 9l"};
     SelectResults[][] sr = new SelectResults[queries.length][2];
 
     for (int i = 0; i < queries.length; ++i) {
@@ -179,7 +187,7 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true, true};
     final boolean[] actualIndexUsed = new boolean[] {false, false};
 
@@ -244,14 +252,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testBug39851() throws QueryException {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 200; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  p.status as sts, p as pos from /pos p  where  p.ID IN  ( Select x.ID from /pos x where x.ID > 10) "
+        "select  p.status as sts, p as pos from " + SEPARATOR
+            + "pos p  where  p.ID IN  ( Select x.ID from " + SEPARATOR + "pos x where x.ID > 10) "
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -261,7 +270,7 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true, true};
     final boolean[] actualIndexUsed = new boolean[] {false, false};
 
@@ -324,14 +333,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testUnionDuringIndexEvaluationWithMultipleFilters() throws QueryException {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 200; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  p.status as sts, p as pos from /pos p  where  p.ID IN  SET( 0,1,2,3,4,5,101,102,103,104,105) AND p.createTime > 9l"
+        "select  p.status as sts, p as pos from " + SEPARATOR
+            + "pos p  where  p.ID IN  SET( 0,1,2,3,4,5,101,102,103,104,105) AND p.createTime > 9l"
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -341,8 +351,8 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
@@ -405,14 +415,15 @@ public class CustomerOptimizationsJUnitTest {
   public void testProjectionEvaluationDuringIndexResultsWithComplexWhereClause_UNIMPLEMENTED_1()
       throws QueryException {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 200; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  p.status as sts, p as pos from /pos p  where   (p.ID IN  SET( 0,1,2,3,4,5,101,102,103,104,105) AND p.createTime > 9l) OR (p.ID IN  SET( 20,30,110,120) AND p.createTime > 7l)"
+        "select  p.status as sts, p as pos from " + SEPARATOR
+            + "pos p  where   (p.ID IN  SET( 0,1,2,3,4,5,101,102,103,104,105) AND p.createTime > 9l) OR (p.ID IN  SET( 20,30,110,120) AND p.createTime > 7l)"
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -422,7 +433,7 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
     // qs.createIndex("CreateTime", IndexType.FUNCTIONAL,"createTime", "/pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
@@ -486,14 +497,15 @@ public class CustomerOptimizationsJUnitTest {
   public void testProjectionEvaluationDuringIndexResultsWithComplexWhereClause_UNIMPLEMENTED_2()
       throws QueryException {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 200; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  p.status as sts, p as pos from /pos p  where   (p.ID IN  SET( 0,1,2,3,4,5,101,102,103,104,105) AND p.createTime > 9l) OR (p.ID IN  SET( 20,30,110,120) AND p.createTime > 7l)"
+        "select  p.status as sts, p as pos from " + SEPARATOR
+            + "pos p  where   (p.ID IN  SET( 0,1,2,3,4,5,101,102,103,104,105) AND p.createTime > 9l) OR (p.ID IN  SET( 20,30,110,120) AND p.createTime > 7l)"
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -503,8 +515,8 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
@@ -565,14 +577,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testSuspectedBug_1() throws Exception {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 200; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  distinct p.status  from /pos p  where   p.ID IN  SET( 0) AND p.createTime IN SET( 4l ) AND  p.\"type\" IN SET( 'type0') AND p.status IN SET( 'active')"
+        "select  distinct p.status  from " + SEPARATOR
+            + "pos p  where   p.ID IN  SET( 0) AND p.createTime IN SET( 4l ) AND  p.\"type\" IN SET( 'type0') AND p.status IN SET( 'active')"
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -582,10 +595,10 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
-    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", "/pos");
-    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
+    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", SEPARATOR + "pos");
+    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
@@ -645,14 +658,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testNestedJunction() throws Exception {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 10000; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  distinct p.status  from /pos p  where  (p.createTime IN SET( 10l ) OR  p.status IN SET( 'active') )AND  p.ID >  0 "
+        "select  distinct p.status  from " + SEPARATOR
+            + "pos p  where  (p.createTime IN SET( 10l ) OR  p.status IN SET( 'active') )AND  p.ID >  0 "
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -662,10 +676,10 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
     final List indexUsed = new ArrayList();
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
-    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", "/pos");
-    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
+    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", SEPARATOR + "pos");
+    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
@@ -727,14 +741,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testRangeQuery() throws Exception {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 200; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  distinct p.status  from /pos p  where  p.createTime > 0 AND p.createTime <11 AND  p.ID IN  SET( 0) "
+        "select  distinct p.status  from " + SEPARATOR
+            + "pos p  where  p.createTime > 0 AND p.createTime <11 AND  p.ID IN  SET( 0) "
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -744,10 +759,10 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
-    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", "/pos");
-    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
+    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", SEPARATOR + "pos");
+    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
@@ -809,14 +824,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testInAndEqualityCombination() throws Exception {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 200; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  distinct p.status  from /pos p  where  p.ID = 11 AND   p.createTime IN  SET( 10L) "
+        "select  distinct p.status  from " + SEPARATOR
+            + "pos p  where  p.ID = 11 AND   p.createTime IN  SET( 10L) "
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -826,10 +842,10 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
-    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", "/pos");
-    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
+    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", SEPARATOR + "pos");
+    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
@@ -891,14 +907,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testRangeAndNotEqualCombination() throws Exception {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 200; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  distinct p.status  from /pos p  where  p.ID > 11 AND  p.ID < 20 AND  p.createTime <>9L "
+        "select  distinct p.status  from " + SEPARATOR
+            + "pos p  where  p.ID > 11 AND  p.ID < 20 AND  p.createTime <>9L "
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -908,10 +925,10 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
-    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", "/pos");
-    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
+    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", SEPARATOR + "pos");
+    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
@@ -980,14 +997,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testInAndRangeCombination() throws Exception {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 200; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  distinct p.status  from /pos p  where  p.ID > 11 AND  p.ID < 19 and  p.createTime IN  SET( 10L) "
+        "select  distinct p.status  from " + SEPARATOR
+            + "pos p  where  p.ID > 11 AND  p.ID < 19 and  p.createTime IN  SET( 10L) "
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -997,10 +1015,10 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
 
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
-    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", "/pos");
-    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
+    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", SEPARATOR + "pos");
+    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
@@ -1062,14 +1080,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testNotFilterableNestedJunction() throws Exception {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 10000; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  distinct p.status  from /pos p  where  (p.createTime IN SET( 10l ) OR  p.status IN SET( 'active') )AND  p.ID >  0 AND  p.createTime = 10l"
+        "select  distinct p.status  from " + SEPARATOR
+            + "pos p  where  (p.createTime IN SET( 10l ) OR  p.status IN SET( 'active') )AND  p.ID >  0 AND  p.createTime = 10l"
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -1079,10 +1098,10 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
     final List indexUsed = new ArrayList();
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
     // qs.createIndex("Status", IndexType.FUNCTIONAL,"status", "/pos");
-    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", "/pos");
+    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
@@ -1146,14 +1165,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testProjectionEvaluationOnORJunction_NOT_IMPLEMENTED() throws Exception {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 10000; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  distinct p.status  from /pos p  where  p.createTime IN SET( 10l ) OR  p.status IN SET( 'active') OR p.ID >  0"
+        "select  distinct p.status  from " + SEPARATOR
+            + "pos p  where  p.createTime IN SET( 10l ) OR  p.status IN SET( 'active') OR p.ID >  0"
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -1163,10 +1183,10 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
     final List indexUsed = new ArrayList();
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
-    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", "/pos");
-    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
+    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", SEPARATOR + "pos");
+    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
@@ -1228,15 +1248,16 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testLiteralBehaviour_1() throws Exception {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 200; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
-    String[] queries = new String[] {"select  distinct p.status  from /pos p  where  true"
+    String[] queries =
+        new String[] {"select  distinct p.status  from " + SEPARATOR + "pos p  where  true"
 
-    };
+        };
     SelectResults[][] sr = new SelectResults[queries.length][2];
 
     for (int i = 0; i < queries.length; ++i) {
@@ -1244,10 +1265,10 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
     final List indexUsed = new ArrayList();
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
-    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", "/pos");
-    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
+    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", SEPARATOR + "pos");
+    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {false};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
@@ -1309,14 +1330,15 @@ public class CustomerOptimizationsJUnitTest {
   @Test
   public void testLiteralBheaviour_2() throws Exception {
     QueryService qs = CacheUtils.getQueryService();
-    Region rgn = CacheUtils.getRegion("/pos");
+    Region rgn = CacheUtils.getRegion(SEPARATOR + "pos");
     for (int i = 100; i < 1000; ++i) {
       Portfolio pf = new Portfolio(i);
       pf.setCreateTime(10l);
       rgn.put("" + i, pf);
     }
     String[] queries = new String[] {
-        "select  distinct p.status  from /pos p  where  p.createTime = 10l AND  p.status IN SET( 'active') AND  true"
+        "select  distinct p.status  from " + SEPARATOR
+            + "pos p  where  p.createTime = 10l AND  p.status IN SET( 'active') AND  true"
 
     };
     SelectResults[][] sr = new SelectResults[queries.length][2];
@@ -1326,10 +1348,10 @@ public class CustomerOptimizationsJUnitTest {
       sr[i][0] = (SelectResults) q.execute();
     }
     final List indexUsed = new ArrayList();
-    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", "/pos");
-    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", "/pos");
-    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", "/pos");
-    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", "/pos");
+    qs.createIndex("PortFolioID", IndexType.FUNCTIONAL, "ID", SEPARATOR + "pos");
+    qs.createIndex("CreateTime", IndexType.FUNCTIONAL, "createTime", SEPARATOR + "pos");
+    qs.createIndex("Status", IndexType.FUNCTIONAL, "status", SEPARATOR + "pos");
+    qs.createIndex("Type", IndexType.FUNCTIONAL, "\"type\"", SEPARATOR + "pos");
     final boolean[] expectedIndexUsed = new boolean[] {true};
     final boolean[] actualIndexUsed = new boolean[] {false};
 
