@@ -43,8 +43,8 @@ import org.apache.geode.util.internal.GeodeGlossary;
 @Category({OQLQueryTest.class})
 public class DistinctResultsWithDupValuesInRegionJUnitTest {
 
-  private static String regionName = "test";
-  private int numElem = 100;
+  private static final String regionName = "test";
+  private final int numElem = 100;
 
   public DistinctResultsWithDupValuesInRegionJUnitTest() {}
 
@@ -59,7 +59,7 @@ public class DistinctResultsWithDupValuesInRegionJUnitTest {
     CacheUtils.closeCache();
   }
 
-  private static String[] queries = new String[] {
+  private static final String[] queries = new String[] {
       "select DISTINCT * from " + SEPARATOR
           + "test p, p.positions.values pos where p.ID> 0 OR p.status = 'active' OR pos.secId = 'IBM' order by p.ID",
       "select DISTINCT * from " + SEPARATOR
@@ -73,7 +73,7 @@ public class DistinctResultsWithDupValuesInRegionJUnitTest {
       "select DISTINCT p.ID, p.status, pos.secId, pos.secType from " + SEPARATOR
           + "test p, p.positions.values pos where p.ID> 0 OR p.status = 'active' OR pos.secId = 'IBM' order by p.ID",};
 
-  private static String[] moreQueries = new String[] {
+  private static final String[] moreQueries = new String[] {
       "select DISTINCT p.ID, p.status from " + SEPARATOR
           + "test p, p.positions.values pos where p.ID> 0 OR p.status = 'active' order by p.ID",};
 
