@@ -26,7 +26,6 @@ import static org.junit.Assert.fail;
 import java.text.SimpleDateFormat;
 import java.util.Collection;
 import java.util.Date;
-import java.util.Iterator;
 
 import org.junit.After;
 import org.junit.Before;
@@ -70,9 +69,9 @@ public class FunctionJUnitTest {
     CompiledValue cv2 = new CompiledLiteral("str2");
     CompiledValue cv3 = new CompiledLiteral(null);
     CompiledValue cv4 = new CompiledLiteral(null);
-    CompiledValue cv5 = new CompiledLiteral(new Integer(10));
-    CompiledValue cv6 = new CompiledLiteral(new Integer(5));
-    CompiledValue cvArr[][] = new CompiledValue[][] {{cv1, cv2, cv3, cv4, cv5, cv6},
+    CompiledValue cv5 = new CompiledLiteral(10);
+    CompiledValue cv6 = new CompiledLiteral(5);
+    CompiledValue[][] cvArr = new CompiledValue[][] {{cv1, cv2, cv3, cv4, cv5, cv6},
         {cv6, cv5, cv3, cv4, cv2, cv1}, {cv1, cv3, cv5, cv2, cv4, cv6}, {cv1}, {cv3}, {cv5}};
 
     String[] canonicalizedArgs =
@@ -103,22 +102,21 @@ public class FunctionJUnitTest {
         .newQuery("SELECT DISTINCT * FROM " + SEPARATOR + "Portfolios where IS_DEFINED(P2.secId)");
     Object result = query.execute();
     if (result instanceof Collection) {
-      Iterator iter = ((Collection) result).iterator();
-      while (iter.hasNext()) {
-        Portfolio p = (Portfolio) iter.next();
+      for (final Object o : (Collection) result) {
+        Portfolio p = (Portfolio) o;
         if (p.getP2() == null) {
           fail(query.getQueryString());
         }
       }
     }
-    Object testData[][] = {{"string", Boolean.TRUE}, {new Integer(0), Boolean.TRUE},
+    Object[][] testData = {{"string", Boolean.TRUE}, {0, Boolean.TRUE},
         {QueryService.UNDEFINED, Boolean.FALSE}, {null, Boolean.TRUE}};
 
-    for (int i = 0; i < testData.length; i++) {
+    for (final Object[] testDatum : testData) {
       query = CacheUtils.getQueryService().newQuery("IS_DEFINED($1)");
-      result = query.execute(testData[i]);
-      if (!result.equals(testData[i][1])) {
-        fail(query.getQueryString() + " for " + testData[i][0]);
+      result = query.execute(testDatum);
+      if (!result.equals(testDatum[1])) {
+        fail(query.getQueryString() + " for " + testDatum[0]);
       }
     }
   }
@@ -130,22 +128,21 @@ public class FunctionJUnitTest {
             "SELECT DISTINCT * FROM " + SEPARATOR + "Portfolios where IS_UNDEFINED(P2.secId)");
     Object result = query.execute();
     if (result instanceof Collection) {
-      Iterator iter = ((Collection) result).iterator();
-      while (iter.hasNext()) {
-        Portfolio p = (Portfolio) iter.next();
+      for (final Object o : (Collection) result) {
+        Portfolio p = (Portfolio) o;
         if (p.getP2() != null) {
           fail(query.getQueryString());
         }
       }
     }
-    Object testData[][] = {{"string", Boolean.FALSE}, {new Integer(0), Boolean.FALSE},
+    Object[][] testData = {{"string", Boolean.FALSE}, {0, Boolean.FALSE},
         {QueryService.UNDEFINED, Boolean.TRUE}, {null, Boolean.FALSE}};
 
-    for (int i = 0; i < testData.length; i++) {
+    for (final Object[] testDatum : testData) {
       query = CacheUtils.getQueryService().newQuery("IS_UNDEFINED($1)");
-      result = query.execute(testData[i]);
-      if (!result.equals(testData[i][1])) {
-        fail(query.getQueryString() + " for " + testData[i][0]);
+      result = query.execute(testDatum);
+      if (!result.equals(testDatum[1])) {
+        fail(query.getQueryString() + " for " + testDatum[0]);
       }
     }
   }
@@ -164,7 +161,7 @@ public class FunctionJUnitTest {
               "ELEMENT(SELECT DISTINCT * FROM " + SEPARATOR + "Portfolios where ID <= 1).status");
       result = query.execute();
       fail(query.getQueryString());
-    } catch (FunctionDomainException e) {
+    } catch (FunctionDomainException ignored) {
 
     }
   }
@@ -229,7 +226,7 @@ public class FunctionJUnitTest {
 
     };
 
-    String noCheckQueries[] = {"to_date('100936', 'MMddyyyy')", "to_date('09/10/05', 'dd/MM/yyyy')",
+    String[] noCheckQueries = {"to_date('100936', 'MMddyyyy')", "to_date('09/10/05', 'dd/MM/yyyy')",
         "to_date('05/10/09', 'yyyy/MM/dd')", "to_date('05/09/10', 'yyyy/dd/MM')",
         "to_date('10/05/09', 'MM/yyyy/dd')", "to_date('09/05/10', 'dd/yyyy/MM')",
 
@@ -245,8 +242,8 @@ public class FunctionJUnitTest {
     Object result = null;
     Date date = new Date(105, 9, 9);
     QueryService qs = CacheUtils.getQueryService();
-    for (int i = 0; i < queries.length; i++) {
-      query = qs.newQuery(queries[i]);
+    for (final String s : queries) {
+      query = qs.newQuery(s);
       result = query.execute();
       // CacheUtils.log(((Date)result));
       if (!result.equals(date)) {
@@ -261,8 +258,7 @@ public class FunctionJUnitTest {
 
     }
 
-    for (int i = 0; i < fineGrainedQueries.length; i++) {
-      String[] dateStringAndFormat = fineGrainedQueries[i];
+    for (String[] dateStringAndFormat : fineGrainedQueries) {
       String dateString = dateStringAndFormat[0];
       String format = dateStringAndFormat[1];
       SimpleDateFormat sdf = new SimpleDateFormat(format);
