@@ -93,10 +93,10 @@ public class IUM6Bug32345ReJUnitTest {
     }
     QueryService qs;
     qs = CacheUtils.getQueryService();
-    String queries[] = {
+    String[] queries = {
         "SELECT DISTINCT * FROM " + SEPARATOR
             + "pos pf,  positions.values pos where pf.status='active' and pos.secId= 'IBM' and ID = 0"};
-    SelectResults sr[][] = new SelectResults[queries.length][2];
+    SelectResults[][] sr = new SelectResults[queries.length][2];
     for (int i = 0; i < queries.length; i++) {
       Query q = null;
       try {
@@ -110,9 +110,8 @@ public class IUM6Bug32345ReJUnitTest {
         strg1 = resType1.getFieldNames();
 
         set1 = ((sr[i][0]).asSet());
-        Iterator iter = set1.iterator();
-        while (iter.hasNext()) {
-          Struct stc1 = (Struct) iter.next();
+        for (final Object o : set1) {
+          Struct stc1 = (Struct) o;
           valPf1 = stc1.get(strg1[0]);
           valPos1 = stc1.get(strg1[1]);
           isActive1 = ((Portfolio) stc1.get(strg1[0])).isActive();
@@ -134,7 +133,7 @@ public class IUM6Bug32345ReJUnitTest {
     // pf.positions.values pos");
     qs.createIndex("IDIndex", IndexType.FUNCTIONAL, "pf.ID",
         SEPARATOR + "pos pf, pf.positions.values pos");
-    String queries2[] = {
+    String[] queries2 = {
         "SELECT DISTINCT * FROM " + SEPARATOR
             + "pos pf,  positions.values pos where pf.status='active' and pos.secId= 'IBM' and ID = 0"};
     for (int i = 0; i < queries.length; i++) {
@@ -155,9 +154,8 @@ public class IUM6Bug32345ReJUnitTest {
         // CacheUtils.log(strg2[1]);
 
         set2 = ((sr[i][1]).asSet());
-        Iterator iter = set2.iterator();
-        while (iter.hasNext()) {
-          Struct stc2 = (Struct) iter.next();
+        for (final Object o : set2) {
+          Struct stc2 = (Struct) o;
           valPf2 = stc2.get(strg2[0]);
           valPos2 = stc2.get(strg2[1]);
           isActive2 = ((Portfolio) stc2.get(strg2[0])).isActive();
