@@ -64,7 +64,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
 
   @Test
   public void testMultiIteratorsMultiRegion1() throws Exception {
-    Object r[][] = new Object[4][2];
+    Object[][] r = new Object[4][2];
     QueryService qs;
     qs = CacheUtils.getQueryService();
     Position.resetCounter();
@@ -87,7 +87,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
     for (int i = 0; i < 4; i++) {
       r3.put(i + "", new Employee("empName", (20 + i), i, "Mr.", (5000 + i), add1));
     }
-    String queries[] = {
+    String[] queries = {
         // Test case No. IUMR021
         "SELECT DISTINCT * FROM " + SEPARATOR + "portfolio1 pf1, " + SEPARATOR + "portfolio2 pf2, "
             + SEPARATOR + "employees e WHERE pf1.status = 'active'",};
@@ -110,9 +110,8 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
         fail("Index is NOT uesd");
       }
 
-      Iterator itr = observer.indexesUsed.iterator();
-      while (itr.hasNext()) {
-        String indexUsed = itr.next().toString();
+      for (final Object o : observer.indexesUsed) {
+        String indexUsed = o.toString();
         if (!(indexUsed).equals("statusIndexPf1")) {
           fail("<statusIndexPf1> was expected but found " + indexUsed);
         }
@@ -126,7 +125,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
 
   @Test
   public void testMultiIteratorsMultiRegion2() throws Exception {
-    Object r[][] = new Object[4][2];
+    Object[][] r = new Object[4][2];
     QueryService qs = CacheUtils.getQueryService();
     Position.resetCounter();
     // Create Regions
@@ -148,7 +147,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
     for (int i = 0; i < 4; i++) {
       r3.put(i + "", new Employee("empName", (20 + i), i, "Mr.", (5000 + i), add1));
     }
-    String queries[] = {
+    String[] queries = {
         // Test case No. IUMR022
         // Both the Indexes Must get used. Presently only one Index is being used.
         "SELECT DISTINCT * FROM " + SEPARATOR + "portfolio1 pf1, " + SEPARATOR + "portfolio2 pf2, "
@@ -198,7 +197,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
 
   @Test
   public void testMultiIteratorsMultiRegion3() throws Exception {
-    Object r[][] = new Object[9][2];
+    Object[][] r = new Object[9][2];
     QueryService qs = CacheUtils.getQueryService();
     Position.resetCounter();
     // Create Regions
@@ -211,7 +210,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
     for (int i = 0; i < 4; i++) {
       r2.put(i + "", new Portfolio(i));
     }
-    String queries[] = {
+    String[] queries = {
         // Test Case No. IUMR004
         "SELECT DISTINCT * FROM " + SEPARATOR + "portfolio1 pf1, " + SEPARATOR
             + "portfolio2 pf2, pf1.positions.values posit1,"
@@ -286,7 +285,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
 
   @Test
   public void testMultiIteratorsMultiRegion4() throws Exception {
-    Object r[][] = new Object[4][2];
+    Object[][] r = new Object[4][2];
     QueryService qs = CacheUtils.getQueryService();
     Position.resetCounter();
     // Create Regions
@@ -299,7 +298,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
     for (int i = 0; i < 4; i++) {
       r2.put(i + "", new Portfolio(i));
     }
-    String queries[] = {
+    String[] queries = {
         // Test case No. IUMR024
         // Both the Indexes Must get used. Presently only one Index is being used.
         "SELECT DISTINCT * FROM " + SEPARATOR + "portfolio1 pf1, pf1.positions.values posit1, "
@@ -353,7 +352,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
 
   @Test
   public void testMultiIteratorsMultiRegion5() throws Exception {
-    Object r[][] = new Object[4][2];
+    Object[][] r = new Object[4][2];
     QueryService qs = CacheUtils.getQueryService();
     Position.resetCounter();
     // Create Regions
@@ -375,7 +374,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
     for (int i = 0; i < 4; i++) {
       r3.put(i + "", new Employee("empName", (20 + i), i, "Mr.", (5000 + i), add1));
     }
-    String queries[] = {
+    String[] queries = {
         // Test case IUMR025
         // Three of the indexes must get used.. Presently only one Index is being used.
         "SELECT DISTINCT * FROM " + SEPARATOR + "portfolio1 pf1, " + SEPARATOR + "portfolio2 pf2, "
@@ -434,7 +433,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
 
   @Test
   public void testMultiIteratorsMultiRegion6() throws Exception {
-    Object r[][] = new Object[4][2];
+    Object[][] r = new Object[4][2];
     QueryService qs = CacheUtils.getQueryService();
     Position.resetCounter();
     // Create Regions
@@ -447,7 +446,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
     for (int i = 0; i < 4; i++) {
       r2.put(i + "", new Portfolio(i));
     }
-    String queries[] = {
+    String[] queries = {
         // Both the Indexes Must get used. Presently only one Index is being used.
         " SELECT DISTINCT * FROM " + SEPARATOR + "portfolio1 pf1, " + SEPARATOR
             + "portfolio2 pf2, pf1.positions.values posit1,"
@@ -504,7 +503,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
 
   @Test
   public void testMultiIteratorsMultiRegion7() throws Exception {
-    Object r[][] = new Object[4][2];
+    Object[][] r = new Object[4][2];
     QueryService qs = CacheUtils.getQueryService();
     Position.resetCounter();
     // Create Regions
@@ -517,7 +516,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
     for (int i = 0; i < 4; i++) {
       r2.put(i + "", new Portfolio(i));
     }
-    String queries[] = {
+    String[] queries = {
         // Task IUMR007
         "SELECT DISTINCT coll1 as collHldrMap1 , coll2 as CollHldrMap2 FROM " + SEPARATOR
             + "portfolio1 pf1, " + SEPARATOR
@@ -572,7 +571,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
 
   @Test
   public void testMultiIteratorsMultiRegion8() throws Exception {
-    Object r[][] = new Object[4][2];
+    Object[][] r = new Object[4][2];
     QueryService qs = CacheUtils.getQueryService();
     Position.resetCounter();
     // Create Regions
@@ -594,7 +593,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
     for (int i = 0; i < 4; i++) {
       r3.put(i + "", new Employee("empName", (20 + i), i, "Mr.", (5000 + i), add1));
     }
-    String queries[] = {
+    String[] queries = {
         "SELECT DISTINCT * FROM " + SEPARATOR + "portfolio1 pf1, pf1.positions.values posit1, "
             + SEPARATOR + "portfolio2 pf2, " + SEPARATOR + "employees e WHERE posit1.secId='IBM'"};
     // Execute Queries without Indexes
@@ -647,7 +646,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
         r2.put(i + "", new Employee("empName", (20 + i), i /* empId */, "Mr.", (5000 + i), add1));
       }
 
-      String queriesWithResCount[][] = {
+      String[][] queriesWithResCount = {
           // Test case No. IUMR021
           {"SELECT DISTINCT * FROM " + SEPARATOR + "portfolio pf, " + SEPARATOR
               + "employee emp WHERE pf.ID = emp.empId",
@@ -678,8 +677,8 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
               + "employee emp WHERE pf.ID = emp.empId AND (pf.status='active' OR pf.ID > 499)",
               "" + 750},};
 
-      String queries[] = new String[queriesWithResCount.length];
-      Object r[][] = new Object[queries.length][2];
+      String[] queries = new String[queriesWithResCount.length];
+      Object[][] r = new Object[queries.length][2];
 
       // Execute Queries without Indexes
       for (int i = 0; i < queries.length; i++) {
@@ -706,12 +705,11 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
           fail("Index is NOT used for query" + queries[i]);
         }
 
-        Iterator itr = observer.indexesUsed.iterator();
-        while (itr.hasNext()) {
-          String temp = itr.next().toString();
+        for (final Object o : observer.indexesUsed) {
+          String temp = o.toString();
           if (!(temp.equals("idIndexPf") || temp.equals("empIdIndexPf2")
               || temp.equals("statusIndexPf"))) {
-            fail("<idIndexPf> or <empIdIndexPf2>    was expected but found " + temp.toString());
+            fail("<idIndexPf> or <empIdIndexPf2>    was expected but found " + temp);
           }
         }
 
@@ -732,7 +730,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
     try {
       IndexManager.TEST_RANGEINDEX_ONLY = true;
 
-      Object r[][] = new Object[1][2];
+      Object[][] r = new Object[1][2];
       QueryService qs = CacheUtils.getQueryService();
       Position.resetCounter();
       // Create Regions
@@ -749,7 +747,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
         r2.put(i + "", new Employee("empName", (20 + i), i, "Mr.", (5000 + i), add1));
       }
 
-      String queries[] = {
+      String[] queries = {
           // Test case No. IUMR021
           "SELECT DISTINCT * FROM " + SEPARATOR + "portfolio pf, pf.positions pos, " + SEPARATOR
               + "employee emp WHERE pf.iD = emp.empId",};
@@ -773,11 +771,10 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
           fail("Index is NOT uesd");
         }
 
-        Iterator itr = observer.indexesUsed.iterator();
-        while (itr.hasNext()) {
-          String temp = itr.next().toString();
+        for (final Object o : observer.indexesUsed) {
+          String temp = o.toString();
           if (!(temp.equals("idIndexPf") || temp.equals("empIdIndexPf2"))) {
-            fail("<idIndexPf> or <empIdIndexPf2>    was expected but found " + temp.toString());
+            fail("<idIndexPf> or <empIdIndexPf2>    was expected but found " + temp);
           }
         }
 
@@ -795,7 +792,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
   public void testBasicCompositeIndexUsageWithMultipleIndexes() throws Exception {
     try {
       IndexManager.TEST_RANGEINDEX_ONLY = true;
-      Object r[][] = new Object[1][2];
+      Object[][] r = new Object[1][2];
       QueryService qs = CacheUtils.getQueryService();
       Position.resetCounter();
       // Create Regions
@@ -812,7 +809,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
         r2.put(i + "", new Employee("empName", (20 + i), i, "Mr.", (5000 + i), add1));
       }
 
-      String queries[] = {
+      String[] queries = {
           // Test case No. IUMR021
           "SELECT DISTINCT * FROM " + SEPARATOR + "portfolio pf, pf.positions pos, " + SEPARATOR
               + "employee emp WHERE pf.iD = emp.empId and pf.status='active' and emp.age > 900",};
@@ -836,12 +833,11 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
           fail("Index is NOT uesd");
         }
 
-        Iterator itr = observer.indexesUsed.iterator();
-        while (itr.hasNext()) {
-          String temp = itr.next().toString();
+        for (final Object o : observer.indexesUsed) {
+          String temp = o.toString();
           if (!(temp.equals("ageIndexemp") || temp.equals("idIndexPf")
               || temp.equals("empIdIndexPf2") || temp.equals("statusIndexPf2"))) {
-            fail("<idIndexPf> or <empIdIndexPf2>    was expected but found " + temp.toString());
+            fail("<idIndexPf> or <empIdIndexPf2>    was expected but found " + temp);
           }
         }
 
@@ -947,7 +943,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
     try {
       IndexManager.TEST_RANGEINDEX_ONLY = true;
 
-      Object r[][] = new Object[1][2];
+      Object[][] r = new Object[1][2];
       QueryService qs = CacheUtils.getQueryService();
       Position.resetCounter();
       // Create Regions
@@ -969,7 +965,7 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
         r2.put(i + "", new Employee("empName", (20 + i), i, "Mr.", (5000 + i), add1));
       }
 
-      String queries[] = {
+      String[] queries = {
           // Test case No. IUMR021
           "SELECT DISTINCT * FROM " + SEPARATOR + "portfolio pf, pf.positions pos, " + SEPARATOR
               + "portfolio3 pf3, " + SEPARATOR
@@ -996,12 +992,11 @@ public class IUMRMultiIndexesMultiRegionJUnitTest {
           fail("Index is NOT uesd");
         }
 
-        Iterator itr = observer.indexesUsed.iterator();
-        while (itr.hasNext()) {
-          String temp = itr.next().toString();
+        for (final Object o : observer.indexesUsed) {
+          String temp = o.toString();
           if (!(temp.equals("ageIndexemp") || temp.equals("idIndexPf")
               || temp.equals("empIdIndexPf2") || temp.equals("statusIndexPf3"))) {
-            fail("<idIndexPf> or <empIdIndexPf2>    was expected but found " + temp.toString());
+            fail("<idIndexPf> or <empIdIndexPf2>    was expected but found " + temp);
           }
         }
 
