@@ -21,7 +21,6 @@ import static org.junit.Assert.assertTrue;
 
 import java.text.ParseException;
 import java.util.Collection;
-import java.util.Iterator;
 import java.util.concurrent.CompletableFuture;
 
 import org.junit.After;
@@ -49,10 +48,10 @@ import org.apache.geode.util.internal.GeodeGlossary;
 @Category({OQLIndexTest.class})
 public class IndexOnEntrySetJUnitTest {
 
-  private static String testRegionName = "regionName";
+  private static final String testRegionName = "regionName";
   private static Region testRegion;
-  private static int numElem = 100;
-  private String newValue = "NEW VALUE";
+  private static final int numElem = 100;
+  private final String newValue = "NEW VALUE";
 
   @Before
   public void setUp() throws Exception {
@@ -156,9 +155,8 @@ public class IndexOnEntrySetJUnitTest {
   }
 
   private void clearData(Region region) {
-    Iterator it = region.entrySet().iterator();
-    while (it.hasNext()) {
-      Region.Entry entry = (Region.Entry) it.next();
+    for (final Object o : region.entrySet()) {
+      Region.Entry entry = (Region.Entry) o;
       region.destroy(entry.getKey());
     }
   }
@@ -209,9 +207,7 @@ public class IndexOnEntrySetJUnitTest {
     QueryService qs = CacheUtils.getQueryService();
     Index index = qs.createIndex("testIndex", indexedExpression, regionPath);
     SelectResults indexedResults = (SelectResults) qs.newQuery(query).execute();
-    Iterator iterator = indexedResults.iterator();
-    while (iterator.hasNext()) {
-      Object row = iterator.next();
+    for (final Object row : indexedResults) {
       if (row instanceof Struct) {
         Object[] fields = ((Struct) row).getFieldValues();
         for (Object field : fields) {
@@ -264,14 +260,14 @@ public class IndexOnEntrySetJUnitTest {
     public int PartitionID = 1;
 
     public SomeKey(int index, int partitionId) {
-      this.Index = index;
-      this.PartitionID = partitionId;
+      Index = index;
+      PartitionID = partitionId;
     }
 
     public boolean equals(Object other) {
       if (other instanceof SomeKey) {
         SomeKey otherKey = (SomeKey) other;
-        return this.Index == otherKey.Index && this.PartitionID == otherKey.PartitionID;
+        return Index == otherKey.Index && PartitionID == otherKey.PartitionID;
       }
       return false;
     }
@@ -289,7 +285,7 @@ public class IndexOnEntrySetJUnitTest {
     boolean isTestHookCalled = false;
     Region r;
 
-    private int testHookSpot;
+    private final int testHookSpot;
 
     public AbstractTestHook(int testHookSpot) {
       this.testHookSpot = testHookSpot;
@@ -330,9 +326,8 @@ public class IndexOnEntrySetJUnitTest {
 
     @Override
     public void doOp() {
-      Iterator it = r.entrySet().iterator();
-      while (it.hasNext()) {
-        Region.Entry entry = (Region.Entry) it.next();
+      for (final Object o : r.entrySet()) {
+        Region.Entry entry = (Region.Entry) o;
         r.destroy(entry.getKey());
       }
     }
@@ -347,9 +342,8 @@ public class IndexOnEntrySetJUnitTest {
 
     @Override
     public void doOp() {
-      Iterator it = r.entrySet().iterator();
-      while (it.hasNext()) {
-        Region.Entry entry = (Region.Entry) it.next();
+      for (final Object o : r.entrySet()) {
+        Region.Entry entry = (Region.Entry) o;
         r.invalidate(entry.getKey());
       }
     }
@@ -364,9 +358,8 @@ public class IndexOnEntrySetJUnitTest {
 
     @Override
     public void doOp() {
-      Iterator it = r.entrySet().iterator();
-      while (it.hasNext()) {
-        Region.Entry entry = (Region.Entry) it.next();
+      for (final Object o : r.entrySet()) {
+        Region.Entry entry = (Region.Entry) o;
         r.put(entry.getKey(), newValue);
       }
     }
