@@ -101,10 +101,10 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
     }
     QueryService qs;
     qs = CacheUtils.getQueryService();
-    String queries[] = {
+    String[] queries = {
         "SELECT DISTINCT * FROM " + SEPARATOR
             + "pos pf,  positions.values pos where pf.status='active' and pos.secId= 'IBM' and ID = 0"};
-    SelectResults sr[][] = new SelectResults[queries.length][2];
+    SelectResults[][] sr = new SelectResults[queries.length][2];
     for (int i = 0; i < queries.length; i++) {
       Query q = null;
       try {
@@ -118,15 +118,14 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
           fail("How could index be present when not created!?");
         }
         // CacheUtils.log(Utils.printResult(r));
-        resType1 = (StructType) ((SelectResults) sr[i][0]).getCollectionType().getElementType();
-        resSize1 = (((SelectResults) sr[i][0]).size());
+        resType1 = (StructType) sr[i][0].getCollectionType().getElementType();
+        resSize1 = (sr[i][0].size());
         CacheUtils.log(resType1);
         strg1 = resType1.getFieldNames();
 
-        set1 = (((SelectResults) sr[i][0]).asSet());
-        Iterator iter = set1.iterator();
-        while (iter.hasNext()) {
-          Struct stc1 = (Struct) iter.next();
+        set1 = (sr[i][0].asSet());
+        for (final Object o : set1) {
+          Struct stc1 = (Struct) o;
           valPf1 = stc1.get(strg1[0]);
           valPos1 = stc1.get(strg1[1]);
           isActive1 = ((Portfolio) stc1.get(strg1[0])).isActive();
@@ -157,14 +156,13 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
         if (!observer2.isIndexesUsed) {
           fail("FAILED: Index NOT Used");
         }
-        resType2 = (StructType) ((SelectResults) sr[i][1]).getCollectionType().getElementType();
-        resSize2 = (((SelectResults) sr[i][1]).size());
+        resType2 = (StructType) sr[i][1].getCollectionType().getElementType();
+        resSize2 = (sr[i][1].size());
         strg2 = resType2.getFieldNames();
 
-        set2 = (((SelectResults) sr[i][1]).asSet());
-        Iterator iter = set2.iterator();
-        while (iter.hasNext()) {
-          Struct stc2 = (Struct) iter.next();
+        set2 = (sr[i][1].asSet());
+        for (final Object o : set2) {
+          Struct stc2 = (Struct) o;
           valPf2 = stc2.get(strg2[0]);
           valPos2 = stc2.get(strg2[1]);
           isActive2 = ((Portfolio) stc2.get(strg2[0])).isActive();
@@ -222,10 +220,10 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
     }
     QueryService qs;
     qs = CacheUtils.getQueryService();
-    String queries[] = {
+    String[] queries = {
         "SELECT DISTINCT * FROM " + SEPARATOR
             + "pos pf,  positions.values pos where pf.ID > 0 and pf.ID < 3  and pf.status='active' and  pos.secId != null "};
-    SelectResults sr[][] = new SelectResults[queries.length][2];
+    SelectResults[][] sr = new SelectResults[queries.length][2];
     for (int i = 0; i < queries.length; i++) {
       Query q = null;
       try {
@@ -239,15 +237,14 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
           fail("How could index be present when not created!?");
         }
         // CacheUtils.log(Utils.printResult(r));
-        resType1 = (StructType) ((SelectResults) sr[i][0]).getCollectionType().getElementType();
-        resSize1 = (((SelectResults) sr[i][0]).size());
+        resType1 = (StructType) sr[i][0].getCollectionType().getElementType();
+        resSize1 = (sr[i][0].size());
         CacheUtils.log(resType1);
         strg1 = resType1.getFieldNames();
 
-        set1 = (((SelectResults) sr[i][0]).asSet());
-        Iterator iter = set1.iterator();
-        while (iter.hasNext()) {
-          Struct stc1 = (Struct) iter.next();
+        set1 = (sr[i][0].asSet());
+        for (final Object o : set1) {
+          Struct stc1 = (Struct) o;
           valPf1 = stc1.get(strg1[0]);
           valPos1 = stc1.get(strg1[1]);
           isActive1 = ((Portfolio) stc1.get(strg1[0])).isActive();
@@ -264,7 +261,7 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
     qs = CacheUtils.getQueryService();
     Index index1 =
         qs.createIndex("statusIndex", IndexType.FUNCTIONAL, "pf.status", SEPARATOR + "pos pf");
-    Index index2 = (Index) qs.createIndex("secIdIndex", IndexType.FUNCTIONAL, "pos.secId",
+    Index index2 = qs.createIndex("secIdIndex", IndexType.FUNCTIONAL, "pos.secId",
         SEPARATOR + "pos pf, pf.positions.values pos");
     Index index3 = qs.createIndex("IDIndex", IndexType.FUNCTIONAL, "pf.ID", SEPARATOR + "pos pf");
 
@@ -280,14 +277,13 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
         }
         assertTrue(observer2.indexesUsed.size() < 2);
 
-        resType2 = (StructType) ((SelectResults) sr[i][1]).getCollectionType().getElementType();
-        resSize2 = (((SelectResults) sr[i][1]).size());
+        resType2 = (StructType) sr[i][1].getCollectionType().getElementType();
+        resSize2 = (sr[i][1].size());
         strg2 = resType2.getFieldNames();
 
-        set2 = (((SelectResults) sr[i][1]).asSet());
-        Iterator iter = set2.iterator();
-        while (iter.hasNext()) {
-          Struct stc2 = (Struct) iter.next();
+        set2 = (sr[i][1].asSet());
+        for (final Object o : set2) {
+          Struct stc2 = (Struct) o;
           valPf2 = stc2.get(strg2[0]);
           valPos2 = stc2.get(strg2[1]);
           isActive2 = ((Portfolio) stc2.get(strg2[0])).isActive();
@@ -346,10 +342,10 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
     }
     QueryService qs;
     qs = CacheUtils.getQueryService();
-    String queries[] = {
+    String[] queries = {
         "SELECT DISTINCT * FROM " + SEPARATOR
             + "pos pf,  positions.values pos where pf.ID > 0 and pf.ID < 250  and pf.status='active' and  pos.secId != null "};
-    SelectResults sr[][] = new SelectResults[queries.length][2];
+    SelectResults[][] sr = new SelectResults[queries.length][2];
     for (int i = 0; i < queries.length; i++) {
       Query q = null;
       try {
@@ -363,15 +359,14 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
           fail("How could index be present when not created!?");
         }
         // CacheUtils.log(Utils.printResult(r));
-        resType1 = (StructType) ((SelectResults) sr[i][0]).getCollectionType().getElementType();
-        resSize1 = (((SelectResults) sr[i][0]).size());
+        resType1 = (StructType) sr[i][0].getCollectionType().getElementType();
+        resSize1 = (sr[i][0].size());
         CacheUtils.log(resType1);
         strg1 = resType1.getFieldNames();
 
-        set1 = (((SelectResults) sr[i][0]).asSet());
-        Iterator iter = set1.iterator();
-        while (iter.hasNext()) {
-          Struct stc1 = (Struct) iter.next();
+        set1 = (sr[i][0].asSet());
+        for (final Object o : set1) {
+          Struct stc1 = (Struct) o;
           valPf1 = stc1.get(strg1[0]);
           valPos1 = stc1.get(strg1[1]);
           isActive1 = ((Portfolio) stc1.get(strg1[0])).isActive();
@@ -388,7 +383,7 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
     qs = CacheUtils.getQueryService();
     Index index1 =
         qs.createIndex("statusIndex", IndexType.FUNCTIONAL, "pf.status", SEPARATOR + "pos pf");
-    Index index2 = (Index) qs.createIndex("secIdIndex", IndexType.FUNCTIONAL, "pos.secId",
+    Index index2 = qs.createIndex("secIdIndex", IndexType.FUNCTIONAL, "pos.secId",
         SEPARATOR + "pos pf, pf.positions.values pos");
     Index index3 = qs.createIndex("IDIndex", IndexType.FUNCTIONAL, "pf.ID", SEPARATOR + "pos pf");
 
@@ -404,15 +399,14 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
         }
         assertEquals(observer2.indexesUsed.size(), 1);
 
-        resType2 = (StructType) ((SelectResults) sr[i][1]).getCollectionType().getElementType();
-        resSize2 = (((SelectResults) sr[i][1]).size());
+        resType2 = (StructType) sr[i][1].getCollectionType().getElementType();
+        resSize2 = (sr[i][1].size());
         CacheUtils.log(resType2);
         strg2 = resType2.getFieldNames();
 
-        set2 = (((SelectResults) sr[i][1]).asSet());
-        Iterator iter = set2.iterator();
-        while (iter.hasNext()) {
-          Struct stc2 = (Struct) iter.next();
+        set2 = (sr[i][1].asSet());
+        for (final Object o : set2) {
+          Struct stc2 = (Struct) o;
           valPf2 = stc2.get(strg2[0]);
           valPos2 = stc2.get(strg2[1]);
           isActive2 = ((Portfolio) stc2.get(strg2[0])).isActive();
@@ -504,10 +498,10 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
   private void executeQuery(Region region, boolean checkReferentialIntegrity) throws Exception {
     QueryService qs;
     qs = CacheUtils.getQueryService();
-    String queries[] = {
+    String[] queries = {
         "SELECT DISTINCT pf FROM " + SEPARATOR
             + "pos pf,  positions.values pos where pf.description = 'XXXX'  and pos.secId= 'IBM' "};
-    SelectResults sr[][] = new SelectResults[queries.length][2];
+    SelectResults[][] sr = new SelectResults[queries.length][2];
 
     ObjectType resType1 = null, resType2 = null;
     for (int i = 0; i < queries.length; i++) {
@@ -523,13 +517,12 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
           fail("How did Index get created?");
         }
         // CacheUtils.log(Utils.printResult(r));
-        resType1 = ((SelectResults) sr[i][0]).getCollectionType().getElementType();
-        resSize1 = (((SelectResults) sr[i][0]).size());
+        resType1 = sr[i][0].getCollectionType().getElementType();
+        resSize1 = (sr[i][0].size());
         CacheUtils.log(resType1);
-        set1 = (((SelectResults) sr[i][0]).asSet());
-        Iterator iter = set1.iterator();
-        while (iter.hasNext()) {
-          valPf1 = iter.next();
+        set1 = (sr[i][0].asSet());
+        for (final Object o : set1) {
+          valPf1 = o;
           isActive1 = ((Portfolio) valPf1).isActive();
 
         }
@@ -544,7 +537,7 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
     qs = CacheUtils.getQueryService();
     Index index1 =
         qs.createIndex("statusIndex", IndexType.FUNCTIONAL, "pf.status", SEPARATOR + "pos pf");
-    Index index2 = (Index) qs.createIndex("secIdIndex", IndexType.FUNCTIONAL, "pos.secId",
+    Index index2 = qs.createIndex("secIdIndex", IndexType.FUNCTIONAL, "pos.secId",
         SEPARATOR + "pos pf, pf.positions.values pos");
     Index index3 =
         qs.createIndex("descriptionIndex", IndexType.FUNCTIONAL, "pf.description",
@@ -562,15 +555,14 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
         } else {
           fail("FAILED: Index NOT Used");
         }
-        resType2 = ((SelectResults) sr[i][1]).getCollectionType().getElementType();
-        resSize2 = (((SelectResults) sr[i][1]).size());
+        resType2 = sr[i][1].getCollectionType().getElementType();
+        resSize2 = (sr[i][1].size());
         CacheUtils.log(resType2);
         // strg2=resType2.getFieldNames();
 
-        set2 = (((SelectResults) sr[i][1]).asSet());
-        Iterator iter = set2.iterator();
-        while (iter.hasNext()) {
-          valPf2 = iter.next();
+        set2 = (sr[i][1].asSet());
+        for (final Object o : set2) {
+          valPf2 = o;
           // valPf2=stc2.get(strg2[0]);
           // valPos2=stc2.get(strg2[1]);
           isActive2 = ((Portfolio) valPf2).isActive();
@@ -663,10 +655,10 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
 
     QueryService qs;
     qs = CacheUtils.getQueryService();
-    String queries[] =
+    String[] queries =
         {"SELECT DISTINCT * FROM " + SEPARATOR
             + "pos pf where pf.description = 'XXXX'  and pf.status='active' "};
-    SelectResults sr[][] = new SelectResults[queries.length][2];
+    SelectResults[][] sr = new SelectResults[queries.length][2];
 
     ObjectType resType1 = null, resType2 = null;
     for (int i = 0; i < queries.length; i++) {
@@ -683,15 +675,14 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
           fail("How did Index get created?");
         }
         // CacheUtils.log(Utils.printResult(r));
-        resType1 = ((SelectResults) sr[i][0]).getCollectionType().getElementType();
-        resSize1 = (((SelectResults) sr[i][0]).size());
+        resType1 = sr[i][0].getCollectionType().getElementType();
+        resSize1 = (sr[i][0].size());
         CacheUtils.log(resType1);
         // strg1=resType1.getFieldNames();
 
-        set1 = (((SelectResults) sr[i][0]).asSet());
-        Iterator iter = set1.iterator();
-        while (iter.hasNext()) {
-          valPf1 = iter.next();
+        set1 = (sr[i][0].asSet());
+        for (final Object o : set1) {
+          valPf1 = o;
           // valPf1 = stc1.get(strg1[0]);
           // valPos1 = stc1.get(strg1[1]);
           isActive1 = ((Portfolio) valPf1).isActive();
@@ -709,7 +700,7 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
     Index index1 =
         qs.createIndex("statusIndex", IndexType.FUNCTIONAL, "pf.status", SEPARATOR + "pos pf");
     Index index2 =
-        (Index) qs.createIndex("IdIndex", IndexType.FUNCTIONAL, "pf.iD", SEPARATOR + "pos pf");
+        qs.createIndex("IdIndex", IndexType.FUNCTIONAL, "pf.iD", SEPARATOR + "pos pf");
     Index index3 =
         qs.createIndex("descriptionIndex", IndexType.FUNCTIONAL, "pf.description",
             SEPARATOR + "pos pf");
@@ -726,15 +717,14 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
         } else {
           fail("FAILED: Index NOT Used");
         }
-        resType2 = ((SelectResults) sr[i][1]).getCollectionType().getElementType();
-        resSize2 = (((SelectResults) sr[i][1]).size());
+        resType2 = sr[i][1].getCollectionType().getElementType();
+        resSize2 = (sr[i][1].size());
         CacheUtils.log(resType2);
         // strg2=resType2.getFieldNames();
 
-        set2 = (((SelectResults) sr[i][1]).asSet());
-        Iterator iter = set2.iterator();
-        while (iter.hasNext()) {
-          valPf2 = iter.next();
+        set2 = (sr[i][1].asSet());
+        for (final Object o : set2) {
+          valPf2 = o;
           // valPf2=stc2.get(strg2[0]);
           // valPos2=stc2.get(strg2[1]);
           isActive2 = ((Portfolio) valPf2).isActive();
@@ -893,10 +883,10 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
 
     QueryService qs;
     qs = CacheUtils.getQueryService();
-    String queries[] = {
+    String[] queries = {
         "SELECT DISTINCT * FROM " + SEPARATOR
             + "pos pf where pf.description = 'XXXX'  and pf.status='active' and pf.createTime = 5 "};
-    SelectResults sr[][] = new SelectResults[queries.length][2];
+    SelectResults[][] sr = new SelectResults[queries.length][2];
     ObjectType resType1 = null, resType2 = null;
     for (int i = 0; i < queries.length; i++) {
       Query q = null;
@@ -911,14 +901,13 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
           fail("How did Index get created!!1?");
         }
         // CacheUtils.log(Utils.printResult(r));
-        resType1 = ((SelectResults) sr[i][0]).getCollectionType().getElementType();
-        resSize1 = (((SelectResults) sr[i][0]).size());
+        resType1 = sr[i][0].getCollectionType().getElementType();
+        resSize1 = (sr[i][0].size());
         CacheUtils.log(resType1);
         assertEquals(1, resSize1);
-        set1 = (((SelectResults) sr[i][0]).asSet());
-        Iterator iter = set1.iterator();
-        while (iter.hasNext()) {
-          valPf1 = iter.next();
+        set1 = (sr[i][0].asSet());
+        for (final Object o : set1) {
+          valPf1 = o;
           isActive1 = ((Portfolio) valPf1).isActive();
           assertTrue(isActive1);
           assertEquals("XXXX", ((Portfolio) valPf1).description);
@@ -952,15 +941,14 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
         } else {
           fail("FAILED: Index NOT Used");
         }
-        resType2 = ((SelectResults) sr[i][1]).getCollectionType().getElementType();
-        resSize2 = (((SelectResults) sr[i][1]).size());
+        resType2 = sr[i][1].getCollectionType().getElementType();
+        resSize2 = (sr[i][1].size());
         CacheUtils.log(resType2);
         // strg2=resType2.getFieldNames();
 
-        set2 = (((SelectResults) sr[i][1]).asSet());
-        Iterator iter = set2.iterator();
-        while (iter.hasNext()) {
-          valPf2 = iter.next();
+        set2 = (sr[i][1].asSet());
+        for (final Object o : set2) {
+          valPf2 = o;
           // valPf2=stc2.get(strg2[0]);
           // valPos2=stc2.get(strg2[1]);
           isActive2 = ((Portfolio) valPf2).isActive();
@@ -1110,11 +1098,11 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
 
     QueryService qs;
     qs = CacheUtils.getQueryService();
-    String queries[] = {
+    String[] queries = {
         "SELECT DISTINCT * FROM " + SEPARATOR
             + "pos pf where pf.description = 'XXXX'  and pf.status='active' and pf.createTime = 5 "};
     ObjectType resType1 = null, resType2 = null;
-    SelectResults sr[][] = new SelectResults[queries.length][2];
+    SelectResults[][] sr = new SelectResults[queries.length][2];
     for (int i = 0; i < queries.length; i++) {
       Query q = null;
       try {
@@ -1126,14 +1114,13 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
           CacheUtils.log("NO INDEX USED");
         }
         // CacheUtils.log(Utils.printResult(r));
-        resType1 = ((SelectResults) sr[i][0]).getCollectionType().getElementType();
-        resSize1 = (((SelectResults) sr[i][0]).size());
+        resType1 = sr[i][0].getCollectionType().getElementType();
+        resSize1 = (sr[i][0].size());
         CacheUtils.log(resType1);
         assertEquals(1, resSize1);
-        set1 = (((SelectResults) sr[i][0]).asSet());
-        Iterator iter = set1.iterator();
-        while (iter.hasNext()) {
-          valPf1 = iter.next();
+        set1 = (sr[i][0].asSet());
+        for (final Object o : set1) {
+          valPf1 = o;
           isActive1 = ((Portfolio) valPf1).isActive();
           assertTrue(isActive1);
           assertEquals("XXXX", ((Portfolio) valPf1).description);
@@ -1152,7 +1139,7 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
     Index index1 =
         qs.createIndex("statusIndex", IndexType.FUNCTIONAL, "pf.status", SEPARATOR + "pos pf");
     Index index2 =
-        (Index) qs.createIndex("IdIndex", IndexType.FUNCTIONAL, "pf.iD", SEPARATOR + "pos pf");
+        qs.createIndex("IdIndex", IndexType.FUNCTIONAL, "pf.iD", SEPARATOR + "pos pf");
     Index index3 =
         qs.createIndex("descriptionIndex", IndexType.FUNCTIONAL, "pf.description",
             SEPARATOR + "pos pf");
@@ -1169,14 +1156,13 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
         } else {
           fail("FAILED: Index NOT Used");
         }
-        resType2 = ((SelectResults) sr[i][1]).getCollectionType().getElementType();
-        resSize2 = (((SelectResults) sr[i][1]).size());
+        resType2 = sr[i][1].getCollectionType().getElementType();
+        resSize2 = (sr[i][1].size());
         // strg2=resType2.getFieldNames();
 
-        set2 = (((SelectResults) sr[i][1]).asSet());
-        Iterator iter = set2.iterator();
-        while (iter.hasNext()) {
-          valPf2 = iter.next();
+        set2 = (sr[i][1].asSet());
+        for (final Object o : set2) {
+          valPf2 = o;
           // valPf2=stc2.get(strg2[0]);
           // valPos2=stc2.get(strg2[1]);
           isActive2 = ((Portfolio) valPf2).isActive();
@@ -1246,7 +1232,7 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
     }
     QueryService qs;
     qs = CacheUtils.getQueryService();
-    String queries[] =
+    String[] queries =
         {"SELECT * FROM " + SEPARATOR
             + "pos pf,  positions.values pos where pf.ID > 0 OR pf.status='active' OR  pos.secId != 'IBM'",
             "SELECT * FROM " + SEPARATOR + "pos pf where pf.ID > 0 OR pf.status='active'",
@@ -1254,7 +1240,7 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
             "SELECT * FROM " + SEPARATOR
                 + "pos pf where pf.ID > 0 OR pf.status IN SET('active', 'inactive')",};
 
-    SelectResults sr[] = new SelectResults[queries.length];
+    SelectResults[] sr = new SelectResults[queries.length];
     for (int i = 0; i < queries.length; i++) {
       Query q = null;
       try {
@@ -1292,9 +1278,7 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
             resultSet.size());
       }
 
-      Iterator itr = resultSet.iterator();
-      while (itr.hasNext()) {
-        Object obj = itr.next();
+      for (final Object obj : resultSet) {
         if (sr[i].getCollectionType().getElementType().toString().equals(
             "struct<pf:org.apache.geode.cache.query.data.Portfolio,pos:java.lang.Object>")) {
           Object[] values = ((Struct) obj).getFieldValues();
@@ -1337,7 +1321,7 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
     }
     QueryService qs;
     qs = CacheUtils.getQueryService();
-    String queries[] =
+    String[] queries =
         {"SELECT * FROM " + SEPARATOR
             + "pos pf,  positions.values pos where pf.ID > 0 OR pf.status='active' OR  pos.secId != 'IBM'",
             "SELECT * FROM " + SEPARATOR + "pos pf where pf.ID > 0 OR pf.status='active'",
@@ -1347,7 +1331,7 @@ public class IndexWithSngleFrmAndMultCondQryJUnitTest {
             "SELECT * FROM " + SEPARATOR
                 + "pos pf where pf.ID > 0 OR pf.status IN SET('active', 'inactive')",};
 
-    SelectResults sr[][] = new SelectResults[queries.length][2];
+    SelectResults[][] sr = new SelectResults[queries.length][2];
     for (int i = 0; i < queries.length; i++) {
       Query q = null;
       try {
