@@ -54,7 +54,7 @@ public class IteratorTypeDefJUnitTest {
 
   @Test
   public void testIteratorDefSyntax() throws Exception {
-    String queries[] = {
+    String[] queries = {
         "IMPORT org.apache.geode.cache.\"query\".data.Position;"
             + "SELECT DISTINCT secId FROM " + SEPARATOR
             + "portfolios,  positions.values pos TYPE Position WHERE iD > 0",
@@ -68,10 +68,10 @@ public class IteratorTypeDefJUnitTest {
             + "portfolios,  positions.values AS pos  WHERE iD > 0",
         "SELECT DISTINCT pos.secId FROM " + SEPARATOR
             + "portfolios, pos IN positions.values  WHERE iD > 0",};
-    for (int i = 0; i < queries.length; i++) {
+    for (final String query : queries) {
       Query q = null;
       try {
-        q = CacheUtils.getQueryService().newQuery(queries[i]);
+        q = CacheUtils.getQueryService().newQuery(query);
         Object r = q.execute();
       } catch (Exception e) {
         e.printStackTrace();
@@ -83,13 +83,13 @@ public class IteratorTypeDefJUnitTest {
 
   @Test
   public void testIteratorDefSyntaxForObtainingResultBag() throws Exception {
-    String queries[] = {"IMPORT org.apache.geode.cache.\"query\".data.Position;"
+    String[] queries = {"IMPORT org.apache.geode.cache.\"query\".data.Position;"
         + "SELECT DISTINCT secId FROM " + SEPARATOR
         + "portfolios, (set<Position>)positions.values WHERE iD > 0",};
-    for (int i = 0; i < queries.length; i++) {
+    for (final String query : queries) {
       Query q = null;
       try {
-        q = CacheUtils.getQueryService().newQuery(queries[i]);
+        q = CacheUtils.getQueryService().newQuery(query);
         Object r = q.execute();
         if (!(r instanceof SelectResults)) {
           fail(
@@ -112,12 +112,12 @@ public class IteratorTypeDefJUnitTest {
   @Test
   public void testNOValueconstraintInCreatRegion() throws Exception {
     CacheUtils.createRegion("pos", null);
-    String queries[] = {"IMPORT org.apache.geode.cache.\"query\".data.Portfolio;"
+    String[] queries = {"IMPORT org.apache.geode.cache.\"query\".data.Portfolio;"
         + "SELECT DISTINCT * FROM (set<Portfolio>)" + SEPARATOR + "pos where iD > 0"};
-    for (int i = 0; i < queries.length; i++) {
+    for (final String query : queries) {
       Query q = null;
       try {
-        q = CacheUtils.getQueryService().newQuery(queries[i]);
+        q = CacheUtils.getQueryService().newQuery(query);
         Object r = q.execute();
       } catch (Exception e) {
         e.printStackTrace();
@@ -134,14 +134,14 @@ public class IteratorTypeDefJUnitTest {
       region.put("" + i, new Portfolio(i));
     }
     CacheUtils.log(region);
-    String queries[] = {"IMPORT org.apache.geode.cache.\"query\".data.Position;"
+    String[] queries = {"IMPORT org.apache.geode.cache.\"query\".data.Position;"
         + "IMPORT org.apache.geode.cache.\"query\".data.Portfolio;"
         + "SELECT DISTINCT secId FROM (set<Portfolio>)" + SEPARATOR
         + "portfl, (set<Position>)positions.values WHERE iD > 0",};
-    for (int i = 0; i < queries.length; i++) {
+    for (final String query : queries) {
       Query q = null;
       try {
-        q = CacheUtils.getQueryService().newQuery(queries[i]);
+        q = CacheUtils.getQueryService().newQuery(query);
         Object r = q.execute();
       } catch (Exception e) {
         e.printStackTrace();
