@@ -200,12 +200,12 @@ public class LimitClauseJUnitTest {
     Object[] params = new Object[2];
     params[0] = 5;
     int[] limits = {1, 5, 0, 10};
-    for (int i = 0; i < limits.length; i++) {
-      params[1] = limits[i];
+    for (final int limit : limits) {
+      params[1] = limit;
 
       SelectResults results =
           helpTestIndexForQuery(queryString, "shortID", SEPARATOR + "portfolios1", params);
-      assertEquals(limits[i], results.size());
+      assertEquals(limit, results.size());
       // clear out indexes for next query.
       qs.removeIndexes();
     }
@@ -238,7 +238,7 @@ public class LimitClauseJUnitTest {
       assertEquals(5, num[0]);
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
     } catch (Exception e) {
       CacheUtils.getLogger().error(e);
@@ -277,7 +277,7 @@ public class LimitClauseJUnitTest {
       assertEquals(5, num[0]);
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
     } catch (Exception e) {
       CacheUtils.getLogger().error(e);
@@ -339,7 +339,7 @@ public class LimitClauseJUnitTest {
       assertEquals((5 + numRepeat[0]), num[0]);
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
 
     } catch (Exception e) {
@@ -399,7 +399,7 @@ public class LimitClauseJUnitTest {
       assertEquals((5 + numRepeat[0]), num[0]);
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
 
     } catch (Exception e) {
@@ -439,7 +439,7 @@ public class LimitClauseJUnitTest {
       assertEquals(5, num[0]);
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
       assertTrue(wrapper.getCollectionType().getElementType() instanceof StructType);
     } catch (Exception e) {
@@ -477,7 +477,7 @@ public class LimitClauseJUnitTest {
       assertEquals(5, num[0]);
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
     } catch (Exception e) {
       CacheUtils.getLogger().error(e);
@@ -575,7 +575,7 @@ public class LimitClauseJUnitTest {
       assertEquals((5 + numRepeat[0]), num[0]);
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
 
     } catch (Exception e) {
@@ -635,7 +635,7 @@ public class LimitClauseJUnitTest {
       assertEquals((20 + 4 * numRepeat[0]), num[0]);
       assertTrue(result instanceof SelectResults);
       assertEquals(20, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(20, wrapper.asSet().size());
 
     } catch (Exception e) {
@@ -671,7 +671,7 @@ public class LimitClauseJUnitTest {
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
       assertTrue(observer.limitAppliedAtIndex);
     } catch (Exception e) {
@@ -708,7 +708,7 @@ public class LimitClauseJUnitTest {
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
       assertTrue(observer.limitAppliedAtIndex);
     } catch (Exception e) {
@@ -752,7 +752,7 @@ public class LimitClauseJUnitTest {
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
       assertTrue(observer.limitAppliedAtIndex);
     } catch (Exception e) {
@@ -797,7 +797,7 @@ public class LimitClauseJUnitTest {
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
       assertTrue(observer.limitAppliedAtIndex);
     } catch (Exception e) {
@@ -834,7 +834,7 @@ public class LimitClauseJUnitTest {
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
       assertTrue(wrapper.getCollectionType().getElementType() instanceof StructType);
       assertTrue(observer.limitAppliedAtIndex);
@@ -871,7 +871,7 @@ public class LimitClauseJUnitTest {
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
       // currently this is false because we disabled limit application at the range index level
       assertFalse(observer.limitAppliedAtIndex);
@@ -917,7 +917,7 @@ public class LimitClauseJUnitTest {
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
       assertEquals(5, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(5, wrapper.asSet().size());
       assertTrue(observer.limitAppliedAtIndex);
     } catch (Exception e) {
@@ -965,7 +965,7 @@ public class LimitClauseJUnitTest {
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
       assertEquals(20, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(20, wrapper.asSet().size());
       // currently this is false because we disabled limit application at the range index level
       assertFalse(observer.limitAppliedAtIndex);
@@ -1009,7 +1009,7 @@ public class LimitClauseJUnitTest {
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
       assertEquals(10, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(10, wrapper.asSet().size());
     } catch (Exception e) {
       CacheUtils.getLogger().error(e);
@@ -1048,7 +1048,7 @@ public class LimitClauseJUnitTest {
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
       assertEquals(10, result.size());
-      SelectResults wrapper = (SelectResults) result;
+      SelectResults wrapper = result;
       assertEquals(10, wrapper.asSet().size());
       assertFalse(observer.limitAppliedAtIndex && observer.indexName.equals("idIndex"));
       assertTrue(observer.limitAppliedAtIndex && observer.indexName.equals("statusIndex"));
@@ -1825,8 +1825,8 @@ public class LimitClauseJUnitTest {
 
     @Override
     public void limitAppliedAtIndexLevel(Index index, int limit, Collection indexResult) {
-      this.limitAppliedAtIndex = true;
-      this.indexName = index.getName();
+      limitAppliedAtIndex = true;
+      indexName = index.getName();
     }
 
     @Override
@@ -1835,5 +1835,5 @@ public class LimitClauseJUnitTest {
         indexUsed = true;
       }
     }
-  };
+  }
 }
