@@ -91,13 +91,13 @@ public class QRegionInterfaceJUnitTest {
 
   @Test
   public void testMiscQueries() throws Exception {
-    String testData[][] = {{SEPARATOR + "Portfolios.fullPath", SEPARATOR + "Portfolios"},
+    String[][] testData = {{SEPARATOR + "Portfolios.fullPath", SEPARATOR + "Portfolios"},
         {SEPARATOR + "Portfolios.size", "4"},
         {SEPARATOR + "Portfolios.size > 0", "true"},};
-    for (int i = 0; i < testData.length; i++) {
-      Query query = CacheUtils.getQueryService().newQuery(testData[i][0]);
+    for (final String[] testDatum : testData) {
+      Query query = CacheUtils.getQueryService().newQuery(testDatum[0]);
       String result = query.execute().toString();
-      if (!result.equals(testData[i][1])) {
+      if (!result.equals(testDatum[1])) {
         fail(query.getQueryString());
       }
     }
@@ -126,13 +126,13 @@ public class QRegionInterfaceJUnitTest {
 
   @Test
   public void testBug35905ContainsValue() throws Exception {
-    String testData[][] = {{SEPARATOR + "Portfolios.containsValue($1)", "true"},};
-    for (int i = 0; i < testData.length; i++) {
-      Query query = CacheUtils.getQueryService().newQuery(testData[i][0]);
+    String[][] testData = {{SEPARATOR + "Portfolios.containsValue($1)", "true"},};
+    for (final String[] testDatum : testData) {
+      Query query = CacheUtils.getQueryService().newQuery(testDatum[0]);
       String result =
-          query.execute(new Object[] {CacheUtils.getRegion(SEPARATOR + "Portfolios").get("1")})
+          query.execute(CacheUtils.getRegion(SEPARATOR + "Portfolios").get("1"))
               .toString();
-      if (!result.equals(testData[i][1])) {
+      if (!result.equals(testDatum[1])) {
         fail(query.getQueryString());
       }
     }
