@@ -22,7 +22,6 @@ import static org.junit.Assert.fail;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.Date;
-import java.util.Iterator;
 
 import org.junit.After;
 import org.junit.Before;
@@ -46,13 +45,13 @@ import org.apache.geode.util.internal.GeodeGlossary;
 @Category({OQLQueryTest.class})
 public class SelectToDateJUnitTest {
 
-  private static String regionName = "test";
-  private static int numElem = 120;
-  private static String format = "MMddyyyyHHmmss";
-  private static String mayDate = "05202012100559";
-  private static int numMonthsBeforeMay = 4;
-  private static int numMonthsAfterMay = 7;
-  private static int numElementsExpectedPerMonth = numElem * 2 / 12;
+  private static final String regionName = "test";
+  private static final int numElem = 120;
+  private static final String format = "MMddyyyyHHmmss";
+  private static final String mayDate = "05202012100559";
+  private static final int numMonthsBeforeMay = 4;
+  private static final int numMonthsAfterMay = 7;
+  private static final int numElementsExpectedPerMonth = numElem * 2 / 12;
 
   @Before
   public void setUp() throws Exception {
@@ -65,7 +64,7 @@ public class SelectToDateJUnitTest {
     CacheUtils.closeCache();
   }
 
-  private static String[] toDateQueries = new String[] {
+  private static final String[] toDateQueries = new String[] {
       "select * from " + SEPARATOR + "test p where p.createDate = to_date('" + mayDate + "', '"
           + format + "')",
       "select * from " + SEPARATOR + "test p where p.createDate < to_date('" + mayDate + "', '"
@@ -79,13 +78,13 @@ public class SelectToDateJUnitTest {
 
   // the test will be validating against the May date, so expected values revolve around month of
   // May
-  private static int[] toDateExpectedResults =
+  private static final int[] toDateExpectedResults =
       new int[] {numElementsExpectedPerMonth, numMonthsBeforeMay * numElementsExpectedPerMonth,
           numMonthsAfterMay * numElementsExpectedPerMonth,
           (numMonthsBeforeMay + 1) * numElementsExpectedPerMonth,
           (numMonthsAfterMay + 1) * numElementsExpectedPerMonth};
 
-  private static String[] projectionQueries = new String[] {
+  private static final String[] projectionQueries = new String[] {
       "select p.createDate from " + SEPARATOR + "test p where p.createDate = to_date('" + mayDate
           + "', '" + format
           + "')",
@@ -126,9 +125,8 @@ public class SelectToDateJUnitTest {
   }
 
   private void printoutResults(SelectResults results) {
-    Iterator iterator = results.iterator();
-    while (iterator.hasNext()) {
-      Portfolio p = (Portfolio) iterator.next();
+    for (final Object result : results) {
+      Portfolio p = (Portfolio) result;
       CacheUtils.log("->" + p + ";" + p.createDate);
     }
   }
