@@ -24,7 +24,6 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.junit.After;
@@ -46,7 +45,7 @@ public class QueryFromClauseCanonicalizationJUnitTest {
 
   QueryService qs = null;
 
-  static String queries[] = {
+  static String[] queries = {
       "SELECT DISTINCT ID, value.secId FROM " + SEPARATOR
           + "pos, getPositions where status = 'active' and ID = 0",
       "SELECT DISTINCT ID, value.secId FROM " + SEPARATOR
@@ -169,9 +168,8 @@ public class QueryFromClauseCanonicalizationJUnitTest {
         new ExecutionContext(new Object[] {"bindkey"}, CacheUtils.getCache());
     context.newScope(context.associateScopeID());
 
-    Iterator iter = list.iterator();
-    while (iter.hasNext()) {
-      CompiledIteratorDef iterDef = (CompiledIteratorDef) iter.next();
+    for (final Object o : list) {
+      CompiledIteratorDef iterDef = (CompiledIteratorDef) o;
       context.addDependencies(new CompiledID("dummy"), iterDef.computeDependencies(context));
       RuntimeIterator rIter = iterDef.getRuntimeIterator(context);
       context.bindIterator(rIter);
