@@ -116,6 +116,7 @@ public class IndexStatisticsJUnitTest {
 
     assertEquals(50, keyIndex1Stats.getTotalUses());
     assertEquals(0, keyIndex1Stats.getReadLockCount());
+    assertEquals(0, keyIndex1Stats.getReadLockCountLong());
 
     // NumOfValues should be reduced.
     for (int i = 0; i < 50; i++) {
@@ -240,6 +241,7 @@ public class IndexStatisticsJUnitTest {
     }
 
     assertEquals(0, keyIndex1Stats.getReadLockCount());
+    assertEquals(0, keyIndex1Stats.getReadLockCountLong());
     assertEquals(50, keyIndex1Stats.getTotalUses());
 
     // NumOfValues should be reduced.
@@ -346,9 +348,8 @@ public class IndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, keyIndexStats.getNumberOfKeys());
-    assertEquals(100, keyIndexStats.getNumberOfKeys());
-    assertEquals(100, keyIndexStats.getNumberOfValues());
-    assertEquals(100, keyIndexStats.getNumUpdates());
+    assertEquals(200, keyIndexStats.getNumberOfValues());
+    assertEquals(200, keyIndexStats.getNumUpdates());
 
     for (int i = 0; i < 100; i++) {
       region.put(Integer.toString(i), new Portfolio(i, i));
@@ -356,8 +357,8 @@ public class IndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, keyIndexStats.getNumberOfKeys());
-    assertEquals(100, keyIndexStats.getNumberOfValues());
-    assertEquals(200, keyIndexStats.getNumUpdates());
+    assertEquals(200, keyIndexStats.getNumberOfValues());
+    assertEquals(400, keyIndexStats.getNumUpdates());
 
     String queryStr =
         "select * from " + SEPARATOR
@@ -369,6 +370,7 @@ public class IndexStatisticsJUnitTest {
     }
 
     assertEquals(0, keyIndexStats.getReadLockCount());
+    assertEquals(0, keyIndexStats.getReadLockCountLong());
 
     assertEquals(100, keyIndexStats.getTotalUses());
 
@@ -378,8 +380,8 @@ public class IndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, keyIndexStats.getNumberOfKeys());
-    assertEquals(50, keyIndexStats.getNumberOfValues());
-    assertEquals(250, keyIndexStats.getNumUpdates());
+    assertEquals(100, keyIndexStats.getNumberOfValues());
+    assertEquals(500, keyIndexStats.getNumUpdates());
 
     for (int i = 0; i < 50; i++) {
       region.destroy(Integer.toString(i));
@@ -387,14 +389,14 @@ public class IndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, keyIndexStats.getNumberOfKeys());
-    assertEquals(50, keyIndexStats.getNumberOfValues());
-    assertEquals(250, keyIndexStats.getNumUpdates());
+    assertEquals(100, keyIndexStats.getNumberOfValues());
+    assertEquals(500, keyIndexStats.getNumUpdates());
 
     for (int i = 50; i < 100; i++) {
       region.destroy(Integer.toString(i));
     }
 
-    assertEquals(300, keyIndexStats.getNumUpdates());
+    assertEquals(600, keyIndexStats.getNumUpdates());
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(0, keyIndexStats.getNumberOfKeys());
@@ -424,8 +426,8 @@ public class IndexStatisticsJUnitTest {
 
     assertEquals(2, mapIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, mapIndexStats.getNumberOfKeys());
-    assertEquals(100, mapIndexStats.getNumberOfValues());
-    assertEquals(100, mapIndexStats.getNumUpdates());
+    assertEquals(200, mapIndexStats.getNumberOfValues());
+    assertEquals(200, mapIndexStats.getNumUpdates());
 
 
     Position.cnt = 0;
@@ -435,8 +437,8 @@ public class IndexStatisticsJUnitTest {
 
     assertEquals(2, mapIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, mapIndexStats.getNumberOfKeys());
-    assertEquals(100, mapIndexStats.getNumberOfValues());
-    assertEquals(200, mapIndexStats.getNumUpdates());
+    assertEquals(200, mapIndexStats.getNumberOfValues());
+    assertEquals(400, mapIndexStats.getNumUpdates());
     String queryStr =
         "select * from " + SEPARATOR
             + "portfolio where positions['DELL'] != NULL OR positions['YHOO'] != NULL";
@@ -448,6 +450,7 @@ public class IndexStatisticsJUnitTest {
 
 
     assertEquals(0, mapIndexStats.getReadLockCount());
+    assertEquals(0, mapIndexStats.getReadLockCountLong());
 
     assertEquals(100, mapIndexStats.getTotalUses());
 
@@ -457,8 +460,8 @@ public class IndexStatisticsJUnitTest {
 
     assertEquals(2, mapIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, mapIndexStats.getNumberOfKeys());
-    assertEquals(50, mapIndexStats.getNumberOfValues());
-    assertEquals(300, mapIndexStats.getNumUpdates());
+    assertEquals(100, mapIndexStats.getNumberOfValues());
+    assertEquals(600, mapIndexStats.getNumUpdates());
 
     for (int i = 0; i < 50; i++) {
       region.destroy(Integer.toString(i));
@@ -466,14 +469,14 @@ public class IndexStatisticsJUnitTest {
 
     assertEquals(2, mapIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, mapIndexStats.getNumberOfKeys());
-    assertEquals(50, mapIndexStats.getNumberOfValues());
-    assertEquals(300, mapIndexStats.getNumUpdates());
+    assertEquals(100, mapIndexStats.getNumberOfValues());
+    assertEquals(600, mapIndexStats.getNumUpdates());
 
     for (int i = 50; i < 100; i++) {
       region.destroy(Integer.toString(i));
     }
 
-    assertEquals(400, mapIndexStats.getNumUpdates());
+    assertEquals(800, mapIndexStats.getNumUpdates());
 
     assertEquals(2, mapIndexStats.getNumberOfMapIndexKeys());
     assertEquals(0, mapIndexStats.getNumberOfKeys());
@@ -667,8 +670,8 @@ public class IndexStatisticsJUnitTest {
     IndexStatistics mapIndexStats = keyIndex3.getStatistics();
 
     assertEquals(100, mapIndexStats.getNumberOfKeys());
-    assertEquals(100, mapIndexStats.getNumberOfValues());
-    assertEquals(100, mapIndexStats.getNumUpdates());
+    assertEquals(200, mapIndexStats.getNumberOfValues());
+    assertEquals(200, mapIndexStats.getNumUpdates());
 
 
     Position.cnt = 0;
@@ -677,8 +680,8 @@ public class IndexStatisticsJUnitTest {
     }
 
     assertEquals(100, mapIndexStats.getNumberOfKeys());
-    assertEquals(100, mapIndexStats.getNumberOfValues());
-    assertEquals(200, mapIndexStats.getNumUpdates());
+    assertEquals(200, mapIndexStats.getNumberOfValues());
+    assertEquals(400, mapIndexStats.getNumUpdates());
 
     String queryStr =
         "select * from " + SEPARATOR
@@ -696,8 +699,8 @@ public class IndexStatisticsJUnitTest {
     }
 
     assertEquals(50, mapIndexStats.getNumberOfKeys());
-    assertEquals(50, mapIndexStats.getNumberOfValues());
-    assertEquals(300, mapIndexStats.getNumUpdates());
+    assertEquals(100, mapIndexStats.getNumberOfValues());
+    assertEquals(600, mapIndexStats.getNumUpdates());
 
 
     for (int i = 0; i < 50; i++) {
@@ -705,14 +708,14 @@ public class IndexStatisticsJUnitTest {
     }
 
     assertEquals(50, mapIndexStats.getNumberOfKeys());
-    assertEquals(50, mapIndexStats.getNumberOfValues());
-    assertEquals(300, mapIndexStats.getNumUpdates());
+    assertEquals(100, mapIndexStats.getNumberOfValues());
+    assertEquals(600, mapIndexStats.getNumUpdates());
 
     for (int i = 50; i < 100; i++) {
       region.destroy(Integer.toString(i));
     }
 
-    assertEquals(400, mapIndexStats.getNumUpdates());
+    assertEquals(800, mapIndexStats.getNumUpdates());
 
     assertEquals(0, mapIndexStats.getNumberOfKeys());
 
@@ -820,6 +823,8 @@ public class IndexStatisticsJUnitTest {
     assertEquals("Read locks should have been taken by the query ", 1, observer.readLockCount);
     assertEquals("Read lock count should have been released by the query ", 0,
         statusIndex.getStatistics().getReadLockCount());
+    assertEquals("Read lock count should have been released by the query ", 0,
+        statusIndex.getStatistics().getReadLockCountLong());
 
     QueryObserverHolder.setInstance(old);
     qs.removeIndexes();
@@ -852,17 +857,19 @@ public class IndexStatisticsJUnitTest {
     assertEquals("Read locks should have been taken by the query ", 1, observer.readLockCount);
     assertEquals("Read lock count should have been released by the query ", 0,
         secIdIndex.getStatistics().getReadLockCount());
+    assertEquals("Read lock count should have been released by the query ", 0,
+        secIdIndex.getStatistics().getReadLockCountLong());
 
     QueryObserverHolder.setInstance(old);
     qs.removeIndexes();
   }
 
   public static class QueryObserverImpl extends QueryObserverAdapter {
-    int readLockCount = 0;
+    long readLockCount = 0L;
 
     @Override
     public void beforeIndexLookup(Index index, int oper, Object key) {
-      readLockCount = index.getStatistics().getReadLockCount();
+      readLockCount = index.getStatistics().getReadLockCountLong();
     }
   }
 }
