@@ -15,6 +15,7 @@
 package org.apache.geode.cache.query.internal.index;
 
 import static org.apache.geode.cache.Region.SEPARATOR;
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 
@@ -40,6 +41,7 @@ import org.apache.geode.cache.query.data.Portfolio;
 import org.apache.geode.cache.query.internal.IndexTrackingQueryObserver;
 import org.apache.geode.cache.query.internal.QueryObserverHolder;
 import org.apache.geode.test.junit.categories.OQLIndexTest;
+import org.apache.geode.util.internal.UncheckedUtils;
 
 @Category({OQLIndexTest.class})
 public class MapRangeIndexMaintenanceJUnitTest {
@@ -47,7 +49,7 @@ public class MapRangeIndexMaintenanceJUnitTest {
   private static final String INDEX_NAME = "keyIndex1";
 
   private static QueryService qs;
-  private static Region region;
+  private static Region<Object, Object> region;
   private static Index keyIndex1;
 
   @Before
@@ -338,7 +340,258 @@ public class MapRangeIndexMaintenanceJUnitTest {
     SelectResults result = (SelectResults) qs
         .newQuery("select * from " + SEPARATOR + "portfolio p where p.positions['SUN'] = null")
         .execute();
-    assertEquals(1, result.size());
+    assertEquals(2, result.size());
+  }
+
+  @Test
+  public void testQueriesForValueInMapFieldWithoutIndex() throws Exception {
+    region =
+        CacheUtils.getCache().createRegionFactory(RegionShortcut.REPLICATE).create("portfolio");
+    qs = CacheUtils.getQueryService();
+    testQueriesForValueInMapField(region, qs);
+  }
+
+  @Test
+  public void testQueriesForValueInMapFieldWithCompactMapIndexWithOneKey() throws Exception {
+    region =
+        CacheUtils.getCache().createRegionFactory(RegionShortcut.REPLICATE).create("portfolio");
+    qs = CacheUtils.getQueryService();
+
+    keyIndex1 = qs.createIndex(INDEX_NAME, "positions['SUN']", SEPARATOR + "portfolio ");
+
+    Class<CompactRangeIndex> indexType = CompactRangeIndex.class;
+    assertThat(keyIndex1).isInstanceOf(indexType);
+    testQueriesForValueInMapField(region, qs);
+    verifyStatsForQueriesForValueInMapFieldWithAnyRangeIndexWithOneKey(indexType);
+  }
+
+  @Test
+  public void testQueriesForValueInMapFieldWithCompactMapIndexWithSeveralKeys() throws Exception {
+    region =
+        CacheUtils.getCache().createRegionFactory(RegionShortcut.REPLICATE).create("portfolio");
+    qs = CacheUtils.getQueryService();
+
+    keyIndex1 =
+        qs.createIndex(INDEX_NAME, "positions['SUN', 'ERICSSON']", SEPARATOR + "portfolio ");
+
+    Class<CompactMapRangeIndex> indexType = CompactMapRangeIndex.class;
+    assertThat(keyIndex1).isInstanceOf(indexType);
+    testQueriesForValueInMapField(region, qs);
+    verifyStatsForQueriesForValueInMapFieldWithAnyMapIndexWithSeveralKeys(indexType);
+  }
+
+  @Test
+  public void testQueriesForValueInMapFieldWithCompactMapIndexWithStar() throws Exception {
+    region =
+        CacheUtils.getCache().createRegionFactory(RegionShortcut.REPLICATE).create("portfolio");
+    qs = CacheUtils.getQueryService();
+
+    keyIndex1 = qs.createIndex(INDEX_NAME, "positions[*]", SEPARATOR + "portfolio ");
+
+    Class<CompactMapRangeIndex> indexType = CompactMapRangeIndex.class;
+    assertThat(keyIndex1).isInstanceOf(indexType);
+    testQueriesForValueInMapField(region, qs);
+    verifyStatsForQueriesForValueInMapFieldWithAnyMapIndexWithStar(indexType);
+  }
+
+  @Test
+  public void testQueriesForValueInMapFieldWithMapIndexWithOneKey() throws Exception {
+    IndexManager.TEST_RANGEINDEX_ONLY = true;
+    region =
+        CacheUtils.getCache().createRegionFactory(RegionShortcut.REPLICATE).create("portfolio");
+    qs = CacheUtils.getQueryService();
+
+    keyIndex1 = qs.createIndex(INDEX_NAME, "positions['SUN']", SEPARATOR + "portfolio ");
+
+    Class<RangeIndex> indexType = RangeIndex.class;
+    assertThat(keyIndex1).isInstanceOf(indexType);
+    testQueriesForValueInMapField(region, qs);
+    verifyStatsForQueriesForValueInMapFieldWithAnyRangeIndexWithOneKey(indexType);
+  }
+
+  @Test
+  public void testQueriesForValueInMapFieldWithMapIndexWithSeveralKeys() throws Exception {
+    IndexManager.TEST_RANGEINDEX_ONLY = true;
+    region =
+        CacheUtils.getCache().createRegionFactory(RegionShortcut.REPLICATE).create("portfolio");
+    qs = CacheUtils.getQueryService();
+
+    keyIndex1 =
+        qs.createIndex(INDEX_NAME, "positions['SUN', 'ERICSSON']", SEPARATOR + "portfolio ");
+
+    Class<MapRangeIndex> indexType = MapRangeIndex.class;
+    assertThat(keyIndex1).isInstanceOf(indexType);
+    testQueriesForValueInMapField(region, qs);
+    verifyStatsForQueriesForValueInMapFieldWithAnyMapIndexWithSeveralKeys(indexType);
+  }
+
+  @Test
+  public void testQueriesForValueInMapFieldWithMapIndexWithStar() throws Exception {
+    IndexManager.TEST_RANGEINDEX_ONLY = true;
+    region =
+        CacheUtils.getCache().createRegionFactory(RegionShortcut.REPLICATE).create("portfolio");
+    qs = CacheUtils.getQueryService();
+
+    keyIndex1 = qs.createIndex(INDEX_NAME, "positions[*]", SEPARATOR + "portfolio ");
+
+    Class<MapRangeIndex> indexType = MapRangeIndex.class;
+    assertThat(keyIndex1).isInstanceOf(indexType);
+    testQueriesForValueInMapField(region, qs);
+    verifyStatsForQueriesForValueInMapFieldWithAnyMapIndexWithStar(indexType);
+  }
+
+  public void testQueriesForValueInMapField(Region<Object, Object> region, QueryService qs)
+      throws Exception {
+
+    // Empty map
+    Portfolio p1 = new Portfolio(1, 1);
+    p1.positions = new HashMap<>();
+    region.put(1, p1);
+
+    // Map is null
+    Portfolio p2 = new Portfolio(2, 2);
+    p2.positions = null;
+    region.put(2, p2);
+
+    // Map with null value for "SUN" key
+    Portfolio p3 = new Portfolio(3, 3);
+    p3.positions = new HashMap<>();
+    p3.positions.put("IBM", "something");
+    p3.positions.put("SUN", null);
+    region.put(3, p3);
+
+    // Map with not null value for "SUN" key
+    Portfolio p4 = new Portfolio(4, 4);
+    p4.positions = new HashMap<>();
+    p4.positions.put("SUN", "nothing");
+    region.put(4, p4);
+
+    // Map with another value for the "SUN" key
+    Portfolio p5 = new Portfolio(5, 5);
+    p5.positions = new HashMap<>();
+    p5.positions.put("SUN", "more");
+    // null is not allowed as key
+    p5.positions.put("cannotBeNull", "empty");
+    region.put(5, p5);
+
+    // One more with map without the "SUN" key
+    Portfolio p6 = new Portfolio(6, 6);
+    p6.positions = new HashMap<>();
+    p6.positions.put("ERICSSON", "hey");
+    region.put(6, p6);
+
+    // Map with a repeated value for the "SUN" key
+    Portfolio p7 = new Portfolio(7, 7);
+    p7.positions = new HashMap<>();
+    p7.positions.put("SUN", "more");
+    p7.positions.put("HP", "tip");
+    region.put(7, p7);
+
+    String query;
+    query = "select * from " + SEPARATOR + "portfolio p where p.positions['SUN'] = null";
+    SelectResults<Object> result = UncheckedUtils.uncheckedCast(qs
+        .newQuery(query)
+        .execute());
+    assertThat(result).containsExactlyInAnyOrder(p1, p3, p6);
+
+    query = "select * from " + SEPARATOR + "portfolio p where p.positions['SUN'] != null";
+    result = UncheckedUtils.uncheckedCast(qs
+        .newQuery(query)
+        .execute());
+    assertThat(result).containsExactlyInAnyOrder(p2, p4, p5, p7);
+
+    query = "select * from " + SEPARATOR + "portfolio p where p.positions['SUN'] = 'nothing'";
+    result = UncheckedUtils.uncheckedCast(qs
+        .newQuery(query)
+        .execute());
+    assertThat(result).containsExactly(p4);
+
+    query = "select * from " + SEPARATOR + "portfolio p where p.positions['SUN'] != 'nothing'";
+    result = UncheckedUtils.uncheckedCast(qs
+        .newQuery(query)
+        .execute());
+    assertThat(result).containsExactlyInAnyOrder(p1, p2, p3, p5, p6, p7);
+
+    query = "select * from " + SEPARATOR + "portfolio p";
+    result = UncheckedUtils.uncheckedCast(qs
+        .newQuery(query)
+        .execute());
+    assertThat(result).containsExactlyInAnyOrder(p1, p2, p3, p4, p5, p6, p7);
+  }
+
+  private <T extends AbstractIndex> void verifyStatsForQueriesForValueInMapFieldWithAnyRangeIndexWithOneKey(
+      Class<T> indexType) {
+    long keys = (indexType.cast(keyIndex1)).internalIndexStats.getNumberOfKeys();
+    long mapIndexKeys =
+        (indexType.cast(keyIndex1)).internalIndexStats.getNumberOfMapIndexKeys();
+    long values =
+        (indexType.cast(keyIndex1)).internalIndexStats.getNumberOfValues();
+    long uses =
+        (indexType.cast(keyIndex1)).internalIndexStats.getTotalUses();
+
+    // The number of keys must be equal to the number of different values the
+    // positions map takes in region entries for the 'SUN' key:
+    // ("nothing", "more"). null or UNDEFINED not included.
+    assertThat(keys).isEqualTo(2);
+    // mapIndexKeys must be zero because the index used is a range index and not a map index.
+    assertThat(mapIndexKeys).isEqualTo(0);
+    // The number of values must be equal to the number of region entries.
+    assertThat(values).isEqualTo(region.keySet().size());
+    // The index must be used in all the queries that have positions['SUN'] in the filter.
+    assertThat(uses).isEqualTo(4);
+  }
+
+  private <T extends AbstractMapIndex> void verifyStatsForQueriesForValueInMapFieldWithAnyMapIndexWithSeveralKeys(
+      Class<T> indexType) {
+    long keys = (indexType.cast(keyIndex1)).internalIndexStats.getNumberOfKeys();
+    long mapIndexKeys =
+        (indexType.cast(keyIndex1)).internalIndexStats.getNumberOfMapIndexKeys();
+    long values =
+        (indexType.cast(keyIndex1)).internalIndexStats.getNumberOfValues();
+    long uses =
+        (indexType.cast(keyIndex1)).internalIndexStats.getTotalUses();
+
+    // The number of keys must be equal to the number of different values the
+    // positions map takes for the 'SUN' key ("nothing", "more") plus
+    // the number of different values the positions map takes for the 'ERICSSON' key
+    // ("hey"). null or UNDEFINED not included.
+    assertThat(keys).isEqualTo(3);
+    // The number of mapIndexKeys must be equal to the number of keys
+    // in the index that appear in region entries:
+    // 'SUN', 'ERICSSON'
+    assertThat(mapIndexKeys).isEqualTo(2);
+    // The number of values must be equal to the number of entries
+    // in the region times the number of indexed keys in the map: 'SUN', 'ERICSSON'.
+    assertThat(values).isEqualTo(region.keySet().size() * 2L);
+    // The index must be used in all the queries that have positions['SUN'] in the filter.
+    assertThat(uses).isEqualTo(4);
+  }
+
+  private <T extends AbstractMapIndex> void verifyStatsForQueriesForValueInMapFieldWithAnyMapIndexWithStar(
+      Class<T> indexType) {
+    long keys = (indexType.cast(keyIndex1)).internalIndexStats.getNumberOfKeys();
+    long mapIndexKeys =
+        (indexType.cast(keyIndex1)).internalIndexStats.getNumberOfMapIndexKeys();
+    long values =
+        (indexType.cast(keyIndex1)).internalIndexStats.getNumberOfValues();
+    long uses =
+        (indexType.cast(keyIndex1)).internalIndexStats.getTotalUses();
+
+    // The number of keys must be equal to the number of different values the
+    // positions map takes for each key for each entry in the region (null not included):
+    // "something", "nothing", "more", "empty", "hey", "tip"
+    assertThat(keys).isEqualTo(6);
+    // The number of mapIndexKeys must be equal to the number of different keys
+    // that appear in entries of the region:
+    // "IBM", "ERICSSON", "HP", "SUN", "cannotBeNull".
+    assertThat(mapIndexKeys).isEqualTo(5);
+    // The number of values must be equal to the number of values the
+    // positions map takes for each key for each entry in the region:
+    // "something", null, "nothing", "more", "empty", "hey", "more", "tip".
+    assertThat(values).isEqualTo(8);
+    // The index must be used in all the queries that have positions['SUN'] in the filter
+    // except for those using "!=" to compare with it or when comparing it with null.
+    assertThat(uses).isEqualTo(1);
   }
 
   @Test
@@ -365,7 +618,7 @@ public class MapRangeIndexMaintenanceJUnitTest {
     SelectResults result = (SelectResults) qs
         .newQuery("select * from " + SEPARATOR + "portfolio p where p.positions['SUN'] = null")
         .execute();
-    assertEquals(1, result.size());
+    assertEquals(2, result.size());
   }
 
   @Test
