@@ -108,6 +108,7 @@ public class PRIndexStatisticsJUnitTest {
 
     IndexStatistics keyIndex1Stats = keyIndex1.getStatistics();
     assertEquals(89, keyIndex1Stats.getNumberOfBucketIndexes());
+    assertEquals(89, keyIndex1Stats.getNumberOfBucketIndexesLong());
 
     // Initial stats test (keys, values & updates)
     assertEquals(2 * 100/* Num of values in region */, keyIndex1Stats.getNumberOfKeys());
@@ -179,6 +180,7 @@ public class PRIndexStatisticsJUnitTest {
 
     IndexStatistics keyIndex1Stats = keyIndex2.getStatistics();
     assertEquals(89, keyIndex1Stats.getNumberOfBucketIndexes());
+    assertEquals(89, keyIndex1Stats.getNumberOfBucketIndexesLong());
 
     // Initial stats test (keys, values & updates)
     assertEquals(100, keyIndex1Stats.getNumberOfKeys());
@@ -249,11 +251,12 @@ public class PRIndexStatisticsJUnitTest {
     IndexStatistics keyIndexStats = keyIndex3.getStatistics();
     assertTrue(keyIndexStats instanceof IndexStatistics);
     assertEquals(89, keyIndexStats.getNumberOfBucketIndexes());
+    assertEquals(89, keyIndexStats.getNumberOfBucketIndexesLong());
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, keyIndexStats.getNumberOfKeys());
-    assertEquals(100, keyIndexStats.getNumberOfValues());
-    assertEquals(100, keyIndexStats.getNumUpdates());
+    assertEquals(200, keyIndexStats.getNumberOfValues());
+    assertEquals(200, keyIndexStats.getNumUpdates());
 
     for (int i = 0; i < 100; i++) {
       region.put(Integer.toString(i), new Portfolio(i, i));
@@ -261,8 +264,8 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, keyIndexStats.getNumberOfKeys());
-    assertEquals(100, keyIndexStats.getNumberOfValues());
-    assertEquals(200, keyIndexStats.getNumUpdates());
+    assertEquals(200, keyIndexStats.getNumberOfValues());
+    assertEquals(400, keyIndexStats.getNumUpdates());
 
     String queryStr =
         "select * from " + SEPARATOR
@@ -273,8 +276,8 @@ public class PRIndexStatisticsJUnitTest {
       query.execute();
     }
 
-    // Both RangeIndex should be used
-    assertEquals(100 /* Execution time */, keyIndexStats.getTotalUses());
+    // Index should be used
+    assertEquals(100, keyIndexStats.getTotalUses());
 
     for (int i = 0; i < 50; i++) {
       region.invalidate(Integer.toString(i));
@@ -282,8 +285,8 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, keyIndexStats.getNumberOfKeys());
-    assertEquals(50, keyIndexStats.getNumberOfValues());
-    assertEquals(250, keyIndexStats.getNumUpdates());
+    assertEquals(100, keyIndexStats.getNumberOfValues());
+    assertEquals(500, keyIndexStats.getNumUpdates());
 
     for (int i = 0; i < 50; i++) {
       region.destroy(Integer.toString(i));
@@ -291,14 +294,14 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, keyIndexStats.getNumberOfKeys());
-    assertEquals(50, keyIndexStats.getNumberOfValues());
-    assertEquals(250, keyIndexStats.getNumUpdates());
+    assertEquals(100, keyIndexStats.getNumberOfValues());
+    assertEquals(500, keyIndexStats.getNumUpdates());
 
     for (int i = 50; i < 100; i++) {
       region.destroy(Integer.toString(i));
     }
 
-    assertEquals(300, keyIndexStats.getNumUpdates());
+    assertEquals(600, keyIndexStats.getNumUpdates());
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(0, keyIndexStats.getNumberOfKeys());
 
@@ -322,12 +325,12 @@ public class PRIndexStatisticsJUnitTest {
     IndexStatistics keyIndexStats = keyIndex3.getStatistics();
     assertTrue(keyIndexStats instanceof IndexStatistics);
     assertEquals(89, keyIndexStats.getNumberOfBucketIndexes());
+    assertEquals(89, keyIndexStats.getNumberOfBucketIndexesLong());
 
-    assertEquals(89, keyIndexStats.getNumberOfBucketIndexes());
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, keyIndexStats.getNumberOfKeys());
-    assertEquals(100, keyIndexStats.getNumberOfValues());
-    assertEquals(100, keyIndexStats.getNumUpdates());
+    assertEquals(200, keyIndexStats.getNumberOfValues());
+    assertEquals(200, keyIndexStats.getNumUpdates());
 
     Position.cnt = 0;
     for (int i = 0; i < 100; i++) {
@@ -336,8 +339,8 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, keyIndexStats.getNumberOfKeys());
-    assertEquals(100, keyIndexStats.getNumberOfValues());
-    assertEquals(200, keyIndexStats.getNumUpdates());
+    assertEquals(200, keyIndexStats.getNumberOfValues());
+    assertEquals(400, keyIndexStats.getNumUpdates());
 
     String queryStr =
         "select * from " + SEPARATOR
@@ -357,8 +360,8 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, keyIndexStats.getNumberOfKeys());
-    assertEquals(50, keyIndexStats.getNumberOfValues());
-    assertEquals(300, keyIndexStats.getNumUpdates());
+    assertEquals(100, keyIndexStats.getNumberOfValues());
+    assertEquals(600, keyIndexStats.getNumUpdates());
 
     for (int i = 0; i < 50; i++) {
       region.destroy(Integer.toString(i));
@@ -366,15 +369,15 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, keyIndexStats.getNumberOfKeys());
-    assertEquals(50, keyIndexStats.getNumberOfValues());
-    assertEquals(300, keyIndexStats.getNumUpdates());
+    assertEquals(100, keyIndexStats.getNumberOfValues());
+    assertEquals(600, keyIndexStats.getNumUpdates());
 
 
     for (int i = 50; i < 100; i++) {
       region.destroy(Integer.toString(i));
     }
 
-    assertEquals(400, keyIndexStats.getNumUpdates());
+    assertEquals(800, keyIndexStats.getNumUpdates());
     assertEquals(0, keyIndexStats.getNumberOfKeys());
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
 
@@ -404,6 +407,7 @@ public class PRIndexStatisticsJUnitTest {
 
     IndexStatistics keyIndex1Stats = keyIndex1.getStatistics();
     assertEquals(89, keyIndex1Stats.getNumberOfBucketIndexes());
+    assertEquals(89, keyIndex1Stats.getNumberOfBucketIndexesLong());
 
     // Initial stats test (keys, values & updates)
     assertEquals(2 * 100/* Num of values in region */, keyIndex1Stats.getNumberOfKeys());
@@ -483,6 +487,7 @@ public class PRIndexStatisticsJUnitTest {
 
     IndexStatistics keyIndex1Stats = keyIndex2.getStatistics();
     assertEquals(89, keyIndex1Stats.getNumberOfBucketIndexes());
+    assertEquals(89, keyIndex1Stats.getNumberOfBucketIndexesLong());
 
     // Initial stats test (keys, values & updates)
     assertEquals(100, keyIndex1Stats.getNumberOfKeys());
@@ -560,11 +565,12 @@ public class PRIndexStatisticsJUnitTest {
     IndexStatistics keyIndexStats = keyIndex3.getStatistics();
     assertTrue(keyIndexStats instanceof IndexStatistics);
     assertEquals(89, keyIndexStats.getNumberOfBucketIndexes());
+    assertEquals(89, keyIndexStats.getNumberOfBucketIndexesLong());
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, keyIndexStats.getNumberOfKeys());
-    assertEquals(100, keyIndexStats.getNumberOfValues());
-    assertEquals(100, keyIndexStats.getNumUpdates());
+    assertEquals(200, keyIndexStats.getNumberOfValues());
+    assertEquals(200, keyIndexStats.getNumUpdates());
 
     Position.cnt = 0;
     for (int i = 0; i < 100; i++) {
@@ -573,8 +579,8 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, keyIndexStats.getNumberOfKeys());
-    assertEquals(100, keyIndexStats.getNumberOfValues());
-    assertEquals(200, keyIndexStats.getNumUpdates());
+    assertEquals(200, keyIndexStats.getNumberOfValues());
+    assertEquals(400, keyIndexStats.getNumUpdates());
 
     String queryStr =
         "select * from " + SEPARATOR
@@ -594,8 +600,8 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, keyIndexStats.getNumberOfKeys());
-    assertEquals(50, keyIndexStats.getNumberOfValues());
-    assertEquals(250, keyIndexStats.getNumUpdates());
+    assertEquals(100, keyIndexStats.getNumberOfValues());
+    assertEquals(500, keyIndexStats.getNumUpdates());
 
     for (int i = 0; i < 50; i++) {
       region.destroy(Integer.toString(i));
@@ -603,14 +609,14 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, keyIndexStats.getNumberOfKeys());
-    assertEquals(50, keyIndexStats.getNumberOfValues());
-    assertEquals(250, keyIndexStats.getNumUpdates());
+    assertEquals(100, keyIndexStats.getNumberOfValues());
+    assertEquals(500, keyIndexStats.getNumUpdates());
 
     for (int i = 50; i < 100; i++) {
       region.destroy(Integer.toString(i));
     }
 
-    assertEquals(300, keyIndexStats.getNumUpdates());
+    assertEquals(600, keyIndexStats.getNumUpdates());
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(0, keyIndexStats.getNumberOfKeys());
 
@@ -642,11 +648,12 @@ public class PRIndexStatisticsJUnitTest {
     IndexStatistics keyIndexStats = keyIndex3.getStatistics();
     assertTrue(keyIndexStats instanceof IndexStatistics);
     assertEquals(89, keyIndexStats.getNumberOfBucketIndexes());
+    assertEquals(89, keyIndexStats.getNumberOfBucketIndexesLong());
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, keyIndexStats.getNumberOfKeys());
-    assertEquals(100, keyIndexStats.getNumberOfValues());
-    assertEquals(100, keyIndexStats.getNumUpdates());
+    assertEquals(200, keyIndexStats.getNumberOfValues());
+    assertEquals(200, keyIndexStats.getNumUpdates());
 
     Position.cnt = 0;
     for (int i = 0; i < 100; i++) {
@@ -655,8 +662,8 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(100, keyIndexStats.getNumberOfKeys());
-    assertEquals(100, keyIndexStats.getNumberOfValues());
-    assertEquals(200, keyIndexStats.getNumUpdates());
+    assertEquals(200, keyIndexStats.getNumberOfValues());
+    assertEquals(400, keyIndexStats.getNumUpdates());
 
     String queryStr =
         "select * from " + SEPARATOR
@@ -676,8 +683,8 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, keyIndexStats.getNumberOfKeys());
-    assertEquals(50, keyIndexStats.getNumberOfValues());
-    assertEquals(300, keyIndexStats.getNumUpdates());
+    assertEquals(100, keyIndexStats.getNumberOfValues());
+    assertEquals(600, keyIndexStats.getNumUpdates());
 
     for (int i = 0; i < 50; i++) {
       region.destroy(Integer.toString(i));
@@ -685,8 +692,8 @@ public class PRIndexStatisticsJUnitTest {
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
     assertEquals(50, keyIndexStats.getNumberOfKeys());
-    assertEquals(50, keyIndexStats.getNumberOfValues());
-    assertEquals(300, keyIndexStats.getNumUpdates());
+    assertEquals(100, keyIndexStats.getNumberOfValues());
+    assertEquals(600, keyIndexStats.getNumUpdates());
 
 
     for (int i = 50; i < 100; i++) {
@@ -694,7 +701,7 @@ public class PRIndexStatisticsJUnitTest {
     }
 
     assertEquals(2, keyIndexStats.getNumberOfMapIndexKeys());
-    assertEquals(400, keyIndexStats.getNumUpdates());
+    assertEquals(800, keyIndexStats.getNumUpdates());
     assertEquals(0, keyIndexStats.getNumberOfKeys());
 
     qs.removeIndex(keyIndex3);
