@@ -119,7 +119,7 @@ public class PRQueryJUnitTest {
     Region region = PartitionedRegionTestHelper.createPartitionedRegion(regionName, "100", 0);
     String[] values = new String[100];
     for (int j = 0; j < 100; j++) {
-      values[j] = new String("" + j);
+      values[j] = "" + j;
     }
 
     try {
@@ -180,7 +180,7 @@ public class PRQueryJUnitTest {
    */
   private void populateData(Region region, Object[] data) {
     for (int j = 0; j < data.length; j++) {
-      region.put(new Integer(j), data[j]);
+      region.put(j, data[j]);
     }
   }
 }
