@@ -205,7 +205,7 @@ public class LauncherMemberMXBeanIntegrationTest extends LauncherIntegrationTest
   }
 
   private MemberMXBean getMXBeanProxy() {
-    this.mbeanObjectName = mbeanNames.iterator().next();
+    mbeanObjectName = mbeanNames.iterator().next();
     return JMX.newMXBeanProxy(getPlatformMBeanServer(), mbeanObjectName, MemberMXBean.class, false);
   }
 
