@@ -21,7 +21,6 @@ import static org.mockito.Mockito.when;
 
 import java.io.File;
 import java.io.IOException;
-import java.net.InetAddress;
 import java.nio.charset.Charset;
 import java.nio.file.Path;
 import java.util.Properties;
@@ -41,6 +40,7 @@ import org.mockito.quality.Strictness;
 
 import org.apache.geode.distributed.Locator;
 import org.apache.geode.distributed.internal.membership.gms.membership.GMSJoinLeave;
+import org.apache.geode.distributed.internal.tcpserver.HostAddress;
 import org.apache.geode.internal.security.SecurableCommunicationChannel;
 import org.apache.geode.logging.internal.LoggingSession;
 
@@ -59,7 +59,7 @@ public class InternalLocatorIntegrationTest {
   @Mock
   private LoggingSession loggingSession;
   private File logFile;
-  private InetAddress bindAddress;
+  private HostAddress bindAddress;
   private String hostnameForClients;
   @Mock
   private Properties distributedSystemProperties;
@@ -119,7 +119,9 @@ public class InternalLocatorIntegrationTest {
     assertThatCode(() -> {
       internalLocator =
           new InternalLocator(port, loggingSession, logFile, null, null,
-              bindAddress, hostnameForClients, distributedSystemProperties, distributionConfig,
+              bindAddress,
+              hostnameForClients,
+              distributedSystemProperties, distributionConfig,
               workingDirectory);
     }).doesNotThrowAnyException();
   }
