@@ -25,13 +25,12 @@ import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
-import static org.mockito.Matchers.isA;
+import static org.mockito.ArgumentMatchers.isA;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
 import java.io.File;
-import java.net.InetAddress;
 import java.util.Comparator;
 import java.util.List;
 import java.util.Properties;
@@ -41,7 +40,6 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 import org.junit.rules.TemporaryFolder;
-import org.mockito.invocation.InvocationOnMock;
 import org.mockito.stubbing.Answer;
 
 import org.apache.geode.distributed.ConfigurationProperties;
@@ -66,6 +64,7 @@ import org.apache.geode.distributed.internal.membership.api.MembershipListener;
 import org.apache.geode.distributed.internal.membership.api.MembershipLocator;
 import org.apache.geode.distributed.internal.membership.api.MembershipView;
 import org.apache.geode.distributed.internal.membership.api.MessageListener;
+import org.apache.geode.distributed.internal.tcpserver.HostAddress;
 import org.apache.geode.distributed.internal.tcpserver.TcpClient;
 import org.apache.geode.distributed.internal.tcpserver.TcpSocketCreator;
 import org.apache.geode.distributed.internal.tcpserver.TcpSocketFactory;
@@ -137,7 +136,7 @@ public class MembershipJUnitTest {
 
       // boot up a locator
       int port = AvailablePortHelper.getRandomAvailableTCPPort();
-      InetAddress localHost = LocalHostUtil.getLocalHost();
+      HostAddress localHost = new HostAddress(LocalHostUtil.getLocalHost());
 
       // this locator will hook itself up with the first Membership
       // to be created
@@ -261,12 +260,9 @@ public class MembershipJUnitTest {
     final SecurityService securityService = SecurityServiceFactory.create();
     DSFIDSerializer serializer = InternalDataSerializer.getDSFIDSerializer();
     final MemberIdentifierFactory memberFactory = mock(MemberIdentifierFactory.class);
-    when(memberFactory.create(isA(MemberData.class))).thenAnswer(new Answer<MemberIdentifier>() {
-      @Override
-      public MemberIdentifier answer(InvocationOnMock invocation) throws Throwable {
-        return new InternalDistributedMember((MemberData) invocation.getArgument(0));
-      }
-    });
+    when(memberFactory.create(isA(MemberData.class))).thenAnswer(
+        (Answer<MemberIdentifier>) invocation -> new InternalDistributedMember(
+            (MemberData) invocation.getArgument(0)));
     LifecycleListener<InternalDistributedMember> lifeCycleListener = mock(LifecycleListener.class);
 
     final MemberIdentifierFactory<InternalDistributedMember> memberIdentifierFactory =
@@ -293,7 +289,7 @@ public class MembershipJUnitTest {
         new GMSAuthenticator(config.getSecurityProps(), securityService,
             mockSystem.getSecurityLogWriter(), mockSystem.getInternalLogWriter());
     final Membership<InternalDistributedMember> m1 =
-        MembershipBuilder.<InternalDistributedMember>newMembershipBuilder(
+        MembershipBuilder.newMembershipBuilder(
             socketCreator, locatorClient, serializer, memberIdentifierFactory)
             .setMembershipLocator(locator)
             .setAuthenticator(authenticator)
@@ -328,13 +324,14 @@ public class MembershipJUnitTest {
 
       // boot up a locator
       int port = AvailablePortHelper.getRandomAvailableTCPPort();
-      InetAddress localHost = LocalHostUtil.getLocalHost();
+      HostAddress localHost = new HostAddress(LocalHostUtil.getLocalHost());
       Properties p = new Properties();
       p.setProperty(ConfigurationProperties.SECURITY_UDP_DHALGO, "AES:128");
       // this locator will hook itself up with the first Membership
       // to be created
       internalLocator =
-          InternalLocator.startLocator(port, new File(""), null, null, localHost, false, p, null,
+          InternalLocator.startLocator(port, new File(""), null, null, localHost, false, p,
+              null,
               temporaryFolder.getRoot().toPath());
 
       // create configuration objects
