@@ -178,12 +178,12 @@ public class DiskIFJUnitTest extends DiskRegionTestingBase {
 
     dr.memberOffline(myOnId);
     dr.memberOfflineAndEqual(myOnId2);
-    HashSet<PersistentMemberID> expSet = new HashSet<PersistentMemberID>();
+    HashSet<PersistentMemberID> expSet = new HashSet<>();
     expSet.add(myOffId);
     expSet.add(myOnId);
     assertTrue(dr.getOnlineMembers().isEmpty());
     assertEquals(expSet, dr.getOfflineMembers());
-    HashSet<PersistentMemberID> expSet2 = new HashSet<PersistentMemberID>();
+    HashSet<PersistentMemberID> expSet2 = new HashSet<>();
     expSet2.add(myEqualsId);
     expSet2.add(myOnId2);
     assertEquals(expSet2, dr.getOfflineAndEqualMembers());
@@ -215,7 +215,7 @@ public class DiskIFJUnitTest extends DiskRegionTestingBase {
     assertTrue(dr.getOfflineMembers().isEmpty());
     assertTrue(dr.getOfflineAndEqualMembers().isEmpty());
     expSet.add(myEqualsId);
-    expSet.add(myOnId2);;
+    expSet.add(myOnId2);
     assertEquals(expSet, dr.getOnlineMembers());
     close(lr);
     // do recovery
@@ -668,7 +668,7 @@ public class DiskIFJUnitTest extends DiskRegionTestingBase {
       lr = (LocalRegion) DiskRegionHelperFactory.getSyncPersistOnlyRegion(cache, diskProps,
           Scope.LOCAL);
       fail("expected IllegalStateException");
-    } catch (IllegalStateException expected) {
+    } catch (IllegalStateException ignored) {
     } finally {
       extraIF.delete();
     }
