@@ -17,6 +17,7 @@ package org.apache.geode.internal.offheap;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
@@ -24,7 +25,6 @@ import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
 import java.io.File;
-import java.io.FilenameFilter;
 import java.io.Serializable;
 import java.util.Arrays;
 import java.util.List;
@@ -89,14 +89,7 @@ public abstract class OffHeapRegionBase {
   @After
   public void cleanUp() {
     File dir = new File(".");
-    File[] files = dir.listFiles(new FilenameFilter() {
-
-      @Override
-      public boolean accept(File dir, String name) {
-        return name.startsWith("BACKUP");
-      }
-
-    });
+    File[] files = dir.listFiles((dir1, name) -> name.startsWith("BACKUP"));
     for (File file : files) {
       file.delete();
     }
@@ -135,7 +128,7 @@ public abstract class OffHeapRegionBase {
       try {
         ma.allocate(1024 * 1024 * 20);
         fail("Expected an out of heap exception");
-      } catch (OutOfOffHeapMemoryException expected) {
+      } catch (OutOfOffHeapMemoryException ignored) {
       }
       assertEquals(0, ma.getUsedMemory());
       assertFalse(gfc.isClosed());
@@ -196,7 +189,7 @@ public abstract class OffHeapRegionBase {
       final long offHeapSize = ma.getFreeMemory();
       assertEquals(0, ma.getUsedMemory());
       byte[] data = new byte[] {1, 2, 3, 4, 5, 6, 7, 8};
-      StoredObject mc1 = (StoredObject) ma.allocateAndInitialize(data, false, false);
+      StoredObject mc1 = ma.allocateAndInitialize(data, false, false);
       assertEquals(data.length + perObjectOverhead(), ma.getUsedMemory());
       assertEquals(offHeapSize - (data.length + perObjectOverhead()), ma.getFreeMemory());
       byte[] data2 = new byte[data.length];
@@ -241,7 +234,7 @@ public abstract class OffHeapRegionBase {
       r = gfc.createRegionFactory(rs).setOffHeap(true).setCompressor(compressor).create(rName);
       assertEquals(true, r.isEmpty());
       assertEquals(0, ma.getUsedMemory());
-      Object data = new Integer(123456789);
+      Object data = 123456789;
       r.put("key1", data);
       // System.out.println("After put of Integer value off heap used memory=" +
       // ma.getUsedMemory());
@@ -258,13 +251,13 @@ public abstract class OffHeapRegionBase {
       r.destroy("key1");
       assertEquals(0, ma.getUsedMemory());
 
-      data = new Long(0x007FFFFFL);
+      data = 0x007FFFFFL;
       r.put("key1", data);
       if (!compressed) {
         assertTrue(ma.getUsedMemory() == 0);
       }
       assertEquals(data, r.get("key1"));
-      data = new Long(0xFF8000000L);
+      data = 0xFF8000000L;
       r.put("key1", data);
       if (!compressed) {
         assertTrue(ma.getUsedMemory() == 0);
@@ -273,13 +266,13 @@ public abstract class OffHeapRegionBase {
 
 
       // now lets set data to something that will be stored offheap
-      data = new Long(Long.MAX_VALUE);
+      data = Long.MAX_VALUE;
       r.put("key1", data);
       assertEquals(data, r.get("key1"));
       // System.out.println("After put of Integer value off heap used memory=" +
       // ma.getUsedMemory());
       assertTrue(ma.getUsedMemory() > 0);
-      data = new Long(Long.MIN_VALUE);
+      data = Long.MIN_VALUE;
       r.put("key1", data);
       assertEquals(data, r.get("key1"));
       // System.out.println("After put of Integer value off heap used memory=" +
@@ -448,15 +441,15 @@ public abstract class OffHeapRegionBase {
         r.clear();
         await()
             .untilAsserted(() -> assertEquals(0, ma.getUsedMemory()));
-      } catch (UnsupportedOperationException ok) {
+      } catch (UnsupportedOperationException ignored) {
       }
 
       r.put("key1", data);
       assertTrue(ma.getUsedMemory() > 0);
       if (r.getAttributes().getDataPolicy().withPersistence()) {
-        r.put("key2", Integer.valueOf(1234567890));
-        r.put("key3", new Long(0x007FFFFFL));
-        r.put("key4", new Long(0xFF8000000L));
+        r.put("key2", 1234567890);
+        r.put("key3", 0x007FFFFFL);
+        r.put("key4", 0xFF8000000L);
         assertEquals(4, r.size());
         r.close();
         await()
@@ -465,9 +458,9 @@ public abstract class OffHeapRegionBase {
         r = gfc.createRegionFactory(rs).setOffHeap(true).create(rName);
         assertEquals(4, r.size());
         assertEquals(data, r.get("key1"));
-        assertEquals(Integer.valueOf(1234567890), r.get("key2"));
-        assertEquals(new Long(0x007FFFFFL), r.get("key3"));
-        assertEquals(new Long(0xFF8000000L), r.get("key4"));
+        assertEquals(1234567890, r.get("key2"));
+        assertEquals(0x007FFFFFL, r.get("key3"));
+        assertEquals(0xFF8000000L, r.get("key4"));
         closeCache(gfc, true);
         assertEquals(0, ma.getUsedMemory());
         gfc = createCache();
@@ -475,12 +468,14 @@ public abstract class OffHeapRegionBase {
           fail("identity of offHeapStore changed when cache was recreated");
         }
         r = gfc.createRegionFactory(rs).setOffHeap(true).create(rName);
-        assertTrue(ma.getUsedMemory() > 0);
+        await().untilAsserted(() -> {
+          assertThat(ma.getUsedMemory()).isGreaterThan(0);
+        });
         assertEquals(4, r.size());
         assertEquals(data, r.get("key1"));
-        assertEquals(Integer.valueOf(1234567890), r.get("key2"));
-        assertEquals(new Long(0x007FFFFFL), r.get("key3"));
-        assertEquals(new Long(0xFF8000000L), r.get("key4"));
+        assertEquals(1234567890, r.get("key2"));
+        assertEquals(0x007FFFFFL, r.get("key3"));
+        assertEquals(0xFF8000000L, r.get("key4"));
       }
 
       r.destroyRegion();
@@ -503,7 +498,7 @@ public abstract class OffHeapRegionBase {
     private final String value;
 
     public MyValueWithPartialEquals(String v) {
-      this.value = v;
+      value = v;
     }
 
     @Override
@@ -511,7 +506,7 @@ public abstract class OffHeapRegionBase {
       if (other instanceof MyValueWithPartialEquals) {
         MyValueWithPartialEquals o = (MyValueWithPartialEquals) other;
         // just compare the first char
-        return this.value.charAt(0) == o.value.charAt(0);
+        return value.charAt(0) == o.value.charAt(0);
       } else {
         return false;
       }
@@ -525,23 +520,23 @@ public abstract class OffHeapRegionBase {
     private String value;
 
     public MyPdxWithPartialEquals(String b, String v) {
-      this.base = b;
-      this.value = v;
+      base = b;
+      value = v;
     }
 
     public MyPdxWithPartialEquals() {}
 
     @Override
     public void toData(PdxWriter writer) {
-      writer.writeString("base", this.base);
-      writer.writeString("value", this.value);
+      writer.writeString("base", base);
+      writer.writeString("value", value);
       writer.markIdentityField("base");
     }
 
     @Override
     public void fromData(PdxReader reader) {
-      this.base = reader.readString("base");
-      this.value = reader.readString("value");
+      base = reader.readString("base");
+      value = reader.readString("value");
     }
   }
 
@@ -559,8 +554,8 @@ public abstract class OffHeapRegionBase {
     private void setEventData(EntryEvent e) {
       close();
       EntryEventImpl event = (EntryEventImpl) e;
-      this.ohOldValue = event.getOffHeapOldValue();
-      this.ohNewValue = event.getOffHeapNewValue();
+      ohOldValue = event.getOffHeapOldValue();
+      ohNewValue = event.getOffHeapNewValue();
     }
 
     @Override
@@ -586,11 +581,11 @@ public abstract class OffHeapRegionBase {
     @Released(OffHeapIdentifier.TEST_OFF_HEAP_REGION_BASE_LISTENER)
     @Override
     public void close() {
-      if (this.ohOldValue instanceof OffHeapStoredObject) {
-        ((OffHeapStoredObject) this.ohOldValue).release();
+      if (ohOldValue instanceof OffHeapStoredObject) {
+        ohOldValue.release();
       }
-      if (this.ohNewValue instanceof OffHeapStoredObject) {
-        ((OffHeapStoredObject) this.ohNewValue).release();
+      if (ohNewValue instanceof OffHeapStoredObject) {
+        ohNewValue.release();
       }
     }
   }
