@@ -21,10 +21,13 @@ package org.apache.geode.admin;
  *             "{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code>
  *             package instead
  */
+@Deprecated
 public interface AlertListener extends java.util.EventListener {
 
   /**
    * Invoked when an <code>Alert</code> is received.
+   *
+   * @param alert the triggering <code>Alert</code>
    */
   void alert(Alert alert);
 }
