@@ -35,6 +35,7 @@ import org.apache.geode.internal.security.SecurableCommunicationChannel;
  *
  * @since GemFire 4.0
  */
+@Deprecated
 public class DistributionLocatorConfigImpl extends ManagedEntityConfigImpl
     implements DistributionLocatorConfig {
 
@@ -107,11 +108,11 @@ public class DistributionLocatorConfigImpl extends ManagedEntityConfigImpl
    * Creates a new <code>DistributionLocatorConfigImpl</code> with the default settings.
    */
   public DistributionLocatorConfigImpl() {
-    this.port = 0;
-    this.bindAddress = null;
-    this.locator = null;
-    this.dsProperties = new java.util.Properties();
-    this.dsProperties.setProperty(MCAST_PORT, "0");
+    port = 0;
+    bindAddress = null;
+    locator = null;
+    dsProperties = new java.util.Properties();
+    dsProperties.setProperty(MCAST_PORT, "0");
   }
 
   ///////////////////// Instance Methods /////////////////////
@@ -125,12 +126,12 @@ public class DistributionLocatorConfigImpl extends ManagedEntityConfigImpl
 
   @Override
   protected boolean isReadOnly() {
-    return this.locator != null && this.locator.isRunning();
+    return locator != null && locator.isRunning();
   }
 
   @Override
   public int getPort() {
-    return this.port;
+    return port;
   }
 
   @Override
@@ -142,7 +143,7 @@ public class DistributionLocatorConfigImpl extends ManagedEntityConfigImpl
 
   @Override
   public String getBindAddress() {
-    return this.bindAddress;
+    return bindAddress;
   }
 
   @Override
@@ -154,12 +155,12 @@ public class DistributionLocatorConfigImpl extends ManagedEntityConfigImpl
 
   @Override
   public void setDistributedSystemProperties(Properties props) {
-    this.dsProperties = props;
+    dsProperties = props;
   }
 
   @Override
   public Properties getDistributedSystemProperties() {
-    return this.dsProperties;
+    return dsProperties;
   }
 
   @Override
@@ -169,14 +170,14 @@ public class DistributionLocatorConfigImpl extends ManagedEntityConfigImpl
     if (port < MIN_PORT || port > MAX_PORT) {
       throw new IllegalArgumentException(
           String.format("Port ( %s ) must be an integer between %s and %s",
-              new Object[] {Integer.valueOf(port), Integer.valueOf(MIN_PORT),
-                  Integer.valueOf(MAX_PORT)}));
+              port, MIN_PORT,
+              MAX_PORT));
     }
 
-    if (this.bindAddress != null && validateHost(this.bindAddress) == null) {
+    if (bindAddress != null && validateHost(bindAddress) == null) {
       throw new IllegalArgumentException(
           String.format("Invalid host %s",
-              this.bindAddress));
+              bindAddress));
     }
   }
 
@@ -197,10 +198,8 @@ public class DistributionLocatorConfigImpl extends ManagedEntityConfigImpl
 
   @Override
   public String toString() {
-    StringBuilder sb = new StringBuilder();
-    sb.append("DistributionLocatorConfig: host=").append(getHost());
-    sb.append(", bindAddress=").append(getBindAddress());
-    sb.append(", port=").append(getPort());
-    return sb.toString();
+    return "DistributionLocatorConfig: host=" + getHost()
+        + ", bindAddress=" + getBindAddress()
+        + ", port=" + getPort();
   }
 }
