@@ -15,6 +15,8 @@
 
 package org.apache.geode.admin.internal;
 
+import static org.apache.commons.lang3.StringUtils.isEmpty;
+
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.util.Collection;
@@ -41,6 +43,7 @@ import org.apache.geode.util.internal.GeodeGlossary;
  *
  * @since GemFire 3.5
  */
+@Deprecated
 public class DistributionLocatorImpl implements DistributionLocator, InternalManagedEntity {
 
   private static final Logger logger = LogService.getLogger();
@@ -66,12 +69,12 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
   /**
    * Used to control the actual DistributionLocator service
    */
-  private ManagedEntityController controller;
+  private final ManagedEntityController controller;
 
   /**
    * The system that this locator is a part of
    */
-  private AdminDistributedSystemImpl system;
+  private final AdminDistributedSystemImpl system;
 
   // -------------------------------------------------------------------------
   // constructor(s)...
@@ -86,8 +89,8 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
     this.config = (DistributionLocatorConfigImpl) config;
     this.config.validate();
     this.config.setManagedEntity(this);
-    this.id = getNewId();
-    this.controller = system.getEntityController();
+    id = getNewId();
+    controller = system.getEntityController();
     this.system = system;
   }
 
@@ -97,7 +100,7 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
 
   @Override
   public String getId() {
-    return this.id;
+    return id;
   }
 
   @Override
@@ -114,12 +117,12 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
    */
   @Override
   public DistributionLocatorConfig getConfig() {
-    return this.config;
+    return config;
   }
 
   @Override
   public AdminDistributedSystem getDistributedSystem() {
-    return this.system;
+    return system;
   }
 
   /**
@@ -149,7 +152,7 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
 
     long start = System.currentTimeMillis();
     while (System.currentTimeMillis() - start < timeout) {
-      if (this.isRunning()) {
+      if (isRunning()) {
         return true;
 
       } else {
@@ -158,7 +161,7 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
     }
 
     logger.info("Done waiting for locator");
-    return this.isRunning();
+    return isRunning();
   }
 
   /**
@@ -173,7 +176,7 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
 
     long start = System.currentTimeMillis();
     while (System.currentTimeMillis() - start < timeout) {
-      if (!this.isRunning()) {
+      if (!isRunning()) {
         return true;
 
       } else {
@@ -181,7 +184,7 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
       }
     }
 
-    return !this.isRunning();
+    return !isRunning();
   }
 
   @Override
@@ -190,7 +193,7 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
         ((AdminDistributedSystemImpl) getDistributedSystem()).getDistributionManager();
     if (dm == null) {
       try {
-        return this.controller.isRunning(this);
+        return controller.isRunning(this);
       } catch (IllegalStateException e) {
         return false;
       }
@@ -204,9 +207,8 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
     Map<InternalDistributedMember, Collection<String>> hostedLocators = dm.getAllHostedLocators();
     for (Iterator<InternalDistributedMember> memberIter =
         hostedLocators.keySet().iterator(); memberIter.hasNext();) {
-      for (Iterator<String> locatorIter =
-          hostedLocators.get(memberIter.next()).iterator(); locatorIter.hasNext();) {
-        DistributionLocatorId locator = new DistributionLocatorId(locatorIter.next());
+      for (final String s : hostedLocators.get(memberIter.next())) {
+        DistributionLocatorId locator = DistributionLocatorId.unmarshal(s);
         found = found || locator.getHostName().equals(host);
         if (!found && !host.contains(".")) {
           try {
@@ -221,8 +223,7 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
             // try config host as if it is an IP address instead of host name
           }
         }
-        if (locator.getBindAddress() != null && !locator.getBindAddress().isEmpty()
-            && bindAddress != null && !bindAddress.isEmpty()) {
+        if (!isEmpty(locator.getBindAddress()) && !isEmpty(bindAddress)) {
           found = found && locator.getBindAddress().equals(bindAddress);
         }
         found = found && locator.getPort() == port;
@@ -236,21 +237,21 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
 
   @Override
   public void start() {
-    this.config.validate();
-    this.controller.start(this);
-    this.config.setLocator(this);
-    this.system.updateLocatorsString();
+    config.validate();
+    controller.start(this);
+    config.setLocator(this);
+    system.updateLocatorsString();
   }
 
   @Override
   public void stop() {
-    this.controller.stop(this);
-    this.config.setLocator(null);
+    controller.stop(this);
+    config.setLocator(null);
   }
 
   @Override
   public String getLog() {
-    return this.controller.getLog(this);
+    return controller.getLog(this);
   }
 
   /**
@@ -267,7 +268,7 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
 
   @Override
   public ManagedEntityConfig getEntityConfig() {
-    return this.getConfig();
+    return getConfig();
   }
 
   @Override
@@ -277,27 +278,28 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
 
   @Override
   public String getStartCommand() {
-    StringBuffer sb = new StringBuffer();
-    sb.append(this.controller.getProductExecutable(this, "gemfire"));
+    StringBuilder sb = new StringBuilder();
+    sb.append(controller.getProductExecutable(this, "gemfire"));
     sb.append(" start-locator -q -dir=");
-    sb.append(this.getConfig().getWorkingDirectory());
+    sb.append(getConfig().getWorkingDirectory());
     sb.append(" -port=");
-    sb.append(this.getConfig().getPort());
+    sb.append(getConfig().getPort());
     Properties props = config.getDistributedSystemProperties();
-    Enumeration en = props.propertyNames();
+    Enumeration<?> en = props.propertyNames();
     while (en.hasMoreElements()) {
       String pn = (String) en.nextElement();
-      sb.append(" -D" + GeodeGlossary.GEMFIRE_PREFIX + "" + pn + "=" + props.getProperty(pn));
+      sb.append(" -D" + GeodeGlossary.GEMFIRE_PREFIX + "").append(pn).append("=")
+          .append(props.getProperty(pn));
     }
 
-    String bindAddress = this.getConfig().getBindAddress();
+    String bindAddress = getConfig().getBindAddress();
     if (bindAddress != null && bindAddress.length() > 0) {
       sb.append(" -address=");
-      sb.append(this.getConfig().getBindAddress());
+      sb.append(getConfig().getBindAddress());
     }
     sb.append(" ");
 
-    String sslArgs = this.controller.buildSSLArguments(this.system.getConfig());
+    String sslArgs = controller.buildSSLArguments(system.getConfig());
     if (sslArgs != null) {
       sb.append(sslArgs);
     }
@@ -307,21 +309,21 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
 
   @Override
   public String getStopCommand() {
-    StringBuffer sb = new StringBuffer();
-    sb.append(this.controller.getProductExecutable(this, "gemfire"));
+    StringBuilder sb = new StringBuilder();
+    sb.append(controller.getProductExecutable(this, "gemfire"));
     sb.append(" stop-locator -q -dir=");
-    sb.append(this.getConfig().getWorkingDirectory());
+    sb.append(getConfig().getWorkingDirectory());
     sb.append(" -port=");
-    sb.append(this.getConfig().getPort());
+    sb.append(getConfig().getPort());
 
-    String bindAddress = this.getConfig().getBindAddress();
+    String bindAddress = getConfig().getBindAddress();
     if (bindAddress != null && bindAddress.length() > 0) {
       sb.append(" -address=");
-      sb.append(this.getConfig().getBindAddress());
+      sb.append(getConfig().getBindAddress());
     }
     sb.append(" ");
 
-    String sslArgs = this.controller.buildSSLArguments(this.system.getConfig());
+    String sslArgs = controller.buildSSLArguments(system.getConfig());
     if (sslArgs != null) {
       sb.append(sslArgs);
     }
@@ -331,21 +333,19 @@ public class DistributionLocatorImpl implements DistributionLocator, InternalMan
 
   @Override
   public String getIsRunningCommand() {
-    StringBuffer sb = new StringBuffer();
-    sb.append(this.controller.getProductExecutable(this, "gemfire"));
-    sb.append(" status-locator -dir=");
-    sb.append(this.getConfig().getWorkingDirectory());
+    final String sb = controller.getProductExecutable(this, "gemfire")
+        + " status-locator -dir="
+        + getConfig().getWorkingDirectory();
 
-    return sb.toString().trim();
+    return sb.trim();
   }
 
   public String getLogCommand() {
-    StringBuffer sb = new StringBuffer();
-    sb.append(this.controller.getProductExecutable(this, "gemfire"));
-    sb.append(" tail-locator-log -dir=");
-    sb.append(this.getConfig().getWorkingDirectory());
+    final String sb = controller.getProductExecutable(this, "gemfire")
+        + " tail-locator-log -dir="
+        + getConfig().getWorkingDirectory();
 
-    return sb.toString().trim();
+    return sb.trim();
   }
 
 }
