@@ -41,9 +41,9 @@ import org.apache.geode.util.internal.GeodeGlossary;
  *
  * <B>JMX Administation Agent Configuration Properties</B>
  *
+ * <a name="auto-connect"></a>
  * <dl>
- * <a name="auto-connect">
- * <dt>{@linkplain #AUTO_CONNECT_NAME auto-connect}</dt></a>
+ * <dt>{@linkplain #AUTO_CONNECT_NAME auto-connect}</dt>
  * <dd><U>Description</U>: whether or not a JMX agent will automatically connect to the distributed
  * system it is configured to administer.</dd>
  * <dd><U>{@linkplain #DEFAULT_AUTO_CONNECT Default}</U>: false</dd>
@@ -59,38 +59,38 @@ import org.apache.geode.util.internal.GeodeGlossary;
  * that these configuration attributes do <b>not</b> effect how the agent connects to the
  * distributed system it administers, only how JMX clients connect to the agent.
  *
+ * <a name="agent-ssl-enabled"></a>
  * <dl>
- * <a name="agent-ssl-enabled">
- * <dt>{@linkplain #AGENT_SSL_ENABLED_NAME agent-ssl-enabled}</dt></a>
+ * <dt>{@linkplain #AGENT_SSL_ENABLED_NAME agent-ssl-enabled}</dt>
  * <dd><U>Description</U>: whether or not connections to the JMX agent require SSL</dd>
  * <dd><U>{@linkplain #DEFAULT_AGENT_SSL_ENABLED Default}</U>: false</dd>
  * </dl>
  *
+ * <a name="agent-ssl-protocols"></a>
  * <dl>
- * <a name="agent-ssl-protocols">
- * <dt>{@linkplain #AGENT_SSL_PROTOCOLS_NAME agent-ssl-protocols}</dt></a>
+ * <dt>{@linkplain #AGENT_SSL_PROTOCOLS_NAME agent-ssl-protocols}</dt>
  * <dd><U>Description</U>: the SSL protocols to be used when connecting to the JMX agent</dd>
  * <dd><U>{@linkplain #DEFAULT_AGENT_SSL_PROTOCOLS Default}</U>: any</dd>
  * </dl>
  *
+ * <a name="agent-ssl-ciphers"></a>
  * <dl>
- * <a name="agent-ssl-ciphers">
- * <dt>{@linkplain #AGENT_SSL_CIPHERS_NAME agent-ssl-ciphers}</dt></a>
+ * <dt>{@linkplain #AGENT_SSL_CIPHERS_NAME agent-ssl-ciphers}</dt>
  * <dd><U>Description</U>: the SSL ciphers to be used when connecting to the JMX agent</dd>
  * <dd><U>{@linkplain #DEFAULT_AGENT_SSL_CIPHERS Default}</U>: any</dd>
  * </dl>
  *
+ * <a name="agent-ssl-require-authentication"></a>
  * <dl>
- * <a name="agent-ssl-require-authentication">
- * <dt>{@linkplain #AGENT_SSL_REQUIRE_AUTHENTICATION_NAME agent-ssl-require-authentication}</dt></a>
+ * <dt>{@linkplain #AGENT_SSL_REQUIRE_AUTHENTICATION_NAME agent-ssl-require-authentication}</dt>
  * <dd><U>Description</U>: whether or not SSL connections to the RMI adapter require authentication
  * </dd>
  * <dd><U>{@linkplain #DEFAULT_AGENT_SSL_REQUIRE_AUTHENTICATION Default}</U>: true</dd>
  * </dl>
  *
+ * <a name="http-ssl-require-authentication"></a>
  * <dl>
- * <a name="http-ssl-require-authentication">
- * <dt>{@linkplain #HTTP_SSL_REQUIRE_AUTHENTICATION_NAME http-ssl-require-authentication}</dt></a>
+ * <dt>{@linkplain #HTTP_SSL_REQUIRE_AUTHENTICATION_NAME http-ssl-require-authentication}</dt>
  * <dd><U>Description</U>: whether or not SSL connections to the HTTP adapter require authentication
  * </dd>
  * <dd><U>{@linkplain #DEFAULT_HTTP_SSL_REQUIRE_AUTHENTICATION Default}</U>: false</dd>
@@ -98,24 +98,24 @@ import org.apache.geode.util.internal.GeodeGlossary;
  *
  * <B>HTTP Adapter Configuration</B>
  *
+ * <a name="http-enabled"></a>
  * <dl>
- * <a name="http-enabled">
- * <dt>{@linkplain #HTTP_ENABLED_NAME http-enabled}</dt></a>
+ * <dt>{@linkplain #HTTP_ENABLED_NAME http-enabled}</dt>
  * <dd><U>Description</U>: whether or not the HTTP adapter is enabled in the JMX agent.</dd>
  * <dd><U>{@linkplain #DEFAULT_HTTP_ENABLED Default}</U>: true</dd>
  * </dl>
  *
+ * <a name="http-port"></a>
  * <dl>
- * <a name="http-port">
- * <dt>{@linkplain #HTTP_PORT_NAME http-port}</dt></a>
+ * <dt>{@linkplain #HTTP_PORT_NAME http-port}</dt>
  * <dd><U>Description</U>: the port on which the HTTP adapter should listen for client connections.
  * </dd>
  * <dd><U>{@linkplain #DEFAULT_HTTP_PORT Default}</U>: 8080</dd>
  * </dl>
  *
+ * <a name="http-bind-address"></a>
  * <dl>
- * <a name="http-bind-address">
- * <dt>{@linkplain #HTTP_BIND_ADDRESS_NAME http-bind-address}</dt></a>
+ * <dt>{@linkplain #HTTP_BIND_ADDRESS_NAME http-bind-address}</dt>
  * <dd><U>Description</U>: the machine name or IP address to which the HTTP listening socket should
  * be bound. If this value is "localhost", then the socket will be bound to the loopback address
  * (127.0.0.1) and the adapter will only be accessible via the URL
@@ -123,126 +123,126 @@ import org.apache.geode.util.internal.GeodeGlossary;
  * <dd><U>{@linkplain #DEFAULT_HTTP_BIND_ADDRESS Default}</U>: "" (all network addresses)</dd>
  * </dl>
  *
+ * <a name="http-authentication-enabled"></a>
  * <dl>
- * <a name="http-authentication-enabled">
- * <dt>{@linkplain #HTTP_AUTHENTICATION_ENABLED_NAME http-authentication-enabled}</dt></a>
+ * <dt>{@linkplain #HTTP_AUTHENTICATION_ENABLED_NAME http-authentication-enabled}</dt>
  * <dd><U>Description</U>: Whether or not connections to the HTTP adapter should be authenticated
  * with a user name and password.</dd>
  * <dd><U>{@linkplain #DEFAULT_HTTP_AUTHENTICATION_ENABLED Default}</U>: false</dd>
  * </dl>
  *
+ * <a name="http-authentication-user"></a>
  * <dl>
- * <a name="http-authentication-user">
- * <dt>{@linkplain #HTTP_AUTHENTICATION_USER_NAME http-authentication-user}</dt></a>
+ * <dt>{@linkplain #HTTP_AUTHENTICATION_USER_NAME http-authentication-user}</dt>
  * <dd><U>Description</U>: the user name for authenticating secure communication.</dd>
  * <dd><U>{@linkplain #DEFAULT_HTTP_AUTHENTICATION_USER Default}</U>: admin</dd>
  * </dl>
  *
+ * <a name="http-authentication-password"></a>
  * <dl>
- * <a name="http-authentication-password">
- * <dt>{@linkplain #HTTP_AUTHENTICATION_PASSWORD_NAME http-authentication-password}</dt></a>
+ * <dt>{@linkplain #HTTP_AUTHENTICATION_PASSWORD_NAME http-authentication-password}</dt>
  * <dd><U>Description</U>: the password for authenticating secure communication.</dd>
  * <dd><U>{@linkplain #DEFAULT_HTTP_AUTHENTICATION_PASSWORD Default}</U>: password</dd>
  * </dl>
  *
  * <B>RMI Adapter Configuration Properties</B>
  *
+ * <a name="rmi-enabled"></a>
  * <dl>
- * <a name="rmi-enabled">
- * <dt>{@linkplain #RMI_ENABLED_NAME rmi-enabled}</dt></a>
+ * <dt>{@linkplain #RMI_ENABLED_NAME rmi-enabled}</dt>
  * <dd><U>Description</U>: whether or not the RMI JMX adapter is enabled</dd>
  * <dd><U>{@linkplain #DEFAULT_RMI_ENABLED Default}</U>: true</dd>
  * </dl>
  *
+ * <a name="rmi-registry-enabled"></a>
  * <dl>
- * <a name="rmi-registry-enabled">
- * <dt>{@linkplain #RMI_REGISTRY_ENABLED_NAME rmi-registry-enabled}</dt></a>
+ * <dt>{@linkplain #RMI_REGISTRY_ENABLED_NAME rmi-registry-enabled}</dt>
  * <dd><U>Description</U>: whether or not the JMX agent should start an RMI registry. Alternatively,
  * a registry outside of the JMX agent VM can be used.</dd>
  * <dd><U>{@linkplain #DEFAULT_RMI_REGISTRY_ENABLED Default}</U>: true</dd>
  * </dl>
  *
+ * <a name="rmi-port"></a>
  * <dl>
- * <a name="rmi-port">
- * <dt>{@linkplain #RMI_PORT_NAME rmi-port}</dt></a>
+ * <dt>{@linkplain #RMI_PORT_NAME rmi-port}</dt>
  * <dd><U>Description</U>: the port of the RMI registry in which the JMX Agent should bind remote
  * objects.</dd>
  * <dd><U>{@linkplain #DEFAULT_RMI_PORT Default}</U>: 1099</dd>
  * </dl>
  *
+ * <a name="rmi-server-port"></a>
  * <dl>
- * <a name="rmi-server-port">
- * <dt>{@linkplain #RMI_PORT_NAME rmi-server-port}</dt></a>
+ * <dt>{@linkplain #RMI_PORT_NAME rmi-server-port}</dt>
  * <dd><U>Description</U>: the port to be used by the RMI Server started by JMX Agent.</dd>
  * <dd><U>{@linkplain #DEFAULT_RMI_SERVER_PORT Default}</U>: 0</dd>
  * </dl>
  *
+ * <a name="rmi-bind-address"></a>
  * <dl>
- * <a name="rmi-bind-address">
- * <dt>{@linkplain #RMI_BIND_ADDRESS_NAME rmi-bind-address}</dt></a>
+ * <dt>{@linkplain #RMI_BIND_ADDRESS_NAME rmi-bind-address}</dt>
  * <dd><U>Description</U>: the bind address on which the RMI registry binds its sockets.</dd>
  * <dd><U>{@linkplain #DEFAULT_RMI_BIND_ADDRESS Default}</U>: "" (all network addresses)</dd>
  * </dl>
  *
  * <B>AdventNet SNMP Adapter Configuration Properties</B>
  *
+ * <a name="snmp-enabled"></a>
  * <dl>
- * <a name="snmp-enabled">
- * <dt>{@linkplain #SNMP_ENABLED_NAME snmp-enabled}</dt></a>
+ * <dt>{@linkplain #SNMP_ENABLED_NAME snmp-enabled}</dt>
  * <dd><U>Description</U>: whether or not the SNMP JMX adapter is enabled</dd>
  * <dd><U>{@linkplain #DEFAULT_SNMP_ENABLED Default}</U>: false</dd>
  * </dl>
  *
+ * <a name="snmp-bind-address"></a>
  * <dl>
- * <a name="snmp-bind-address">
- * <dt>{@linkplain #SNMP_BIND_ADDRESS_NAME snmp-bind-address}</dt></a>
+ * <dt>{@linkplain #SNMP_BIND_ADDRESS_NAME snmp-bind-address}</dt>
  * <dd><U>Description</U>: the host name to which sockets used by the SNMP adapter should be bound.
  * </dd>
  * <dd><U>{@linkplain #DEFAULT_SNMP_BIND_ADDRESS Default}</U>: the name of the local machine (not
  * <code>localhost</code>)</dd>
  * </dl>
  *
+ * <a name="snmp-directory"></a>
  * <dl>
- * <a name="snmp-directory">
- * <dt>{@linkplain #SNMP_DIRECTORY_NAME snmp-directory}</dt></a>
+ * <dt>{@linkplain #SNMP_DIRECTORY_NAME snmp-directory}</dt>
  * <dd><U>Description</U>: the deployment directory for AdventNet SNMP Adaptor</dd>
  * <dd><U>{@linkplain #DEFAULT_SNMP_DIRECTORY Default}</U>: ""</dd>
  * </dl>
  *
  * <B>JMX Agent Email Notification Properties (for statistics alerts)</B>
  *
+ * <a name="email-notification-enabled"></a>
  * <dl>
- * <a name="email-notification-enabled">
- * <dt>{@linkplain #EMAIL_NOTIFICATIONS_ENABLED_NAME email-notification-enabled}</dt></a>
+ * <dt>{@linkplain #EMAIL_NOTIFICATIONS_ENABLED_NAME email-notification-enabled}</dt>
  * <dd><U>Description</U>: Whether or not email notifications are enabled for statistics alerts.
  * </dd>
  * <dd><U>{@linkplain #DEFAULT_EMAIL_NOTIFICATIONS_ENABLED Default}</U>: false</dd>
  * </dl>
  *
+ * <a name="email-notification-from"></a>
  * <dl>
- * <a name="email-notification-from">
- * <dt>{@linkplain #EMAIL_NOTIFICATIONS_FROM_NAME email-notification-from}</dt></a>
+ * <dt>{@linkplain #EMAIL_NOTIFICATIONS_FROM_NAME email-notification-from}</dt>
  * <dd><U>Description</U>: Email address to be used to send email notifications.</dd>
  * <dd><U>{@linkplain #DEFAULT_EMAIL_FROM Default}</U>: ""</dd>
  * </dl>
  *
+ * <a name="email-notification-host"></a>
  * <dl>
- * <a name="email-notification-host">
- * <dt>{@linkplain #EMAIL_NOTIFICATIONS_HOST_NAME email-notification-host}</dt></a>
+ * <dt>{@linkplain #EMAIL_NOTIFICATIONS_HOST_NAME email-notification-host}</dt>
  * <dd><U>Description</U>: The host name of the mail server to be used for email communication.</dd>
  * <dd><U>{@linkplain #DEFAULT_EMAIL_HOST Default}</U>: ""</dd>
  * </dl>
  *
+ * <a name="email-notification-to"></a>
  * <dl>
- * <a name="email-notification-to">
- * <dt>{@linkplain #EMAIL_NOTIFICATIONS_TO_LIST_NAME email-notification-to}</dt></a>
+ * <dt>{@linkplain #EMAIL_NOTIFICATIONS_TO_LIST_NAME email-notification-to}</dt>
  * <dd><U>Description</U>: Email address where the email notifications should be sent.</dd>
  * <dd><U>{@linkplain #DEFAULT_EMAIL_TO_LIST Default}</U>: ""</dd>
  * </dl>
  *
+ * <a name="state-save-file"></a>
  * <dl>
- * <a name="state-save-file">
- * <dt>{@linkplain #STATE_SAVE_FILE_NAME state-save-file}</dt></a>
+ * <dt>{@linkplain #STATE_SAVE_FILE_NAME state-save-file}</dt>
  * <dd><U>Description</U>: The name of the file to be used for saving agent state. The file is
  * stored in the same directory in which the agent.properties file is located</dd>
  * <dd><U>{@linkplain #DEFAULT_STATE_SAVE_FILE Default}</U>: ""</dd>
@@ -254,6 +254,7 @@ import org.apache.geode.util.internal.GeodeGlossary;
  *             "{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code>
  *             package instead
  */
+@Deprecated
 public interface AgentConfig extends DistributedSystemConfig {
 
   /** The prefix for JMX Agent configuration system properties */
@@ -479,6 +480,9 @@ public interface AgentConfig extends DistributedSystemConfig {
    * administers.
    *
    * See <a href="#auto-connect">description</a> above.
+   *
+   * @return whether or not the JMX agent will automatically connect to the distributed system it
+   *         administers
    */
   boolean getAutoConnect();
 
@@ -487,6 +491,9 @@ public interface AgentConfig extends DistributedSystemConfig {
    * administers.
    *
    * See <a href="#auto-connect">description</a> above.
+   *
+   * @param autoConnect whether or not the JMX agent will automatically connect to the distributed
+   *        system it administers
    */
   void setAutoConnect(boolean autoConnect);
 
@@ -494,6 +501,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns whether or not the HTTP adapter is enabled.
    *
    * See <a href="#http-enabled">description</a> above.
+   *
+   * @return whether or not the HTTP adapter is enabled
    */
   boolean isHttpEnabled();
 
@@ -501,6 +510,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets whether or not the HTTP adapter is enabled.
    *
    * See <a href="#http-enabled">description</a> above.
+   *
+   * @param httpEnabled whether or not the HTTP adapter is enabled
    */
   void setHttpEnabled(boolean httpEnabled);
 
@@ -508,6 +519,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the port of the HTTP adapter.
    *
    * See <a href="#http-port">description</a> above.
+   *
+   * @return the port of the HTTP adapter
    */
   int getHttpPort();
 
@@ -515,6 +528,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the port of the HTTP adapter.
    *
    * See <a href="#http-port">description</a> above.
+   *
+   * @param port the port of the HTTP adapter
    */
   void setHttpPort(int port);
 
@@ -522,6 +537,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the bind address to which the HTTP adapter's listening socket is bound.
    *
    * See <a href="#http-bind-address">description</a> above.
+   *
+   * @return the bind address to which the HTTP adapter's listening socket is bound
    */
   String getHttpBindAddress();
 
@@ -529,6 +546,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the bind address to which the HTTP adapter's listening socket is bound.
    *
    * See <a href="#http-bind-address">description</a> above.
+   *
+   * @param address the bind address to which the HTTP adapter's listening socket is bound
    */
   void setHttpBindAddress(String address);
 
@@ -536,6 +555,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns whether or not the HTTP adapter authenticates connections.
    *
    * See <a href="#http-authentication-enabled">description</a> above.
+   *
+   * @return whether or not the HTTP adapter authenticates connections
    */
   boolean isHttpAuthEnabled();
 
@@ -543,6 +564,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets whether or not the HTTP adapter authenticates connections.
    *
    * See <a href="#http-authentication-enabled">description</a> above.
+   *
+   * @param enabled whether or not the HTTP adapter authenticates connections
    */
   void setHttpAuthEnabled(boolean enabled);
 
@@ -550,6 +573,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the user name for HTTP adapter authentication.
    *
    * See <a href="#http-authentication-user">description</a> above.
+   *
+   * @return the user name for HTTP adapter authentication
    */
   String getHttpAuthUser();
 
@@ -557,6 +582,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the user name for HTTP adapter authentication.
    *
    * See <a href="#http-authentication-user">description</a> above.
+   *
+   * @param user the user name for HTTP adapter authentication
    */
   void setHttpAuthUser(String user);
 
@@ -564,6 +591,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the password for HTTP adapter authentication.
    *
    * See <a href="#http-authentication-password">description</a> above.
+   *
+   * @return the password for HTTP adapter authentication
    */
   String getHttpAuthPassword();
 
@@ -571,6 +600,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the password for HTTP adapter authentication.
    *
    * See <a href="#http-authentication-password">description</a> above.
+   *
+   * @param password the password for HTTP adapter authentication
    */
   void setHttpAuthPassword(String password);
 
@@ -578,6 +609,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns whether or not the RMI adapter is enabled.
    *
    * See <a href="#rmi-enabled">description</a> above.
+   *
+   * @return whether or not the RMI adapter is enabled
    */
   boolean isRmiEnabled();
 
@@ -585,6 +618,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets whether or not the RMI adapter is enabled.
    *
    * See <a href="#rmi-enabled">description</a> above.
+   *
+   * @param rmiEnabled whether or not the RMI adapter is enabled
    */
   void setRmiEnabled(boolean rmiEnabled);
 
@@ -592,6 +627,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns whether or not the agent hosts an RMI registry.
    *
    * See <a href="#rmi-registry-enabled">description</a> above.
+   *
+   * @return whether or not the agent hosts an RMI registry
    */
   boolean isRmiRegistryEnabled();
 
@@ -599,6 +636,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets whether or not the agent hosts an RMI registry.
    *
    * See <a href="#rmi-registry-enabled">description</a> above.
+   *
+   * @param enabled whether or not the agent hosts an RMI registry
    */
   void setRmiRegistryEnabled(boolean enabled);
 
@@ -606,6 +645,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the port of the RMI adapter.
    *
    * See <a href="#rmi-port">description</a> above.
+   *
+   * @return the port of the RMI adapter
    */
   int getRmiPort();
 
@@ -613,6 +654,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the port of the RMI adapter.
    *
    * See <a href="#rmi-port">description</a> above.
+   *
+   * @param port the port of the RMI adapter
    */
   void setRmiPort(int port);
 
@@ -640,6 +683,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the bind address to which the RMI adapter's listening sockets are bound.
    *
    * See <a href="#rmi-bind-address">description</a> above.
+   *
+   * @return the bind address to which the RMI adapter's listening sockets are bound
    */
   String getRmiBindAddress();
 
@@ -647,6 +692,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the bind address to which the RMI adapter's listening sockets are bound.
    *
    * See <a href="#rmi-bind-address">description</a> above.
+   *
+   * @param address the bind address to which the RMI adapter's listening sockets are bound
    */
   void setRmiBindAddress(String address);
 
@@ -654,6 +701,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns whether or not the SNMP adapter is enabled.
    *
    * See <a href="#snmp-enabled">description</a> above.
+   *
+   * @return whether or not the SNMP adapter is enabled
    */
   boolean isSnmpEnabled();
 
@@ -661,6 +710,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets whether or not the SNMP adapter is enabled.
    *
    * See <a href="#snmp-enabled">description</a> above.
+   *
+   * @param enabled whether or not the SNMP adapter is enabled
    */
   void setSnmpEnabled(boolean enabled);
 
@@ -668,6 +719,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the bind address used with the SNMP adapter.
    *
    * See <a href="#snmp-bind-address">description</a> above.
+   *
+   * @return the bind address used with the SNMP adapter
    */
   String getSnmpBindAddress();
 
@@ -675,20 +728,26 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the bind address used with the SNMP adapter.
    *
    * See <a href="#snmp-bind-address">description</a> above.
+   *
+   * @param address the bind address used with the SNMP adapter
    */
   void setSnmpBindAddress(String address);
 
   /**
-   * Returns the directory for the SNMP adapater.
+   * Returns the directory for the SNMP adapter.
    *
    * See <a href="#snmp-directory">description</a> above.
+   *
+   * @return the directory for the SNMP adapter
    */
   String getSnmpDirectory();
 
   /**
-   * Sets the directory for the SNMP adapater.
+   * Sets the directory for the SNMP adapter.
    *
    * See <a href="#snmp-directory">description</a> above.
+   *
+   * @param snmpDirectory the directory for the SNMP adapter
    */
   void setSnmpDirectory(String snmpDirectory);
 
@@ -696,6 +755,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns whether or not SSL is required for the JMX agent.
    *
    * See <a href="#agent-ssl-enabled">description</a> above.
+   *
+   * @return whether or not SSL is required for the JMX agent
    */
   boolean isAgentSSLEnabled();
 
@@ -703,6 +764,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets whether or not SSL is required for the JMX agent.
    *
    * See <a href="#agent-ssl-enabled">description</a> above.
+   *
+   * @param enabled whether or not SSL is required for the JMX agent
    */
   void setAgentSSLEnabled(boolean enabled);
 
@@ -710,6 +773,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the SSL protocols used when connecting to the JMX agent.
    *
    * See <a href="#agent-ssl-protocols">description</a> above.
+   *
+   * @return the SSL protocols used when connecting to the JMX agent
    */
   String getAgentSSLProtocols();
 
@@ -717,6 +782,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the SSL protocols used when connecting to the JMX agent.
    *
    * See <a href="#agent-ssl-protocols">description</a> above.
+   *
+   * @param protocols the SSL protocols used when connecting to the JMX agent
    */
   void setAgentSSLProtocols(String protocols);
 
@@ -724,6 +791,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the SSL ciphers used when connecting to the JMX agent.
    *
    * See <a href="#agent-ssl-ciphers">description</a> above.
+   *
+   * @return the SSL ciphers used when connecting to the JMX agent
    */
   String getAgentSSLCiphers();
 
@@ -731,6 +800,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the SSL ciphers used when connecting to the JMX agent.
    *
    * See <a href="#agent-ssl-ciphers">description</a> above.
+   *
+   * @param ciphers the SSL ciphers used when connecting to the JMX agent
    */
   void setAgentSSLCiphers(String ciphers);
 
@@ -738,6 +809,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns whether SSL authentication is used when connecting to the RMI connector.
    *
    * See <a href="#agent-ssl-require-authentication">description</a> above.
+   *
+   * @return whether SSL authentication is used when connecting to the RMI connector
    */
   boolean isAgentSSLRequireAuth();
 
@@ -745,6 +818,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets whether SSL authentication is used when connecting to the RMI connector.
    *
    * See <a href="#agent-ssl-require-authentication">description</a> above.
+   *
+   * @param require whether SSL authentication is used when connecting to the RMI connector
    */
   void setAgentSSLRequireAuth(boolean require);
 
@@ -752,6 +827,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns whether SSL authentication is used when connecting to the HTTP connector.
    *
    * See <a href="#http-ssl-require-authentication">description</a> above.
+   *
+   * @return whether SSL authentication is used when connecting to the HTTP connector
    */
   boolean isHttpSSLRequireAuth();
 
@@ -759,6 +836,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets whether SSL authentication is used when connecting to the HTTP connector.
    *
    * See <a href="#http-ssl-require-authentication">description</a> above.
+   *
+   * @param require whether SSL authentication is used when connecting to the HTTP connector
    */
   void setHttpSSLRequireAuth(boolean require);
 
@@ -766,6 +845,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns whether Emails for Notifications is enabled
    *
    * See <a href="#email-notification-enabled">description</a> above.
+   *
+   * @return whether Emails for Notifications is enabled
    */
   boolean isEmailNotificationEnabled();
 
@@ -773,6 +854,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets whether Emails for Notifications is enabled
    *
    * See <a href="#email-notification-enabled">description</a> above.
+   *
+   * @param enabled whether Emails for Notifications is enabled
    */
   void setEmailNotificationEnabled(boolean enabled);
 
@@ -780,6 +863,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the EmailID from whom notification emails are sent.
    *
    * See <a href="#email-notification-from">description</a> above.
+   *
+   * @return the EmailID from whom notification emails are sent
    */
   String getEmailNotificationFrom();
 
@@ -787,6 +872,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the EmailID from whom notification emails are sent.
    *
    * See <a href="#email-notification-from">description</a> above.
+   *
+   * @param emailID the EmailID from whom notification emails are sent
    */
   void setEmailNotificationFrom(String emailID);
 
@@ -794,6 +881,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the Host Name using which notification emails are sent.
    *
    * See <a href="#email-notification-host">description</a> above.
+   *
+   * @return the Host Name using which notification emails are sent
    */
   String getEmailNotificationHost();
 
@@ -801,6 +890,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the Host Name from whom notification emails are sent.
    *
    * See <a href="#email-notification-host">description</a> above.
+   *
+   * @param hostName the Host Name from whom notification emails are sent
    */
   void setEmailNotificationHost(String hostName);
 
@@ -808,6 +899,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the comma separated EmailID list to whom notification emails are sent.
    *
    * See <a href="#email-notification-to">description</a> above.
+   *
+   * @return the comma separated EmailID list to whom notification emails are sent
    */
   String getEmailNotificationToList();
 
@@ -815,6 +908,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the EmailID from whom notification emails are sent as a comma separated list.
    *
    * See <a href="#email-notification-to">description</a> above.
+   *
+   * @param emailIDs the EmailID from whom notification emails are sent as a comma separated list
    */
   void setEmailNotificationToList(String emailIDs);
 
@@ -822,6 +917,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Returns the name of the file to be used for saving agent state
    *
    * See <a href="#state-save-file">description</a> above.
+   *
+   * @return the name of the file to be used for saving agent state
    */
   String getStateSaveFile();
 
@@ -829,6 +926,8 @@ public interface AgentConfig extends DistributedSystemConfig {
    * Sets the name of the file to be used for saving agent state
    *
    * See <a href="#state-save-file">description</a> above.
+   *
+   * @param file the name of the file to be used for saving agent state
    */
   void setStateSaveFile(String file);
 
