@@ -52,6 +52,7 @@ import org.apache.geode.logging.internal.log4j.api.LogService;
  *
  * @since GemFire 4.0
  */
+@Deprecated
 public class CacheServerJmxImpl extends CacheServerImpl
     implements ManagedResource, CacheVmConfig, CacheServerConfig, SystemMemberJmx {
 
@@ -75,8 +76,8 @@ public class CacheServerJmxImpl extends CacheServerImpl
   private SystemMemberCacheJmxImpl managedSystemMemberCache;
 
   /** collection to collect all the resources created for this member */
-  private Map<StatResource, StatisticResourceJmxImpl> managedStatisticsResourcesMap =
-      new HashMap<StatResource, StatisticResourceJmxImpl>();
+  private final Map<StatResource, StatisticResourceJmxImpl> managedStatisticsResourcesMap =
+      new HashMap<>();
 
   ////////////////////// Constructors //////////////////////
 
@@ -105,28 +106,28 @@ public class CacheServerJmxImpl extends CacheServerImpl
    * Creates and registers the MBean to manage this resource
    */
   private void initializeMBean() throws AdminException {
-    this.mbeanName = new StringBuffer("GemFire.CacheVm:").append("id=")
-        .append(MBeanUtil.makeCompliantMBeanNameProperty(getId())).append(",type=")
-        .append(MBeanUtil.makeCompliantMBeanNameProperty(getType().getName())).toString();
+    mbeanName = "GemFire.CacheVm:" + "id="
+        + MBeanUtils.makeCompliantMBeanNameProperty(getId()) + ",type="
+        + MBeanUtils.makeCompliantMBeanNameProperty(getType().getName());
 
-    this.objectName =
-        MBeanUtil.createMBean(this, addDynamicAttributes(MBeanUtil.lookupManagedBean(this)));
+    objectName =
+        MBeanUtils.createMBean(this, addDynamicAttributes(MBeanUtils.lookupManagedBean(this)));
 
     // Refresh Interval
     AdminDistributedSystemJmxImpl sysJmx = (AdminDistributedSystemJmxImpl) system;
     if (sysJmx.getRefreshInterval() > 0) {
-      this.refreshInterval = sysJmx.getRefreshInterval();
+      refreshInterval = sysJmx.getRefreshInterval();
     }
   }
 
   @Override
   public String getMBeanName() {
-    return this.mbeanName;
+    return mbeanName;
   }
 
   @Override
   public ModelMBean getModelMBean() {
-    return this.modelMBean;
+    return modelMBean;
   }
 
   @Override
@@ -136,7 +137,7 @@ public class CacheServerJmxImpl extends CacheServerImpl
 
   @Override
   public ObjectName getObjectName() {
-    return this.objectName;
+    return objectName;
   }
 
   @Override
@@ -155,70 +156,69 @@ public class CacheServerJmxImpl extends CacheServerImpl
    */
   @Override
   public void cleanupResource() {
-    synchronized (this.managedStatisticsResourcesMap) {
+    synchronized (managedStatisticsResourcesMap) {
       ConfigurationParameter[] names = getConfiguration();
       if (names != null) {
-        for (int i = 0; i < names.length; i++) {
-          ConfigurationParameter parm = names[i];
+        for (ConfigurationParameter parm : names) {
           ((ConfigurationParameterImpl) parm).removeConfigurationParameterListener(this);
         }
       }
-      this.parms.clear();
+      parms.clear();
 
       Collection<StatisticResourceJmxImpl> statisticResources =
           managedStatisticsResourcesMap.values();
 
       for (StatisticResourceJmxImpl statisticResource : statisticResources) {
-        MBeanUtil.unregisterMBean(statisticResource);
+        MBeanUtils.unregisterMBean(statisticResource);
       }
 
-      this.managedStatisticsResourcesMap.clear();
+      managedStatisticsResourcesMap.clear();
     }
 
-    MBeanUtil.unregisterMBean(this.managedSystemMemberCache);
-    this.managedSystemMemberCache = null;
+    MBeanUtils.unregisterMBean(managedSystemMemberCache);
+    managedSystemMemberCache = null;
   }
 
   /////////////////////// Configuration ///////////////////////
 
   @Override
   public String getHost() {
-    return this.getConfig().getHost();
+    return getConfig().getHost();
   }
 
   @Override
   public void setHost(String host) {
-    this.getConfig().setHost(host);
+    getConfig().setHost(host);
   }
 
   @Override
   public String getWorkingDirectory() {
-    return this.getConfig().getWorkingDirectory();
+    return getConfig().getWorkingDirectory();
   }
 
   @Override
   public void setWorkingDirectory(String dir) {
-    this.getConfig().setWorkingDirectory(dir);
+    getConfig().setWorkingDirectory(dir);
   }
 
   @Override
   public String getProductDirectory() {
-    return this.getConfig().getProductDirectory();
+    return getConfig().getProductDirectory();
   }
 
   @Override
   public void setProductDirectory(String dir) {
-    this.getConfig().setProductDirectory(dir);
+    getConfig().setProductDirectory(dir);
   }
 
   @Override
   public String getRemoteCommand() {
-    return this.getConfig().getRemoteCommand();
+    return getConfig().getRemoteCommand();
   }
 
   @Override
   public void setRemoteCommand(String remoteCommand) {
-    this.getConfig().setRemoteCommand(remoteCommand);
+    getConfig().setRemoteCommand(remoteCommand);
   }
 
   @Override
@@ -233,22 +233,22 @@ public class CacheServerJmxImpl extends CacheServerImpl
 
   @Override
   public String getCacheXMLFile() {
-    return this.getConfig().getCacheXMLFile();
+    return getConfig().getCacheXMLFile();
   }
 
   @Override
   public void setCacheXMLFile(String cacheXMLFile) {
-    this.getConfig().setCacheXMLFile(cacheXMLFile);
+    getConfig().setCacheXMLFile(cacheXMLFile);
   }
 
   @Override
   public String getClassPath() {
-    return this.getConfig().getClassPath();
+    return getConfig().getClassPath();
   }
 
   @Override
   public void setClassPath(String classpath) {
-    this.getConfig().setClassPath(classpath);
+    getConfig().setClassPath(classpath);
   }
 
   // -------------------------------------------------------------------------
@@ -262,7 +262,7 @@ public class CacheServerJmxImpl extends CacheServerImpl
    */
   @Override
   public int getRefreshInterval() {
-    return this.refreshInterval;
+    return refreshInterval;
   }
 
   /**
@@ -273,7 +273,7 @@ public class CacheServerJmxImpl extends CacheServerImpl
    */
   @Override
   public void _setRefreshInterval(int refreshInterval) {
-    boolean isRegistered = MBeanUtil.isRefreshNotificationRegistered(this,
+    boolean isRegistered = MBeanUtils.isRefreshNotificationRegistered(this,
         RefreshNotificationType.SYSTEM_MEMBER_CONFIG);
 
     if (isRegistered && (getRefreshInterval() == refreshInterval)) {
@@ -307,8 +307,8 @@ public class CacheServerJmxImpl extends CacheServerImpl
   public void refreshConfig() throws org.apache.geode.admin.AdminException {
     // 1st call to refreshConfig would trigger
     // the auto-refresh if an interval is set
-    if (this.refreshInterval > 0) {
-      this._setRefreshInterval(this.refreshInterval);
+    if (refreshInterval > 0) {
+      _setRefreshInterval(refreshInterval);
     }
 
     super.refreshConfig();
@@ -360,7 +360,7 @@ public class CacheServerJmxImpl extends CacheServerImpl
    */
   @Override
   public void handleNotification(Notification notification, Object hb) {
-    AdminDistributedSystemJmxImpl systemJmx = (AdminDistributedSystemJmxImpl) this.system;
+    AdminDistributedSystemJmxImpl systemJmx = (AdminDistributedSystemJmxImpl) system;
 
     if (!systemJmx.isRmiClientCountZero()) {
       Helper.handleNotification(this, notification, hb);
@@ -396,7 +396,7 @@ public class CacheServerJmxImpl extends CacheServerImpl
       throws org.apache.geode.admin.AdminException {
     StatisticResourceJmxImpl managedStatisticResource = null;
 
-    synchronized (this.managedStatisticsResourcesMap) {
+    synchronized (managedStatisticsResourcesMap) {
       /*
        * Ensuring that a single instance of Statistic Resource is created per StatResource.
        */
@@ -458,12 +458,12 @@ public class CacheServerJmxImpl extends CacheServerImpl
    * is not supposed to contain '/' as per InternalDistributedMember.toString().
    */
   public List<ManagedResource> cleanupBridgeClientResources(String clientId) {
-    List<ManagedResource> returnedResources = new ArrayList<ManagedResource>();
+    List<ManagedResource> returnedResources = new ArrayList<>();
 
-    String compatibleId = "id_" + MBeanUtil.makeCompliantMBeanNameProperty(clientId);
-    synchronized (this.managedStatisticsResourcesMap) {
+    String compatibleId = "id_" + MBeanUtils.makeCompliantMBeanNameProperty(clientId);
+    synchronized (managedStatisticsResourcesMap) {
       Set<Entry<StatResource, StatisticResourceJmxImpl>> entrySet =
-          this.managedStatisticsResourcesMap.entrySet();
+          managedStatisticsResourcesMap.entrySet();
 
       for (Iterator<Entry<StatResource, StatisticResourceJmxImpl>> it = entrySet.iterator(); it
           .hasNext();) {
@@ -502,11 +502,11 @@ public class CacheServerJmxImpl extends CacheServerImpl
 
     if (cleanedUp != null) {
       for (ManagedResource resource : cleanedUp) {
-        MBeanUtil.unregisterMBean(resource);
+        MBeanUtils.unregisterMBean(resource);
       }
     }
 
-    Helper.sendNotification(this, new Notification(notifType, this.modelMBean,
+    Helper.sendNotification(this, new Notification(notifType, modelMBean,
         Helper.getNextNotificationSequenceNumber(), clientId));
   }
 
@@ -519,7 +519,7 @@ public class CacheServerJmxImpl extends CacheServerImpl
    */
   @Override
   public void handleCacheCreate(SystemMemberCacheEvent event) {
-    Helper.sendNotification(this, new Notification(NOTIF_CACHE_CREATED, this.modelMBean,
+    Helper.sendNotification(this, new Notification(NOTIF_CACHE_CREATED, modelMBean,
         Helper.getNextNotificationSequenceNumber(), Helper.getCacheEventDetails(event)));
   }
 
@@ -532,7 +532,7 @@ public class CacheServerJmxImpl extends CacheServerImpl
    */
   @Override
   public void handleCacheClose(SystemMemberCacheEvent event) {
-    Helper.sendNotification(this, new Notification(NOTIF_CACHE_CLOSED, this.modelMBean,
+    Helper.sendNotification(this, new Notification(NOTIF_CACHE_CLOSED, modelMBean,
         Helper.getNextNotificationSequenceNumber(), Helper.getCacheEventDetails(event)));
   }
 
@@ -545,7 +545,7 @@ public class CacheServerJmxImpl extends CacheServerImpl
    */
   @Override
   public void handleRegionCreate(SystemMemberRegionEvent event) {
-    Notification notification = new Notification(NOTIF_REGION_CREATED, this.modelMBean,
+    Notification notification = new Notification(NOTIF_REGION_CREATED, modelMBean,
         Helper.getNextNotificationSequenceNumber(), Helper.getRegionEventDetails(event));
 
     notification.setUserData(event.getRegionPath());
@@ -563,17 +563,17 @@ public class CacheServerJmxImpl extends CacheServerImpl
    */
   @Override
   public void handleRegionLoss(SystemMemberRegionEvent event) {
-    SystemMemberCacheJmxImpl cacheResource = this.managedSystemMemberCache;
+    SystemMemberCacheJmxImpl cacheResource = managedSystemMemberCache;
 
     if (cacheResource != null) {
       ManagedResource cleanedUp = cacheResource.cleanupRegionResources(event.getRegionPath());
 
       if (cleanedUp != null) {
-        MBeanUtil.unregisterMBean(cleanedUp);
+        MBeanUtils.unregisterMBean(cleanedUp);
       }
     }
 
-    Notification notification = new Notification(NOTIF_REGION_LOST, this.modelMBean,
+    Notification notification = new Notification(NOTIF_REGION_LOST, modelMBean,
         Helper.getNextNotificationSequenceNumber(), Helper.getRegionEventDetails(event));
 
     notification.setUserData(event.getRegionPath());
