@@ -33,8 +33,8 @@ import org.xml.sax.SAXParseException;
 import org.xml.sax.helpers.DefaultHandler;
 
 import org.apache.geode.annotations.Immutable;
-import org.apache.geode.internal.ClassPathLoader;
 import org.apache.geode.internal.ExitCode;
+import org.apache.geode.internal.classloader.ClassPathLoader;
 
 /**
  * A tool that reads the XML description of MBeans used with the Jakarta Commons Modeler and
@@ -42,6 +42,7 @@ import org.apache.geode.internal.ExitCode;
  *
  * @since GemFire 3.5
  */
+@Deprecated
 public class GenerateMBeanHTML extends DefaultHandler {
 
   /** The location of the DTD for the MBean descriptions */
@@ -90,7 +91,7 @@ public class GenerateMBeanHTML extends DefaultHandler {
   ////////////////////// Instance Fields ///////////////////////
 
   /** Where the generated HTML data is written */
-  private PrintWriter pw;
+  private final PrintWriter pw;
 
   /** Have we seen attributes for the current MBean? */
   private boolean seenAttribute = false;
@@ -136,7 +137,7 @@ public class GenerateMBeanHTML extends DefaultHandler {
 
     if (publicId == null || systemId == null) {
       throw new SAXException(String.format("Public Id: %s System Id: %s",
-          new Object[] {publicId, systemId}));
+          publicId, systemId));
     }
 
     // Figure out the location for the publicId.
@@ -193,7 +194,7 @@ public class GenerateMBeanHTML extends DefaultHandler {
     pw.println("");
     pw.println("<P>This document describes the attributes, operations,");
     pw.println("and notifications of the GemFire Administration");
-    pw.println("Management Beans (MBeans).</P>");
+    pw.println("Management Beans (MBeans).<p>");
     pw.println("");
   }
 
@@ -222,14 +223,14 @@ public class GenerateMBeanHTML extends DefaultHandler {
    * Ends the MBean table
    */
   private void endMBean() {
-    this.seenAttribute = false;
-    this.seenOperation = false;
-    this.seenNotifications = false;
+    seenAttribute = false;
+    seenOperation = false;
+    seenNotifications = false;
 
     pw.println("</table>");
     pw.println("");
 
-    pw.println("<P></P>");
+    pw.println("<P><p>");
     pw.println("");
   }
 
@@ -237,7 +238,7 @@ public class GenerateMBeanHTML extends DefaultHandler {
    * Generates a table row for an MBean attribute
    */
   private void startAttribute(Attributes atts) {
-    if (!this.seenAttribute) {
+    if (!seenAttribute) {
       // Print header row
       pw.println("<tr valign=\"top\">");
       pw.println("  <th align=\"left\">Attributes</th>");
@@ -249,7 +250,7 @@ public class GenerateMBeanHTML extends DefaultHandler {
 
     }
 
-    this.seenAttribute = true;
+    seenAttribute = true;
 
     String name = atts.getValue(NAME);
     String description = atts.getValue(DESCRIPTION);
@@ -269,8 +270,8 @@ public class GenerateMBeanHTML extends DefaultHandler {
    * Generates a table row for an MBean operation
    */
   private void startOperation(Attributes atts) {
-    if (!this.seenOperation) {
-      if (!this.seenAttribute) {
+    if (!seenOperation) {
+      if (!seenAttribute) {
         pw.println("<tr valign=\"top\">");
         pw.println("  <th align=\"left\">Operations</th>");
         pw.println("  <th align=\"left\" colspan=\"2\">Name</th>");
@@ -287,7 +288,7 @@ public class GenerateMBeanHTML extends DefaultHandler {
       }
     }
 
-    this.seenOperation = true;
+    seenOperation = true;
 
     String name = atts.getValue(NAME);
     String type = atts.getValue(RETURN_TYPE);
@@ -323,8 +324,8 @@ public class GenerateMBeanHTML extends DefaultHandler {
    * Generates a row in a table for an MBean notification
    */
   private void startNotification(Attributes atts) {
-    if (!this.seenNotifications) {
-      if (!this.seenAttribute && !this.seenOperation) {
+    if (!seenNotifications) {
+      if (!seenAttribute && !seenOperation) {
         pw.println("<tr valign=\"top\">");
         pw.println("  <th align=\"left\">Notifications</th>");
         pw.println("  <th align=\"left\" colspan=\"2\">Name</th>");
@@ -341,7 +342,7 @@ public class GenerateMBeanHTML extends DefaultHandler {
       }
     }
 
-    this.seenNotifications = true;
+    seenNotifications = true;
 
     String name = atts.getValue(NAME);
     String description = atts.getValue(DESCRIPTION);
@@ -453,11 +454,11 @@ public class GenerateMBeanHTML extends DefaultHandler {
   private static void usage(String s) {
     err.println("\n** " + s + "\n");
     err.println("usage: java GenerateMBeanHTML xmlFile htmlFile");
-    err.println("");
+    err.println();
     err.println("Converts an MBeans description XML file into an HTML");
     err.println("file suitable for documentation");
 
-    err.println("");
+    err.println();
 
     ExitCode.FATAL.doSystemExit();
   }
@@ -466,15 +467,15 @@ public class GenerateMBeanHTML extends DefaultHandler {
     String xmlFileName = null;
     String htmlFileName = null;
 
-    for (int i = 0; i < args.length; i++) {
+    for (final String arg : args) {
       if (xmlFileName == null) {
-        xmlFileName = args[i];
+        xmlFileName = arg;
 
       } else if (htmlFileName == null) {
-        htmlFileName = args[i];
+        htmlFileName = arg;
 
       } else {
-        usage("Extraneous command line argument: " + args[i]);
+        usage("Extraneous command line argument: " + arg);
       }
     }
 
