@@ -35,6 +35,7 @@ import org.apache.geode.internal.serialization.SerializationContext;
  *
  * @since GemFire 5.7
  */
+@Deprecated
 public class StatAlertNotification extends StatAlert
     implements Serializable, DataSerializableFixedID {
   private static final long serialVersionUID = -1634729103430107871L;
@@ -43,9 +44,9 @@ public class StatAlertNotification extends StatAlert
   public StatAlertNotification() {}
 
   public StatAlertNotification(StatAlert statAlert, String memberId) {
-    this.setDefinitionId(statAlert.getDefinitionId());
-    this.setValues(statAlert.getValues());
-    this.setTime(statAlert.getTime());
+    setDefinitionId(statAlert.getDefinitionId());
+    setValues(statAlert.getValues());
+    setTime(statAlert.getTime());
     this.memberId = memberId;
   }
 
@@ -74,13 +75,13 @@ public class StatAlertNotification extends StatAlert
    */
   @Override
   public String toString() {
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     buf.append("[");
     for (int i = 0; i < getValues().length; i++) {
       buf.append(getValues()[i] + ", ");
     }
     buf.append("]");
-    return Integer.valueOf(getDefinitionId()) + ":" + buf.toString();
+    return getDefinitionId() + ":" + buf;
   }
 
   /**
@@ -90,16 +91,16 @@ public class StatAlertNotification extends StatAlert
    * @return String representation of this object based on {@link StatAlertDefinition}
    */
   public String toString(StatAlertDefinition defn) {
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     buf.append("For Member ID: ");
-    buf.append(this.memberId);
+    buf.append(memberId);
     buf.append("\n");
     buf.append("[ ");
     for (int i = 0; i < getValues().length; i++) {
       buf.append(defn.getStatisticInfo()[i].toString() + "=" + getValues()[i] + "\n");
     }
     buf.append("]");
-    return getTime().toString() + ":" + buf.toString();
+    return getTime().toString() + ":" + buf;
   }
 
   @Override
@@ -112,12 +113,8 @@ public class StatAlertNotification extends StatAlert
 
     int defId = getDefinitionId();
 
-    if (defId != -1 && defId == other.getDefinitionId() && memberId != null
-        && memberId.equals(other.getMemberId())) {
-      return true;
-    }
-
-    return false;
+    return defId != -1 && defId == other.getDefinitionId() && memberId != null
+        && memberId.equals(other.getMemberId());
   }
 
   @Override
@@ -130,11 +127,11 @@ public class StatAlertNotification extends StatAlert
       SerializationContext context) throws IOException {
     // Do not modify StatAlert to allow 57 cacheservers to function with 57+ agent
     // However, update of a new StatAlertDefn on 57 server from 57+ agent not covered with this
-    DataSerializer.writePrimitiveInt(this.getDefinitionId(), out);
-    DataSerializer.writeDate(this.getTime(), out);
-    DataSerializer.writeObjectArray(this.getValues(), out);
+    DataSerializer.writePrimitiveInt(getDefinitionId(), out);
+    DataSerializer.writeDate(getTime(), out);
+    DataSerializer.writeObjectArray(getValues(), out);
 
-    DataSerializer.writeString(this.memberId, out);
+    DataSerializer.writeString(memberId, out);
   }
 
   @Override
@@ -142,11 +139,11 @@ public class StatAlertNotification extends StatAlert
       DeserializationContext context) throws IOException, ClassNotFoundException {
     // Do not modify StatAlert to allow 57 cacheservers to function with 57+ agent
     // However, update of a new StatAlertDefn on 57 server from 57+ agent not covered with this
-    this.setDefinitionId(DataSerializer.readPrimitiveInt(in));
-    this.setTime(DataSerializer.readDate(in));
-    this.setValues((Number[]) DataSerializer.readObjectArray(in));
+    setDefinitionId(DataSerializer.readPrimitiveInt(in));
+    setTime(DataSerializer.readDate(in));
+    setValues((Number[]) DataSerializer.readObjectArray(in));
 
-    this.memberId = DataSerializer.readString(in);
+    memberId = DataSerializer.readString(in);
   }
 
   @Override
