@@ -47,6 +47,7 @@ import org.apache.geode.util.internal.GeodeGlossary;
  *
  * @since GemFire 4.0
  */
+@Deprecated
 public interface SystemMemberJmx extends SystemMember, NotificationListener {
   /**
    * Notification type for indicating a cache got created on a member of this distributed system.
@@ -209,7 +210,7 @@ public interface SystemMemberJmx extends SystemMember, NotificationListener {
       int ret = refreshInterval;
 
       try {
-        MBeanUtil.registerRefreshNotification(member, // NotificationListener
+        MBeanUtils.registerRefreshNotification(member, // NotificationListener
             ((ManagedResource) member).getMBeanName(), // User Data
             RefreshNotificationType.SYSTEM_MEMBER_CONFIG, refreshInterval); // int
 
@@ -382,8 +383,8 @@ public interface SystemMemberJmx extends SystemMember, NotificationListener {
       // need to create a new instance of ManagedBean to clean the "slate"...
       ManagedBean newManagedBean = new DynamicManagedBean(managed);
       ConfigurationParameter[] params = member.getConfiguration();
-      for (int i = 0; i < params.length; i++) {
-        ConfigurationParameterJmxImpl parm = (ConfigurationParameterJmxImpl) params[i];
+      for (final ConfigurationParameter param : params) {
+        ConfigurationParameterJmxImpl parm = (ConfigurationParameterJmxImpl) param;
         ConfigAttributeInfo attrInfo = new ConfigAttributeInfo(parm);
 
         attrInfo.setName(parm.getName());
@@ -445,7 +446,7 @@ public interface SystemMemberJmx extends SystemMember, NotificationListener {
      */
     /* default */static void sendNotification(ManagedResource resource, Notification notif) {
       try {
-        if (MBeanUtil.isRegistered(resource.getObjectName())) {
+        if (MBeanUtils.isRegistered(resource.getObjectName())) {
           resource.getModelMBean().sendNotification(notif);
           if (logger.isDebugEnabled()) {
             logger.debug("Sent '{}' notification", notif.getType());
@@ -454,12 +455,12 @@ public interface SystemMemberJmx extends SystemMember, NotificationListener {
       } catch (RuntimeOperationsException e) {
         logger
             .info(String.format("Failed to send %s notification for %s",
-                new Object[] {"'" + notif.getType() + "'", "'" + notif.getMessage() + "'"}),
+                "'" + notif.getType() + "'", "'" + notif.getMessage() + "'"),
                 e);
       } catch (MBeanException e) {
         logger
             .info(String.format("Failed to send %s notification for %s",
-                new Object[] {"'" + notif.getType() + "'", "'" + notif.getMessage() + "'"}),
+                "'" + notif.getType() + "'", "'" + notif.getMessage() + "'"),
                 e);
       }
     }
