@@ -55,6 +55,7 @@ import org.apache.geode.logging.internal.log4j.api.LogService;
  * @since GemFire 3.5
  *
  */
+@Deprecated
 public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemMemberImpl
     implements SystemMemberJmx, javax.management.NotificationListener,
     org.apache.geode.admin.jmx.internal.ManagedResource {
@@ -73,8 +74,8 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
   private SystemMemberCacheJmxImpl managedSystemMemberCache;
 
   /** collection to collect all the resources created for this member */
-  private Map<StatResource, StatisticResourceJmxImpl> managedStatisticsResourcesMap =
-      new HashMap<StatResource, StatisticResourceJmxImpl>();
+  private final Map<StatResource, StatisticResourceJmxImpl> managedStatisticsResourcesMap =
+      new HashMap<>();
 
 
   // -------------------------------------------------------------------------
@@ -112,17 +113,17 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
 
   /** Create and register the MBean to manage this resource */
   private void initializeMBean() throws org.apache.geode.admin.AdminException {
-    this.mbeanName = new StringBuffer("GemFire.Member:id=")
-        .append(MBeanUtil.makeCompliantMBeanNameProperty(getId())).append(",type=")
-        .append(MBeanUtil.makeCompliantMBeanNameProperty(getType().getName())).toString();
+    mbeanName = "GemFire.Member:id="
+        + MBeanUtils.makeCompliantMBeanNameProperty(getId()) + ",type="
+        + MBeanUtils.makeCompliantMBeanNameProperty(getType().getName());
 
-    this.objectName =
-        MBeanUtil.createMBean(this, addDynamicAttributes(MBeanUtil.lookupManagedBean(this)));
+    objectName =
+        MBeanUtils.createMBean(this, addDynamicAttributes(MBeanUtils.lookupManagedBean(this)));
 
     // Refresh Interval
     AdminDistributedSystemJmxImpl sysJmx = (AdminDistributedSystemJmxImpl) system;
     if (sysJmx.getRefreshInterval() > 0) {
-      this.refreshInterval = sysJmx.getRefreshInterval();
+      refreshInterval = sysJmx.getRefreshInterval();
     }
   }
 
@@ -137,7 +138,7 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
    */
   @Override
   public int getRefreshInterval() {
-    return this.refreshInterval;
+    return refreshInterval;
   }
 
   /**
@@ -164,7 +165,7 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
    */
   @Override
   public void _setRefreshInterval(int refreshInterval) {
-    boolean isRegistered = MBeanUtil.isRefreshNotificationRegistered(this,
+    boolean isRegistered = MBeanUtils.isRefreshNotificationRegistered(this,
         RefreshNotificationType.SYSTEM_MEMBER_CONFIG);
 
     if (isRegistered && (getRefreshInterval() == refreshInterval)) {
@@ -182,8 +183,8 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
   public void refreshConfig() throws org.apache.geode.admin.AdminException {
     // 1st call to refreshConfig would trigger
     // the auto-refresh if an interval is set
-    if (this.refreshInterval > 0) {
-      this._setRefreshInterval(this.refreshInterval);
+    if (refreshInterval > 0) {
+      _setRefreshInterval(refreshInterval);
     }
 
     super.refreshConfig();
@@ -239,7 +240,7 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
    */
   @Override
   public void handleNotification(Notification notification, Object hb) {
-    AdminDistributedSystemJmxImpl systemJmx = (AdminDistributedSystemJmxImpl) this.system;
+    AdminDistributedSystemJmxImpl systemJmx = (AdminDistributedSystemJmxImpl) system;
 
     if (!systemJmx.isRmiClientCountZero()) {
       Helper.handleNotification(this, notification, hb);
@@ -273,7 +274,7 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
       throws org.apache.geode.admin.AdminException {
     StatisticResourceJmxImpl managedStatisticResource = null;
 
-    synchronized (this.managedStatisticsResourcesMap) {
+    synchronized (managedStatisticsResourcesMap) {
       /*
        * Ensuring that a single instance of Statistic Resource is created per StatResource.
        */
@@ -335,12 +336,12 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
 
   @Override
   public String getMBeanName() {
-    return this.mbeanName;
+    return mbeanName;
   }
 
   @Override
   public ModelMBean getModelMBean() {
-    return this.modelMBean;
+    return modelMBean;
   }
 
   @Override
@@ -350,7 +351,7 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
 
   @Override
   public ObjectName getObjectName() {
-    return this.objectName;
+    return objectName;
   }
 
   @Override
@@ -364,26 +365,25 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
    */
   @Override
   public void cleanupResource() {
-    synchronized (this.managedStatisticsResourcesMap) {
+    synchronized (managedStatisticsResourcesMap) {
       ConfigurationParameter[] names = getConfiguration();
       if (names != null) {
-        for (int i = 0; i < names.length; i++) {
-          ConfigurationParameter parm = names[i];
+        for (ConfigurationParameter parm : names) {
           ((ConfigurationParameterImpl) parm).removeConfigurationParameterListener(this);
         }
       }
-      this.parms.clear();
+      parms.clear();
 
       Collection<StatisticResourceJmxImpl> statisticResources =
           managedStatisticsResourcesMap.values();
 
       for (StatisticResourceJmxImpl statisticResource : statisticResources) {
-        MBeanUtil.unregisterMBean(statisticResource);
+        MBeanUtils.unregisterMBean(statisticResource);
       }
 
-      this.managedStatisticsResourcesMap.clear();
+      managedStatisticsResourcesMap.clear();
     }
-    MBeanUtil.unregisterMBean(managedSystemMemberCache);
+    MBeanUtils.unregisterMBean(managedSystemMemberCache);
   }
 
 
@@ -399,12 +399,12 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
    * is not supposed to contain '/' as per InternalDistributedMember.toString().
    */
   public List<ManagedResource> cleanupBridgeClientResources(String clientId) {
-    List<ManagedResource> returnedResources = new ArrayList<ManagedResource>();
+    List<ManagedResource> returnedResources = new ArrayList<>();
 
-    String compatibleId = "id_" + MBeanUtil.makeCompliantMBeanNameProperty(clientId);
-    synchronized (this.managedStatisticsResourcesMap) {
+    String compatibleId = "id_" + MBeanUtils.makeCompliantMBeanNameProperty(clientId);
+    synchronized (managedStatisticsResourcesMap) {
       Set<Entry<StatResource, StatisticResourceJmxImpl>> entrySet =
-          this.managedStatisticsResourcesMap.entrySet();
+          managedStatisticsResourcesMap.entrySet();
 
       for (Iterator<Entry<StatResource, StatisticResourceJmxImpl>> it = entrySet.iterator(); it
           .hasNext();) {
@@ -443,11 +443,11 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
 
     if (cleanedUp != null) {
       for (ManagedResource resource : cleanedUp) {
-        MBeanUtil.unregisterMBean(resource);
+        MBeanUtils.unregisterMBean(resource);
       }
     }
 
-    Helper.sendNotification(this, new Notification(notifType, this.modelMBean,
+    Helper.sendNotification(this, new Notification(notifType, modelMBean,
         Helper.getNextNotificationSequenceNumber(), clientId));
   }
 
@@ -460,7 +460,7 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
    */
   @Override
   public void handleCacheCreate(SystemMemberCacheEvent event) {
-    Helper.sendNotification(this, new Notification(NOTIF_CACHE_CREATED, this.modelMBean,
+    Helper.sendNotification(this, new Notification(NOTIF_CACHE_CREATED, modelMBean,
         Helper.getNextNotificationSequenceNumber(), Helper.getCacheEventDetails(event)));
   }
 
@@ -473,7 +473,7 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
    */
   @Override
   public void handleCacheClose(SystemMemberCacheEvent event) {
-    Helper.sendNotification(this, new Notification(NOTIF_CACHE_CLOSED, this.modelMBean,
+    Helper.sendNotification(this, new Notification(NOTIF_CACHE_CLOSED, modelMBean,
         Helper.getNextNotificationSequenceNumber(), Helper.getCacheEventDetails(event)));
   }
 
@@ -486,7 +486,7 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
    */
   @Override
   public void handleRegionCreate(SystemMemberRegionEvent event) {
-    Notification notification = new Notification(NOTIF_REGION_CREATED, this.modelMBean,
+    Notification notification = new Notification(NOTIF_REGION_CREATED, modelMBean,
         Helper.getNextNotificationSequenceNumber(), Helper.getRegionEventDetails(event));
 
     notification.setUserData(event.getRegionPath());
@@ -504,17 +504,17 @@ public class SystemMemberJmxImpl extends org.apache.geode.admin.internal.SystemM
    */
   @Override
   public void handleRegionLoss(SystemMemberRegionEvent event) {
-    SystemMemberCacheJmxImpl cacheResource = this.managedSystemMemberCache;
+    SystemMemberCacheJmxImpl cacheResource = managedSystemMemberCache;
 
     if (cacheResource != null) {
       ManagedResource cleanedUp = cacheResource.cleanupRegionResources(event.getRegionPath());
 
       if (cleanedUp != null) {
-        MBeanUtil.unregisterMBean(cleanedUp);
+        MBeanUtils.unregisterMBean(cleanedUp);
       }
     }
 
-    Notification notification = new Notification(NOTIF_REGION_LOST, this.modelMBean,
+    Notification notification = new Notification(NOTIF_REGION_LOST, modelMBean,
         Helper.getNextNotificationSequenceNumber(), Helper.getRegionEventDetails(event));
 
     notification.setUserData(event.getRegionPath());
