@@ -55,7 +55,6 @@ import org.apache.geode.security.GemFireSecurityException;
  * GemFire DistributedSystem that has created an instance of this class will automatically
  * instantiate regions created through the factory from anywhere else in the DistributedSystem.
  * <p>
- * <p>
  * Instructions for Use:<br>
  * <ul>
  * <li>If your application is a client in a client/server installation, either specify the pool name
@@ -112,7 +111,6 @@ import org.apache.geode.security.GemFireSecurityException;
  * register interest in server keys or not. You will generally want this to be turned on so that
  * clients will see updates made to servers. In server processes, DynamicRegionFactory forces use of
  * NotifyBySubscription.
- * </ul>
  * <p>
  * Notes:
  * <ul>
@@ -136,7 +134,6 @@ import org.apache.geode.security.GemFireSecurityException;
  * @deprecated This class is deprecated. Use {@link FunctionService} to create regions on other
  *             members instead.
  */
-@SuppressWarnings("deprecation")
 @Deprecated
 public abstract class DynamicRegionFactory {
 
@@ -179,7 +176,7 @@ public abstract class DynamicRegionFactory {
    * @param conf the configuration for this factory.
    */
   public void open(Config conf) {
-    this.config = new Config(conf);
+    config = new Config(conf);
   }
 
   /**
@@ -187,12 +184,14 @@ public abstract class DynamicRegionFactory {
    * regions in this cache.
    */
   protected void doClose() {
-    this.config = null;
-    this.cache = null;
+    config = null;
+    cache = null;
   }
 
   /**
    * Returns true if dynamic region factory is open; false if closed.
+   *
+   * @return whether this dynamic region factory is open
    */
   public boolean isOpen() {
     return getConfig() != null;
@@ -201,13 +200,17 @@ public abstract class DynamicRegionFactory {
   /**
    * Returns true if this factory is open and can produce dynamic regions. Factories are only active
    * after their cache has been created.
+   *
+   * @return whether this factory is open and can produce dynamic regions
    */
   public boolean isActive() {
-    return isOpen() && this.cache != null;
+    return isOpen() && cache != null;
   }
 
   /**
    * Returns true if dynamic region factory is closed.
+   *
+   * @return whether the dynamic region factory is closed
    */
   public boolean isClosed() {
     return !isOpen();
@@ -215,12 +218,14 @@ public abstract class DynamicRegionFactory {
 
   /**
    * Returns the configuration for this factory. Returns null if the factory is closed;
+   *
+   * @return the configuration for this factory
    */
   public Config getConfig() {
-    if (this.config == null) {
+    if (config == null) {
       return null;
     } else {
-      return new Config(this.config);
+      return new Config(config);
     }
   }
 
@@ -244,18 +249,18 @@ public abstract class DynamicRegionFactory {
     }
 
     try {
-      this.cache = theCache;
-      this.dynamicRegionList = theCache.getRegion(DYNAMIC_REGION_LIST_NAME);
-      final boolean isClient = this.config.getPoolName() != null;
-      if (this.dynamicRegionList == null) {
+      cache = theCache;
+      dynamicRegionList = theCache.getRegion(DYNAMIC_REGION_LIST_NAME);
+      final boolean isClient = config.getPoolName() != null;
+      if (dynamicRegionList == null) {
         InternalRegionFactory factory = cache.createInternalRegionFactory();
         factory.setDestroyLockFlag(true).setInternalRegion(true).setSnapshotInputStream(null)
             .setImageTarget(null);
-        if (this.config.getPersistBackup()) {
+        if (config.getPersistBackup()) {
           factory.setDataPolicy(DataPolicy.PERSISTENT_REPLICATE);
           factory.setDiskWriteAttributes(new DiskWriteAttributesFactory().create());
-          if (this.config.getDiskDir() != null) {
-            factory.setDiskDirs(new File[] {this.config.getDiskDir()});
+          if (config.getDiskDir() != null) {
+            factory.setDiskDirs(new File[] {config.getDiskDir()});
           }
         }
 
@@ -263,7 +268,7 @@ public abstract class DynamicRegionFactory {
           factory.setScope(Scope.LOCAL);
           factory.setDataPolicy(DataPolicy.NORMAL);
           factory.setStatisticsEnabled(true);
-          String cpName = this.config.getPoolName();
+          String cpName = config.getPoolName();
           if (cpName != null) {
             Pool cp = PoolManager.find(cpName);
             if (cp == null) {
@@ -284,28 +289,28 @@ public abstract class DynamicRegionFactory {
           factory.setScope(Scope.DISTRIBUTED_ACK);
           factory.setValueConstraint(DynamicRegionAttributes.class);
 
-          if (!this.config.getPersistBackup()) { // if persistBackup, the data policy has already
-                                                 // been set
+          if (!config.getPersistBackup()) { // if persistBackup, the data policy has already
+                                            // been set
             factory.setDataPolicy(DataPolicy.REPLICATE);
           }
 
-          for (GatewaySender gs : this.cache.getGatewaySenders()) {
+          for (GatewaySender gs : cache.getGatewaySenders()) {
             if (!gs.isParallel()) {
               factory.addGatewaySenderId(gs.getId());
             }
           }
           factory.setInternalMetaRegion(new DistributedMetaRegion(factory.getCreateAttributes()));
         }
-        this.dynamicRegionList = factory.create(DYNAMIC_REGION_LIST_NAME);
+        dynamicRegionList = factory.create(DYNAMIC_REGION_LIST_NAME);
         if (isClient) {
-          this.dynamicRegionList.registerInterest("ALL_KEYS");
+          dynamicRegionList.registerInterest("ALL_KEYS");
         }
         if (theCache.getLogger().fineEnabled()) {
-          theCache.getLogger().fine("Created dynamic region: " + this.dynamicRegionList);
+          theCache.getLogger().fine("Created dynamic region: " + dynamicRegionList);
         }
       } else {
         if (theCache.getLogger().fineEnabled()) {
-          theCache.getLogger().fine("Retrieved dynamic region: " + this.dynamicRegionList);
+          theCache.getLogger().fine("Retrieved dynamic region: " + dynamicRegionList);
         }
       }
 
@@ -323,7 +328,7 @@ public abstract class DynamicRegionFactory {
    */
   private void createDefinedDynamicRegions() throws CacheException {
     // TODO: perhaps add some logic here to avoid the possibility of synchronization issues
-    Set set = this.dynamicRegionList.entrySet(false);
+    Set set = dynamicRegionList.entrySet(false);
 
     Iterator iterator = set.iterator();
     SortedMap sorted = new TreeMap();
@@ -404,7 +409,7 @@ public abstract class DynamicRegionFactory {
         // error condition, so you also need to check to see if the JVM
         // is still usable:
         SystemFailure.checkFailure();
-        this.cache.getLogger().warning(
+        cache.getLogger().warning(
             String.format("DynamicRegionListener %s threw exception on beforeRegionCreated",
                 listener),
             t);
@@ -432,7 +437,7 @@ public abstract class DynamicRegionFactory {
         // error condition, so you also need to check to see if the JVM
         // is still usable:
         SystemFailure.checkFailure();
-        this.cache.getLogger().warning(
+        cache.getLogger().warning(
             String.format("DynamicRegionListener %s threw exception on afterRegionCreated",
                 listener),
             t);
@@ -465,7 +470,7 @@ public abstract class DynamicRegionFactory {
         // error condition, so you also need to check to see if the JVM
         // is still usable:
         SystemFailure.checkFailure();
-        this.cache.getLogger().warning(
+        cache.getLogger().warning(
             String.format("DynamicRegionListener %s threw exception on beforeRegionDestroyed",
                 listener),
             t);
@@ -498,7 +503,7 @@ public abstract class DynamicRegionFactory {
         // error condition, so you also need to check to see if the JVM
         // is still usable:
         SystemFailure.checkFailure();
-        this.cache.getLogger().warning(
+        cache.getLogger().warning(
             String.format("DynamicRegionListener %s threw exception on afterRegionDestroyed",
                 listener),
             t);
@@ -509,7 +514,7 @@ public abstract class DynamicRegionFactory {
   /** return the argument, or if null the DistributedMember id of this vm */
   private DistributedMember getMember(DistributedMember mbr) {
     if (mbr == null) {
-      return this.cache.getInternalDistributedSystem().getDistributedMember();
+      return cache.getInternalDistributedSystem().getDistributedMember();
     } else {
       return null;
     }
@@ -541,7 +546,7 @@ public abstract class DynamicRegionFactory {
    *         destroyed
    */
   public void destroyDynamicRegion(String fullRegionName) throws CacheException {
-    if (!this.dynamicRegionList.containsKey(fullRegionName)) {
+    if (!dynamicRegionList.containsKey(fullRegionName)) {
       throw new RegionDestroyedException(
           String.format("Dynamic region %s has not been created.",
               fullRegionName),
@@ -552,7 +557,7 @@ public abstract class DynamicRegionFactory {
     }
 
     // Retrieve the region to destroy
-    Region region = this.cache.getRegion(fullRegionName);
+    Region region = cache.getRegion(fullRegionName);
     if (region != null) {
       DistributedMember mbr = getMember(null);
       doBeforeRegionDestroyed(region, false, false, false, mbr);
@@ -570,14 +575,14 @@ public abstract class DynamicRegionFactory {
   private Region createDynamicRegionImpl(String parentRegionName, String newRegionName,
       boolean addEntry) throws CacheException {
 
-    Region parentRegion = this.cache.getRegion(parentRegionName);
+    Region parentRegion = cache.getRegion(parentRegionName);
 
     if (parentRegion == null) {
       String errMsg =
           String.format("Error -- Could not find a region named: '%s'",
               parentRegionName);
       RegionDestroyedException e = new RegionDestroyedException(errMsg, parentRegionName);
-      this.cache.getLogger().warning(
+      cache.getLogger().warning(
           String.format("Error -- Could not find a region named: '%s'",
               parentRegionName),
           e);
@@ -606,10 +611,10 @@ public abstract class DynamicRegionFactory {
     Region newRegion;
     try {
       newRegion = parentRegion.createSubregion(newRegionName, newRegionAttributes);
-      this.cache.getLogger().fine("Created dynamic region " + newRegion);
+      cache.getLogger().fine("Created dynamic region " + newRegion);
     } catch (RegionExistsException ex) {
       // a race condition exists that can cause this so just fine log it
-      this.cache.getLogger().fine(
+      cache.getLogger().fine(
           "DynamicRegion " + newRegionName + " in parent " + parentRegionName + " already existed");
       newRegion = ex.getRegion();
     }
@@ -618,25 +623,25 @@ public abstract class DynamicRegionFactory {
       DynamicRegionAttributes dra = new DynamicRegionAttributes();
       dra.name = newRegionName;
       dra.rootRegionName = parentRegion.getFullPath();
-      if (this.cache.getLogger().fineEnabled()) {
-        this.cache.getLogger()
+      if (cache.getLogger().fineEnabled()) {
+        cache.getLogger()
             .fine("Putting entry into dynamic region list at key: " + newRegion.getFullPath());
       }
-      this.dynamicRegionList.put(newRegion.getFullPath(), dra);
+      dynamicRegionList.put(newRegion.getFullPath(), dra);
     }
 
-    if (this.config.getRegisterInterest()) {
+    if (config.getRegisterInterest()) {
       ServerRegionProxy proxy = ((InternalRegion) newRegion).getServerProxy();
       if (proxy != null) {
-        if (((Pool) proxy.getPool()).getSubscriptionEnabled()) {
+        if (proxy.getPool().getSubscriptionEnabled()) {
           try {
             newRegion.registerInterest("ALL_KEYS");
           } catch (GemFireSecurityException ex) {
             // Ignore security exceptions here
-            this.cache.getSecurityLogger().warning(
+            cache.getSecurityLogger().warning(
                 String.format(
                     "Exception when registering interest for all keys in dynamic region [%s]. %s",
-                    new Object[] {newRegion.getFullPath(), ex}));
+                    newRegion.getFullPath(), ex));
           }
         }
       }
@@ -650,8 +655,8 @@ public abstract class DynamicRegionFactory {
       }
     }
 
-    if (this.cache.getLogger().fineEnabled()) {
-      this.cache.getLogger().fine("Created Dynamic Region " + newRegion.getFullPath());
+    if (cache.getLogger().fineEnabled()) {
+      cache.getLogger().fine("Created Dynamic Region " + newRegion.getFullPath());
     }
     return newRegion;
   }
@@ -659,20 +664,20 @@ public abstract class DynamicRegionFactory {
   private void destroyDynamicRegionImpl(String fullRegionName) throws CacheException {
     // Destroy the entry in the dynamicRegionList
     try {
-      if (this.cache.getLogger().fineEnabled()) {
-        this.cache.getLogger()
+      if (cache.getLogger().fineEnabled()) {
+        cache.getLogger()
             .fine("Destroying entry from dynamic region list at key: " + fullRegionName);
       }
-      this.dynamicRegionList.destroy(fullRegionName);
+      dynamicRegionList.destroy(fullRegionName);
     } catch (CacheException e) {
-      this.cache.getLogger().warning(
+      cache.getLogger().warning(
           String.format("Error destroying Dynamic Region '%s'", fullRegionName),
           e);
       throw e;
     }
 
-    if (this.cache.getLogger().fineEnabled()) {
-      this.cache.getLogger().fine("Destroyed Dynamic Region " + fullRegionName);
+    if (cache.getLogger().fineEnabled()) {
+      cache.getLogger().fine("Destroyed Dynamic Region " + fullRegionName);
     }
   }
 
@@ -717,6 +722,9 @@ public abstract class DynamicRegionFactory {
 
     /**
      * Creates a configuration with defaults and the given diskDir and poolName.
+     *
+     * @param diskDir the directory to which the region's data is written
+     * @param poolName the name of the connection pool to use
      */
     public Config(File diskDir, String poolName) {
       this(diskDir, poolName, !DISABLE_PERSIST_BACKUP, !DISABLE_REGISTER_INTEREST);
@@ -724,6 +732,12 @@ public abstract class DynamicRegionFactory {
 
     /**
      * Creates a configuration with the given attributes
+     *
+     * @param diskDir the directory to which the region's data is written
+     * @param poolName the name of the connection pool to use
+     * @param persistBackup boolean specifying if a persistent backup should be made of the region
+     * @param registerInterest whether regions created by the factory will register interest in all
+     *        keys in a corresponding server cache region
      */
     public Config(File diskDir, String poolName, boolean persistBackup, boolean registerInterest) {
       this.registerInterest = registerInterest;
@@ -772,56 +786,62 @@ public abstract class DynamicRegionFactory {
       } else if (!poolName.equals(other.poolName)) {
         return false;
       }
-      if (registerInterest != other.registerInterest) {
-        return false;
-      }
-      return true;
+      return registerInterest == other.registerInterest;
     }
 
     /**
      * Returns true if the factory is persisted to disk; false if not.
+     *
+     * @return whether the factory is persisted to disk
      */
     public boolean getPersistBackup() {
-      return this.persistBackup;
+      return persistBackup;
     }
 
     /**
      * Returns true if the region will register interest in all keys of a corresponding server cache
      * region
+     *
+     * @return whether the region will register interest in all keys of a corresponding server cache
+     *         region
      */
     public boolean getRegisterInterest() {
-      return this.registerInterest;
+      return registerInterest;
     }
 
     /**
      * Returns the disk directory that the dynamic region factory data will be written to. Returns
      * null if no directory has been specified. The diskDir is only used if {@code persistBackup} is
      * true.
+     *
+     * @return the disk directory that the dynamic region factory data will be written to
      */
     public File getDiskDir() {
-      return this.diskDir;
+      return diskDir;
     }
 
 
     /**
      * Returns the name of the {@link Pool} associated with the dynamic region factory. Returns null
      * if there is no connection pool for dynamic regions.
+     *
+     * @return the name of the {@link Pool} associated with the dynamic region factory
      */
     public String getPoolName() {
-      return this.poolName;
+      return poolName;
     }
 
     /** create a new Config with settings from another one */
     Config(Config conf) {
-      this.diskDir = conf.diskDir;
-      this.persistBackup = conf.persistBackup;
-      this.registerInterest = conf.registerInterest;
-      this.poolName = conf.poolName;
+      diskDir = conf.diskDir;
+      persistBackup = conf.persistBackup;
+      registerInterest = conf.registerInterest;
+      poolName = conf.poolName;
     }
   }
 
   protected void buildDynamicRegion(EntryEvent event) {
-    if (!DynamicRegionFactory.this.isOpen()) {
+    if (!isOpen()) {
       return;
     }
 
@@ -848,7 +868,7 @@ public abstract class DynamicRegionFactory {
   }
 
   protected void razeDynamicRegion(EntryEvent event) {
-    if (!DynamicRegionFactory.this.isOpen()) {
+    if (!isOpen()) {
       return;
     }
 
