@@ -70,16 +70,21 @@ public class RegionFactory<K, V> {
   /**
    * For internal use only.
    *
+   * @param cache the cache
+   *
    * @since GemFire 6.5
    */
   protected RegionFactory(InternalCache cache) {
     this.cache = cache;
-    this.attrsFactory = new AttributesFactory<K, V>();
+    attrsFactory = new AttributesFactory<>();
   }
 
   /**
    * For internal use only.
    *
+   * @param cache the cache
+   * @param pra the {@link RegionShortcut} with which to initialize the Region
+   *
    * @since GemFire 6.5
    */
   protected RegionFactory(InternalCache cache, RegionShortcut pra) {
@@ -88,33 +93,40 @@ public class RegionFactory<K, V> {
     if (ra == null) {
       throw new IllegalStateException("The region shortcut " + pra + " has been removed.");
     }
-    this.attrsFactory = new AttributesFactory<K, V>(ra);
+    attrsFactory = new AttributesFactory<>(ra);
   }
 
   /**
    * For internal use only.
    *
+   * @param cache the cache
+   * @param ra the {@link RegionAttributes} with which to initialize the Region
+   *
    * @since GemFire 6.5
    */
   protected RegionFactory(InternalCache cache, RegionAttributes ra) {
     this.cache = cache;
-    this.attrsFactory = new AttributesFactory<K, V>(ra);
+    attrsFactory = new AttributesFactory<>(ra);
   }
 
   /**
    * Constructs a RegionFactory that is a copy of an existing RegionFactory
    *
+   * @param regionFactory the RegionFactory to copy
    * @since Geode 1.12.0
    */
   @VisibleForTesting
   protected RegionFactory(RegionFactory<K, V> regionFactory) {
-    this.attrsFactory = new AttributesFactory<>(regionFactory.getRegionAttributes());
-    this.cache = regionFactory.getCache();
+    attrsFactory = new AttributesFactory<>(regionFactory.getRegionAttributes());
+    cache = regionFactory.getCache();
   }
 
   /**
    * For internal use only.
    *
+   * @param cache the cache
+   * @param regionAttributesId the id of the {@link RegionAttributes} with which to initialize the
+   *        Region
    * @since GemFire 6.5
    */
   protected RegionFactory(InternalCache cache, String regionAttributesId) {
@@ -124,7 +136,7 @@ public class RegionFactory<K, V> {
       throw new IllegalStateException(String.format("No attributes associated with %s",
           regionAttributesId));
     }
-    this.attrsFactory = new AttributesFactory<>(ra);
+    attrsFactory = new AttributesFactory<>(ra);
   }
 
   /**
@@ -146,6 +158,7 @@ public class RegionFactory<K, V> {
    * existing DistributedSystem. The Region configuration is initialized using the provided
    * RegionAttributes.
    *
+   * @param regionAttributes the {@link RegionAttributes} with which to initialize the Region
    * @throws CacheException if unable to connect the DistributedSystem or create a Cache
    * @deprecated as of 6.5 use {@link Cache#createRegionFactory(RegionAttributes)} instead.
    */
@@ -235,16 +248,19 @@ public class RegionFactory<K, V> {
         regionAttributesId);
   }
 
-
   /**
    * Returns the cache used by this factory.
+   *
+   * @return he cache used by this factory
    */
   protected synchronized InternalCache getCache() {
-    return this.cache;
+    return cache;
   }
 
   /**
    * Returns the attributes used by this factory to create a region.
+   *
+   * @return the attributes used by this factory to create a region
    */
   protected RegionAttributes<K, V> getRegionAttributes() {
     return attrsFactory.create();
@@ -259,7 +275,7 @@ public class RegionFactory<K, V> {
    *
    */
   public RegionFactory<K, V> setCacheLoader(CacheLoader<K, V> cacheLoader) {
-    this.attrsFactory.setCacheLoader(cacheLoader);
+    attrsFactory.setCacheLoader(cacheLoader);
     return this;
   }
 
@@ -271,7 +287,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setCacheWriter
    */
   public RegionFactory<K, V> setCacheWriter(CacheWriter<K, V> cacheWriter) {
-    this.attrsFactory.setCacheWriter(cacheWriter);
+    attrsFactory.setCacheWriter(cacheWriter);
     return this;
   }
 
@@ -284,7 +300,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#addCacheListener
    */
   public RegionFactory<K, V> addCacheListener(CacheListener<K, V> aListener) {
-    this.attrsFactory.addCacheListener(aListener);
+    attrsFactory.addCacheListener(aListener);
     return this;
   }
 
@@ -298,7 +314,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#initCacheListeners
    */
   public RegionFactory<K, V> initCacheListeners(CacheListener<K, V>[] newListeners) {
-    this.attrsFactory.initCacheListeners(newListeners);
+    attrsFactory.initCacheListeners(newListeners);
     return this;
   }
 
@@ -309,7 +325,7 @@ public class RegionFactory<K, V> {
    * @return a reference to this RegionFactory object
    */
   public RegionFactory<K, V> setEvictionAttributes(EvictionAttributes evictionAttributes) {
-    this.attrsFactory.setEvictionAttributes(evictionAttributes);
+    attrsFactory.setEvictionAttributes(evictionAttributes);
     return this;
   }
 
@@ -324,7 +340,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setEntryIdleTimeout
    */
   public RegionFactory<K, V> setEntryIdleTimeout(ExpirationAttributes idleTimeout) {
-    this.attrsFactory.setEntryIdleTimeout(idleTimeout);
+    attrsFactory.setEntryIdleTimeout(idleTimeout);
     return this;
   }
 
@@ -336,7 +352,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setCustomEntryIdleTimeout(CustomExpiry)
    */
   public RegionFactory<K, V> setCustomEntryIdleTimeout(CustomExpiry<K, V> custom) {
-    this.attrsFactory.setCustomEntryIdleTimeout(custom);
+    attrsFactory.setCustomEntryIdleTimeout(custom);
     return this;
   }
 
@@ -350,7 +366,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setEntryTimeToLive
    */
   public RegionFactory<K, V> setEntryTimeToLive(ExpirationAttributes timeToLive) {
-    this.attrsFactory.setEntryTimeToLive(timeToLive);
+    attrsFactory.setEntryTimeToLive(timeToLive);
     return this;
   }
 
@@ -362,7 +378,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setCustomEntryTimeToLive(CustomExpiry)
    */
   public RegionFactory<K, V> setCustomEntryTimeToLive(CustomExpiry<K, V> custom) {
-    this.attrsFactory.setCustomEntryTimeToLive(custom);
+    attrsFactory.setCustomEntryTimeToLive(custom);
     return this;
   }
 
@@ -377,7 +393,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setRegionIdleTimeout
    */
   public RegionFactory<K, V> setRegionIdleTimeout(ExpirationAttributes idleTimeout) {
-    this.attrsFactory.setRegionIdleTimeout(idleTimeout);
+    attrsFactory.setRegionIdleTimeout(idleTimeout);
     return this;
   }
 
@@ -391,7 +407,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setRegionTimeToLive
    */
   public RegionFactory<K, V> setRegionTimeToLive(ExpirationAttributes timeToLive) {
-    this.attrsFactory.setRegionTimeToLive(timeToLive);
+    attrsFactory.setRegionTimeToLive(timeToLive);
     return this;
   }
 
@@ -404,7 +420,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setScope
    */
   public RegionFactory<K, V> setScope(Scope scopeType) {
-    this.attrsFactory.setScope(scopeType);
+    attrsFactory.setScope(scopeType);
     return this;
   }
 
@@ -417,7 +433,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setDataPolicy
    */
   public RegionFactory<K, V> setDataPolicy(DataPolicy dataPolicy) {
-    this.attrsFactory.setDataPolicy(dataPolicy);
+    attrsFactory.setDataPolicy(dataPolicy);
     return this;
   }
 
@@ -431,7 +447,7 @@ public class RegionFactory<K, V> {
    */
   @Deprecated
   public RegionFactory<K, V> setEarlyAck(boolean earlyAck) {
-    this.attrsFactory.setEarlyAck(earlyAck);
+    attrsFactory.setEarlyAck(earlyAck);
     return this;
   }
 
@@ -444,7 +460,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setMulticastEnabled(boolean)
    */
   public RegionFactory<K, V> setMulticastEnabled(boolean value) {
-    this.attrsFactory.setMulticastEnabled(value);
+    attrsFactory.setMulticastEnabled(value);
     return this;
   }
 
@@ -465,13 +481,14 @@ public class RegionFactory<K, V> {
    * @since GemFire 5.7
    */
   public RegionFactory<K, V> setPoolName(String poolName) {
-    this.attrsFactory.setPoolName(poolName);
+    attrsFactory.setPoolName(poolName);
     return this;
   }
 
   /**
    * Sets whether or not this region should be considered a publisher.
    *
+   * @param v whether this region should be considered a publisher
    * @since GemFire 5.0
    * @deprecated as of 6.5
    */
@@ -486,7 +503,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setEnableAsyncConflation(boolean)
    */
   public RegionFactory<K, V> setEnableAsyncConflation(boolean value) {
-    this.attrsFactory.setEnableAsyncConflation(value);
+    attrsFactory.setEnableAsyncConflation(value);
     return this;
   }
 
@@ -499,7 +516,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setEnableSubscriptionConflation(boolean)
    */
   public RegionFactory<K, V> setEnableSubscriptionConflation(boolean value) {
-    this.attrsFactory.setEnableSubscriptionConflation(value);
+    attrsFactory.setEnableSubscriptionConflation(value);
     return this;
   }
 
@@ -514,7 +531,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setKeyConstraint
    */
   public RegionFactory<K, V> setKeyConstraint(Class<K> keyConstraint) {
-    this.attrsFactory.setKeyConstraint(keyConstraint);
+    attrsFactory.setKeyConstraint(keyConstraint);
     return this;
   }
 
@@ -530,7 +547,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setValueConstraint
    */
   public RegionFactory<K, V> setValueConstraint(Class<V> valueConstraint) {
-    this.attrsFactory.setValueConstraint(valueConstraint);
+    attrsFactory.setValueConstraint(valueConstraint);
     return this;
   }
 
@@ -545,7 +562,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setInitialCapacity
    */
   public RegionFactory<K, V> setInitialCapacity(int initialCapacity) {
-    this.attrsFactory.setInitialCapacity(initialCapacity);
+    attrsFactory.setInitialCapacity(initialCapacity);
     return this;
   }
 
@@ -560,7 +577,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setLoadFactor
    */
   public RegionFactory<K, V> setLoadFactor(float loadFactor) {
-    this.attrsFactory.setLoadFactor(loadFactor);
+    attrsFactory.setLoadFactor(loadFactor);
     return this;
   }
 
@@ -574,7 +591,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setConcurrencyLevel
    */
   public RegionFactory<K, V> setConcurrencyLevel(int concurrencyLevel) {
-    this.attrsFactory.setConcurrencyLevel(concurrencyLevel);
+    attrsFactory.setConcurrencyLevel(concurrencyLevel);
     return this;
   }
 
@@ -585,16 +602,18 @@ public class RegionFactory<K, V> {
    *
    * @since GemFire 7.0
    * @param enabled whether concurrency checks should be enabled for the region
+   * @return a reference to this RegionFactory object
    * @see AttributesFactory#setConcurrencyChecksEnabled
    */
   public RegionFactory<K, V> setConcurrencyChecksEnabled(boolean enabled) {
-    this.attrsFactory.setConcurrencyChecksEnabled(enabled);
+    attrsFactory.setConcurrencyChecksEnabled(enabled);
     return this;
   }
 
   /**
-   * Returns whether or not disk writes are asynchronous.
+   * Sets the {@link DiskWriteAttributes} for this factory
    *
+   * @param attrs the {@link DiskWriteAttributes} to be set for this factory
    * @return a reference to this RegionFactory object
    * @see Region#writeToDisk
    * @see AttributesFactory#setDiskWriteAttributes
@@ -603,7 +622,7 @@ public class RegionFactory<K, V> {
    */
   @Deprecated
   public RegionFactory<K, V> setDiskWriteAttributes(DiskWriteAttributes attrs) {
-    this.attrsFactory.setDiskWriteAttributes(attrs);
+    attrsFactory.setDiskWriteAttributes(attrs);
     return this;
   }
 
@@ -617,7 +636,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setDiskStoreName
    */
   public RegionFactory<K, V> setDiskStoreName(String name) {
-    this.attrsFactory.setDiskStoreName(name);
+    attrsFactory.setDiskStoreName(name);
     return this;
   }
 
@@ -629,7 +648,7 @@ public class RegionFactory<K, V> {
    * @since GemFire 6.5
    */
   public RegionFactory<K, V> setDiskSynchronous(boolean isSynchronous) {
-    this.attrsFactory.setDiskSynchronous(isSynchronous);
+    attrsFactory.setDiskSynchronous(isSynchronous);
     return this;
   }
 
@@ -637,6 +656,7 @@ public class RegionFactory<K, V> {
    * Sets the directories to which the region's data are written. If multiple directories are used,
    * GemFire will attempt to distribute the data evenly amongst them.
    *
+   * @param diskDirs the directories to which the region's data is written
    * @return a reference to this RegionFactory object
    *
    * @see AttributesFactory#setDiskDirs
@@ -644,7 +664,7 @@ public class RegionFactory<K, V> {
    */
   @Deprecated
   public RegionFactory<K, V> setDiskDirs(File[] diskDirs) {
-    this.attrsFactory.setDiskDirs(diskDirs);
+    attrsFactory.setDiskDirs(diskDirs);
     return this;
   }
 
@@ -652,6 +672,8 @@ public class RegionFactory<K, V> {
    * Sets the directories to which the region's data are written and also set their sizes in
    * megabytes
    *
+   * @param diskDirs the directories to which the region's data is written
+   * @param diskSizes the size in megabytes for each directory
    * @return a reference to this RegionFactory object
    * @throws IllegalArgumentException if length of the size array does not match to the length of
    *         the dir array
@@ -662,7 +684,7 @@ public class RegionFactory<K, V> {
    */
   @Deprecated
   public RegionFactory<K, V> setDiskDirsAndSizes(File[] diskDirs, int[] diskSizes) {
-    this.attrsFactory.setDiskDirsAndSizes(diskDirs, diskSizes);
+    attrsFactory.setDiskDirsAndSizes(diskDirs, diskSizes);
     return this;
   }
 
@@ -670,11 +692,13 @@ public class RegionFactory<K, V> {
    * Sets the {@code PartitionAttributes} that describe how the region is partitioned among members
    * of the distributed system.
    *
+   * @param partition the {@code PartitionAttributes} that describe how the region is partitioned
+   *        among members of the distributed system
    * @return a reference to this RegionFactory object
    * @see AttributesFactory#setPartitionAttributes
    */
   public RegionFactory<K, V> setPartitionAttributes(PartitionAttributes partition) {
-    this.attrsFactory.setPartitionAttributes(partition);
+    attrsFactory.setPartitionAttributes(partition);
     return this;
   }
 
@@ -689,7 +713,7 @@ public class RegionFactory<K, V> {
    */
   @Deprecated
   public RegionFactory<K, V> setMembershipAttributes(MembershipAttributes ra) {
-    this.attrsFactory.setMembershipAttributes(ra);
+    attrsFactory.setMembershipAttributes(ra);
     return this;
   }
 
@@ -700,7 +724,7 @@ public class RegionFactory<K, V> {
    * @return a reference to this RegionFactory object
    */
   public RegionFactory<K, V> setIndexMaintenanceSynchronous(boolean synchronous) {
-    this.attrsFactory.setIndexMaintenanceSynchronous(synchronous);
+    attrsFactory.setIndexMaintenanceSynchronous(synchronous);
     return this;
   }
 
@@ -712,17 +736,20 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setStatisticsEnabled
    */
   public RegionFactory<K, V> setStatisticsEnabled(boolean statisticsEnabled) {
-    this.attrsFactory.setStatisticsEnabled(statisticsEnabled);
+    attrsFactory.setStatisticsEnabled(statisticsEnabled);
     return this;
   }
 
   /**
    * Sets whether operations on this region should be controlled by JTA transactions or not
    *
+   * @param flag whether operations on this region should be controlled by JTA transactions
+   * @return a reference to this RegionFactory object
+   *
    * @since GemFire 5.0
    */
   public RegionFactory<K, V> setIgnoreJTA(boolean flag) {
-    this.attrsFactory.setIgnoreJTA(flag);
+    attrsFactory.setIgnoreJTA(flag);
     return this;
   }
 
@@ -734,7 +761,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setLockGrantor
    */
   public RegionFactory<K, V> setLockGrantor(boolean isLockGrantor) {
-    this.attrsFactory.setLockGrantor(isLockGrantor);
+    attrsFactory.setLockGrantor(isLockGrantor);
     return this;
   }
 
@@ -747,7 +774,7 @@ public class RegionFactory<K, V> {
    * @see AttributesFactory#setSubscriptionAttributes(SubscriptionAttributes)
    */
   public RegionFactory<K, V> setSubscriptionAttributes(SubscriptionAttributes sa) {
-    this.attrsFactory.setSubscriptionAttributes(sa);
+    attrsFactory.setSubscriptionAttributes(sa);
     return this;
   }
 
@@ -796,24 +823,26 @@ public class RegionFactory<K, V> {
   /**
    * Sets cloning on region Note: off-heap regions always behave as if cloning is enabled.
    *
+   * @param cloningEnable whether cloning is enabled for the region
    * @return a reference to this RegionFactory object
    * @since GemFire 6.1
    * @see AttributesFactory#setCloningEnabled
    */
   public RegionFactory<K, V> setCloningEnabled(boolean cloningEnable) {
-    this.attrsFactory.setCloningEnabled(cloningEnable);
+    attrsFactory.setCloningEnabled(cloningEnable);
     return this;
   }
 
   /**
    * Adds a gatewaySenderId to the RegionAttributes
    *
+   * @param gatewaySenderId the gatewaySenderId to add
    * @return a reference to this RegionFactory object
    * @since GemFire 7.0
    * @see AttributesFactory#addGatewaySenderId(String)
    */
   public RegionFactory<K, V> addGatewaySenderId(String gatewaySenderId) {
-    this.attrsFactory.addGatewaySenderId(gatewaySenderId);
+    attrsFactory.addGatewaySenderId(gatewaySenderId);
     return this;
   }
 
@@ -825,7 +854,7 @@ public class RegionFactory<K, V> {
    * @since GemFire 7.0
    */
   public RegionFactory<K, V> addAsyncEventQueueId(String asyncEventQueueId) {
-    this.attrsFactory.addAsyncEventQueueId(asyncEventQueueId);
+    attrsFactory.addAsyncEventQueueId(asyncEventQueueId);
     return this;
   }
 
@@ -837,7 +866,7 @@ public class RegionFactory<K, V> {
    * @since GemFire 8.0
    */
   public RegionFactory<K, V> setCompressor(Compressor compressor) {
-    this.attrsFactory.setCompressor(compressor);
+    attrsFactory.setCompressor(compressor);
     return this;
   }
 
@@ -845,10 +874,11 @@ public class RegionFactory<K, V> {
    * Enables this region's usage of off-heap memory if true.
    *
    * @param offHeap boolean flag to enable off-heap memory
+   * @return a reference to this RegionFactory instance
    * @since Geode 1.0
    */
   public RegionFactory<K, V> setOffHeap(boolean offHeap) {
-    this.attrsFactory.setOffHeap(offHeap);
+    attrsFactory.setOffHeap(offHeap);
     return this;
   }
 }
