@@ -24,10 +24,13 @@ import java.util.Set;
  * @deprecated this feature is scheduled to be removed
  * @see RegionRoleListener
  */
+@Deprecated
 public interface RoleEvent<K, V> extends RegionEvent<K, V> {
 
   /**
    * Returns the required roles that were lost or gained because of this event.
+   *
+   * @return the required roles that were lost or gained because of this event
    */
   Set<String> getRequiredRoles();
 
