@@ -15,10 +15,14 @@
 
 package org.apache.geode.cache.client.internal;
 
+import static org.apache.geode.logging.internal.spi.LoggingProvider.SECURITY_LOGGER_NAME;
+
 import java.io.IOException;
 import java.net.SocketTimeoutException;
 
 import org.apache.logging.log4j.Logger;
+import org.jetbrains.annotations.NotNull;
+import org.jetbrains.annotations.Nullable;
 
 import org.apache.geode.InternalGemFireError;
 import org.apache.geode.cache.client.ServerConnectivityException;
@@ -42,8 +46,8 @@ import org.apache.geode.logging.internal.log4j.api.LogService;
  * @since GemFire 5.7
  */
 public abstract class AbstractOp implements Op {
-
-  private static final Logger logger = LogService.getLogger();
+  protected static final Logger logger = LogService.getLogger();
+  protected static final Logger secureLogger = LogService.getLogger(SECURITY_LOGGER_NAME);
 
   private final Message msg;
 
@@ -117,6 +121,10 @@ public abstract class AbstractOp implements Op {
 
       if (UserAttributes.userAttributes.get() == null) { // single user mode
         userId = cnx.getServer().getUserId();
+        if (userId == -1) {
+          throw new ServerConnectivityException(
+              "Invalid userId. Connection error while authenticating user");
+        }
       } else { // multi user mode
         Long id = UserAttributes.userAttributes.get().getServerToId().get(cnx.getServer());
         if (id == null) {
@@ -126,6 +134,8 @@ public abstract class AbstractOp implements Op {
         }
         userId = id;
       }
+      secureLogger.debug("{} Using userId {}: ",
+          MessageType.getString(getMessage().getMessageType()), userId);
       try (HeapDataOutputStream hdos = new HeapDataOutputStream(KnownVersion.CURRENT)) {
         hdos.writeLong(cnx.getConnectionID());
         hdos.writeLong(userId);
@@ -166,11 +176,14 @@ public abstract class AbstractOp implements Op {
   }
 
   /**
-   * New implementations of AbstractOp should override this method to return false if the
-   * implementation should be excluded from client authentication. e.g. PingOp#needsUserId()
-   * <P/>
-   * Also, such an operation's <code>MessageType</code> must be added in the 'if' condition in
-   * {@link ServerConnection#updateAndGetSecurityPart()}
+   * @return true if this operation needs to be authenticated first
+   *
+   *         New implementations of AbstractOp should override this method to return false if the
+   *         implementation should be excluded from client authentication. e.g. PingOp#needsUserId()
+   *         <p>
+   *         Also, such an operation's <code>MessageType</code> must be added in the 'if' condition
+   *         in
+   *         {@link ServerConnection#updateAndGetSecurityPart()}
    *
    * @see AbstractOp#sendMessage(Connection)
    * @see ServerConnection#updateAndGetSecurityPart()
@@ -187,40 +200,37 @@ public abstract class AbstractOp implements Op {
    * @return the result of the operation or <code>null</code> if the operation has no result.
    * @throws Exception if the execute failed
    */
-  protected Object attemptReadResponse(Connection cnx) throws Exception {
-    Message msg = createResponseMessage();
-    if (msg != null) {
-      msg.setComms(cnx.getSocket(), cnx.getInputStream(), cnx.getOutputStream(),
-          cnx.getCommBuffer(), cnx.getStats());
-      if (msg instanceof ChunkedMessage) {
-        try {
-          return processResponse(msg, cnx);
-        } finally {
-          msg.unsetComms();
-          processSecureBytes(cnx, msg);
-        }
-      } else {
-        try {
-          msg.receive();
-        } finally {
-          msg.unsetComms();
-          processSecureBytes(cnx, msg);
-        }
+  protected Object attemptReadResponse(final @NotNull Connection cnx) throws Exception {
+    final Message msg = createResponseMessage();
+    msg.setComms(cnx.getSocket(), cnx.getInputStream(), cnx.getOutputStream(),
+        cnx.getCommBuffer(), cnx.getStats());
+    if (msg instanceof ChunkedMessage) {
+      try {
         return processResponse(msg, cnx);
+      } finally {
+        msg.unsetComms();
+        processSecureBytes(cnx, msg);
       }
     } else {
-      return null;
+      try {
+        msg.receive();
+      } finally {
+        msg.unsetComms();
+        processSecureBytes(cnx, msg);
+      }
+      return processResponse(msg, cnx);
     }
   }
 
   /**
    * By default just create a normal one part msg. Subclasses can override this.
    */
-  protected Message createResponseMessage() {
+  protected @NotNull Message createResponseMessage() {
     return new Message(1, KnownVersion.CURRENT);
   }
 
-  protected Object processResponse(Message m, Connection con) throws Exception {
+  protected @Nullable Object processResponse(final @NotNull Message m,
+      final @NotNull Connection con) throws Exception {
     return processResponse(m);
   }
 
@@ -231,7 +241,7 @@ public abstract class AbstractOp implements Op {
    * @throws Exception if response could not be processed or we received a response with a server
    *         exception.
    */
-  protected abstract Object processResponse(Message msg) throws Exception;
+  protected abstract @Nullable Object processResponse(final @NotNull Message msg) throws Exception;
 
   /**
    * Return true of <code>messageType</code> indicates the operation had an error on the server.
