@@ -20,22 +20,21 @@ import java.net.ConnectException;
 import java.net.InetSocketAddress;
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
-import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicReference;
 
 import org.apache.logging.log4j.Logger;
+import org.jetbrains.annotations.NotNull;
 
 import org.apache.geode.ToDataException;
 import org.apache.geode.annotations.Immutable;
 import org.apache.geode.cache.client.NoAvailableLocatorsException;
+import org.apache.geode.cache.client.NoAvailableServersException;
 import org.apache.geode.cache.client.SocketFactory;
 import org.apache.geode.cache.client.internal.PoolImpl.PoolTask;
 import org.apache.geode.cache.client.internal.locator.ClientConnectionRequest;
@@ -69,39 +68,16 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
 
   private static final Logger logger = LogService.getLogger();
 
-  private TcpClient tcpClient;
+  private final TcpClient tcpClient;
 
   @Immutable
   private static final LocatorListRequest LOCATOR_LIST_REQUEST = new LocatorListRequest();
 
-  /**
-   * A Comparator used to sort a list of locator addresses. This should not be
-   * used in other ways as it can return zero when two addresses aren't actually equal.
-   */
-  @Immutable
-  private static final Comparator<HostAndPort> SOCKET_ADDRESS_COMPARATOR =
-      (address, otherAddress) -> {
-        InetSocketAddress inetSocketAddress = address.getSocketInetAddress();
-        InetSocketAddress otherInetSocketAddress = otherAddress.getSocketInetAddress();
-        // shouldn't happen, but if it does we'll say they're the same.
-        if (inetSocketAddress.getHostString() == null
-            || otherInetSocketAddress.getHostString() == null) {
-          return 0;
-        }
-
-        int result = inetSocketAddress.getHostString()
-            .compareTo(otherInetSocketAddress.getHostString());
-        if (result != 0) {
-          return result;
-        } else {
-          return inetSocketAddress.getPort() - otherInetSocketAddress.getPort();
-        }
-      };
   private final List<HostAndPort> initialLocators;
 
   private final String serverGroup;
-  private AtomicReference<LocatorList> locators = new AtomicReference<>();
-  private AtomicReference<LocatorList> onlineLocators = new AtomicReference<>();
+  private final AtomicReference<LocatorList> locators = new AtomicReference<>();
+  private final AtomicReference<LocatorList> onlineLocators = new AtomicReference<>();
   protected InternalPool pool;
   private final int connectionTimeout;
   private long locatorUpdateInterval;
@@ -113,19 +89,25 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
    */
   private final Map<InetSocketAddress, Exception> locatorState = new HashMap<>();
 
-  public AutoConnectionSourceImpl(List<HostAndPort> contacts, String serverGroup,
-      int handshakeTimeout,
-      SocketFactory socketFactory) {
-    this.locators.set(new LocatorList(new ArrayList<>(contacts)));
-    this.onlineLocators.set(new LocatorList(Collections.emptyList()));
-    this.initialLocators = Collections.unmodifiableList(this.locators.get().getLocatorAddresses());
-    this.connectionTimeout = handshakeTimeout;
-    this.serverGroup = serverGroup;
-    this.tcpClient = new TcpClient(SocketCreatorFactory
+  public AutoConnectionSourceImpl(final @NotNull List<HostAndPort> contacts,
+      final @NotNull String serverGroup,
+      final int handshakeTimeout, final @NotNull SocketFactory socketFactory) {
+    this(contacts, serverGroup, handshakeTimeout, new TcpClient(SocketCreatorFactory
         .getSocketCreatorForComponent(SecurableCommunicationChannel.LOCATOR),
         InternalDataSerializer.getDSFIDSerializer().getObjectSerializer(),
         InternalDataSerializer.getDSFIDSerializer().getObjectDeserializer(),
-        socketFactory::createSocket);
+        socketFactory::createSocket));
+  }
+
+  AutoConnectionSourceImpl(final @NotNull List<HostAndPort> contacts,
+      final @NotNull String serverGroup,
+      final int handshakeTimeout, final @NotNull TcpClient tcpClient) {
+    locators.set(new LocatorList(new ArrayList<>(contacts)));
+    onlineLocators.set(new LocatorList(Collections.emptyList()));
+    initialLocators = Collections.unmodifiableList(locators.get().getLocatorAddresses());
+    connectionTimeout = handshakeTimeout;
+    this.serverGroup = serverGroup;
+    this.tcpClient = tcpClient;
   }
 
   @Override
@@ -160,11 +142,14 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
       throw new NoAvailableLocatorsException(
           "Unable to connect to any locators in the list " + locators);
     }
+    if (!response.hasResult()) {
+      throw new NoAvailableServersException("No servers found");
+    }
     return response.getServer();
   }
 
   @Override
-  public ServerLocation findServer(Set excludedServers) {
+  public ServerLocation findServer(Set<ServerLocation> excludedServers) {
     if (PoolImpl.TEST_DURABLE_IS_NET_DOWN) {
       return null;
     }
@@ -174,6 +159,9 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
       throw new NoAvailableLocatorsException(
           "Unable to connect to any locators in the list " + locators);
     }
+    if (!response.hasResult()) {
+      throw new NoAvailableServersException("No servers found");
+    }
     return response.getServer();
   }
 
@@ -190,6 +178,9 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
       throw new NoAvailableLocatorsException(
           "Unable to connect to any locators in the list " + locators);
     }
+    if (!response.hasResult()) {
+      throw new NoAvailableServersException("No servers found");
+    }
     return response.getServers();
   }
 
@@ -214,8 +205,7 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
     Object returnObj = null;
     try {
       pool.getStats().incLocatorRequests();
-      returnObj = locatorConnection.requestToServer(locator, request,
-          connectionTimeout, true);
+      returnObj = locatorConnection.requestToServer(locator, request, connectionTimeout, true);
       ServerLocationResponse response = (ServerLocationResponse) returnObj;
       pool.getStats().incLocatorResponses();
       if (response != null) {
@@ -241,21 +231,25 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
     }
   }
 
-  private ServerLocationResponse queryLocators(ServerLocationRequest request) {
-    Iterator controllerItr = locators.get().iterator();
-    ServerLocationResponse response;
-
+  ServerLocationResponse queryLocators(ServerLocationRequest request) {
+    ServerLocationResponse response = null;
     final boolean isDebugEnabled = logger.isDebugEnabled();
-    do {
-      HostAndPort hostAddress = (HostAndPort) controllerItr.next();
+
+    for (final HostAndPort locator : locators.get()) {
       if (isDebugEnabled) {
-        logger.debug("Sending query to locator {}: {}", hostAddress, request);
+        logger.debug("Sending query to locator {}: {}", locator, request);
       }
-      response = queryOneLocator(hostAddress, request);
+      ServerLocationResponse tempResponse = queryOneLocator(locator, request);
       if (isDebugEnabled) {
-        logger.debug("Received query response from locator {}: {}", hostAddress, response);
+        logger.debug("Received query response from locator {}: {}", locator, tempResponse);
       }
-    } while (controllerItr.hasNext() && (response == null || !response.hasResult()));
+      if (tempResponse != null) {
+        response = tempResponse;
+        if (response.hasResult()) {
+          break;
+        }
+      }
+    }
 
     return response;
   }
@@ -279,7 +273,7 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
       badLocators.remove(hostAddress);
     }
 
-    addbadLocators(newLocatorAddresses, badLocators);
+    addBadLocators(newLocatorAddresses, badLocators);
 
     LocatorList newLocatorList = new LocatorList(newLocatorAddresses);
 
@@ -312,12 +306,12 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
    * This method will add bad locator only when locator with hostname and port is not already in
    * list.
    */
-  protected void addbadLocators(List<HostAndPort> newLocators, Set<HostAndPort> badLocators) {
-    for (HostAndPort badloc : badLocators) {
+  protected void addBadLocators(List<HostAndPort> newLocators, Set<HostAndPort> badLocators) {
+    for (HostAndPort badLocator : badLocators) {
       boolean addIt = true;
-      for (HostAndPort goodloc : newLocators) {
-        boolean isSameHost = badloc.getHostName().equals(goodloc.getHostName());
-        if (isSameHost && badloc.getPort() == goodloc.getPort()) {
+      for (HostAndPort goodLocator : newLocators) {
+        boolean isSameHost = badLocator.getHostName().equals(goodLocator.getHostName());
+        if (isSameHost && badLocator.getPort() == goodLocator.getPort()) {
           // ip has been changed so don't add this in current
           // list
           addIt = false;
@@ -326,7 +320,7 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
         }
       }
       if (addIt) {
-        newLocators.add(badloc);
+        newLocators.add(badLocator);
       }
     }
   }
@@ -335,14 +329,14 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
   public void start(InternalPool pool) {
     this.pool = pool;
     pool.getStats().setInitialContacts((locators.get()).size());
-    this.locatorUpdateInterval = Long.getLong(
+    locatorUpdateInterval = Long.getLong(
         GeodeGlossary.GEMFIRE_PREFIX + "LOCATOR_UPDATE_INTERVAL", pool.getPingInterval());
 
     if (locatorUpdateInterval > 0) {
       pool.getBackgroundProcessor().scheduleWithFixedDelay(new UpdateLocatorListTask(), 0,
           locatorUpdateInterval, TimeUnit.MILLISECONDS);
       logger.info("AutoConnectionSource UpdateLocatorListTask started with interval={} ms.",
-          new Object[] {this.locatorUpdateInterval});
+          locatorUpdateInterval);
     }
   }
 
@@ -352,18 +346,18 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
   }
 
   public void setLocatorDiscoveryCallback(LocatorDiscoveryCallback callback) {
-    this.locatorCallback = callback;
+    locatorCallback = callback;
   }
 
   private synchronized void reportLiveLocator(InetSocketAddress l) {
-    Object prevState = this.locatorState.put(l, null);
+    Object prevState = locatorState.put(l, null);
     if (prevState != null) {
       logger.info("Communication has been restored with locator {}.", l);
     }
   }
 
   private synchronized void reportDeadLocator(InetSocketAddress l, Exception ex) {
-    Object prevState = this.locatorState.put(l, ex);
+    Object prevState = locatorState.put(l, ex);
     if (prevState == null) {
       if (ex instanceof ConnectException) {
         logger.info("locator {} is not running.", l, ex);
@@ -374,79 +368,7 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
   }
 
   long getLocatorUpdateInterval() {
-    return this.locatorUpdateInterval;
-  }
-
-  /**
-   * A list of locators, which remembers the last known good locator.
-   */
-  private static class LocatorList {
-    protected final List<HostAndPort> locators;
-    AtomicInteger currentLocatorIndex = new AtomicInteger();
-
-    LocatorList(List<HostAndPort> locators) {
-      locators.sort(SOCKET_ADDRESS_COMPARATOR);
-      this.locators = Collections.unmodifiableList(locators);
-    }
-
-    public List<InetSocketAddress> getLocators() {
-      List<InetSocketAddress> locs = new ArrayList<>();
-      for (HostAndPort la : locators) {
-        locs.add(la.getSocketInetAddress());
-      }
-      return locs;
-    }
-
-    List<HostAndPort> getLocatorAddresses() {
-      return locators;
-    }
-
-    public int size() {
-      return locators.size();
-    }
-
-    public Iterator<HostAndPort> iterator() {
-      return new LocatorIterator();
-    }
-
-    @Override
-    public String toString() {
-      return locators.toString();
-    }
-
-
-    /**
-     * An iterator which iterates all of the controllers, starting at the last known good
-     * controller.
-     *
-     */
-    protected class LocatorIterator implements Iterator<HostAndPort> {
-      private int startLocator = currentLocatorIndex.get();
-      private int locatorNum = 0;
-
-      @Override
-      public boolean hasNext() {
-        return locatorNum < locators.size();
-      }
-
-      @Override
-      public HostAndPort next() {
-        if (!hasNext()) {
-          return null;
-        } else {
-          int index = (locatorNum + startLocator) % locators.size();
-          HostAndPort nextLocator = locators.get(index);
-          currentLocatorIndex.set(index);
-          locatorNum++;
-          return nextLocator;
-        }
-      }
-
-      @Override
-      public void remove() {
-        throw new UnsupportedOperationException();
-      }
-    }
+    return locatorUpdateInterval;
   }
 
   protected class UpdateLocatorListTask extends PoolTask {
