@@ -25,6 +25,7 @@ import java.util.Set;
 import java.util.function.Supplier;
 
 import org.apache.logging.log4j.Logger;
+import org.jetbrains.annotations.NotNull;
 
 import org.apache.geode.InternalGemFireError;
 import org.apache.geode.cache.CacheClosedException;
@@ -149,11 +150,11 @@ public class ExecuteRegionFunctionSingleHopOp {
 
     private final byte hasResult;
 
-    private Set<String> failedNodes;
+    private final Set<String> failedNodes;
 
-    private boolean isHA;
+    private final boolean isHA;
 
-    private boolean optimizeForWrite;
+    private final boolean optimizeForWrite;
 
     ExecuteRegionFunctionSingleHopOpImpl(String region, Function function,
         ServerRegionFunctionExecutor serverRegionExecutor, ResultCollector rc, byte hasResult,
@@ -254,7 +255,7 @@ public class ExecuteRegionFunctionSingleHopOp {
     }
 
     @Override
-    protected Object processResponse(Message msg) throws Exception {
+    protected Object processResponse(final @NotNull Message msg) throws Exception {
       ChunkedMessage executeFunctionResponseMsg = (ChunkedMessage) msg;
       try {
         executeFunctionResponseMsg.readHeader();
@@ -433,7 +434,7 @@ public class ExecuteRegionFunctionSingleHopOp {
     }
 
     @Override
-    protected Message createResponseMessage() {
+    protected @NotNull Message createResponseMessage() {
       return new ChunkedMessage(1, KnownVersion.CURRENT);
     }
 
