@@ -15,6 +15,7 @@
 
 package org.apache.geode.cache.client.internal;
 
+
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
@@ -33,12 +34,14 @@ import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.logging.log4j.Logger;
+import org.jetbrains.annotations.NotNull;
 
 import org.apache.geode.CancelException;
 import org.apache.geode.GemFireConfigException;
 import org.apache.geode.GemFireException;
 import org.apache.geode.SystemFailure;
 import org.apache.geode.annotations.Immutable;
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.cache.InterestResultPolicy;
 import org.apache.geode.cache.NoSubscriptionServersAvailableException;
 import org.apache.geode.cache.client.ServerConnectivityException;
@@ -91,10 +94,10 @@ public class QueueManagerImpl implements QueueManager {
   private final ClientProxyMembershipID proxyId;
   protected final InternalPool pool;
   private final QueueStateImpl state;
-  private boolean printPrimaryNotFoundError;
-  private boolean printRedundancyNotSatisfiedError;
-  private boolean printRecoveringPrimary;
-  private boolean printRecoveringRedundant;
+  private boolean printPrimaryNotFoundError = true;
+  private boolean printRedundancyNotSatisfiedError = true;
+  private boolean printRecoveringPrimary = true;
+  private boolean printRecoveringRedundant = true;
   private final ServerDenyList denyList;
   // Lock which guards updates to queueConnections.
   // Also threads calling getAllConnections will wait on this
@@ -106,39 +109,38 @@ public class QueueManagerImpl implements QueueManager {
   private ScheduledExecutorService recoveryThread;
   private volatile boolean sentClientReady;
 
+  void clearQueueConnections() {
+    this.queueConnections = new ConnectionList();
+  }
+
   // queueConnections in maintained by using copy-on-write
   private volatile ConnectionList queueConnections = new ConnectionList();
   private volatile RedundancySatisfierTask redundancySatisfierTask = null;
   private volatile boolean shuttingDown;
 
   public QueueManagerImpl(InternalPool pool, EndpointManager endpointManager,
-      ConnectionSource source, ConnectionFactory factory, int queueRedundancyLevel,
+      ConnectionSource source, ConnectionFactory factory, int redundancyLevel,
       long redundancyRetryInterval,
       @SuppressWarnings("deprecation") InternalLogWriter securityLogger,
       ClientProxyMembershipID proxyId) {
-    this.printPrimaryNotFoundError = true;
-    this.printRedundancyNotSatisfiedError = true;
-    this.printRecoveringRedundant = true;
-    this.printRecoveringPrimary = true;
     this.pool = pool;
     this.endpointManager = endpointManager;
     this.source = source;
     this.factory = factory;
-    this.redundancyLevel = queueRedundancyLevel;
+    this.redundancyLevel = redundancyLevel;
     this.securityLogger = securityLogger;
     this.proxyId = proxyId;
     this.redundancyRetryInterval = redundancyRetryInterval;
     denyList = new ServerDenyList(redundancyRetryInterval);
 
-
-    this.endpointListener = new EndpointManager.EndpointListenerAdapter() {
+    endpointListener = new EndpointManager.EndpointListenerAdapter() {
       @Override
       public void endpointCrashed(Endpoint endpoint) {
         QueueManagerImpl.this.endpointCrashed(endpoint);
       }
     };
 
-    this.state = new QueueStateImpl(this);
+    state = new QueueStateImpl(this);
   }
 
   @Override
@@ -284,8 +286,8 @@ public class QueueManagerImpl implements QueueManager {
       // Use a separate timer for queue management tasks
       // We don't want primary recovery (and therefore user threads) to wait for
       // things like pinging connections for health checks.
-      final String name = "queueTimer-" + this.pool.getName();
-      this.recoveryThread = LoggingExecutors.newScheduledThreadPool(1, name, false);
+      final String name = "queueTimer-" + pool.getName();
+      recoveryThread = LoggingExecutors.newScheduledThreadPool(1, name, false);
 
       getState().start(background, getPool().getSubscriptionAckInterval());
 
@@ -299,7 +301,7 @@ public class QueueManagerImpl implements QueueManager {
       DenyListListener denyListListener = new DenyListListenerAdapter() {
         @Override
         public void serverRemoved(ServerLocation location) {
-          QueueManagerImpl.this.scheduleRedundancySatisfierIfNeeded(0);
+          scheduleRedundancySatisfierIfNeeded(0);
         }
       };
 
@@ -311,11 +313,21 @@ public class QueueManagerImpl implements QueueManager {
   }
 
 
+  /*
+   * This is for test only, it does bad stuff that one should only do in test,
+   * if ever.
+   */
+  @VisibleForTesting
+  public void setSendClientReadyInTestOnly() {
+    synchronized (lock) {
+      sentClientReady = true;
+    }
+  }
 
   @Override
   public void readyForEvents(InternalDistributedSystem system) {
     synchronized (lock) {
-      this.sentClientReady = true;
+      sentClientReady = true;
     }
 
     QueueConnectionImpl primary = null;
@@ -358,7 +370,8 @@ public class QueueManagerImpl implements QueueManager {
     endpointCrashed(con.getEndpoint());
   }
 
-  private void endpointCrashed(Endpoint endpoint) {
+  @VisibleForTesting
+  void endpointCrashed(Endpoint endpoint) {
     QueueConnectionImpl deadConnection;
     // We must be synchronized while checking to see if we have a queue connection for the endpoint,
     // because when we need to prevent a race between adding a queue connection to the map
@@ -376,8 +389,8 @@ public class QueueManagerImpl implements QueueManager {
                   ? (deadConnection.getUpdater().isPrimary() ? "Primary" : "Redundant")
                   : "Queue",
                   endpoint});
-      scheduleRedundancySatisfierIfNeeded(0);
       deadConnection.internalDestroy();
+      scheduleRedundancySatisfierIfNeeded(0);
     } else {
       if (logger.isDebugEnabled()) {
         logger.debug("Ignoring crashed endpoint {} it does not have a queue.", endpoint);
@@ -423,7 +436,7 @@ public class QueueManagerImpl implements QueueManager {
   private void initializeConnections() {
     final boolean isDebugEnabled = logger.isDebugEnabled();
     if (isDebugEnabled) {
-      logger.debug("SubscriptionManager - intitializing connections");
+      logger.debug("SubscriptionManager - initializing connections");
     }
 
     int queuesNeeded = redundancyLevel == -1 ? -1 : redundancyLevel + 1;
@@ -541,6 +554,9 @@ public class QueueManagerImpl implements QueueManager {
           // couldn't find a server to make primary
           break;
         }
+
+        markQueueAsReadyForEvents(primaryQueue);
+
         if (!addToConnectionList(primaryQueue, true)) {
           excludedServers.add(primaryQueue.getServer());
           primaryQueue = null;
@@ -665,7 +681,7 @@ public class QueueManagerImpl implements QueueManager {
           throw e;
         } catch (Exception e) {
           if (isDebugEnabled) {
-            logger.debug("SubscriptionManager - Error connecting to server: ()", server, e);
+            logger.debug("SubscriptionManager - Error connecting to server: {}", server, e);
           }
         }
         if (connection == null) {
@@ -679,21 +695,10 @@ public class QueueManagerImpl implements QueueManager {
             if (recoverInterest && queueConnections.getPrimary() == null
                 && queueConnections.getBackups().isEmpty()) {
               // we lost our queue at some point. We Need to recover
-              // interest. This server will be made primary after this method
-              // finishes
-              // because whoever killed the primary when this method started
-              // should
+              // interest. This server will be made primary after this method finishes
+              // because whoever killed the primary when this method started should
               // have scheduled a task to recover the primary.
               isFirstNewConnection = true;
-              // TODO - Actually, we need a better check than the above. There's
-              // still a chance
-              // that we haven't realized that the primary has died but it is
-              // already gone. We should
-              // get some information from the queue server about whether it was
-              // able to copy the
-              // queue from another server and decide if we need to recover our
-              // interest based on
-              // that information.
             }
           }
           boolean promotionFailed = false;
@@ -727,7 +732,8 @@ public class QueueManagerImpl implements QueueManager {
     }
   }
 
-  private QueueConnectionImpl promoteBackupToPrimary(List backups) {
+  @VisibleForTesting
+  public QueueConnectionImpl promoteBackupToPrimary(List<Connection> backups) {
     QueueConnectionImpl primary = null;
     for (int i = 0; primary == null && i < backups.size(); i++) {
       QueueConnectionImpl lastConnection = (QueueConnectionImpl) backups.get(i);
@@ -745,7 +751,7 @@ public class QueueManagerImpl implements QueueManager {
       bo.beforePrimaryIdentificationFromBackup();
     }
     try {
-      boolean haveSentClientReady = this.sentClientReady;
+      boolean haveSentClientReady = sentClientReady;
       if (haveSentClientReady) {
         cnx.sendClientReady();
       }
@@ -805,10 +811,13 @@ public class QueueManagerImpl implements QueueManager {
       excludedServers.addAll(servers);
     }
 
-    if (primary != null && sentClientReady && primary.sendClientReady()) {
+    return primary;
+  }
+
+  public void markQueueAsReadyForEvents(@NotNull QueueConnectionImpl primary) {
+    if (sentClientReady && primary.sendClientReady()) {
       readyForEventsAfterFailover(primary);
     }
-    return primary;
   }
 
   private List<ServerLocation> findQueueServers(Set<ServerLocation> excludedServers, int count,
@@ -847,12 +856,13 @@ public class QueueManagerImpl implements QueueManager {
    * First we try to make a backup server the primary, but if run out of backup servers we will try
    * to find a new server.
    */
-  private void recoverPrimary(Set<ServerLocation> excludedServers) {
+  @VisibleForTesting
+  public void recoverPrimary(Set<ServerLocation> excludedServers) {
     if (pool.getPoolOrCacheCancelInProgress() != null) {
       return;
     }
     final boolean isDebugEnabled = logger.isDebugEnabled();
-    if (queueConnections.getPrimary() != null) {
+    if (!isPrimaryRecoveryNeeded(queueConnections)) {
       if (isDebugEnabled) {
         logger.debug("Primary recovery not needed");
       }
@@ -872,7 +882,7 @@ public class QueueManagerImpl implements QueueManager {
 
     QueueConnectionImpl newPrimary = null;
     while (newPrimary == null && pool.getPoolOrCacheCancelInProgress() == null) {
-      List backups = queueConnections.getBackups();
+      List<Connection> backups = queueConnections.getBackups();
       newPrimary = promoteBackupToPrimary(backups);
       // Hitesh now lets say that server crashed
       if (newPrimary == null) {
@@ -886,7 +896,6 @@ public class QueueManagerImpl implements QueueManager {
         }
         newPrimary = null;
       }
-
     }
 
     if (newPrimary != null) {
@@ -913,6 +922,7 @@ public class QueueManagerImpl implements QueueManager {
         // could not find a new primary to create
         break;
       }
+
       if (!addToConnectionList(newPrimary, true)) {
         excludedServers.add(newPrimary.getServer());
         newPrimary = null;
@@ -929,6 +939,9 @@ public class QueueManagerImpl implements QueueManager {
           excludedServers.add(newPrimary.getServer());
           newPrimary = null;
         }
+
+        markQueueAsReadyForEvents(newPrimary);
+
         // New primary queue was found from a non backup, alert the affected cqs
         cqsConnected();
       }
@@ -952,6 +965,16 @@ public class QueueManagerImpl implements QueueManager {
     }
   }
 
+  static boolean isPrimaryRecoveryNeeded(final ConnectionList queueConnectionList) {
+    if (queueConnectionList != null) {
+      final Connection primaryConnection = queueConnectionList.getPrimary();
+      if (primaryConnection != null) {
+        return primaryConnection.isDestroyed();
+      }
+    }
+    return true;
+  }
+
   private QueueConnectionImpl initializeQueueConnection(Connection connection, boolean isPrimary,
       ClientUpdater failedUpdater) {
     QueueConnectionImpl queueConnection = null;
@@ -983,7 +1006,8 @@ public class QueueManagerImpl implements QueueManager {
   // connection but CCU may died as endpoint closed....
   // so before putting connection need to see if something(crash) happen we should be able to
   // recover from it
-  private boolean addToConnectionList(QueueConnectionImpl connection, boolean isPrimary) {
+  @VisibleForTesting
+  public boolean addToConnectionList(QueueConnectionImpl connection, boolean isPrimary) {
     boolean isBadConnection;
     synchronized (lock) {
       ClientUpdater cu = connection.getUpdater();
@@ -992,7 +1016,7 @@ public class QueueManagerImpl implements QueueManager {
       }
       // now still CCU can died but then it will execute Checkendpoint with lock it will remove
       // connection connection and it will reschedule it.
-      if (connection.getEndpoint().isClosed() || shuttingDown
+      if (connection.getEndpoint().isClosed() || connection.isDestroyed() || shuttingDown
           || pool.getPoolOrCacheCancelInProgress() != null) {
         isBadConnection = true;
       } else {
@@ -1013,7 +1037,7 @@ public class QueueManagerImpl implements QueueManager {
             connection.getEndpoint());
       }
       try {
-        connection.internalClose(pool.getKeepAlive());
+        connection.internalClose(true);
       } catch (Exception e) {
         if (logger.isDebugEnabled()) {
           logger.debug("Error destroying client to server connection to {}",
@@ -1025,7 +1049,8 @@ public class QueueManagerImpl implements QueueManager {
     return !isBadConnection;
   }
 
-  private void scheduleRedundancySatisfierIfNeeded(long delay) {
+  @VisibleForTesting
+  public void scheduleRedundancySatisfierIfNeeded(long delay) {
     if (shuttingDown) {
       return;
     }
@@ -1046,7 +1071,7 @@ public class QueueManagerImpl implements QueueManager {
 
         redundancySatisfierTask = new RedundancySatisfierTask();
         try {
-          ScheduledFuture future =
+          ScheduledFuture<?> future =
               recoveryThread.schedule(redundancySatisfierTask, delay, TimeUnit.MILLISECONDS);
           redundancySatisfierTask.setFuture(future);
         } catch (RejectedExecutionException e) {
@@ -1091,12 +1116,13 @@ public class QueueManagerImpl implements QueueManager {
 
   @Override
   public QueueState getState() {
-    return this.state;
+    return state;
   }
 
-  private void recoverSingleList(int interestType, Connection recoveredConnection,
+  private void recoverSingleList(final @NotNull InterestType interestType,
+      Connection recoveredConnection,
       boolean isDurable, boolean receiveValues, boolean isFirstNewConnection) {
-    for (RegionInterestEntry e : this.getPool().getRITracker()
+    for (RegionInterestEntry e : getPool().getRITracker()
         .getRegionToInterestsMap(interestType, isDurable, !receiveValues)
         .values()) {
       // restore a region
@@ -1106,14 +1132,13 @@ public class QueueManagerImpl implements QueueManager {
   }
 
   private void recoverCqs(Connection recoveredConnection, boolean isDurable) {
-    Map cqs = this.getPool().getRITracker().getCqsMap();
-    for (Object o : cqs.entrySet()) {
-      Map.Entry e = (Map.Entry) o;
-      ClientCQ cqi = (ClientCQ) e.getKey();
+    Map<ClientCQ, Boolean> cqs = getPool().getRITracker().getCqsMap();
+    for (Map.Entry<ClientCQ, Boolean> e : cqs.entrySet()) {
+      ClientCQ cqi = e.getKey();
       String name = cqi.getName();
-      if (this.pool.getMultiuserAuthentication()) {
+      if (pool.getMultiuserAuthentication()) {
         UserAttributes.userAttributes
-            .set(((DefaultQueryService) this.pool.getQueryService()).getUserAttributes(name));
+            .set(((DefaultQueryService) pool.getQueryService()).getUserAttributes(name));
       }
       try {
         if (((CqStateImpl) cqi.getState()).getState() != CqStateImpl.INIT
@@ -1128,7 +1153,7 @@ public class QueueManagerImpl implements QueueManager {
 
   // TODO this is distressingly similar to LocalRegion#processSingleInterest
   private void recoverSingleRegion(LocalRegion r, Map<Object, InterestResultPolicy> keys,
-      int interestType,
+      final @NotNull InterestType interestType,
       Connection recoveredConnection, boolean isDurable, boolean receiveValues,
       boolean isFirstNewConnection) {
 
@@ -1169,8 +1194,10 @@ public class QueueManagerImpl implements QueueManager {
     }
   }
 
-  private void recoverSingleKey(LocalRegion r, Object keys, InterestResultPolicy policy,
-      int interestType, Connection recoveredConnection, boolean isDurable, boolean receiveValues,
+  private void recoverSingleKey(LocalRegion r, final @NotNull Object keys,
+      InterestResultPolicy policy,
+      final @NotNull InterestType interestType, Connection recoveredConnection, boolean isDurable,
+      boolean receiveValues,
       boolean isFirstNewConnection) {
     r.startRegisterInterest();
     try {
@@ -1185,10 +1212,10 @@ public class QueueManagerImpl implements QueueManager {
         }
       }
       // Register interest, get new values back
-      List serverKeys;
+      List<Object> serverKeys;
       if (policy != InterestResultPolicy.KEYS_VALUES) {
         serverKeys = r.getServerProxy().registerInterestOn(recoveredConnection, keys, interestType,
-            policy, isDurable, !receiveValues, r.getAttributes().getDataPolicy().ordinal);
+            policy, isDurable, !receiveValues, r.getAttributes().getDataPolicy());
         // Restore keys based on server's response
         if (isFirstNewConnection) {
           // only if this recoveredEP becomes primaryEndpoint
@@ -1203,11 +1230,11 @@ public class QueueManagerImpl implements QueueManager {
           // need to use policy NONE or KEYS.
           r.getServerProxy().registerInterestOn(recoveredConnection, keys,
               interestType, InterestResultPolicy.NONE, isDurable, !receiveValues,
-              r.getAttributes().getDataPolicy().ordinal);
+              r.getAttributes().getDataPolicy());
         } else {
           serverKeys =
               r.getServerProxy().registerInterestOn(recoveredConnection, keys, interestType, policy,
-                  isDurable, !receiveValues, r.getAttributes().getDataPolicy().ordinal);
+                  isDurable, !receiveValues, r.getAttributes().getDataPolicy());
           r.refreshEntriesFromServerKeys(recoveredConnection, serverKeys, policy);
         }
       }
@@ -1310,10 +1337,10 @@ public class QueueManagerImpl implements QueueManager {
       if (primary != null) {
         allConnectionsTmp.put(primary.getEndpoint(), primary);
       }
-      this.connectionMap = Collections.unmodifiableMap(allConnectionsTmp);
+      connectionMap = Collections.unmodifiableMap(allConnectionsTmp);
       this.backups = Collections.unmodifiableList(new ArrayList<>(backups));
       pool.getStats().setSubscriptionCount(connectionMap.size());
-      this.primaryDiscoveryException = discoveryException;
+      primaryDiscoveryException = discoveryException;
       this.failedPrimary = failedPrimary;
     }
 
@@ -1406,7 +1433,7 @@ public class QueueManagerImpl implements QueueManager {
   }
 
   /**
-   * Asynchronous task which tries to restablish a primary connection and satisfy redundant
+   * Asynchronous task which tries to reestablish a primary connection and satisfy redundant
    * requirements.
    *
    * This task should only be running in a single thread at a time. This task is the only way that
@@ -1416,9 +1443,9 @@ public class QueueManagerImpl implements QueueManager {
    */
   protected class RedundancySatisfierTask extends PoolTask {
     private boolean isCancelled;
-    private ScheduledFuture future;
+    private ScheduledFuture<?> future;
 
-    public void setFuture(ScheduledFuture future) {
+    public void setFuture(ScheduledFuture<?> future) {
       this.future = future;
     }
 
@@ -1463,8 +1490,8 @@ public class QueueManagerImpl implements QueueManager {
         SystemFailure.checkFailure();
         synchronized (lock) {
           if (t instanceof GemFireSecurityException) {
-            queueConnections =
-                queueConnections.setPrimaryDiscoveryFailed((GemFireSecurityException) t);
+            queueConnections = queueConnections
+                .setPrimaryDiscoveryFailed((GemFireSecurityException) t);
           } else {
             queueConnections = queueConnections.setPrimaryDiscoveryFailed(null);
           }
