@@ -14,10 +14,15 @@
  */
 package org.apache.geode.cache.client.internal;
 
+import static org.apache.geode.util.internal.UncheckedUtils.uncheckedCast;
+
 import java.util.ArrayList;
 import java.util.List;
 
+import org.jetbrains.annotations.NotNull;
+
 import org.apache.geode.InternalGemFireError;
+import org.apache.geode.cache.DataPolicy;
 import org.apache.geode.cache.InterestResultPolicy;
 import org.apache.geode.cache.client.ServerOperationException;
 import org.apache.geode.distributed.internal.ServerLocation;
@@ -50,12 +55,13 @@ public class RegisterInterestOp {
    * @param regionDataPolicy the data policy ordinal of the region
    * @return list of keys
    */
-  public static List execute(ExecutablePool pool, String region, Object key, int interestType,
-      InterestResultPolicy policy, boolean isDurable, boolean receiveUpdatesAsInvalidates,
-      byte regionDataPolicy) {
+  public static <K> List<List<K>> execute(final @NotNull ExecutablePool pool,
+      final @NotNull String region, final @NotNull K key, final @NotNull InterestType interestType,
+      final @NotNull InterestResultPolicy policy, final boolean isDurable,
+      final boolean receiveUpdatesAsInvalidates, final @NotNull DataPolicy regionDataPolicy) {
     AbstractOp op = new RegisterInterestOpImpl(region, key, interestType, policy, isDurable,
         receiveUpdatesAsInvalidates, regionDataPolicy);
-    return (List) pool.executeOnQueuesAndReturnPrimaryResult(op);
+    return uncheckedCast(pool.executeOnQueuesAndReturnPrimaryResult(op));
   }
 
   /**
@@ -72,12 +78,14 @@ public class RegisterInterestOp {
    * @param regionDataPolicy the data policy ordinal of the region
    * @return list of keys
    */
-  public static List executeOn(ServerLocation sl, ExecutablePool pool, String region, Object key,
-      int interestType, InterestResultPolicy policy, boolean isDurable,
-      boolean receiveUpdatesAsInvalidates, byte regionDataPolicy) {
+  public static <K> List<K> executeOn(final @NotNull ServerLocation sl,
+      final @NotNull ExecutablePool pool, final @NotNull String region, final @NotNull K key,
+      final @NotNull InterestType interestType, final @NotNull InterestResultPolicy policy,
+      final boolean isDurable, final boolean receiveUpdatesAsInvalidates,
+      final @NotNull DataPolicy regionDataPolicy) {
     AbstractOp op = new RegisterInterestOpImpl(region, key, interestType, policy, isDurable,
         receiveUpdatesAsInvalidates, regionDataPolicy);
-    return (List) pool.executeOn(sl, op);
+    return uncheckedCast(pool.executeOn(sl, op));
   }
 
 
@@ -95,12 +103,14 @@ public class RegisterInterestOp {
    * @param regionDataPolicy the data policy ordinal of the region
    * @return list of keys
    */
-  public static List executeOn(Connection conn, ExecutablePool pool, String region, Object key,
-      int interestType, InterestResultPolicy policy, boolean isDurable,
-      boolean receiveUpdatesAsInvalidates, byte regionDataPolicy) {
+  public static <K> List<K> executeOn(final @NotNull Connection conn,
+      final @NotNull ExecutablePool pool, final @NotNull String region,
+      final @NotNull K key, final @NotNull InterestType interestType,
+      final @NotNull InterestResultPolicy policy, final boolean isDurable,
+      final boolean receiveUpdatesAsInvalidates, final @NotNull DataPolicy regionDataPolicy) {
     AbstractOp op = new RegisterInterestOpImpl(region, key, interestType, policy, isDurable,
         receiveUpdatesAsInvalidates, regionDataPolicy);
-    return (List) pool.executeOn(conn, op);
+    return uncheckedCast(pool.executeOn(conn, op));
   }
 
 
@@ -114,13 +124,16 @@ public class RegisterInterestOp {
     /**
      * @throws org.apache.geode.SerializationException if serialization fails
      */
-    public RegisterInterestOpImpl(String region, Object key, int interestType,
-        InterestResultPolicy policy, boolean isDurable, boolean receiveUpdatesAsInvalidates,
-        byte regionDataPolicy) {
+    public RegisterInterestOpImpl(final @NotNull String region, final @NotNull Object key,
+        final @NotNull InterestType interestType,
+        final @NotNull InterestResultPolicy policy,
+        final boolean isDurable,
+        final boolean receiveUpdatesAsInvalidates,
+        final @NotNull DataPolicy regionDataPolicy) {
       super(MessageType.REGISTER_INTEREST, 7);
       this.region = region;
       getMessage().addStringPart(region, true);
-      getMessage().addIntPart(interestType);
+      getMessage().addIntPart(interestType.ordinal());
       getMessage().addObjPart(policy);
       {
         byte durableByte = (byte) (isDurable ? 0x01 : 0x00);
@@ -134,7 +147,7 @@ public class RegisterInterestOp {
       // Java clients always expect serializeValues to be true in VersionObjectList unlike Native
       // clients.
       // This was being sent as part of GetAllOp prior to fixing #43684.
-      getMessage().addBytesPart(new byte[] {regionDataPolicy, (byte) 0x01});
+      getMessage().addBytesPart(new byte[] {(byte) regionDataPolicy.ordinal(), (byte) 0x01});
     }
 
     /**
@@ -158,7 +171,7 @@ public class RegisterInterestOp {
     }
 
     @Override
-    protected Object processResponse(Message m, Connection con) throws Exception {
+    protected List<List<Object>> processResponse(Message m, Connection con) throws Exception {
       ChunkedMessage chunkedMessage = (ChunkedMessage) m;
       chunkedMessage.readHeader();
       switch (chunkedMessage.getMessageType()) {
@@ -166,16 +179,16 @@ public class RegisterInterestOp {
           LocalRegion localRegion = null;
 
           try {
-            localRegion = (LocalRegion) GemFireCacheImpl.getInstance().getRegion(this.region);
+            localRegion = (LocalRegion) GemFireCacheImpl.getInstance().getRegion(region);
           } catch (Exception ignore) {
           }
 
-          ArrayList list = new ArrayList();
-          ArrayList listOfList = new ArrayList();
+          final List<Object> list = new ArrayList<>();
+          final List<List<Object>> listOfList = new ArrayList<>();
           listOfList.add(list);
 
           // Process the chunks
-          List serverKeys = new ArrayList();
+          final List<List<Object>> serverKeys = new ArrayList<>();
           VersionedObjectList serverEntries = null;
           do {
             // Read the chunk
@@ -203,12 +216,12 @@ public class RegisterInterestOp {
                   try {
                     localRegion.refreshEntriesFromServerKeys(con, listOfList,
                         InterestResultPolicy.KEYS_VALUES);
-                  } catch (Exception ex) {
+                  } catch (Exception ignore) {
                   }
                 }
               } else {
                 // Add the result to the list of results
-                serverKeys.add((List) partObj);
+                serverKeys.add(uncheckedCast(partObj));
               }
             }
 
