@@ -19,6 +19,8 @@ package org.apache.geode.cache.configuration;
 import java.util.ArrayList;
 import java.util.List;
 
+import javax.resource.spi.ManagedConnectionFactory;
+import javax.sql.ConnectionPoolDataSource;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
@@ -41,61 +43,61 @@ import org.apache.geode.annotations.Experimental;
  * The following schema fragment specifies the expected content contained within this class.
  *
  * <pre>
- * &lt;complexType name="jndi-bindings-type">
- *   &lt;complexContent>
- *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- *       &lt;sequence>
- *         &lt;element name="jndi-binding" maxOccurs="unbounded" minOccurs="0">
- *           &lt;complexType>
- *             &lt;complexContent>
- *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- *                 &lt;sequence>
- *                   &lt;element name="config-property" maxOccurs="unbounded" minOccurs="0">
- *                     &lt;complexType>
- *                       &lt;complexContent>
- *                         &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- *                           &lt;sequence>
- *                             &lt;element name="config-property-name" type="{http://www.w3.org/2001/XMLSchema}string"/>
- *                             &lt;element name="config-property-type" type="{http://www.w3.org/2001/XMLSchema}string"/>
- *                             &lt;element name="config-property-value" type="{http://www.w3.org/2001/XMLSchema}string"/>
- *                           &lt;/sequence>
- *                         &lt;/restriction>
- *                       &lt;/complexContent>
- *                     &lt;/complexType>
- *                   &lt;/element>
- *                 &lt;/sequence>
- *                 &lt;attribute name="blocking-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="conn-pooled-datasource-class" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="connection-url" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="idle-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="init-pool-size" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="jdbc-driver-class" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="jndi-name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="login-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="managed-conn-factory-class" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="max-pool-size" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="password" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="transaction-type" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="type" use="required">
- *                   &lt;simpleType>
- *                     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
- *                       &lt;enumeration value="ManagedDataSource"/>
- *                       &lt;enumeration value="SimpleDataSource"/>
- *                       &lt;enumeration value="PooledDataSource"/>
- *                       &lt;enumeration value="XAPooledDataSource"/>
- *                     &lt;/restriction>
- *                   &lt;/simpleType>
- *                 &lt;/attribute>
- *                 &lt;attribute name="user-name" type="{http://www.w3.org/2001/XMLSchema}string" />
- *                 &lt;attribute name="xa-datasource-class" type="{http://www.w3.org/2001/XMLSchema}string" />
- *               &lt;/restriction>
- *             &lt;/complexContent>
- *           &lt;/complexType>
- *         &lt;/element>
- *       &lt;/sequence>
- *     &lt;/restriction>
- *   &lt;/complexContent>
- * &lt;/complexType>
+ * &lt;complexType name="jndi-bindings-type"&gt;
+ *   &lt;complexContent&gt;
+ *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ *       &lt;sequence&gt;
+ *         &lt;element name="jndi-binding" maxOccurs="unbounded" minOccurs="0"&gt;
+ *           &lt;complexType&gt;
+ *             &lt;complexContent&gt;
+ *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ *                 &lt;sequence&gt;
+ *                   &lt;element name="config-property" maxOccurs="unbounded" minOccurs="0"&gt;
+ *                     &lt;complexType&gt;
+ *                       &lt;complexContent&gt;
+ *                         &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ *                           &lt;sequence&gt;
+ *                             &lt;element name="config-property-name" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
+ *                             &lt;element name="config-property-type" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
+ *                             &lt;element name="config-property-value" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
+ *                           &lt;/sequence&gt;
+ *                         &lt;/restriction&gt;
+ *                       &lt;/complexContent&gt;
+ *                     &lt;/complexType&gt;
+ *                   &lt;/element&gt;
+ *                 &lt;/sequence&gt;
+ *                 &lt;attribute name="blocking-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="conn-pooled-datasource-class" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="connection-url" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="idle-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="init-pool-size" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="jdbc-driver-class" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="jndi-name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="login-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="managed-conn-factory-class" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="max-pool-size" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="password" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="transaction-type" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="type" use="required"&gt;
+ *                   &lt;simpleType&gt;
+ *                     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
+ *                       &lt;enumeration value="ManagedDataSource"/&gt;
+ *                       &lt;enumeration value="SimpleDataSource"/&gt;
+ *                       &lt;enumeration value="PooledDataSource"/&gt;
+ *                       &lt;enumeration value="XAPooledDataSource"/&gt;
+ *                     &lt;/restriction&gt;
+ *                   &lt;/simpleType&gt;
+ *                 &lt;/attribute&gt;
+ *                 &lt;attribute name="user-name" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *                 &lt;attribute name="xa-datasource-class" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+ *               &lt;/restriction&gt;
+ *             &lt;/complexContent&gt;
+ *           &lt;/complexType&gt;
+ *         &lt;/element&gt;
+ *       &lt;/sequence&gt;
+ *     &lt;/restriction&gt;
+ *   &lt;/complexContent&gt;
+ * &lt;/complexType&gt;
  * </pre>
  *
  *
@@ -130,13 +132,13 @@ public class JndiBindingsType {
    * Objects of the following type(s) are allowed in the list
    * {@link JndiBindingsType.JndiBinding }
    *
-   *
+   * @return the {@link List} of {@link JndiBinding}s.
    */
   public List<JndiBinding> getJndiBindings() {
     if (jndiBindings == null) {
-      jndiBindings = new ArrayList<JndiBinding>();
+      jndiBindings = new ArrayList<>();
     }
-    return this.jndiBindings;
+    return jndiBindings;
   }
 
 
@@ -148,51 +150,51 @@ public class JndiBindingsType {
    * The following schema fragment specifies the expected content contained within this class.
    *
    * <pre>
-   * &lt;complexType>
-   *   &lt;complexContent>
-   *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
-   *       &lt;sequence>
-   *         &lt;element name="config-property" maxOccurs="unbounded" minOccurs="0">
-   *           &lt;complexType>
-   *             &lt;complexContent>
-   *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
-   *                 &lt;sequence>
-   *                   &lt;element name="config-property-name" type="{http://www.w3.org/2001/XMLSchema}string"/>
-   *                   &lt;element name="config-property-type" type="{http://www.w3.org/2001/XMLSchema}string"/>
-   *                   &lt;element name="config-property-value" type="{http://www.w3.org/2001/XMLSchema}string"/>
-   *                 &lt;/sequence>
-   *               &lt;/restriction>
-   *             &lt;/complexContent>
-   *           &lt;/complexType>
-   *         &lt;/element>
-   *       &lt;/sequence>
-   *       &lt;attribute name="blocking-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="conn-pooled-datasource-class" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="connection-url" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="idle-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="init-pool-size" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="jdbc-driver-class" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="jndi-name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="login-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="managed-conn-factory-class" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="max-pool-size" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="password" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="transaction-type" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="type" use="required">
-   *         &lt;simpleType>
-   *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
-   *             &lt;enumeration value="ManagedDataSource"/>
-   *             &lt;enumeration value="SimpleDataSource"/>
-   *             &lt;enumeration value="PooledDataSource"/>
-   *             &lt;enumeration value="XAPooledDataSource"/>
-   *           &lt;/restriction>
-   *         &lt;/simpleType>
-   *       &lt;/attribute>
-   *       &lt;attribute name="user-name" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *       &lt;attribute name="xa-datasource-class" type="{http://www.w3.org/2001/XMLSchema}string" />
-   *     &lt;/restriction>
-   *   &lt;/complexContent>
-   * &lt;/complexType>
+   * &lt;complexType&gt;
+   *   &lt;complexContent&gt;
+   *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+   *       &lt;sequence&gt;
+   *         &lt;element name="config-property" maxOccurs="unbounded" minOccurs="0"&gt;
+   *           &lt;complexType&gt;
+   *             &lt;complexContent&gt;
+   *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+   *                 &lt;sequence&gt;
+   *                   &lt;element name="config-property-name" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
+   *                   &lt;element name="config-property-type" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
+   *                   &lt;element name="config-property-value" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
+   *                 &lt;/sequence&gt;
+   *               &lt;/restriction&gt;
+   *             &lt;/complexContent&gt;
+   *           &lt;/complexType&gt;
+   *         &lt;/element&gt;
+   *       &lt;/sequence&gt;
+   *       &lt;attribute name="blocking-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="conn-pooled-datasource-class" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="connection-url" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="idle-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="init-pool-size" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="jdbc-driver-class" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="jndi-name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="login-timeout-seconds" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="managed-conn-factory-class" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="max-pool-size" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="password" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="transaction-type" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="type" use="required"&gt;
+   *         &lt;simpleType&gt;
+   *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
+   *             &lt;enumeration value="ManagedDataSource"/&gt;
+   *             &lt;enumeration value="SimpleDataSource"/&gt;
+   *             &lt;enumeration value="PooledDataSource"/&gt;
+   *             &lt;enumeration value="XAPooledDataSource"/&gt;
+   *           &lt;/restriction&gt;
+   *         &lt;/simpleType&gt;
+   *       &lt;/attribute&gt;
+   *       &lt;attribute name="user-name" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *       &lt;attribute name="xa-datasource-class" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
+   *     &lt;/restriction&gt;
+   *   &lt;/complexContent&gt;
+   * &lt;/complexType&gt;
    * </pre>
    *
    *
@@ -256,13 +258,13 @@ public class JndiBindingsType {
      * Objects of the following type(s) are allowed in the list
      * {@link JndiBindingsType.JndiBinding.ConfigProperty }
      *
-     *
+     * @return the {@link List} of configuration properties.
      */
     public List<ConfigProperty> getConfigProperties() {
       if (configProperties == null) {
-        configProperties = new ArrayList<ConfigProperty>();
+        configProperties = new ArrayList<>();
       }
-      return this.configProperties;
+      return configProperties;
     }
 
     /**
@@ -271,6 +273,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the blocking timeout in seconds.
      */
     public String getBlockingTimeoutSeconds() {
       return blockingTimeoutSeconds;
@@ -282,9 +285,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the blocking timeout in seconds.
      */
     public void setBlockingTimeoutSeconds(String value) {
-      this.blockingTimeoutSeconds = value;
+      blockingTimeoutSeconds = value;
     }
 
     /**
@@ -293,6 +297,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the {@link ConnectionPoolDataSource} type.
      */
     public String getConnPooledDatasourceClass() {
       return connPooledDatasourceClass;
@@ -304,9 +309,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value {@link ConnectionPoolDataSource} type.
      */
     public void setConnPooledDatasourceClass(String value) {
-      this.connPooledDatasourceClass = value;
+      connPooledDatasourceClass = value;
     }
 
     /**
@@ -315,6 +321,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the connection URL.
      */
     public String getConnectionUrl() {
       return connectionUrl;
@@ -326,9 +333,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the connection URL.
      */
     public void setConnectionUrl(String value) {
-      this.connectionUrl = value;
+      connectionUrl = value;
     }
 
     /**
@@ -337,6 +345,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the idle timeout in seconds.
      */
     public String getIdleTimeoutSeconds() {
       return idleTimeoutSeconds;
@@ -348,9 +357,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the idle timeout in seconds.
      */
     public void setIdleTimeoutSeconds(String value) {
-      this.idleTimeoutSeconds = value;
+      idleTimeoutSeconds = value;
     }
 
     /**
@@ -359,6 +369,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the initial pool size.
      */
     public String getInitPoolSize() {
       return initPoolSize;
@@ -370,9 +381,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the initial pool size.
      */
     public void setInitPoolSize(String value) {
-      this.initPoolSize = value;
+      initPoolSize = value;
     }
 
     /**
@@ -381,6 +393,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the JDBC driver class.
      */
     public String getJdbcDriverClass() {
       return jdbcDriverClass;
@@ -392,9 +405,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the JDBC driver class.
      */
     public void setJdbcDriverClass(String value) {
-      this.jdbcDriverClass = value;
+      jdbcDriverClass = value;
     }
 
     /**
@@ -403,6 +417,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the JNDI name.
      */
     public String getJndiName() {
       return jndiName;
@@ -414,9 +429,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the JNDI name.
      */
     public void setJndiName(String value) {
-      this.jndiName = value;
+      jndiName = value;
     }
 
     /**
@@ -425,6 +441,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the login timeout in seconds.
      */
     public String getLoginTimeoutSeconds() {
       return loginTimeoutSeconds;
@@ -436,9 +453,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the login timeout in seconds.
      */
     public void setLoginTimeoutSeconds(String value) {
-      this.loginTimeoutSeconds = value;
+      loginTimeoutSeconds = value;
     }
 
     /**
@@ -447,6 +465,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the name of the {@link ManagedConnectionFactory} type.
      */
     public String getManagedConnFactoryClass() {
       return managedConnFactoryClass;
@@ -458,9 +477,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the {@link ManagedConnectionFactory} class name.
      */
     public void setManagedConnFactoryClass(String value) {
-      this.managedConnFactoryClass = value;
+      managedConnFactoryClass = value;
     }
 
     /**
@@ -469,6 +489,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the maximum pool size.
      */
     public String getMaxPoolSize() {
       return maxPoolSize;
@@ -480,9 +501,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the maximum pool size.
      */
     public void setMaxPoolSize(String value) {
-      this.maxPoolSize = value;
+      maxPoolSize = value;
     }
 
     /**
@@ -491,6 +513,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the password.
      */
     public String getPassword() {
       return password;
@@ -502,9 +525,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the password.
      */
     public void setPassword(String value) {
-      this.password = value;
+      password = value;
     }
 
     /**
@@ -513,6 +537,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the transaction type.
      */
     public String getTransactionType() {
       return transactionType;
@@ -524,9 +549,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the transaction type.
      */
     public void setTransactionType(String value) {
-      this.transactionType = value;
+      transactionType = value;
     }
 
     /**
@@ -535,6 +561,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the type.
      */
     public String getType() {
       return type;
@@ -546,9 +573,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the type.
      */
     public void setType(String value) {
-      this.type = value;
+      type = value;
     }
 
     /**
@@ -557,6 +585,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the username.
      */
     public String getUserName() {
       return userName;
@@ -568,9 +597,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the username.
      */
     public void setUserName(String value) {
-      this.userName = value;
+      userName = value;
     }
 
     /**
@@ -579,6 +609,7 @@ public class JndiBindingsType {
      * possible object is
      * {@link String }
      *
+     * @return the XA datasource class.
      */
     public String getXaDatasourceClass() {
       return xaDatasourceClass;
@@ -590,9 +621,10 @@ public class JndiBindingsType {
      * allowed object is
      * {@link String }
      *
+     * @param value the XA datasource class.
      */
     public void setXaDatasourceClass(String value) {
-      this.xaDatasourceClass = value;
+      xaDatasourceClass = value;
     }
 
     @Override
@@ -608,17 +640,17 @@ public class JndiBindingsType {
      * The following schema fragment specifies the expected content contained within this class.
      *
      * <pre>
-     * &lt;complexType>
-     *   &lt;complexContent>
-     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
-     *       &lt;sequence>
-     *         &lt;element name="config-property-name" type="{http://www.w3.org/2001/XMLSchema}string"/>
-     *         &lt;element name="config-property-type" type="{http://www.w3.org/2001/XMLSchema}string"/>
-     *         &lt;element name="config-property-value" type="{http://www.w3.org/2001/XMLSchema}string"/>
-     *       &lt;/sequence>
-     *     &lt;/restriction>
-     *   &lt;/complexContent>
-     * &lt;/complexType>
+     * &lt;complexType&gt;
+     *   &lt;complexContent&gt;
+     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+     *       &lt;sequence&gt;
+     *         &lt;element name="config-property-name" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
+     *         &lt;element name="config-property-type" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
+     *         &lt;element name="config-property-value" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
+     *       &lt;/sequence&gt;
+     *     &lt;/restriction&gt;
+     *   &lt;/complexContent&gt;
+     * &lt;/complexType&gt;
      * </pre>
      *
      *
@@ -638,17 +670,17 @@ public class JndiBindingsType {
           namespace = "http://geode.apache.org/schema/cache", required = true)
       protected String configPropertyValue;
 
-      public ConfigProperty() {};
+      public ConfigProperty() {}
 
       public ConfigProperty(String name, String type, String value) {
-        this.configPropertyName = name;
-        this.configPropertyType = type;
-        this.configPropertyValue = value;
+        configPropertyName = name;
+        configPropertyType = type;
+        configPropertyValue = value;
       }
 
       public ConfigProperty(String name, String value) {
-        this.configPropertyName = name;
-        this.configPropertyValue = value;
+        configPropertyName = name;
+        configPropertyValue = value;
       }
 
       /**
@@ -667,6 +699,7 @@ public class JndiBindingsType {
        * possible object is
        * {@link String }
        *
+       * @return the name.
        */
       public String getName() {
         return configPropertyName;
@@ -678,9 +711,10 @@ public class JndiBindingsType {
        * allowed object is
        * {@link String }
        *
+       * @param value the name.
        */
       public void setName(String value) {
-        this.configPropertyName = value;
+        configPropertyName = value;
       }
 
       /**
@@ -689,6 +723,7 @@ public class JndiBindingsType {
        * possible object is
        * {@link String }
        *
+       * @return the type.
        */
       public String getType() {
         return configPropertyType;
@@ -700,9 +735,10 @@ public class JndiBindingsType {
        * allowed object is
        * {@link String }
        *
+       * @param value the type.
        */
       public void setType(String value) {
-        this.configPropertyType = value;
+        configPropertyType = value;
       }
 
       /**
@@ -711,6 +747,7 @@ public class JndiBindingsType {
        * possible object is
        * {@link String }
        *
+       * @return the value.
        */
       public String getValue() {
         return configPropertyValue;
@@ -722,9 +759,10 @@ public class JndiBindingsType {
        * allowed object is
        * {@link String }
        *
+       * @param value the value.
        */
       public void setValue(String value) {
-        this.configPropertyValue = value;
+        configPropertyValue = value;
       }
 
     }
