@@ -18,20 +18,24 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Set;
 
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.cache.EntryDestroyedException;
 import org.apache.geode.cache.Region;
 import org.apache.geode.cache.query.AmbiguousNameException;
 import org.apache.geode.cache.query.FunctionDomainException;
+import org.apache.geode.cache.query.Index;
 import org.apache.geode.cache.query.IndexType;
 import org.apache.geode.cache.query.NameResolutionException;
 import org.apache.geode.cache.query.QueryInvocationTargetException;
 import org.apache.geode.cache.query.QueryService;
 import org.apache.geode.cache.query.SelectResults;
-import org.apache.geode.cache.query.Struct;
 import org.apache.geode.cache.query.TypeMismatchException;
+import org.apache.geode.cache.query.internal.index.AbstractIndex;
+import org.apache.geode.cache.query.internal.index.AbstractMapIndex;
 import org.apache.geode.cache.query.internal.index.IndexData;
 import org.apache.geode.cache.query.internal.index.IndexProtocol;
 import org.apache.geode.cache.query.internal.index.IndexUtils;
+import org.apache.geode.cache.query.internal.index.PartitionedIndex;
 import org.apache.geode.cache.query.internal.parse.OQLLexerTokenTypes;
 import org.apache.geode.cache.query.internal.types.StructTypeImpl;
 import org.apache.geode.cache.query.internal.types.TypeUtils;
@@ -230,7 +234,7 @@ public class CompiledComparison extends AbstractCompiledValue
                    * be false, which can happen only in case of CompiledComparison/CompiledUndefined
                    * called from roupJunction or CompositeGroupJunction
                    */,
-        true, this.isConditioningNeededForIndex(indpndntItr, context, true),
+        true, isConditioningNeededForIndex(indpndntItr, context, true),
         true /* evaluate projection attribute */);
   }
 
@@ -257,14 +261,14 @@ public class CompiledComparison extends AbstractCompiledValue
   // Invariant: the receiver is dependent on the current iterator.
   @Override
   protected PlanInfo protGetPlanInfo(ExecutionContext context)
-      throws TypeMismatchException, AmbiguousNameException, NameResolutionException {
+      throws TypeMismatchException, NameResolutionException {
     PlanInfo result = new PlanInfo();
     IndexInfo[] indexInfo = getIndexInfo(context);
     if (indexInfo == null) {
       return result;
     }
-    for (int i = 0; i < indexInfo.length; ++i) {
-      result.indexes.add(indexInfo[i]._index);
+    for (final IndexInfo info : indexInfo) {
+      result.indexes.add(info._index);
     }
     result.evalAsFilter = true;
     String preferredCondn = (String) context.cacheGet(PREF_INDEX_COND);
@@ -283,7 +287,7 @@ public class CompiledComparison extends AbstractCompiledValue
 
   @Override
   public Set computeDependencies(ExecutionContext context)
-      throws TypeMismatchException, AmbiguousNameException, NameResolutionException {
+      throws TypeMismatchException, NameResolutionException {
     context.addDependencies(this, _left.computeDependencies(context));
     return context.addDependencies(this, _right.computeDependencies(context));
   }
@@ -298,10 +302,7 @@ public class CompiledComparison extends AbstractCompiledValue
 
   @Override
   public boolean isRangeEvaluatable() {
-    if (this._left instanceof MapIndexable || this._right instanceof MapIndexable) {
-      return false;
-    }
-    return true;
+    return !(_left instanceof MapIndexable) && !(_right instanceof MapIndexable);
   }
 
   @Override
@@ -349,7 +350,7 @@ public class CompiledComparison extends AbstractCompiledValue
       SelectResults intermediateResults, final boolean completeExpansionNeeded,
       @Retained CompiledValue iterOperands, IndexInfo indexInfo, RuntimeIterator[] indpndntItr,
       boolean isIntersection, boolean conditioningNeeded, boolean evaluateProj)
-      throws TypeMismatchException, AmbiguousNameException, FunctionDomainException,
+      throws TypeMismatchException, FunctionDomainException,
       NameResolutionException, QueryInvocationTargetException {
     ObjectType resultType = indexInfo._index.getResultSetType();
     int indexFieldsSize = -1;
@@ -396,7 +397,7 @@ public class CompiledComparison extends AbstractCompiledValue
       boolean useLinkedDataStructure = false;
       boolean nullValuesAtStart = true;
       Boolean orderByClause = (Boolean) context.cacheGet(CompiledValue.CAN_APPLY_ORDER_BY_AT_INDEX);
-      if (orderByClause != null && orderByClause.booleanValue()) {
+      if (orderByClause != null && orderByClause) {
         List orderByAttrs = (List) context.cacheGet(CompiledValue.ORDERBY_ATTRIB);
         useLinkedDataStructure = orderByAttrs.size() == 1;
         nullValuesAtStart = !((CompiledSortCriterion) orderByAttrs.get(0)).getCriterion();
@@ -417,7 +418,7 @@ public class CompiledComparison extends AbstractCompiledValue
                 .fine("StructType resultType.class=" + resultType.getClass().getName());
             if (useLinkedDataStructure) {
               set = context.isDistinct() ? new LinkedStructSet((StructTypeImpl) resultType)
-                  : new SortedResultsBag<Struct>((StructTypeImpl) resultType, nullValuesAtStart);
+                  : new SortedResultsBag<>(resultType, nullValuesAtStart);
             } else {
               set = QueryUtils.createStructCollection(context, (StructTypeImpl) resultType);
             }
@@ -445,7 +446,7 @@ public class CompiledComparison extends AbstractCompiledValue
                   .fine("StructType resultType.class=" + resultType.getClass().getName());
               if (useLinkedDataStructure) {
                 set = context.isDistinct() ? new LinkedStructSet((StructTypeImpl) resultType)
-                    : new SortedResultsBag<Struct>((StructTypeImpl) resultType, nullValuesAtStart);
+                    : new SortedResultsBag<>(resultType, nullValuesAtStart);
               } else {
                 set = QueryUtils.createStructCollection(context, (StructTypeImpl) resultType);
               }
@@ -474,7 +475,7 @@ public class CompiledComparison extends AbstractCompiledValue
               .fine("StructType resultType.class=" + resultType.getClass().getName());
           if (useLinkedDataStructure) {
             set = context.isDistinct() ? new LinkedStructSet((StructTypeImpl) resultType)
-                : new SortedResultsBag<Struct>((StructTypeImpl) resultType, nullValuesAtStart);
+                : new SortedResultsBag<>(resultType, nullValuesAtStart);
           } else {
             set = QueryUtils.createStructCollection(context, (StructTypeImpl) resultType);
           }
@@ -517,7 +518,7 @@ public class CompiledComparison extends AbstractCompiledValue
   private SelectResults doubleBaseCollectionFilterEvaluate(ExecutionContext context,
       SelectResults intermediateResults, boolean completeExpansionNeeded,
       CompiledValue iterOperands, IndexInfo[] indxInfo, RuntimeIterator[] indpdntItrs)
-      throws TypeMismatchException, AmbiguousNameException, FunctionDomainException,
+      throws TypeMismatchException, FunctionDomainException,
       NameResolutionException, QueryInvocationTargetException {
     // Asif : First we need to collect the results of the two indexes
     // We will be calling a function of Index & passing the other Index as a
@@ -574,13 +575,13 @@ public class CompiledComparison extends AbstractCompiledValue
        * StructBag , then only we need to do any expansion.
        *
        */
-      Support.Assert(this._operator == TOK_EQ,
+      Support.Assert(_operator == TOK_EQ,
           "A relationship index is not usable for any condition other than equality");
 
       List data = null;
       try {
-        observer.beforeIndexLookup(indxInfo[0]._index, this._operator, null);
-        observer.beforeIndexLookup(indxInfo[1]._index, this._operator, null);
+        observer.beforeIndexLookup(indxInfo[0]._index, _operator, null);
+        observer.beforeIndexLookup(indxInfo[1]._index, _operator, null);
         if (context.getBucketList() != null) {
           data = QueryUtils.queryEquijoinConditionBucketIndexes(indxInfo, context);
         } else {
@@ -616,7 +617,7 @@ public class CompiledComparison extends AbstractCompiledValue
   // and 1th element will refer to RHS operannd
   @Override
   public IndexInfo[] getIndexInfo(ExecutionContext context)
-      throws TypeMismatchException, AmbiguousNameException, NameResolutionException {
+      throws TypeMismatchException, NameResolutionException {
     IndexInfo[] indexInfo = privGetIndexInfo(context);
     if (indexInfo != null) {
       if (indexInfo == NO_INDEXES_IDENTIFIER) {
@@ -631,28 +632,38 @@ public class CompiledComparison extends AbstractCompiledValue
     }
     // get the path and index key to try
     PathAndKey pAndK = getPathAndKey(context);
-    IndexInfo newIndexInfo[] = null;
+    IndexInfo[] newIndexInfo = null;
     if (pAndK == null) {
       IndexData[] indexData =
-          QueryUtils.getRelationshipIndexIfAny(_left, _right, context, this._operator);// findOnlyFunctionalIndex.
+          QueryUtils.getRelationshipIndexIfAny(_left, _right, context, _operator);// findOnlyFunctionalIndex.
       if (indexData != null) {
         newIndexInfo = new IndexInfo[2];
         for (int i = 0; i < 2; ++i) {
           newIndexInfo[i] = new IndexInfo(null, i == 0 ? _left : _right, indexData[i].getIndex(),
               indexData[i].getMatchLevel(), indexData[i].getMapping(),
-              i == 0 ? this._operator : reflectOperator(this._operator));
+              i == 0 ? _operator : reflectOperator(_operator));
         }
       }
     } else {
       CompiledValue path = pAndK._path;
       CompiledValue indexKey = pAndK._key;
-      IndexData indexData = null;
+      IndexData indexData;
       // CompiledLike should not use HashIndex and PrimarKey Index.
       if (this instanceof CompiledLike) {
         indexData =
             QueryUtils.getAvailableIndexIfAny(path, context, OQLLexerTokenTypes.LITERAL_like);
       } else {
-        indexData = QueryUtils.getAvailableIndexIfAny(path, context, this._operator);
+        indexData = QueryUtils.getAvailableIndexIfAny(path, context, _operator);
+      }
+
+      if (indexCannotBeUsed(context, indexData)) {
+        Index prIndex = ((AbstractIndex) indexData.getIndex()).getPRIndex();
+        if (prIndex != null) {
+          ((PartitionedIndex) prIndex).releaseIndexReadLockForRemove();
+        } else {
+          ((AbstractIndex) indexData.getIndex()).releaseIndexReadLockForRemove();
+        }
+        return null;
       }
 
       IndexProtocol index = null;
@@ -673,6 +684,42 @@ public class CompiledComparison extends AbstractCompiledValue
     return newIndexInfo;
   }
 
+  /**
+   *
+   * @return true if the index is a MapIndex of type allkeys ([*]) and this is a != comparison
+   *         or it is comparing the map value against null
+   */
+  @VisibleForTesting
+  boolean indexCannotBeUsed(ExecutionContext context, IndexData indexData) {
+    if (indexData == null) {
+      return false;
+    }
+    if (!(indexData.getIndex() instanceof AbstractMapIndex)) {
+      return false;
+    }
+    if (!(((AbstractMapIndex) indexData.getIndex()).getIsAllKeys())) {
+      return false;
+    }
+    if (_operator == TOK_NE) {
+      return true;
+    }
+    try {
+      if (_right != null
+          && (_right instanceof CompiledLiteral)
+          && _right.evaluate(context) == null) {
+        return true;
+      }
+      if (_left != null
+          && (_left instanceof CompiledLiteral)
+          && _left.evaluate(context) == null) {
+        return true;
+      }
+    } catch (Exception e) {
+      return false;
+    }
+    return false;
+  }
+
   CompiledValue getKey(ExecutionContext context)
       throws AmbiguousNameException, TypeMismatchException {
     return getPathAndKey(context)._key;
@@ -745,14 +792,12 @@ public class CompiledComparison extends AbstractCompiledValue
       String canonicalizedOrderByClause) throws FunctionDomainException, TypeMismatchException,
       NameResolutionException, QueryInvocationTargetException {
 
-    if (this.getPlanInfo(context).evalAsFilter) {
-      PlanInfo pi = this.getPlanInfo(context);
+    if (getPlanInfo(context).evalAsFilter) {
+      PlanInfo pi = getPlanInfo(context);
       if (pi.indexes.size() == 1) {
         IndexProtocol ip = (IndexProtocol) pi.indexes.get(0);
-        if (ip.getCanonicalizedIndexedExpression().equals(canonicalizedOrderByClause)
-            && ip.getType() != IndexType.PRIMARY_KEY && pi.isPreferred) {
-          return true;
-        }
+        return ip.getCanonicalizedIndexedExpression().equals(canonicalizedOrderByClause)
+            && ip.getType() != IndexType.PRIMARY_KEY && pi.isPreferred;
       }
     }
     return false;
@@ -761,7 +806,7 @@ public class CompiledComparison extends AbstractCompiledValue
   @Override
   public boolean isConditioningNeededForIndex(RuntimeIterator independentIter,
       ExecutionContext context, boolean completeExpnsNeeded)
-      throws AmbiguousNameException, TypeMismatchException, NameResolutionException {
+      throws TypeMismatchException, NameResolutionException {
     IndexConditioningHelper ich = null;
     IndexInfo[] idxInfo = getIndexInfo(context);
     int indexFieldsSize = -1;
@@ -788,7 +833,7 @@ public class CompiledComparison extends AbstractCompiledValue
 
   @Override
   public int getOperator() {
-    return this._operator;
+    return _operator;
   }
 
   @Override
@@ -808,7 +853,7 @@ public class CompiledComparison extends AbstractCompiledValue
     }
 
     // There may be some hard rules that give unoptimal selections based on these switch cases.
-    if (this._operator == TOK_EQ || this._operator == TOK_NE || this._operator == TOK_NE_ALT) {
+    if (_operator == TOK_EQ || _operator == TOK_NE || _operator == TOK_NE_ALT) {
       switch (thatOperator) {
         case TOK_EQ:
         case TOK_NE:
@@ -817,7 +862,7 @@ public class CompiledComparison extends AbstractCompiledValue
           break;
         case LITERAL_and:
           // This is is possible only in case of RangeJunction.
-          if (this._operator == TOK_NE || this._operator == TOK_NE_ALT) {
+          if (_operator == TOK_NE || _operator == TOK_NE_ALT) {
             // Asif: Give preference to range as I am assuming that range will fetch less data
             // as compared to NOT EQUALs
             isThisBetter = false;
