@@ -25,7 +25,6 @@ import java.util.Set;
 
 import org.apache.logging.log4j.Logger;
 
-import org.apache.geode.cache.query.AmbiguousNameException;
 import org.apache.geode.cache.query.FunctionDomainException;
 import org.apache.geode.cache.query.Index;
 import org.apache.geode.cache.query.NameResolutionException;
@@ -39,6 +38,8 @@ import org.apache.geode.cache.query.internal.index.IndexData;
 import org.apache.geode.cache.query.internal.index.IndexManager;
 import org.apache.geode.cache.query.internal.index.IndexProtocol;
 import org.apache.geode.cache.query.internal.index.IndexUtils;
+import org.apache.geode.cache.query.internal.index.MemoryIndexStore;
+import org.apache.geode.cache.query.internal.index.MemoryIndexStore.CachedEntryWrapper;
 import org.apache.geode.cache.query.internal.index.PartitionedIndex;
 import org.apache.geode.cache.query.internal.parse.OQLLexerTokenTypes;
 import org.apache.geode.cache.query.internal.types.ObjectTypeImpl;
@@ -187,6 +188,9 @@ public class QueryUtils {
       try {
         for (Iterator itr = small.iterator(); itr.hasNext();) {
           Object element = itr.next();
+          if (element instanceof MemoryIndexStore.CachedEntryWrapper) {
+            element = ((CachedEntryWrapper) element).getKey();
+          }
           int count = large.occurrences(element);
           if (small.occurrences(element) > count) {
             // bag intersection: only retain smaller number of dups
@@ -202,6 +206,9 @@ public class QueryUtils {
       try {
         for (Iterator itr = large.iterator(); itr.hasNext();) {
           Object element = itr.next();
+          if (element instanceof MemoryIndexStore.CachedEntryWrapper) {
+            element = ((CachedEntryWrapper) element).getKey();
+          }
           int count = small.occurrences(element);
           if (large.occurrences(element) > count) {
             // bag intersection: only retain smaller number of dups
@@ -276,8 +283,7 @@ public class QueryUtils {
       rs = new ResultsBag(large, null);
     }
 
-    for (Iterator itr = small.iterator(); itr.hasNext();) {
-      Object element = itr.next();
+    for (Object element : small) {
       rs.add(element);
     }
     return rs;
@@ -369,7 +375,7 @@ public class QueryUtils {
       Iterator itr = finalItrs.iterator();
       int len = finalItrs.size();
       if (len > 1) {
-        Object values[] = new Object[len];
+        Object[] values = new Object[len];
         int j = 0;
         while (itr.hasNext()) {
           values[j++] = ((RuntimeIterator) itr.next()).evaluate(context);
@@ -600,7 +606,7 @@ public class QueryUtils {
       StructTypeImpl resultType = (StructTypeImpl) createStructTypeForRuntimeIterators(finalItrs);
       if (useLinkedDataStructure) {
         returnSet = context.isDistinct() ? new LinkedStructSet(resultType)
-            : new SortedResultsBag<Struct>((StructTypeImpl) resultType, nullValuesAtStart);
+            : new SortedResultsBag<>(resultType, nullValuesAtStart);
       } else {
         returnSet = QueryUtils.createStructCollection(context, resultType);
       }
@@ -873,7 +879,7 @@ public class QueryUtils {
    */
   static IndexData[] getRelationshipIndexIfAny(CompiledValue lhs, CompiledValue rhs,
       ExecutionContext context, int operator)
-      throws AmbiguousNameException, TypeMismatchException, NameResolutionException {
+      throws TypeMismatchException, NameResolutionException {
     if (operator != OQLLexerTokenTypes.TOK_EQ) {
       // Operator must be '='
       return null;
@@ -915,7 +921,7 @@ public class QueryUtils {
    * @return IndexData object
    */
   static IndexData getAvailableIndexIfAny(CompiledValue cv, ExecutionContext context, int operator)
-      throws AmbiguousNameException, TypeMismatchException, NameResolutionException {
+      throws TypeMismatchException, NameResolutionException {
     // If operator is = or != then first search for PRIMARY_KEY Index
     boolean usePrimaryIndex =
         operator == OQLLexerTokenTypes.TOK_EQ || operator == OQLLexerTokenTypes.TOK_NE;
@@ -924,7 +930,7 @@ public class QueryUtils {
 
   private static IndexData getAvailableIndexIfAny(CompiledValue cv, ExecutionContext context,
       boolean usePrimaryIndex)
-      throws AmbiguousNameException, TypeMismatchException, NameResolutionException {
+      throws TypeMismatchException, NameResolutionException {
     Set set = new HashSet();
     context.computeUltimateDependencies(cv, set);
     if (set.size() != 1) {
@@ -1207,8 +1213,8 @@ public class QueryUtils {
         // identify the iterators which we need to expand to
         // TODO: Make the code compact by using a common function to take care of this
         int size = finalList.size();
-        for (int i = 0; i < size; ++i) {
-          RuntimeIterator currItr = (RuntimeIterator) finalList.get(i);
+        for (Object o : finalList) {
+          RuntimeIterator currItr = (RuntimeIterator) o;
           // If the runtimeIterators of scope not present in CheckSet add it to the expansion list
           if (!expnItrsToIgnore.contains(currItr)) {
             totalExpList.add(currItr);
@@ -1290,8 +1296,8 @@ public class QueryUtils {
         // identify the iterators which we need to expand to
         // TODO: Make the code compact by using a common function to take care of this
         int size = finalList.size();
-        for (int i = 0; i < size; ++i) {
-          RuntimeIterator currItr = (RuntimeIterator) finalList.get(i);
+        for (Object o : finalList) {
+          RuntimeIterator currItr = (RuntimeIterator) o;
           // If the runtimeIterators of scope not present in CheckSet add it to the expansion list
           if (!expnItrsToIgnore.contains(currItr)) {
             totalExpList.add(currItr);
@@ -1453,8 +1459,8 @@ public class QueryUtils {
       expnItrsAlreadyAccounted.addAll(ich1.finalList);
       expnItrsAlreadyAccounted.addAll(ich2.finalList);
       int size = totalFinalList.size();
-      for (int i = 0; i < size; ++i) {
-        RuntimeIterator currItr = (RuntimeIterator) totalFinalList.get(i);
+      for (Object o : totalFinalList) {
+        RuntimeIterator currItr = (RuntimeIterator) o;
         // If the runtimeIterators of scope not present in CheckSet add it to the expansion list
         if (!expnItrsAlreadyAccounted.contains(currItr)) {
           totalExpList.add(currItr);
@@ -1462,8 +1468,7 @@ public class QueryUtils {
       }
     } else {
       totalFinalList = new ArrayList();
-      for (int i = 0; i < indpdntItrs.length; ++i) {
-        RuntimeIterator indpndntItr = indpdntItrs[i];
+      for (RuntimeIterator indpndntItr : indpdntItrs) {
         if (indpndntItr == ich1.finalList.get(0)) {
           totalFinalList.addAll(ich1.finalList);
         } else if (indpndntItr == ich2.finalList.get(0)) {
