@@ -21,7 +21,6 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Comparator;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 import java.util.TreeSet;
@@ -76,7 +75,7 @@ public class SortedResultSet extends TreeSet
     if (!(other instanceof SortedResultSet)) {
       return false;
     }
-    if (!this.elementType.equals(((SortedResultSet) other).elementType)) {
+    if (!elementType.equals(((SortedResultSet) other).elementType)) {
       return false;
     }
     return super.equals(other);
@@ -84,7 +83,7 @@ public class SortedResultSet extends TreeSet
 
   @Override
   public int hashCode() {
-    return this.elementType.hashCode();
+    return elementType.hashCode();
   }
 
   @Override
@@ -108,7 +107,7 @@ public class SortedResultSet extends TreeSet
 
   @Override
   public CollectionType getCollectionType() {
-    return new CollectionTypeImpl(SortedResultSet.class, this.elementType);
+    return new CollectionTypeImpl(SortedResultSet.class, elementType);
   }
 
   @Override
@@ -130,9 +129,9 @@ public class SortedResultSet extends TreeSet
   public void fromData(DataInput in,
       DeserializationContext context) throws IOException, ClassNotFoundException {
     int size = in.readInt();
-    this.elementType = (ObjectType) context.getDeserializer().readObject(in);
+    elementType = context.getDeserializer().readObject(in);
     for (int j = size; j > 0; j--) {
-      this.add(context.getDeserializer().readObject(in));
+      add(context.getDeserializer().readObject(in));
     }
   }
 
@@ -140,10 +139,10 @@ public class SortedResultSet extends TreeSet
   public void toData(DataOutput out,
       SerializationContext context) throws IOException {
     // how do we serialize the comparator?
-    out.writeInt(this.size());
-    context.getSerializer().writeObject(this.elementType, out);
-    for (Iterator i = this.iterator(); i.hasNext();) {
-      context.getSerializer().writeObject(i.next(), out);
+    out.writeInt(size());
+    context.getSerializer().writeObject(elementType, out);
+    for (final Object o : this) {
+      context.getSerializer().writeObject(o, out);
     }
   }
 
