@@ -22,7 +22,7 @@ public class AvgDistinct extends SumDistinct {
   @Override
   public Object terminate() {
     double sum = ((Number) super.terminate()).doubleValue();
-    double result = sum / this.distinct.size();
+    double result = sum / distinct.size();
     return downCast(result);
   }
 }
