@@ -29,12 +29,12 @@ public class CountDistinctPRQueryNode extends DistinctAggregator {
   @Override
   public void accumulate(Object value) {
     if (value != null && value != QueryService.UNDEFINED) {
-      this.distinct.addAll((Set) value);
+      distinct.addAll((Set) value);
     }
   }
 
   @Override
   public Object terminate() {
-    return this.distinct.size();
+    return distinct.size();
   }
 }
