@@ -14,7 +14,7 @@
  */
 package org.apache.geode.cache.query.internal.index;
 
-import static org.apache.geode.internal.lang.SystemUtils.getLineSeparator;
+import static java.lang.System.lineSeparator;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -40,7 +40,6 @@ import org.apache.geode.SystemFailure;
 import org.apache.geode.annotations.internal.MakeNotStatic;
 import org.apache.geode.annotations.internal.MutableForTesting;
 import org.apache.geode.cache.Region;
-import org.apache.geode.cache.query.AmbiguousNameException;
 import org.apache.geode.cache.query.Index;
 import org.apache.geode.cache.query.IndexExistsException;
 import org.apache.geode.cache.query.IndexInvalidException;
@@ -102,7 +101,7 @@ public class IndexManager {
    */
   private final ConcurrentMap indexes = new ConcurrentHashMap();
   // TODO Asif : Fix the appropriate size of the Map & the concurrency level
-  private ConcurrentMap canonicalizedIteratorNameMap = new ConcurrentHashMap();
+  private final ConcurrentMap canonicalizedIteratorNameMap = new ConcurrentHashMap();
   private IndexUpdaterThread updater;
 
   // Threshold for Queue.
@@ -127,13 +126,13 @@ public class IndexManager {
    * without this the old-values are not removed from the index-maps thus resulting in inconsistent
    * results.
    */
-  public static final boolean INPLACE_OBJECT_MODIFICATION = Boolean.valueOf(System.getProperty(
+  public static final boolean INPLACE_OBJECT_MODIFICATION = Boolean.parseBoolean(System.getProperty(
       GeodeGlossary.GEMFIRE_PREFIX + "index.INPLACE_OBJECT_MODIFICATION", "false"));
 
   /**
    * System property to turn-off the compact-index support.
    */
-  public static final boolean RANGEINDEX_ONLY = Boolean.valueOf(
+  public static final boolean RANGEINDEX_ONLY = Boolean.parseBoolean(
       System.getProperty(GeodeGlossary.GEMFIRE_PREFIX + "index.RANGEINDEX_ONLY", "false"));
 
   @MutableForTesting
@@ -142,6 +141,9 @@ public class IndexManager {
   public static final String INDEX_ELEMARRAY_SIZE_PROP = "index_elemarray_size";
   public static final int INDEX_ELEMARRAY_THRESHOLD =
       Integer.parseInt(System.getProperty(INDEX_ELEMARRAY_THRESHOLD_PROP, "100"));
+  @MutableForTesting
+  public static int INDEX_ELEMARRAY_THRESHOLD_FOR_TESTING = -1;
+
   public static final int INDEX_ELEMARRAY_SIZE =
       Integer.parseInt(System.getProperty(INDEX_ELEMARRAY_SIZE_PROP, "5"));
   @MakeNotStatic
@@ -168,9 +170,9 @@ public class IndexManager {
     indexMaintenanceSynchronous = region.getAttributes().getIndexMaintenanceSynchronous();
     isOverFlowToDisk =
         region.getAttributes().getEvictionAttributes().getAction().isOverflowToDisk();
-    this.offHeap = region.getAttributes().getOffHeap();
+    offHeap = region.getAttributes().getOffHeap();
     if (!indexMaintenanceSynchronous) {
-      updater = new IndexUpdaterThread(this.INDEX_MAINTENANCE_BUFFER,
+      updater = new IndexUpdaterThread(INDEX_MAINTENANCE_BUFFER,
           "OqlIndexUpdater:" + region.getFullPath());
       updater.start();
     }
@@ -241,7 +243,7 @@ public class IndexManager {
    * Used by tests to access the updater thread to determine its progress
    */
   public IndexUpdaterThread getUpdaterThread() {
-    return this.updater;
+    return updater;
   }
 
   // @todo need more specific list of exceptions
@@ -266,12 +268,12 @@ public class IndexManager {
           "Index creation canceled due to low memory");
     }
 
-    boolean oldReadSerialized = this.cache.getPdxReadSerializedOverride();
-    this.cache.setPdxReadSerializedOverride(true);
+    boolean oldReadSerialized = cache.getPdxReadSerializedOverride();
+    cache.setPdxReadSerializedOverride(true);
 
     TXStateProxy tx = null;
-    if (!((InternalCache) this.cache).isClient()) {
-      tx = ((TXManagerImpl) this.cache.getCacheTransactionManager()).pauseTransaction();
+    if (!cache.isClient()) {
+      tx = ((TXManagerImpl) cache.getCacheTransactionManager()).pauseTransaction();
     }
 
     try {
@@ -348,7 +350,7 @@ public class IndexManager {
           logger.debug("IndexManager TestHook is set.");
         }
 
-        if (((LocalRegion) this.region).isInitialized()) {
+        if (((LocalRegion) region).isInitialized()) {
           testHook.hook(1);
         } else {
           testHook.hook(0);
@@ -357,8 +359,8 @@ public class IndexManager {
 
       IndexTask indexTask = new IndexTask(cache, indexName, indexType, origFromClause,
           origIndexedExpression, helper, isCompactOrHash, prIndex, loadEntries);
-      FutureTask<Index> indexFutureTask = new FutureTask<Index>(indexTask);
-      Object oldIndex = this.indexes.putIfAbsent(indexTask, indexFutureTask);
+      FutureTask<Index> indexFutureTask = new FutureTask<>(indexTask);
+      Object oldIndex = indexes.putIfAbsent(indexTask, indexFutureTask);
 
       Index index = null;
 
@@ -368,7 +370,7 @@ public class IndexManager {
           // Initialize index.
           indexFutureTask.run();
           // Set the index.
-          index = (Index) indexFutureTask.get();
+          index = indexFutureTask.get();
         } else {
           // Index with same name or characteristic already exists.
           // Check if index creation is complete.
@@ -406,9 +408,9 @@ public class IndexManager {
         // If the index is not successfully created, remove IndexTask from
         // the map.
         if (oldIndex == null && index == null) {
-          Object ind = this.indexes.get(indexTask);
+          Object ind = indexes.get(indexTask);
           if (ind != null && !(ind instanceof Index)) {
-            this.indexes.remove(indexTask);
+            indexes.remove(indexTask);
           }
         }
         if (interrupted) {
@@ -423,8 +425,8 @@ public class IndexManager {
       return index;
 
     } finally {
-      this.cache.setPdxReadSerializedOverride(oldReadSerialized);
-      ((TXManagerImpl) this.cache.getCacheTransactionManager()).unpauseTransaction(tx);
+      cache.setPdxReadSerializedOverride(oldReadSerialized);
+      ((TXManagerImpl) cache.getCacheTransactionManager()).unpauseTransaction(tx);
 
     }
   }
@@ -456,7 +458,7 @@ public class IndexManager {
     do {
       nodeType = cv.getType();
       if (nodeType == CompiledValue.PATH) {
-        cv = ((CompiledPath) cv).getReceiver();
+        cv = cv.getReceiver();
       }
     } while (nodeType == CompiledValue.PATH);
     // end of path, nodeType at this point should be an Identifier
@@ -487,15 +489,12 @@ public class IndexManager {
 
     }
     String tailId = ((CompiledPath) missingLink).getTailID();
-    if (!(tailId.equals("value") || tailId.equals("key"))) {
-      return false;
-    }
-    return true;
+    return tailId.equals("value") || tailId.equals("key");
   }
 
   public Index getIndex(String indexName) {
     IndexTask indexTask = new IndexTask(cache, indexName);
-    Object ind = this.indexes.get(indexTask);
+    Object ind = indexes.get(indexTask);
     // Check if the returned value is instance of Index (this means
     // the index is not in create phase, its created successfully).
     if (ind instanceof Index) {
@@ -506,7 +505,7 @@ public class IndexManager {
 
   public void addIndex(String indexName, Index index) {
     IndexTask indexTask = new IndexTask(cache, indexName);
-    this.indexes.put(indexTask, index);
+    indexes.put(indexTask, index);
   }
 
   /**
@@ -524,15 +523,15 @@ public class IndexManager {
    */
   public IndexData getIndex(IndexType indexType, String[] definitions,
       CompiledValue indexedExpression, ExecutionContext context)
-      throws AmbiguousNameException, TypeMismatchException, NameResolutionException {
+      throws TypeMismatchException, NameResolutionException {
     IndexData indxData = null;
     int qItrSize = definitions.length;
-    Iterator it = this.indexes.values().iterator();
+    Iterator it = indexes.values().iterator();
     StringBuilder sb = new StringBuilder();
     indexedExpression.generateCanonicalizedExpression(sb, context);
     String indexExprStr = sb.toString();
     while (it.hasNext()) {
-      int mapping[] = new int[qItrSize];
+      int[] mapping = new int[qItrSize];
       Object ind = it.next();
       // Check if the returned value is instance of Index (this means
       // the index is not in create phase, its created successfully).
@@ -559,7 +558,7 @@ public class IndexManager {
 
   public int compareIndexData(IndexType indexType, String[] indexDefinitions,
       String indexExpression, IndexType otherType, String[] otherDefinitions,
-      String otherExpression, int mapping[]) {
+      String otherExpression, int[] mapping) {
 
     int matchLevel = -2;
 
@@ -586,7 +585,7 @@ public class IndexManager {
    */
   public IndexData getBestMatchIndex(IndexType indexType, String[] definitions,
       CompiledValue indexedExpression, ExecutionContext context)
-      throws AmbiguousNameException, TypeMismatchException, NameResolutionException {
+      throws TypeMismatchException, NameResolutionException {
 
     Index bestIndex = null;
     Index bestPRIndex = null;
@@ -594,7 +593,7 @@ public class IndexManager {
 
     int qItrSize = definitions.length;
     int bestIndexMatchLevel = qItrSize;
-    Iterator iter = this.indexes.values().iterator();
+    Iterator iter = indexes.values().iterator();
     StringBuilder sb = new StringBuilder();
     indexedExpression.generateCanonicalizedExpression(sb, context);
     String indexExprStr = sb.toString();
@@ -664,9 +663,9 @@ public class IndexManager {
          * criteria for match level is the absence or presence of extra iterators. The order of
          * preference will be 0 , <0 , > 0 for first cut.
          */
-        String indexDefinitions[] = ((IndexProtocol) index).getCanonicalizedIteratorDefinitions();
+        String[] indexDefinitions = ((IndexProtocol) index).getCanonicalizedIteratorDefinitions();
 
-        int mapping[] = new int[qItrSize];
+        int[] mapping = new int[qItrSize];
         int matchLevel = getMatchLevel(definitions, indexDefinitions, mapping);
 
         if (matchLevel == 0) {
@@ -784,9 +783,7 @@ public class IndexManager {
    */
   public Collection getIndexes(IndexType indexType) {
     ArrayList<Index> list = new ArrayList<>();
-    Iterator it = this.indexes.values().iterator();
-    while (it.hasNext()) {
-      Object ind = it.next();
+    for (final Object ind : indexes.values()) {
       // Check if the value is instance of FutureTask, this means
       // the index is in create phase.
       if (ind instanceof FutureTask) {
@@ -818,7 +815,7 @@ public class IndexManager {
    * @param index the Index to remove
    */
   public void removeIndex(Index index) {
-    if (index.getRegion() != this.region) {
+    if (index.getRegion() != region) {
       throw new IllegalArgumentException(
           "Index does not belong to this IndexManager");
     }
@@ -831,7 +828,7 @@ public class IndexManager {
     // the index invalid , that is OK. Because of this flag a query
     // may or may not use the Index
     IndexTask indexTask = new IndexTask(cache, index.getName());
-    if (this.indexes.remove(indexTask) != null) {
+    if (indexes.remove(indexTask) != null) {
       AbstractIndex indexHandle = (AbstractIndex) index;
       indexHandle.destroy();
     }
@@ -844,9 +841,8 @@ public class IndexManager {
   public int removeIndexes() {
     // Remove indexes which are available (create completed).
     int numIndexes = 0;
-    Iterator it = this.indexes.entrySet().iterator();
-    while (it.hasNext()) {
-      Map.Entry entry = (Map.Entry) it.next();
+    for (final Object o : indexes.entrySet()) {
+      Map.Entry entry = (Map.Entry) o;
       Object ind = entry.getValue();
       // Check if the returned value is instance of Index (this means
       // the index is not in create phase, its created successfully).
@@ -855,7 +851,7 @@ public class IndexManager {
       }
       numIndexes++;
       IndexTask indexTask = (IndexTask) entry.getKey();
-      this.indexes.remove(indexTask);
+      indexes.remove(indexTask);
     }
     return numIndexes;
   }
@@ -896,9 +892,9 @@ public class IndexManager {
       region.getCache().getLogger().info("Populating indexes for region " + region.getName());
     }
     boolean throwException = false;
-    HashMap<String, Exception> exceptionsMap = new HashMap<String, Exception>();
-    boolean oldReadSerialized = this.cache.getPdxReadSerializedOverride();
-    this.cache.setPdxReadSerializedOverride(true);
+    HashMap<String, Exception> exceptionsMap = new HashMap<>();
+    boolean oldReadSerialized = cache.getPdxReadSerializedOverride();
+    cache.setPdxReadSerializedOverride(true);
     try {
       Iterator entryIter = ((LocalRegion) region).getBestIterator(true);
       while (entryIter.hasNext()) {
@@ -909,16 +905,16 @@ public class IndexManager {
         // Fault in the value once before index update so that every index
         // update does not have
         // to read the value from disk every time.
-        entry.getValue((LocalRegion) this.region);
+        entry.getValue((LocalRegion) region);
         Iterator<Index> indexSetIterator = indexSet.iterator();
         while (indexSetIterator.hasNext()) {
           AbstractIndex index = (AbstractIndex) indexSetIterator.next();
           if (!index.isPopulated() && index.getType() != IndexType.PRIMARY_KEY) {
             if (logger.isDebugEnabled()) {
               logger.debug("Adding to index :{}{} value :{}", index.getName(),
-                  this.region.getFullPath(), entry.getKey());
+                  region.getFullPath(), entry.getKey());
             }
-            long start = ((AbstractIndex) index).updateIndexUpdateStats();
+            long start = index.updateIndexUpdateStats();
             try {
               index.addIndexMapping(entry);
             } catch (IMQException e) {
@@ -930,7 +926,7 @@ public class IndexManager {
               indexSetIterator.remove();
               throwException = true;
             }
-            ((AbstractIndex) index).updateIndexUpdateStats(start);
+            index.updateIndexUpdateStats(start);
           }
         }
       }
@@ -939,7 +935,7 @@ public class IndexManager {
         throw new MultiIndexCreationException(exceptionsMap);
       }
     } finally {
-      this.cache.setPdxReadSerializedOverride(oldReadSerialized);
+      cache.setPdxReadSerializedOverride(oldReadSerialized);
       notifyAfterUpdate();
     }
   }
@@ -971,7 +967,7 @@ public class IndexManager {
   public void updateIndexes(RegionEntry entry, int action, int opCode,
       boolean isDiskRecoveryInProgress) throws QueryException {
     if (isDiskRecoveryInProgress) {
-      assert !((LocalRegion) this.region).isInitialized();
+      assert !((LocalRegion) region).isInitialized();
     } else {
       assert Assert.assertHoldsLock(entry, true);
     }
@@ -995,11 +991,11 @@ public class IndexManager {
    */
   private void processAction(RegionEntry entry, int action, int opCode) throws QueryException {
     final long startPA = getCachePerfStats().startIndexUpdate();
-    Boolean initialPdxReadSerialized = this.cache.getPdxReadSerializedOverride();
-    this.cache.setPdxReadSerializedOverride(true);
+    Boolean initialPdxReadSerialized = cache.getPdxReadSerializedOverride();
+    cache.setPdxReadSerializedOverride(true);
     TXStateProxy tx = null;
-    if (!this.cache.isClient()) {
-      tx = ((TXManagerImpl) this.cache.getCacheTransactionManager()).pauseTransaction();
+    if (!cache.isClient()) {
+      tx = ((TXManagerImpl) cache.getCacheTransactionManager()).pauseTransaction();
     }
 
     try {
@@ -1036,9 +1032,7 @@ public class IndexManager {
           // so we need to remove the mapping even if it is an Add action
           // as otherwise the new results will get added into the
           // old results instead of replacement
-          Iterator iter = this.indexes.values().iterator();
-          while (iter.hasNext()) {
-            Object ind = iter.next();
+          for (final Object ind : indexes.values()) {
             // Check if the value is instance of FutureTask, this means
             // the index is in create phase.
             if (ind instanceof FutureTask) {
@@ -1055,7 +1049,7 @@ public class IndexManager {
               if (!index.containsEntry(entry)) {
                 if (logger.isDebugEnabled()) {
                   logger.debug("Adding to index: {}{} value: {}", index.getName(),
-                      this.region.getFullPath(), entry.getKey());
+                      region.getFullPath(), entry.getKey());
                 }
                 start = ((AbstractIndex) index).updateIndexUpdateStats();
                 addIndexMapping(entry, index);
@@ -1077,9 +1071,7 @@ public class IndexManager {
 
           // this action is only called with opCode AFTER_UPDATE_OP
           assert opCode == IndexProtocol.AFTER_UPDATE_OP;
-          Iterator iter = this.indexes.values().iterator();
-          while (iter.hasNext()) {
-            Object ind = iter.next();
+          for (final Object ind : indexes.values()) {
             // Check if the value is instance of FutureTask, this means
             // the index is in create phase.
             if (ind instanceof FutureTask) {
@@ -1090,7 +1082,7 @@ public class IndexManager {
             if (((AbstractIndex) index).isPopulated() && index.getType() != IndexType.PRIMARY_KEY) {
               if (logger.isDebugEnabled()) {
                 logger.debug("Updating index: {}{} value: {}", index.getName(),
-                    this.region.getFullPath(), entry.getKey());
+                    region.getFullPath(), entry.getKey());
               }
               start = ((AbstractIndex) index).updateIndexUpdateStats();
 
@@ -1110,9 +1102,7 @@ public class IndexManager {
             testHook.hook(5);
             testHook.hook(10);
           }
-          Iterator iter = this.indexes.values().iterator();
-          while (iter.hasNext()) {
-            Object ind = iter.next();
+          for (final Object ind : indexes.values()) {
             // Check if the value is instance of FutureTask, this means
             // the index is in create phase.
             if (ind instanceof FutureTask) {
@@ -1124,7 +1114,7 @@ public class IndexManager {
               AbstractIndex abstractIndex = (AbstractIndex) index;
               if (logger.isDebugEnabled()) {
                 logger.debug("Removing from index: {}{} value: {}", index.getName(),
-                    this.region.getFullPath(), entry.getKey());
+                    region.getFullPath(), entry.getKey());
               }
               start = ((AbstractIndex) index).updateIndexUpdateStats();
 
@@ -1141,8 +1131,8 @@ public class IndexManager {
         }
       }
     } finally {
-      this.cache.setPdxReadSerializedOverride(initialPdxReadSerialized);
-      ((TXManagerImpl) this.cache.getCacheTransactionManager()).unpauseTransaction(tx);
+      cache.setPdxReadSerializedOverride(initialPdxReadSerialized);
+      ((TXManagerImpl) cache.getCacheTransactionManager()).unpauseTransaction(tx);
 
       getCachePerfStats().endIndexUpdate(startPA);
     }
@@ -1157,6 +1147,7 @@ public class IndexManager {
       logger.warn(String.format(
           "Updating the Index %s failed. The index is corrupted and marked as invalid.",
           ((AbstractIndex) index).indexName), exception);
+      logger.debug("Corrupted key is " + entry.getKey());
     }
   }
 
@@ -1169,6 +1160,7 @@ public class IndexManager {
       logger.warn(String.format(
           "Updating the Index %s failed. The index is corrupted and marked as invalid.",
           ((AbstractIndex) index).indexName), exception);
+      logger.debug("Corrupted key is " + entry.getKey());
     }
   }
 
@@ -1230,9 +1222,7 @@ public class IndexManager {
     waitBeforeUpdate();
     try {
       // opCode is ignored for this operation
-      Iterator iter = this.indexes.values().iterator();
-      while (iter.hasNext()) {
-        Object ind = iter.next();
+      for (final Object ind : indexes.values()) {
         // Check if the value is instance of FutureTask, this means
         // the index is in create phase.
         if (ind instanceof FutureTask) {
@@ -1261,13 +1251,13 @@ public class IndexManager {
    * getting region entry lock to avoid deadlock (#44431).
    */
   public void waitForIndexInit() {
-    synchronized (this.indexes) {
-      ++this.numUpdatersInWaiting;
-      while (this.numCreators > 0) {
-        ((LocalRegion) this.getRegion()).getCancelCriterion().checkCancelInProgress(null);
+    synchronized (indexes) {
+      ++numUpdatersInWaiting;
+      while (numCreators > 0) {
+        ((LocalRegion) getRegion()).getCancelCriterion().checkCancelInProgress(null);
         boolean interrupted = Thread.interrupted();
         try {
-          this.indexes.wait();
+          indexes.wait();
         } catch (InterruptedException ignored) {
           interrupted = true;
         } finally {
@@ -1276,8 +1266,8 @@ public class IndexManager {
           }
         }
       } // while
-      --this.numUpdatersInWaiting;
-      ++this.numUpdatersInProgress;
+      --numUpdatersInWaiting;
+      ++numUpdatersInProgress;
     }
   }
 
@@ -1285,27 +1275,27 @@ public class IndexManager {
    * Necessary finally block call for above method.
    */
   public void countDownIndexUpdaters() {
-    synchronized (this.indexes) {
-      --this.numUpdatersInProgress;
+    synchronized (indexes) {
+      --numUpdatersInProgress;
       // Asif: Since Index creator threads can progress only if
       // there is no update threads in progress, thus we need to issue
       // notify all iff there are any creator threads in action & also
       // if the upDateInProgress Count has dipped to 0
-      if (this.numUpdatersInProgress == 0 && this.numCreators > 0) {
-        this.indexes.notifyAll();
+      if (numUpdatersInProgress == 0 && numCreators > 0) {
+        indexes.notifyAll();
       }
     }
   }
 
   private CachePerfStats getCachePerfStats() {
-    return ((HasCachePerfStats) this.region).getCachePerfStats();
+    return ((HasCachePerfStats) region).getCachePerfStats();
   }
 
   /**
    * Callback for destroying IndexManager Called after Region.destroy() called
    */
   public void destroy() throws QueryException {
-    this.indexes.clear();
+    indexes.clear();
     if (!isIndexMaintenanceTypeSynchronous()) {
       updater.shutdown();
     }
@@ -1320,12 +1310,11 @@ public class IndexManager {
   public void removeBucketIndexes(PartitionedRegion prRegion) throws QueryException {
     IndexManager parentManager = prRegion.getIndexManager();
     if (parentManager != null) {
-      Iterator bucketIndexIterator = indexes.values().iterator();
-      while (bucketIndexIterator.hasNext()) {
-        Index bucketIndex = (Index) bucketIndexIterator.next();
+      for (final Object o : indexes.values()) {
+        Index bucketIndex = (Index) o;
         Index prIndex = parentManager.getIndex(bucketIndex.getName());
         if (prIndex instanceof PartitionedIndex) {
-          ((PartitionedIndex) prIndex).removeFromBucketIndexes(this.region, bucketIndex);
+          ((PartitionedIndex) prIndex).removeFromBucketIndexes(region, bucketIndex);
         }
       }
     }
@@ -1334,29 +1323,27 @@ public class IndexManager {
   @Override
   public String toString() {
     StringBuilder sb = new StringBuilder();
-    Iterator iter = this.indexes.values().iterator();
-    while (iter.hasNext()) {
-      Object ind = iter.next();
+    for (final Object ind : indexes.values()) {
       // Check if the value is instance of FutureTask, this means
       // the index is in create phase.
       if (ind instanceof FutureTask) {
         continue;
       }
-      sb.append(ind).append(getLineSeparator());
+      sb.append(ind).append(lineSeparator());
     }
     return sb.toString();
   }
 
   public boolean isIndexMaintenanceTypeSynchronous() {
-    return this.indexMaintenanceSynchronous;
+    return indexMaintenanceSynchronous;
   }
 
   public boolean isOverFlowRegion() {
-    return this.isOverFlowToDisk;
+    return isOverFlowToDisk;
   }
 
   public boolean isOffHeap() {
-    return this.offHeap;
+    return offHeap;
   }
 
   public static boolean isObjectModificationInplace() {
@@ -1374,11 +1361,11 @@ public class IndexManager {
   public String putCanonicalizedIteratorNameIfAbsent(String definition) {
     String str = null;
     synchronized (canonicalizedIteratorNameMap) {
-      if ((str = (String) this.canonicalizedIteratorNameMap.get(definition)) == null) {
-        str = new StringBuilder("index_iter").append(this.getIncrementedCounter()).toString();
+      if ((str = (String) canonicalizedIteratorNameMap.get(definition)) == null) {
+        str = "index_iter" + getIncrementedCounter();
         String temp;
         if ((temp =
-            (String) this.canonicalizedIteratorNameMap.putIfAbsent(definition, str)) != null) {
+            (String) canonicalizedIteratorNameMap.putIfAbsent(definition, str)) != null) {
           str = temp;
         }
       }
@@ -1388,12 +1375,12 @@ public class IndexManager {
 
   public void putCanonicalizedIteratorName(String definition, String name) {
     synchronized (canonicalizedIteratorNameMap) {
-      this.canonicalizedIteratorNameMap.put(definition, name);
+      canonicalizedIteratorNameMap.put(definition, name);
     }
   }
 
   private synchronized int getIncrementedCounter() {
-    return ++this.iternameCounter;
+    return ++iternameCounter;
   }
 
   /**
@@ -1402,7 +1389,7 @@ public class IndexManager {
    *
    */
   public String getCanonicalizedIteratorName(String definition) {
-    return ((String) (this.canonicalizedIteratorNameMap.get(definition)));
+    return ((String) (canonicalizedIteratorNameMap.get(definition)));
   }
 
   ////////////////////// Inner Classes //////////////////////
@@ -1413,7 +1400,7 @@ public class IndexManager {
 
     private volatile boolean shutdownRequested = false;
 
-    private volatile BlockingQueue pendingTasks;
+    private final BlockingQueue pendingTasks;
 
     /**
      * Creates instance of IndexUpdaterThread
@@ -1442,13 +1429,13 @@ public class IndexManager {
      * Stops this thread. Does not return until it has stopped.
      */
     public void shutdown() {
-      if (!this.running) {
+      if (!running) {
         return;
       }
-      this.shutdownRequested = true;
-      this.interrupt();
+      shutdownRequested = true;
+      interrupt();
       try {
-        this.join();
+        join();
       } catch (InterruptedException ignore) {
         Thread.currentThread().interrupt();
         // just return, we're done
@@ -1461,7 +1448,7 @@ public class IndexManager {
       // logger.debug("DiskRegion writer started (writer=" + this + ")");
       org.apache.geode.CancelCriterion stopper = ((LocalRegion) region).getCancelCriterion();
       try {
-        while (!this.shutdownRequested) {
+        while (!shutdownRequested) {
           // Termination checks
           SystemFailure.checkFailure();
           if (stopper.isCancelInProgress()) {
@@ -1469,7 +1456,7 @@ public class IndexManager {
           }
           try {
             Object[] task = (Object[]) pendingTasks.take();
-            if (this.shutdownRequested) {
+            if (shutdownRequested) {
               break;
             }
             updateIndexes(task);
@@ -1478,7 +1465,7 @@ public class IndexManager {
           }
         }
       } finally {
-        this.running = false;
+        running = false;
       }
     }
 
@@ -1513,7 +1500,7 @@ public class IndexManager {
      * point of view.
      */
     public synchronized boolean isDone() {
-      return this.pendingTasks.size() == 0;
+      return pendingTasks.size() == 0;
     }
 
   }
@@ -1551,7 +1538,7 @@ public class IndexManager {
         PartitionedIndex prIndex, boolean loadEntries) {
       this.cache = cache;
       this.indexName = indexName;
-      this.indexType = type;
+      indexType = type;
       this.origFromClause = origFromClause;
       this.origIndexedExpression = origIndexedExpression;
       this.helper = helper;
@@ -1573,25 +1560,22 @@ public class IndexManager {
       }
       IndexTask otherIndexTask = (IndexTask) other;
       // compare indexName.
-      if (this.indexName.equals(otherIndexTask.indexName)) {
+      if (indexName.equals(otherIndexTask.indexName)) {
         return true;
       }
 
-      if (otherIndexTask.helper == null || this.helper == null) {
+      if (otherIndexTask.helper == null || helper == null) {
         return false;
       }
 
-      String[] indexDefinitions = this.helper.getCanonicalizedIteratorDefinitions();
+      String[] indexDefinitions = helper.getCanonicalizedIteratorDefinitions();
       // TODO: avoid object creation in equals
       int[] mapping = new int[indexDefinitions.length];
       // compare index based on its type, expression and definition.
-      if (compareIndexData(this.indexType, indexDefinitions,
-          this.helper.getCanonicalizedIndexedExpression(), otherIndexTask.indexType,
+      return compareIndexData(indexType, indexDefinitions,
+          helper.getCanonicalizedIndexedExpression(), otherIndexTask.indexType,
           otherIndexTask.helper.getCanonicalizedIteratorDefinitions(),
-          otherIndexTask.helper.getCanonicalizedIndexedExpression(), mapping) == 0) {
-        return true;
-      }
-      return false;
+          otherIndexTask.helper.getCanonicalizedIndexedExpression(), mapping) == 0;
     }
 
     public int hashCode() {
@@ -1613,10 +1597,10 @@ public class IndexManager {
       String projectionAttributes = helper.getCanonicalizedProjectionAttributes();
       String[] definitions = helper.getCanonicalizedIteratorDefinitions();
       IndexStatistics stats = null;
-      this.isLDM = IndexManager.IS_TEST_LDM;
+      isLDM = IndexManager.IS_TEST_LDM;
 
-      if (this.prIndex != null) {
-        stats = this.prIndex.getStatistics();
+      if (prIndex != null) {
+        stats = prIndex.getStatistics();
       }
       if (indexType == IndexType.PRIMARY_KEY) {
         index = new PrimaryKeyIndex(cache, indexName, region, fromClause, indexedExpression,
@@ -1632,7 +1616,7 @@ public class IndexManager {
       } else {
         // boolean isCompact = !helper.isMapTypeIndex() &&
         // shouldCreateCompactIndex((FunctionalIndexCreationHelper)helper);
-        if (this.isCompactOrHash || this.isLDM) {
+        if (isCompactOrHash || isLDM) {
           if (indexType == IndexType.FUNCTIONAL && !helper.isMapTypeIndex()) {
             index = new CompactRangeIndex(cache, indexName, region, fromClause, indexedExpression,
                 projectionAttributes, origFromClause, origIndexedExpression, definitions, stats);
@@ -1680,8 +1664,8 @@ public class IndexManager {
           indexCreatedSuccessfully = true;
           if (loadEntries) {
             aIndex.setPopulated(true);
-            if (this.prIndex != null) {
-              ((AbstractIndex) this.prIndex).setPopulated(true);
+            if (prIndex != null) {
+              prIndex.setPopulated(true);
             }
           }
           indexes.put(this, index);
@@ -1705,8 +1689,8 @@ public class IndexManager {
         if (region instanceof BucketRegion && prIndex != null) {
           prIndex.addToBucketIndexes(region, index);
         }
-        if (this.prIndex != null) {
-          ((AbstractIndex) this.prIndex).setPopulated(true);
+        if (prIndex != null) {
+          prIndex.setPopulated(true);
         }
       }
       return index;
