@@ -58,6 +58,11 @@ public class MapIndexStore implements IndexStore {
     addMapping(indexKey, re);
   }
 
+  @Override
+  public void removeMappingGII(Object indexKey, RegionEntry re) {
+    removeMapping(indexKey, re);
+  }
+
   @Override
   public void removeMapping(Object indexKey, RegionEntry re) {
     indexMap.remove(indexKey, re.getKey());
