@@ -17,6 +17,8 @@ package org.apache.geode.cache.wan;
 import java.util.List;
 
 import org.apache.geode.annotations.Immutable;
+import org.apache.geode.internal.lang.SystemProperty;
+import org.apache.geode.internal.lang.SystemPropertyHelper;
 import org.apache.geode.util.internal.GeodeGlossary;
 
 /**
@@ -50,8 +52,7 @@ public interface GatewaySender {
    */
   int DEFAULT_SOCKET_READ_TIMEOUT = Integer
       .getInteger(
-          GeodeGlossary.GEMFIRE_PREFIX + "cache.gatewaySender.default-socket-read-timeout", 0)
-      .intValue();
+          GeodeGlossary.GEMFIRE_PREFIX + "cache.gatewaySender.default-socket-read-timeout", 0);
 
   /**
    * The default minimum socket read timeout.
@@ -63,7 +64,7 @@ public interface GatewaySender {
    */
   int QUEUE_OPLOG_SIZE =
       Integer.getInteger(GeodeGlossary.GEMFIRE_PREFIX + "cache.gatewaySender.queueOpLogSize",
-          1024 * 1024 * 100).intValue();
+          1024 * 1024 * 100);
 
 
   /**
@@ -93,7 +94,7 @@ public interface GatewaySender {
   int DEFAULT_ALERT_THRESHOLD = 0;
 
   int DEFAULT_PARALLELISM_REPLICATED_REGION = Integer.getInteger(GeodeGlossary.GEMFIRE_PREFIX
-      + "cache.gatewaySender.defaultParallelismForReplicatedRegion", 113).intValue();
+      + "cache.gatewaySender.defaultParallelismForReplicatedRegion", 113);
 
   int DEFAULT_DISTRIBUTED_SYSTEM_ID = -1;
 
@@ -110,11 +111,11 @@ public interface GatewaySender {
   int DEFAULT_MAXIMUM_QUEUE_MEMORY = 100;
 
   /**
-   * Time, in seconds, that we allow before a <code>GatewaySender is considered dead and should be
-   * aborted
+   * Time, in seconds, that we allow before a <code>GatewaySender</code> is considered dead and
+   * should be aborted
    */
   long GATEWAY_SENDER_TIMEOUT = Integer
-      .getInteger(GeodeGlossary.GEMFIRE_PREFIX + "GATEWAY_SENDER_TIMEOUT", 30).intValue();
+      .getInteger(GeodeGlossary.GEMFIRE_PREFIX + "GATEWAY_SENDER_TIMEOUT", 30);
 
 
   /**
@@ -126,17 +127,15 @@ public interface GatewaySender {
 
   int GATEWAY_CONNECTION_IDLE_TIMEOUT = Integer
       .getInteger(
-          GeodeGlossary.GEMFIRE_PREFIX + "GatewaySender.GATEWAY_CONNECTION_IDLE_TIMEOUT", -1)
-      .intValue();
+          GeodeGlossary.GEMFIRE_PREFIX + "GatewaySender.GATEWAY_CONNECTION_IDLE_TIMEOUT", -1);
 
   /**
    * If the System property is set, use it. Otherwise, set default to 'true'.
    */
-  boolean REMOVE_FROM_QUEUE_ON_EXCEPTION = (System.getProperty(
-      GeodeGlossary.GEMFIRE_PREFIX + "GatewaySender.REMOVE_FROM_QUEUE_ON_EXCEPTION") != null)
-          ? Boolean.getBoolean(
-              GeodeGlossary.GEMFIRE_PREFIX + "GatewaySender.REMOVE_FROM_QUEUE_ON_EXCEPTION")
-          : true;
+  boolean REMOVE_FROM_QUEUE_ON_EXCEPTION = System.getProperty(
+      GeodeGlossary.GEMFIRE_PREFIX + "GatewaySender.REMOVE_FROM_QUEUE_ON_EXCEPTION") == null
+      || Boolean.getBoolean(
+          GeodeGlossary.GEMFIRE_PREFIX + "GatewaySender.REMOVE_FROM_QUEUE_ON_EXCEPTION");
 
   boolean EARLY_ACK =
       Boolean.getBoolean(GeodeGlossary.GEMFIRE_PREFIX + "GatewaySender.EARLY_ACK");
@@ -154,8 +153,7 @@ public interface GatewaySender {
    * case receiver is not up and running. Default is set to 1000 milliseconds i.e. 1 second.
    */
   int CONNECTION_RETRY_INTERVAL = Integer
-      .getInteger(GeodeGlossary.GEMFIRE_PREFIX + "gateway-connection-retry-interval", 1000)
-      .intValue();
+      .getInteger(GeodeGlossary.GEMFIRE_PREFIX + "gateway-connection-retry-interval", 1000);
 
   /**
    * Number of times to retry to get events for a transaction from the gateway sender queue when
@@ -175,9 +173,16 @@ public interface GatewaySender {
   int GET_TRANSACTION_EVENTS_FROM_QUEUE_RETRIES =
       Integer.getInteger(GeodeGlossary.GEMFIRE_PREFIX + "get-transaction-events-from-queue-retries",
           10);
+  /**
+   * Milliseconds to wait before retrying to get events for a transaction from the
+   * gateway sender queue when group-transaction-events is true.
+   */
+  int GET_TRANSACTION_EVENTS_FROM_QUEUE_WAIT_TIME_MS =
+      SystemProperty.getProductIntegerProperty(
+          SystemPropertyHelper.GET_TRANSACTION_EVENTS_FROM_QUEUE_WAIT_TIME_MS).orElse(1);
 
   /**
-   * The order policy. This enum is applicable only when concurrency-level is > 1.
+   * The order policy. This enum is applicable only when concurrency-level is &gt; 1.
    *
    * @since GemFire 6.5.1
    */
@@ -255,24 +260,29 @@ public interface GatewaySender {
 
   /**
    * Returns whether or not this GatewaySender is running.
+   *
+   * @return whether this GatewaySender is running
    */
   boolean isRunning();
 
   /**
    * Returns whether or not this GatewaySender is paused.
    *
+   * @return whether this GatewaySender is paused
    */
   boolean isPaused();
 
   /**
    * Adds the provided <code>GatewayEventFilter</code> to this GatewaySender.
    *
+   * @param filter the <code>GatewayEventFilter</code> to add
    */
   void addGatewayEventFilter(GatewayEventFilter filter);
 
   /**
    * Removes the provided <code>GatewayEventFilter</code> from this GatewaySender.
    *
+   * @param filter the <code>GatewayEventFilter</code> to remove
    */
   void removeGatewayEventFilter(GatewayEventFilter filter);
 
@@ -431,7 +441,7 @@ public interface GatewaySender {
 
   /**
    * Returns the order policy followed while dispatching the events to remote ds. Order policy is
-   * set only when dispatcher threads are > 1. Default value of order policy is KEY.
+   * set only when dispatcher threads are &gt; 1. Default value of order policy is KEY.
    *
    * @return the order policy followed while dispatching the events to remote ds.
    */
@@ -440,7 +450,6 @@ public interface GatewaySender {
 
   int getMaxParallelismForReplicatedRegion();
 
-
   /**
    * Destroys the GatewaySender.
    * <p>
