@@ -22,6 +22,7 @@ import java.util.List;
 import java.util.Properties;
 
 import org.apache.geode.distributed.internal.InternalLocator;
+import org.apache.geode.distributed.internal.tcpserver.HostAddress;
 import org.apache.geode.internal.inet.LocalHostUtil;
 
 /**
@@ -63,9 +64,12 @@ public abstract class Locator {
   /** The file to which this locator logs */
   protected File logFile;
 
-  /** The bind address for this locator */
+  /** no longer used but kept for binary compatibility */
   protected InetAddress bindAddress;
 
+  /** The bind address for this locator */
+  protected HostAddress hostAddress;
+
   /**
    * the hostname to give to clients so they can connect to this locator.
    *
@@ -90,6 +94,7 @@ public abstract class Locator {
    * @param logFile The file to which the locator logs information. The directory that contains the
    *        log file is used as the output directory of the locator (see <code>-dir</code> option to
    *        the <code>gemfire</code> command).
+   * @return the newly started locator
    *
    * @throws IllegalArgumentException If <code>port</code> is not in the range 0 to 65536
    * @throws org.apache.geode.SystemIsRunningException If another locator is already running in
@@ -99,9 +104,10 @@ public abstract class Locator {
    * @throws IOException If the locator cannot be started
    * @deprecated as of 7.0 use startLocatorAndDS instead.
    */
+  @Deprecated
   public static Locator startLocator(int port, File logFile) throws IOException {
 
-    return startLocator(port, logFile, false, (InetAddress) null, (Properties) null, true, true,
+    return startLocator(port, logFile, false, null, null, true, true,
         null);
   }
 
@@ -125,6 +131,7 @@ public abstract class Locator {
    *        system. If there are multiple locators in the system, this should note them in the
    *        "locators" setting. If The distributed system is using multicast, the "mcast-port"
    *        should also be set.
+   * @return the newly started locator
    *
    * @throws IllegalArgumentException If <code>port</code> is not in the range 0 to 65536
    * @throws org.apache.geode.SystemIsRunningException If another locator is already running in
@@ -136,7 +143,7 @@ public abstract class Locator {
   public static Locator startLocatorAndDS(int port, File logFile,
       Properties distributedSystemProperties) throws IOException {
 
-    return startLocator(port, logFile, (InetAddress) null, distributedSystemProperties, true, true,
+    return startLocator(port, logFile, null, distributedSystemProperties, true, true,
         null);
   }
 
@@ -154,6 +161,7 @@ public abstract class Locator {
    *        log file is used as the output directory of the locator (see <code>-dir</code> option to
    *        the <code>gemfire</code> command).
    * @param bindAddress The IP address to which the locator's socket binds
+   * @return the newly started locator
    *
    * @throws IllegalArgumentException If <code>port</code> is not in the range 0 to 65536
    * @throws org.apache.geode.SystemIsRunningException If another locator is already running in
@@ -163,10 +171,12 @@ public abstract class Locator {
    * @throws IOException If the locator cannot be started
    * @deprecated as of 7.0 use startLocatorAndDS instead.
    */
+  @Deprecated
   public static Locator startLocator(int port, File logFile, InetAddress bindAddress)
       throws IOException {
-
-    return startLocator(port, logFile, false, bindAddress, (Properties) null, true, true, null);
+    HostAddress hostAddress = bindAddress == null ? null : new HostAddress(bindAddress);
+    return startLocator(port, logFile, false, hostAddress, null, true,
+        true, null);
   }
 
 
@@ -188,6 +198,7 @@ public abstract class Locator {
    * @param dsProperties The properties used to configure the locator's DistributedSystem. If there
    *        are multiple locators, the "locators" property should be set. If multicast is being
    *        used, the "mcast-port" property should be set.
+   * @return the newly started locator
    *
    * @throws IllegalArgumentException If <code>port</code> is not in the range 0 to 65536
    * @throws org.apache.geode.SystemIsRunningException If another locator is already running in
@@ -198,7 +209,9 @@ public abstract class Locator {
    */
   public static Locator startLocatorAndDS(int port, File logFile, InetAddress bindAddress,
       java.util.Properties dsProperties) throws IOException {
-    return startLocator(port, logFile, bindAddress, dsProperties, true, true, null);
+    HostAddress hostAddress = bindAddress == null ? null : new HostAddress(bindAddress);
+    return startLocator(port, logFile, hostAddress, dsProperties, true, true,
+        null);
   }
 
   /**
@@ -225,6 +238,7 @@ public abstract class Locator {
    * @param serverLocator True if the locator should provide information about cache servers to
    *        clients connecting to the distributed system.
    * @param hostnameForClients the name to give to clients for connecting to this locator
+   * @return the newly started locator
    *
    * @throws IllegalArgumentException If <code>port</code> is not in the range 0 to 65536 or
    *         <code>peerLocator</code> and <code> serverLocator</code> are both false.
@@ -236,17 +250,20 @@ public abstract class Locator {
    *
    * @since GemFire 5.7
    */
+  @Deprecated
   public static Locator startLocatorAndDS(int port, File logFile, InetAddress bindAddress,
       java.util.Properties dsProperties, boolean peerLocator, boolean serverLocator,
       String hostnameForClients) throws IOException {
-    return startLocator(port, logFile, bindAddress, dsProperties, true, true, hostnameForClients);
+    HostAddress hostAddress = bindAddress == null ? null : new HostAddress(bindAddress);
+    return startLocator(port, logFile, hostAddress, dsProperties, true, true,
+        hostnameForClients);
   }
 
   /**
    * all Locator methods that start locators should use this method to start the locator and its
    * distributed system
    */
-  private static Locator startLocator(int port, File logFile, InetAddress bindAddress,
+  private static Locator startLocator(int port, File logFile, HostAddress bindAddress,
       java.util.Properties dsProperties, boolean peerLocator, boolean serverLocator,
       String hostnameForClients) throws IOException {
     return InternalLocator.startLocator(port, logFile, null, null, bindAddress, true, dsProperties,
@@ -257,8 +274,9 @@ public abstract class Locator {
    * @deprecated as of 7.0 use startLocator(int, File, InetAddress, java.util.Properties,
    *             peerLocator, serverLocator, hostnameForClients) instead.
    */
+  @Deprecated
   private static Locator startLocator(int port, File logFile, boolean startDistributedSystem,
-      InetAddress bindAddress, java.util.Properties dsProperties, boolean peerLocator,
+      HostAddress bindAddress, java.util.Properties dsProperties, boolean peerLocator,
       boolean serverLocator, String hostnameForClients) throws IOException {
     return InternalLocator.startLocator(port, logFile, null, null, bindAddress,
         startDistributedSystem, dsProperties, hostnameForClients);
@@ -268,8 +286,11 @@ public abstract class Locator {
    * Returns an unmodifiable <code>List</code> of all of the <code>Locator</code>s that are hosted
    * by this VM.
    *
+   * @return an unmodifiable <code>List</code> of all of the <code>Locator</code>s that are hosted
+   *         by this VM
    * @deprecated as of 7.0 use {@link #getLocator} instead
    */
+  @Deprecated
   public static List<Locator> getLocators() {
     Locator result = getLocator();
     if (result == null) {
@@ -295,6 +316,7 @@ public abstract class Locator {
    * @return the number of locators running in this VM
    * @deprecated as of 7.0 use {@link #hasLocator} instead.
    */
+  @Deprecated
   public static boolean hasLocators() {
     return hasLocator();
   }
@@ -312,37 +334,45 @@ public abstract class Locator {
 
   /**
    * Returns the port on which this locator runs
+   *
+   * @return the port on which this locator runs
    */
   public abstract Integer getPort();
 
   /**
    * Returns the distributed system started by this locator, if any
+   *
+   * @return the distributed system started by this locator, if any
    */
   public abstract DistributedSystem getDistributedSystem();
 
-
   /**
    * Returns the log file to which this locator's output is written
+   *
+   * @return the log file to which this locator's output is written
    */
   public File getLogFile() {
-    return this.logFile;
+    return logFile;
   }
 
   /**
    * Returns the IP address to which this locator's listening socket is bound.
+   *
+   * @return the IP address to which this locator's listening socket is bound
    */
   public InetAddress getBindAddress() {
-    return this.bindAddress;
+    return bindAddress;
   }
 
   /**
    * Returns the hostname that will be given to clients so that they can connect to this locator.
    * Returns <code>null</code> if clients should use the bind address.
    *
+   * @return the hostname that will be given to clients so that they can connect to this locator
    * @since GemFire 5.7
    */
   public String getHostnameForClients() {
-    String result = this.hostnameForClients;
+    String result = hostnameForClients;
     if (result != null && result.equals("")) {
       result = null;
     }
@@ -371,6 +401,8 @@ public abstract class Locator {
 
   /**
    * Returns a brief description of this <code>Locator</code>
+   *
+   * @return a brief description of this <code>Locator</code>
    */
   @Override
   public String toString() {
@@ -380,19 +412,23 @@ public abstract class Locator {
 
   /**
    * Get the string representation of this <code>Locator</code> in host[port] format.
+   *
+   * @return the string representation of this <code>Locator</code> in host[port] format
    */
   public String asString() {
-    Object ba = this.bindAddress;
-    if (ba == null) {
+    String bindAddressString = null;
+    if (hostAddress == null) {
       try {
-        ba = LocalHostUtil.getLocalHostName();
-      } catch (java.net.UnknownHostException uh) {
+        bindAddressString = LocalHostUtil.getLocalHostName();
+      } catch (java.net.UnknownHostException ignored) {
       }
+    } else {
+      bindAddressString = hostAddress.getHostName();
     }
-    StringBuilder locatorString = new StringBuilder(String.valueOf(ba));
+    StringBuilder locatorString = new StringBuilder(String.valueOf(bindAddressString));
     Integer port = getPort();
-    if (port != null && port.intValue() > 0) {
-      locatorString.append('[').append(this.getPort()).append(']');
+    if (port != null && port > 0) {
+      locatorString.append('[').append(getPort()).append(']');
     }
     return locatorString.toString();
   }
@@ -429,10 +465,13 @@ public abstract class Locator {
    * hostname-for-clients - the ip address or host name that clients will be told to use to connect
    * to this locator. If unspecified, defaults to the bind-address.
    *
+   * @param args the arguments to start the locator with
+   *
    * @deprecated as of Geode 1.4 use {@link org.apache.geode.distributed.LocatorLauncher
    *             "LocatorLauncher" to start a locator}
    */
-  public static void main(String args[]) {
+  @Deprecated
+  public static void main(String[] args) {
     org.apache.geode.internal.DistributionLocator.main(args);
   }
 
