@@ -111,10 +111,6 @@ import static org.apache.geode.distributed.ConfigurationProperties.MEMCACHED_POR
 import static org.apache.geode.distributed.ConfigurationProperties.MEMCACHED_PROTOCOL;
 import static org.apache.geode.distributed.ConfigurationProperties.NAME;
 import static org.apache.geode.distributed.ConfigurationProperties.OFF_HEAP_MEMORY_SIZE;
-import static org.apache.geode.distributed.ConfigurationProperties.REDIS_BIND_ADDRESS;
-import static org.apache.geode.distributed.ConfigurationProperties.REDIS_ENABLED;
-import static org.apache.geode.distributed.ConfigurationProperties.REDIS_PASSWORD;
-import static org.apache.geode.distributed.ConfigurationProperties.REDIS_PORT;
 import static org.apache.geode.distributed.ConfigurationProperties.REDUNDANCY_ZONE;
 import static org.apache.geode.distributed.ConfigurationProperties.REMOTE_LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.REMOVE_UNRESPONSIVE_CLIENT;
@@ -149,6 +145,7 @@ import static org.apache.geode.distributed.ConfigurationProperties.SERVER_SSL_TR
 import static org.apache.geode.distributed.ConfigurationProperties.SOCKET_BUFFER_SIZE;
 import static org.apache.geode.distributed.ConfigurationProperties.SOCKET_LEASE_TIME;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_CIPHERS;
+import static org.apache.geode.distributed.ConfigurationProperties.SSL_CLIENT_PROTOCOLS;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_CLUSTER_ALIAS;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_DEFAULT_ALIAS;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_ENABLED_COMPONENTS;
@@ -163,6 +160,7 @@ import static org.apache.geode.distributed.ConfigurationProperties.SSL_PARAMETER
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_PROTOCOLS;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_REQUIRE_AUTHENTICATION;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_SERVER_ALIAS;
+import static org.apache.geode.distributed.ConfigurationProperties.SSL_SERVER_PROTOCOLS;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_TRUSTSTORE;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_TRUSTSTORE_PASSWORD;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_TRUSTSTORE_TYPE;
@@ -291,7 +289,7 @@ public abstract class AbstractDistributionConfig extends AbstractConfig
   protected String checkStartLocator(String value) {
     if (value != null && value.trim().length() > 0) {
       // throws IllegalArgumentException if string is malformed
-      new DistributionLocatorId(value);
+      DistributionLocatorId.unmarshal(value);
     }
     return value;
   }
@@ -349,11 +347,12 @@ public abstract class AbstractDistributionConfig extends AbstractConfig
   }
 
   @ConfigAttributeChecker(name = CLUSTER_SSL_ENABLED)
-  protected Boolean checkClusterSSLEnabled(Boolean value) {
+  protected boolean checkClusterSSLEnabled(boolean value) {
     if (value && getMcastPort() != 0) {
       throw new IllegalArgumentException(
-          String.format("Could not set %s to %s because its value must be false when %s is not 0.",
-              CLUSTER_SSL_ENABLED, value, MCAST_PORT));
+          String.format(
+              "Could not set %s to true because its value must be false when %s is not 0.",
+              CLUSTER_SSL_ENABLED, MCAST_PORT));
     }
     return value;
   }
@@ -668,17 +667,6 @@ public abstract class AbstractDistributionConfig extends AbstractConfig
     return value;
   }
 
-  @ConfigAttributeChecker(name = REDIS_BIND_ADDRESS)
-  protected String checkRedisBindAddress(String value) {
-    if (value != null && value.length() > 0 && !LocalHostUtil.isLocalHost(value)) {
-      throw new IllegalArgumentException(
-          String.format(
-              "The compatible-with-redis-bind-address %s is not a valid address for this machine.  These are the valid addresses for this machine: %s",
-              value, LocalHostUtil.getMyAddresses()));
-    }
-    return value;
-  }
-
   /**
    * First check if sslComponents are in the list of valid components. If so, check that no other
    * *-ssl-* properties other than cluster-ssl-* are set. This would mean one is mixing the "old"
@@ -906,7 +894,7 @@ public abstract class AbstractDistributionConfig extends AbstractConfig
   }
 
   @Immutable
-  static final Map dcAttDescriptions;
+  static final Map<String, String> dcAttDescriptions;
 
   static {
     Map<String, String> m = new HashMap<>();
@@ -1312,14 +1300,6 @@ public abstract class AbstractDistributionConfig extends AbstractConfig
         "The protocol that GemFireMemcachedServer understands. Default is ASCII. Values may be ASCII or BINARY");
     m.put(MEMCACHED_BIND_ADDRESS,
         "The address the GemFireMemcachedServer will listen on for remote connections. Default is \"\" which causes the GemFireMemcachedServer to listen on the host's default address. This property is ignored if memcached-port is \"0\".");
-    m.put(REDIS_BIND_ADDRESS,
-        "Specifies the address on which the Redis API for Geode is listening. If set to the empty string or this property is not specified, localhost is requested from the operating system.");
-    m.put(REDIS_ENABLED,
-        "When the default value of false, the Redis API for Geode is not available.  Set to true to enable the Redis API for Geode.");
-    m.put(REDIS_PASSWORD,
-        "Specifies the password that the server uses when a client attempts to authenticate. The default is none and no authentication will be required.");
-    m.put(REDIS_PORT,
-        "Specifies the port on which the server listens for Redis API for Geode connections. A value of 0 selects a random port.  Default is 6379.");
     m.put(ENABLE_CLUSTER_CONFIGURATION,
         "Enables cluster configuration support in dedicated locators.  This allows the locator to share configuration information amongst members and save configuration changes made using GFSH.");
     m.put(ENABLE_MANAGEMENT_REST_SERVICE,
@@ -1460,6 +1440,14 @@ public abstract class AbstractDistributionConfig extends AbstractConfig
         + DEFAULT_SSL_CIPHERS + "\" meaning your provider's defaults.");
     m.put(SSL_PROTOCOLS, "List of available SSL protocols that are to be enabled. Defaults to \""
         + DEFAULT_SSL_PROTOCOLS + "\" meaning defaults of your provider.");
+    m.put(SSL_CLIENT_PROTOCOLS,
+        "List of available SSL protocols that are to be enabled on the client side of SSL socket. Defaults to \""
+            + DEFAULT_SSL_SERVER_PROTOCOLS + "\" meaning defaults of your provider" + SSL_PROTOCOLS
+            + ".");
+    m.put(SSL_SERVER_PROTOCOLS,
+        "List of available SSL protocols that are to be enabled on the server side of SSL socket. Defaults to \""
+            + DEFAULT_SSL_SERVER_PROTOCOLS + "\" meaning defaults to the value of " + SSL_PROTOCOLS
+            + ".");
     m.put(SSL_REQUIRE_AUTHENTICATION,
         "If set to false, ciphers and protocols that permit anonymous clients are allowed. Defaults to \""
             + DEFAULT_SSL_REQUIRE_AUTHENTICATION + "\".");
