@@ -39,6 +39,8 @@ import java.util.concurrent.Semaphore;
 import java.util.stream.Collectors;
 
 import org.apache.logging.log4j.Logger;
+import org.jetbrains.annotations.NotNull;
+import org.jetbrains.annotations.Nullable;
 
 import org.apache.geode.CancelCriterion;
 import org.apache.geode.CancelException;
@@ -89,18 +91,17 @@ import org.apache.geode.logging.internal.executors.LoggingUncaughtExceptionHandl
 import org.apache.geode.logging.internal.log4j.api.LogService;
 
 /**
- * The <code>DistributionManager</code> uses a {@link Membership} to distribute
- * {@link DistributionMessage messages}. It also reports on who is currently in the distributed
- * system and tracks the elder member for the distributed lock service. You may also register a
- * membership listener with the DistributionManager to receive notification of changes in
- * membership.
- *
- * <P>
+ * The <code>DistributionManager</code> uses a {@link Membership} to distribute {@link
+ * DistributionMessage messages}. It also reports on who is currently in the distributed system and
+ * tracks the elder member for the distributed lock service. You may also register a membership
+ * listener with the DistributionManager to receive notification of changes in membership.
  *
+ * <p>
+ * <p>
  * Code that wishes to send a {@link DistributionMessage} must get the
  * <code>DistributionManager</code> and invoke {@link #putOutgoing}.
  *
- * <P>
+ * <p>
  *
  * @see DistributionMessage#process
  * @see IgnoredByManager
@@ -118,25 +119,33 @@ public class ClusterDistributionManager implements DistributionManager {
   private static final int MAX_STOP_ATTEMPTS = 10;
 
 
-
   private static final boolean SYNC_EVENTS = Boolean.getBoolean("DistributionManager.syncEvents");
 
 
-  /** The DM type for regular distribution managers */
+  /**
+   * The DM type for regular distribution managers
+   */
   public static final int NORMAL_DM_TYPE = MemberIdentifier.NORMAL_DM_TYPE;
 
-  /** The DM type for locator distribution managers */
+  /**
+   * The DM type for locator distribution managers
+   */
   public static final int LOCATOR_DM_TYPE = MemberIdentifier.LOCATOR_DM_TYPE;
 
-  /** The DM type for Console (admin-only) distribution managers */
+  /**
+   * The DM type for Console (admin-only) distribution managers
+   */
   public static final int ADMIN_ONLY_DM_TYPE = MemberIdentifier.ADMIN_ONLY_DM_TYPE;
 
-  /** The DM type for stand-alone members */
+  /**
+   * The DM type for stand-alone members
+   */
   public static final int LONER_DM_TYPE = MemberIdentifier.LONER_DM_TYPE;
 
 
-
-  /** Is this node running an AdminDistributedSystem? */
+  /**
+   * Is this node running an AdminDistributedSystem?
+   */
   @MakeNotStatic
   private static volatile boolean isDedicatedAdminVM = false;
 
@@ -148,7 +157,9 @@ public class ClusterDistributionManager implements DistributionManager {
   private final Stopper stopper = new Stopper(this);
 
 
-  /** The id of this distribution manager */
+  /**
+   * The id of this distribution manager
+   */
   private final InternalDistributedMember localAddress;
 
   /**
@@ -161,7 +172,7 @@ public class ClusterDistributionManager implements DistributionManager {
    */
   private final ConcurrentMap<MembershipListener, Boolean> membershipListeners;
   private final ClusterElderManager clusterElderManager = new ClusterElderManager(this);
-  private Distribution distribution;
+  private final Distribution distribution;
   private ClusterOperationExecutors executors;
 
   /**
@@ -184,25 +195,37 @@ public class ClusterDistributionManager implements DistributionManager {
    */
   private final Object allMembershipListenersLock = new Object();
 
-  /** A queue of MemberEvent instances */
+  /**
+   * A queue of MemberEvent instances
+   */
   private final BlockingQueue<MemberEvent> membershipEventQueue = new LinkedBlockingQueue<>();
 
-  /** Used to invoke registered membership listeners in the background. */
+  /**
+   * Used to invoke registered membership listeners in the background.
+   */
   private Thread memberEventThread;
 
 
-  /** A brief description of this DistributionManager */
+  /**
+   * A brief description of this DistributionManager
+   */
   protected final String description;
 
-  /** Statistics about distribution */
+  /**
+   * Statistics about distribution
+   */
   protected final DistributionStats stats;
 
-  /** Did an exception occur in one of the DM threads? */
+  /**
+   * Did an exception occur in one of the DM threads?
+   */
   private boolean exceptionInThreads;
 
   private volatile boolean shutdownMsgSent = false;
 
-  /** Set to true when this manager is being shutdown */
+  /**
+   * Set to true when this manager is being shutdown
+   */
   private volatile boolean closeInProgress = false;
 
   private volatile boolean receivedStartupResponse = false;
@@ -225,9 +248,6 @@ public class ClusterDistributionManager implements DistributionManager {
   private Map<InternalDistributedMember, Collection<String>> hostedLocatorsWithSharedConfiguration =
       Collections.emptyMap();
 
-  /** a map keyed on InternalDistributedMember, to direct channels to other systems */
-  // protected final Map channelMap = CFactory.createCM();
-
   private volatile boolean readyForMessages = false;
 
   /**
@@ -237,16 +257,20 @@ public class ClusterDistributionManager implements DistributionManager {
   private volatile boolean readyToSendMsgs = false;
   private final Object readyToSendMsgsLock = new Object();
 
-  /** Is this distribution manager closed? */
+  /**
+   * Is this distribution manager closed?
+   */
   private volatile boolean closed = false;
 
   /**
    * The distributed system to which this distribution manager is connected.
    */
-  private InternalDistributedSystem system;
+  private final InternalDistributedSystem system;
 
-  /** The remote transport configuration for this dm */
-  private RemoteTransportConfig transport;
+  /**
+   * The remote transport configuration for this dm
+   */
+  private final RemoteTransportConfig transport;
 
   /**
    * The administration agent associated with this distribution manager.
@@ -285,7 +309,7 @@ public class ClusterDistributionManager implements DistributionManager {
 
   private final AlertingService alertingService;
 
-  private Object membersLock = new Object();
+  private final Object membersLock = new Object();
 
   ////////////////////// Static Methods //////////////////////
 
@@ -425,10 +449,10 @@ public class ClusterDistributionManager implements DistributionManager {
    * manager and executors
    *
    * @param transport The configuration for the communications transport
-   *
    */
   private ClusterDistributionManager(RemoteTransportConfig transport,
-      InternalDistributedSystem system, AlertingService alertingService,
+      InternalDistributedSystem system,
+      AlertingService alertingService,
       MembershipLocator<InternalDistributedMember> locator) {
 
     this.system = system;
@@ -475,7 +499,7 @@ public class ClusterDistributionManager implements DistributionManager {
               (logger.isInfoEnabled(LogMarker.DM_MARKER) ? sb.toString() : "")});
 
       description = "Distribution manager on " + localAddress + " started at "
-          + (new Date(System.currentTimeMillis())).toString();
+          + (new Date(System.currentTimeMillis()));
 
       finishedConstructor = true;
     } finally {
@@ -937,7 +961,6 @@ public class ClusterDistributionManager implements DistributionManager {
   }
 
 
-
   /**
    * Gets the value in {@link #hostedLocatorsAll} for a member with one or more hosted locators. The
    * value is a collection of host[port] strings. If a bind-address was used for a locator then the
@@ -956,13 +979,13 @@ public class ClusterDistributionManager implements DistributionManager {
    * Returns a copy of the map of all members hosting locators. The key is the member, and the value
    * is a collection of host[port] strings. If a bind-address was used for a locator then the form
    * is bind-addr[port].
-   *
+   * <p>
    * The member is the vm that hosts one or more locator, if another locator starts up linking to
    * this locator, it will put that member in this map as well, and this member will in the map on
    * the other locato vm as well.
-   *
+   * <p>
    * The keyset of the map are the locator vms in this cluster.
-   *
+   * <p>
    * the value is a collection of strings in case one vm can have multiple locators ????
    *
    * @since GemFire 6.6.3
@@ -1058,8 +1081,12 @@ public class ClusterDistributionManager implements DistributionManager {
         handleConsoleStartup(member);
         break;
       case LOCATOR_DM_TYPE:
+        addMemberEvent(new MemberJoinedEvent(member));
+        break;
       case NORMAL_DM_TYPE:
-        handleManagerStartup(member);
+        // Note test is under membersLock
+        stats.setNodes(getNormalDistributionManagerIds().size());
+        addMemberEvent(new MemberJoinedEvent(member));
         break;
       default:
         throw new InternalGemFireError(String.format("Unknown member type: %s",
@@ -1076,7 +1103,8 @@ public class ClusterDistributionManager implements DistributionManager {
   }
 
   @Override
-  public Set<InternalDistributedMember> putOutgoing(final DistributionMessage msg) {
+  @Nullable
+  public Set<InternalDistributedMember> putOutgoing(final @NotNull DistributionMessage msg) {
     try {
       DistributionMessageObserver observer = DistributionMessageObserver.getInstance();
       if (observer != null) {
@@ -1104,7 +1132,7 @@ public class ClusterDistributionManager implements DistributionManager {
         return;
       }
       closeInProgress = true;
-      this.distribution.setCloseInProgress();
+      distribution.setCloseInProgress();
     } // synchronized
 
     // [bruce] log shutdown at info level and with ID to balance the
@@ -1229,7 +1257,6 @@ public class ClusterDistributionManager implements DistributionManager {
 
   /**
    * Wait for the ancillary queues to exit. Kills them if they are still around.
-   *
    */
   private void forceThreadsToStop() {
     executors.forceThreadsToStop();
@@ -1241,10 +1268,14 @@ public class ClusterDistributionManager implements DistributionManager {
 
   private volatile boolean shutdownInProgress = false;
 
-  /** guard for membershipViewIdAcknowledged */
+  /**
+   * guard for membershipViewIdAcknowledged
+   */
   private final Object membershipViewIdGuard = new Object();
 
-  /** the latest view ID that has been processed by all membership listeners */
+  /**
+   * the latest view ID that has been processed by all membership listeners
+   */
   private long membershipViewIdAcknowledged;
 
   @Override
@@ -1414,7 +1445,6 @@ public class ClusterDistributionManager implements DistributionManager {
    * @see ClusterDistributionManager.MemberCrashedEvent
    * @see ClusterDistributionManager.MemberJoinedEvent
    * @see ClusterDistributionManager.MemberDepartedEvent
-   *
    */
   protected class MemberEventInvoker implements Runnable {
 
@@ -1606,7 +1636,7 @@ public class ClusterDistributionManager implements DistributionManager {
     }
     setRedundancyZone(getDistributionManagerId(), redundancyZone);
     if (logger.isDebugEnabled()) {
-      StringBuffer sb = new StringBuffer();
+      StringBuilder sb = new StringBuilder();
       sb.append("Equivalent IPs for this host: ");
       Iterator it = equivs.iterator();
       while (it.hasNext()) {
@@ -1660,7 +1690,6 @@ public class ClusterDistributionManager implements DistributionManager {
         }
       } // synchronized
 
-
       // Bug 35887:
       // If there are other members, we must receive at least _one_ response
       if (allOthers.size() != 0) { // there exist others
@@ -1680,7 +1709,7 @@ public class ClusterDistributionManager implements DistributionManager {
           throw new SystemConnectException(
               String.format(
                   "Received no connection acknowledgments from any of the %s senior cache members: %s",
-                  Integer.toString(allOthers.size()), sb.toString()));
+                  allOthers.size(), sb));
         } // and none responded
       } // there exist others
 
@@ -1698,7 +1727,8 @@ public class ClusterDistributionManager implements DistributionManager {
           logger.warn(
               "Forcing an elder join event since a startup response was not received from elder {}.",
               e);
-          handleManagerStartup(e);
+          // Note test is under membersLock
+          addMemberEvent(new MemberJoinedEvent(e));
         }
       } // an elder exists
     } // someone didn't reply
@@ -1794,21 +1824,6 @@ public class ClusterDistributionManager implements DistributionManager {
     return r;
   }
 
-  /**
-   * Makes note of a new distribution manager that has started up in the distributed cache. Invokes
-   * the appropriately listeners.
-   *
-   * @param theId The id of the distribution manager starting up
-   *
-   */
-  private void handleManagerStartup(InternalDistributedMember theId) {
-    // Note test is under membersLock
-    if (theId.getVmKind() != ClusterDistributionManager.LOCATOR_DM_TYPE) {
-      stats.incNodes(1);
-    }
-    addMemberEvent(new MemberJoinedEvent(theId));
-  }
-
   @Override
   public boolean isCurrentMember(DistributedMember id) {
     return distribution.getView().contains((InternalDistributedMember) id);
@@ -1816,7 +1831,6 @@ public class ClusterDistributionManager implements DistributionManager {
 
   /**
    * Makes note of a new console that has started up in the distributed cache.
-   *
    */
   private void handleConsoleStartup(InternalDistributedMember theId) {
     for (MembershipListener listener : allMembershipListeners) {
@@ -1846,7 +1860,6 @@ public class ClusterDistributionManager implements DistributionManager {
    *
    * @param theId The id of the console shutting down
    * @param crashed only true if we detect this id to be gone from a javagroup view
-   *
    * @see AdminConsoleDisconnectMessage#process
    */
   public void handleConsoleShutdown(InternalDistributedMember theId, boolean crashed,
@@ -1891,9 +1904,6 @@ public class ClusterDistributionManager implements DistributionManager {
     removeHostedLocators(theId);
     redundancyZones.remove(theId);
 
-    if (theId.getVmKind() != ClusterDistributionManager.LOCATOR_DM_TYPE) {
-      stats.incNodes(-1);
-    }
     String msg;
     if (memberCrashed && !shouldInhibitMembershipWarnings()) {
       msg =
@@ -1906,6 +1916,7 @@ public class ClusterDistributionManager implements DistributionManager {
     }
     logger.info(msg, new Object[] {theId, prettifyReason(reason)});
     executors.handleManagerDeparture(theId);
+    stats.setNodes(getNormalDistributionManagerIds().size());
   }
 
   private void handleManagerSuspect(InternalDistributedMember suspect,
@@ -2011,7 +2022,6 @@ public class ClusterDistributionManager implements DistributionManager {
   }
 
 
-
   /**
    * @return recipients who did not receive the message
    * @throws NotSerializableException If <codE>message</code> cannot be serialized
@@ -2232,7 +2242,9 @@ public class ClusterDistributionManager implements DistributionManager {
             Collectors.toSet());
   }
 
-  /** Returns count of members filling the specified role */
+  /**
+   * Returns count of members filling the specified role
+   */
   @Override
   public int getRoleCount(Role role) {
     int count = 0;
@@ -2249,7 +2261,9 @@ public class ClusterDistributionManager implements DistributionManager {
     return count;
   }
 
-  /** Returns true if at least one member is filling the specified role */
+  /**
+   * Returns true if at least one member is filling the specified role
+   */
   @Override
   public boolean isRolePresent(Role role) {
     Set<InternalDistributedMember> mbrs = getDistributionManagerIds();
@@ -2264,7 +2278,9 @@ public class ClusterDistributionManager implements DistributionManager {
     return false;
   }
 
-  /** Returns a set of all roles currently in the distributed system. */
+  /**
+   * Returns a set of all roles currently in the distributed system.
+   */
   @Override
   public Set<Role> getAllRoles() {
     Set<Role> allRoles = new HashSet<>();
@@ -2290,14 +2306,11 @@ public class ClusterDistributionManager implements DistributionManager {
     return distribution;
   }
 
-
   ////////////////////// Inner Classes //////////////////////
 
 
-
   /**
    * This is the listener implementation for responding from events from the Membership Manager.
-   *
    */
   static class DMListener implements
       org.apache.geode.distributed.internal.membership.api.MembershipListener<InternalDistributedMember> {
@@ -2369,9 +2382,8 @@ public class ClusterDistributionManager implements DistributionManager {
           message.setSender(theId);
           message.setCrashed(crashed);
           message.setAlertListenerExpected(true);
-          message.setIgnoreAlertListenerRemovalFailure(true); // we don't know if it was a listener
-                                                              // so
-          // don't issue a warning
+          // we don't know if it was a listener so don't issue a warning
+          message.setIgnoreAlertListenerRemovalFailure(true);
           message.setRecipient(dm.getDistributionManagerId());
           message.setReason(reason);
           dm.handleIncomingDMsg(message);
@@ -2396,7 +2408,7 @@ public class ClusterDistributionManager implements DistributionManager {
     public void viewInstalled(MembershipView view) {
       try {
         dm.handleViewInstalled(view);
-      } catch (DistributedSystemDisconnectedException se) {
+      } catch (DistributedSystemDisconnectedException ignored) {
       }
     }
 
@@ -2417,7 +2429,7 @@ public class ClusterDistributionManager implements DistributionManager {
 
   private abstract static class MemberEvent {
 
-    private InternalDistributedMember id;
+    private final InternalDistributedMember id;
 
     MemberEvent(InternalDistributedMember id) {
       this.id = id;
@@ -2471,8 +2483,6 @@ public class ClusterDistributionManager implements DistributionManager {
 
   /**
    * This is an event reflecting that a InternalDistributedMember has joined the system.
-   *
-   *
    */
   private static class MemberJoinedEvent extends MemberEvent {
     MemberJoinedEvent(InternalDistributedMember id) {
@@ -2492,7 +2502,6 @@ public class ClusterDistributionManager implements DistributionManager {
 
   /**
    * This is an event reflecting that a InternalDistributedMember has left the system.
-   *
    */
   private static class MemberDepartedEvent extends MemberEvent {
     String reason;
@@ -2516,8 +2525,6 @@ public class ClusterDistributionManager implements DistributionManager {
   /**
    * This is an event reflecting that a InternalDistributedMember has left the system in an
    * unexpected way.
-   *
-   *
    */
   private static class MemberCrashedEvent extends MemberEvent {
     String reason;
@@ -2726,13 +2733,13 @@ public class ClusterDistributionManager implements DistributionManager {
 
   @Override
   public void registerTestHook(MembershipTestHook mth) {
-    this.getDistribution().doWithViewLocked(() -> {
-      if (this.membershipTestHooks == null) {
-        this.membershipTestHooks = Collections.singletonList(mth);
+    getDistribution().doWithViewLocked(() -> {
+      if (membershipTestHooks == null) {
+        membershipTestHooks = Collections.singletonList(mth);
       } else {
-        List<MembershipTestHook> l = new ArrayList<>(this.membershipTestHooks);
+        List<MembershipTestHook> l = new ArrayList<>(membershipTestHooks);
         l.add(mth);
-        this.membershipTestHooks = l;
+        membershipTestHooks = l;
       }
       return null;
     });
@@ -2740,14 +2747,14 @@ public class ClusterDistributionManager implements DistributionManager {
 
   @Override
   public void unregisterTestHook(MembershipTestHook mth) {
-    this.getDistribution().doWithViewLocked(() -> {
-      if (this.membershipTestHooks != null) {
-        if (this.membershipTestHooks.size() == 1) {
-          this.membershipTestHooks = null;
+    getDistribution().doWithViewLocked(() -> {
+      if (membershipTestHooks != null) {
+        if (membershipTestHooks.size() == 1) {
+          membershipTestHooks = null;
         } else {
-          List<MembershipTestHook> l = new ArrayList<>(this.membershipTestHooks);
+          List<MembershipTestHook> l = new ArrayList<>(membershipTestHooks);
           l.remove(mth);
-          this.membershipTestHooks = l;
+          membershipTestHooks = l;
         }
       }
       return null;
@@ -2812,7 +2819,9 @@ public class ClusterDistributionManager implements DistributionManager {
             Collectors.toSet());
   }
 
-  /** test method to get the member IDs of all locators in the distributed system */
+  /**
+   * test method to get the member IDs of all locators in the distributed system
+   */
   public Set<InternalDistributedMember> getLocatorDistributionManagerIds() {
     return distribution.getMembersNotShuttingDown().stream()
         .filter((id) -> id.getVmKind() == LOCATOR_DM_TYPE).collect(
@@ -2846,7 +2855,7 @@ public class ClusterDistributionManager implements DistributionManager {
 
 
   private static class Stopper extends CancelCriterion {
-    private ClusterDistributionManager dm;
+    private final ClusterDistributionManager dm;
 
     Stopper(ClusterDistributionManager dm) {
       this.dm = dm;
@@ -2860,10 +2869,10 @@ public class ClusterDistributionManager implements DistributionManager {
 
       if (dm.shutdownMsgSent) {
         return String.format("%s: Message distribution has terminated",
-            dm.toString());
+            dm);
       }
       if (dm.rootCause != null) {
-        return dm.toString() + ": " + dm.rootCause.getMessage();
+        return dm + ": " + dm.rootCause.getMessage();
       }
 
       // Nope.
