@@ -47,16 +47,14 @@ import org.apache.geode.logging.internal.log4j.api.LogService;
 /**
  * <P>
  * A <code>DistributionMessage</code> carries some piece of information to a distribution manager.
- * </P>
- *
- * <P>
+ * <p>
  * Messages that don't have strict ordering requirements should extend
  * {@link org.apache.geode.distributed.internal.PooledDistributionMessage}. Messages that must be
  * processed serially in the order they were received can extend
  * {@link org.apache.geode.distributed.internal.SerialDistributionMessage}. To customize the
  * sequentialness/thread requirements of a message, extend DistributionMessage and implement
  * getExecutor().
- * </P>
+ * <p>
  */
 public abstract class DistributionMessage
     implements Message<InternalDistributedMember>, Cloneable {
@@ -87,8 +85,14 @@ public abstract class DistributionMessage
   protected static final short HAS_TX_ID = 0x4;
   /** Flag set when this message is a possible duplicate. */
   protected static final short POS_DUP = 0x8;
-  /** Indicate time statistics capturing as part of this message processing */
-  protected static final short ENABLE_TIMESTATS = 0x10;
+  /**
+   * Indicate time statistics capturing as part of this message processing
+   *
+   * @deprecated no replacement
+   */
+  @SuppressWarnings("unused") // kept for documentation only
+  @Deprecated
+  private static final short ENABLE_TIMESTATS = 0x10;
   /** If message sender has set the processor type to be used explicitly. */
   protected static final short HAS_PROCESSOR_TYPE = 0x20;
 
@@ -128,7 +132,7 @@ public abstract class DistributionMessage
   ////////////////////// Constructors //////////////////////
 
   protected DistributionMessage() {
-    this.timeStamp = DistributionStats.getStatTime();
+    timeStamp = DistributionStats.getStatTime();
   }
 
   ////////////////////// Static Helper Methods //////////////////////
@@ -165,7 +169,7 @@ public abstract class DistributionMessage
   ////////////////////// Instance Methods //////////////////////
 
   public void setDoDecMessagesBeingReceived(boolean v) {
-    this.doDecMessagesBeingReceived = v;
+    doDecMessagesBeingReceived = v;
   }
 
   public void setReplySender(ReplySender acker) {
@@ -214,12 +218,12 @@ public abstract class DistributionMessage
    * message will be sent to all distribution managers.
    */
   public void setRecipient(InternalDistributedMember recipient) {
-    if (this.recipients != null) {
+    if (recipients != null) {
       throw new IllegalStateException(
           "Recipients can only be set once");
     }
 
-    this.recipients = Collections.singletonList(recipient);
+    recipients = Collections.singletonList(recipient);
   }
 
   /**
@@ -228,7 +232,7 @@ public abstract class DistributionMessage
    * @since GemFire 5.0
    */
   public void setMulticast(boolean v) {
-    this.multicast = v;
+    multicast = v;
   }
 
   /**
@@ -237,7 +241,7 @@ public abstract class DistributionMessage
    * @since GemFire 5.0
    */
   public boolean getMulticast() {
-    return this.multicast;
+    return multicast;
   }
 
   /**
@@ -279,29 +283,29 @@ public abstract class DistributionMessage
   }
 
   public void resetRecipients() {
-    this.recipients = null;
-    this.multicast = false;
+    recipients = null;
+    multicast = false;
   }
 
   /**
    * Returns true if message will be sent to everyone.
    */
   public boolean forAll() {
-    return (this.recipients == null) || (this.multicast)
-        || ((!this.recipients.isEmpty()) && (this.recipients.get(0) == ALL_RECIPIENTS));
+    return (recipients == null) || (multicast)
+        || ((!recipients.isEmpty()) && (recipients.get(0) == ALL_RECIPIENTS));
   }
 
   public String getRecipientsDescription() {
     if (forAll()) {
       return "recipients: ALL";
     } else {
-      StringBuffer sb = new StringBuffer(100);
+      StringBuilder sb = new StringBuilder(100);
       sb.append("recipients: <");
-      for (int i = 0; i < this.recipients.size(); i++) {
+      for (int i = 0; i < recipients.size(); i++) {
         if (i != 0) {
           sb.append(", ");
         }
-        sb.append(this.recipients.get(i));
+        sb.append(recipients.get(i));
       }
       sb.append(">");
 
@@ -314,7 +318,7 @@ public abstract class DistributionMessage
    * received by a distribution manager.
    */
   public InternalDistributedMember getSender() {
-    return this.sender;
+    return sender;
   }
 
   /**
@@ -323,7 +327,7 @@ public abstract class DistributionMessage
    */
   @Override
   public void setSender(InternalDistributedMember _sender) {
-    this.sender = _sender;
+    sender = _sender;
   }
 
   /**
@@ -396,7 +400,7 @@ public abstract class DistributionMessage
       logger.fatal(String.format("Uncaught exception processing %s", this), t);
     } finally {
       if (doDecMessagesBeingReceived) {
-        dm.getStats().decMessagesBeingReceived(this.bytesRead);
+        dm.getStats().decMessagesBeingReceived(bytesRead);
       }
       dm.getStats().incProcessedMessages(1L);
       if (DistributionStats.enableClockStats) {
@@ -415,7 +419,7 @@ public abstract class DistributionMessage
         && getProcessorType() == OperationExecutors.SERIAL_EXECUTOR
         && !isMembershipMessengerThread();
 
-    boolean forceInline = this.acker != null || getInlineProcess() || Connection.isDominoThread();
+    boolean forceInline = acker != null || getInlineProcess() || Connection.isDominoThread();
 
     if (inlineProcess && !forceInline && isSharedReceiver()) {
       // If processing this message notify a serial gateway sender then don't do it inline.
@@ -435,7 +439,7 @@ public abstract class DistributionMessage
       }
     } else { // not inline
       try {
-        getExecutor(dm).execute(new SizeableRunnable(this.getBytesRead()) {
+        getExecutor(dm).execute(new SizeableRunnable(getBytesRead()) {
           @Override
           public void run() {
             scheduleAction(dm);
@@ -443,12 +447,12 @@ public abstract class DistributionMessage
 
           @Override
           public String toString() {
-            return "Processing {" + DistributionMessage.this.toString() + "}";
+            return "Processing {" + DistributionMessage.this + "}";
           }
         });
       } catch (RejectedExecutionException ex) {
-        if (!dm.shutdownInProgress()) { // fix for bug 32395
-          logger.warn(String.format("%s schedule() rejected", this.toString()), ex);
+        if (!dm.shutdownInProgress()) {
+          logger.warn(String.format("%s schedule() rejected", this), ex);
         }
       } catch (VirtualMachineError err) {
         SystemFailure.initiateFailure(err);
@@ -503,27 +507,34 @@ public abstract class DistributionMessage
    */
   public void setBreadcrumbsInReceiver() {
     if (Breadcrumbs.ENABLED) {
-      String sender = null;
-      String procId = "";
-      long pid = getProcessorId();
-      if (pid != 0) {
-        procId = " processorId=" + pid;
-      }
-      if (Thread.currentThread().getName().startsWith(Connection.THREAD_KIND_IDENTIFIER)) {
-        sender = procId;
-      } else {
-        sender = "sender=" + getSender() + procId;
-      }
+      final String procId = getProcId();
+      final String sender = getSender(procId);
       if (sender.length() > 0) {
         Breadcrumbs.setReceiveSide(sender);
       }
-      Object evID = getEventID();
+      final Object evID = getEventID();
       if (evID != null) {
         Breadcrumbs.setEventId(evID);
       }
     }
   }
 
+  private String getSender(final String procId) {
+    if (Thread.currentThread().getName().startsWith(Connection.THREAD_KIND_IDENTIFIER)) {
+      return procId;
+    }
+
+    return "sender=" + getSender() + procId;
+  }
+
+  private String getProcId() {
+    final long pid = getProcessorId();
+    if (pid != 0) {
+      return " processorId=" + pid;
+    }
+    return "";
+  }
+
   /**
    * sets breadcrumbs in a thread that is sending a message to another member
    */
@@ -535,7 +546,7 @@ public abstract class DistributionMessage
         procId = "processorId=" + pid;
       }
 
-      if (this.recipients != null && this.recipients.size() <= 10) { // set a limit on recipients
+      if (recipients != null && recipients.size() <= 10) { // set a limit on recipients
         Breadcrumbs.setSendSide(procId + " recipients=" + getRecipients());
       } else {
         if (procId.length() > 0) {
@@ -560,7 +571,7 @@ public abstract class DistributionMessage
    */
   public void reset() {
     resetRecipients();
-    this.sender = null;
+    sender = null;
   }
 
   /**
@@ -607,8 +618,8 @@ public abstract class DistributionMessage
   public long resetTimestamp() {
     if (DistributionStats.enableClockStats) {
       long now = DistributionStats.getStatTime();
-      long result = now - this.timeStamp;
-      this.timeStamp = now;
+      long result = now - timeStamp;
+      timeStamp = now;
       return result;
     } else {
       return 0;
@@ -624,11 +635,11 @@ public abstract class DistributionMessage
   }
 
   public void setSharedReceiver(boolean v) {
-    this.sharedReceiver = v;
+    sharedReceiver = v;
   }
 
   public boolean isSharedReceiver() {
-    return this.sharedReceiver;
+    return sharedReceiver;
   }
 
   /**
@@ -692,11 +703,9 @@ public abstract class DistributionMessage
   @Override
   public String toString() {
     String cname = getShortClassName();
-    final StringBuilder sb = new StringBuilder(cname);
-    sb.append('@').append(Integer.toHexString(System.identityHashCode(this)));
-    sb.append(" processorId=").append(getProcessorId());
-    sb.append(" sender=").append(getSender());
-    return sb.toString();
+    return cname + '@' + Integer.toHexString(System.identityHashCode(this))
+        + " processorId=" + getProcessorId()
+        + " sender=" + getSender();
   }
 
   @Override
