@@ -67,7 +67,6 @@ import org.apache.geode.distributed.ConfigurationPersistenceService;
 import org.apache.geode.distributed.DistributedLockService;
 import org.apache.geode.distributed.DistributedMember;
 import org.apache.geode.distributed.internal.locks.DLockService;
-import org.apache.geode.internal.JarDeployer;
 import org.apache.geode.internal.cache.ClusterConfigurationLoader;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.InternalRegionFactory;
@@ -85,6 +84,7 @@ import org.apache.geode.management.internal.configuration.domain.XmlEntity;
 import org.apache.geode.management.internal.configuration.messages.ConfigurationResponse;
 import org.apache.geode.management.internal.configuration.messages.SharedConfigurationStatusResponse;
 import org.apache.geode.management.internal.configuration.utils.XmlUtils;
+import org.apache.geode.management.internal.utils.JarFileUtils;
 import org.apache.geode.security.AuthenticationRequiredException;
 
 public class InternalConfigurationPersistenceService implements ConfigurationPersistenceService {
@@ -273,8 +273,8 @@ public class InternalConfigurationPersistenceService implements ConfigurationPer
   }
 
   @VisibleForTesting
-  void addJarsToThisLocator(String deployedBy, String deployedTime,
-      List<String> jarFullPaths, String[] groups) throws IOException {
+  void addJarsToThisLocator(String deployedBy, String deployedTime, List<String> jarFullPaths,
+      String[] groups) throws IOException {
     lockSharedConfiguration();
     try {
       addJarsToGroups(listOf(groups), jarFullPaths, deployedBy, deployedTime);
@@ -291,7 +291,8 @@ public class InternalConfigurationPersistenceService implements ConfigurationPer
     }
   }
 
-  private void addJarsToGroupConfig(String group, List<String> jarFullPaths, String deployedBy,
+  private void addJarsToGroupConfig(String group, List<String> jarFullPaths,
+      String deployedBy,
       String deployedTime) throws IOException {
     Region<String, Configuration> configRegion = getConfigurationRegion();
     Configuration configuration = getConfigurationCopy(configRegion, group);
@@ -328,12 +329,12 @@ public class InternalConfigurationPersistenceService implements ConfigurationPer
   }
 
   private static void removeOtherVersionsOf(Path groupDir, String jarFileName) {
-    String artifactId = JarDeployer.getArtifactId(jarFileName);
+    String artifactId = JarFileUtils.getArtifactId(jarFileName);
     for (File file : groupDir.toFile().listFiles()) {
       if (file.getName().equals(jarFileName)) {
         continue;
       }
-      if (JarDeployer.getArtifactId(file.getName()).equals(artifactId)) {
+      if (JarFileUtils.getArtifactId(file.getName()).equals(artifactId)) {
         FileUtils.deleteQuietly(file);
       }
     }
@@ -373,22 +374,28 @@ public class InternalConfigurationPersistenceService implements ConfigurationPer
           break;
         }
 
-        for (String jarRemoved : jarNames) {
-          File jar = getPathToJarOnThisLocator(group, jarRemoved).toFile();
+        logger.debug("Configuration before removing deployment: " + configuration);
+        Configuration configurationCopy = new Configuration(configuration);
+
+        for (String jarName : jarNames) {
+          File jar = getPathToJarOnThisLocator(group, jarName).toFile();
           if (jar.exists()) {
             try {
               FileUtils.forceDelete(jar);
+              logger.debug("Successfully deleted: " + jar.getName());
+              configurationCopy
+                  .removeDeployments(Collections.singleton(jarName));
+              logger.debug("deploymentToRemove.getKey(): " + jarName);
             } catch (IOException e) {
               logger.error(
                   "Exception occurred while attempting to delete a jar from the filesystem: {}",
-                  jarRemoved, e);
+                  jarName, e);
             }
           }
         }
-
-        Configuration configurationCopy = new Configuration(configuration);
-        configurationCopy.removeJarNames(jarNames);
         configRegion.put(group, configurationCopy);
+        logger.debug("Configuration updated for group: " + group);
+        logger.debug("Configuration after removing deployment: " + configurationCopy);
       }
     } catch (Exception e) {
       logger.info("Exception occurred while deleting the jar files", e);
@@ -694,10 +701,8 @@ public class InternalConfigurationPersistenceService implements ConfigurationPer
     lockSharedConfiguration();
     try {
       File[] groupNames = configDir.listFiles((FileFilter) DirectoryFileFilter.INSTANCE);
-      boolean needToCopyJars = true;
-      if (configDir.getAbsolutePath().equals(configDirPath.toAbsolutePath().toString())) {
-        needToCopyJars = false;
-      }
+      boolean needToCopyJars =
+          !configDir.getAbsolutePath().equals(configDirPath.toAbsolutePath().toString());
 
       logger.info("loading the cluster configuration: ");
       Map<String, Configuration> sharedConfiguration = new HashMap<>();
