@@ -14,12 +14,12 @@
  */
 package org.apache.geode.distributed.internal;
 
+import static java.util.Collections.singleton;
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
 import static org.apache.commons.lang3.exception.ExceptionUtils.getStackTrace;
 import static org.apache.geode.distributed.ConfigurationProperties.BIND_ADDRESS;
 import static org.apache.geode.distributed.ConfigurationProperties.CACHE_XML_FILE;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
-import static org.apache.geode.internal.admin.remote.DistributionLocatorId.asDistributionLocatorIds;
 import static org.apache.geode.util.internal.GeodeGlossary.GEMFIRE_PREFIX;
 
 import java.io.File;
@@ -32,6 +32,7 @@ import java.nio.file.Paths;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
@@ -45,6 +46,7 @@ import java.util.function.Supplier;
 
 import org.apache.commons.lang3.StringUtils;
 import org.apache.logging.log4j.Logger;
+import org.jetbrains.annotations.Nullable;
 
 import org.apache.geode.CancelException;
 import org.apache.geode.GemFireConfigException;
@@ -64,12 +66,15 @@ import org.apache.geode.distributed.Locator;
 import org.apache.geode.distributed.internal.InternalDistributedSystem.ConnectListener;
 import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
 import org.apache.geode.distributed.internal.membership.adapter.ServiceConfig;
+import org.apache.geode.distributed.internal.membership.api.LocatorConfigurationParser;
 import org.apache.geode.distributed.internal.membership.api.MemberIdentifier;
 import org.apache.geode.distributed.internal.membership.api.MembershipConfig;
 import org.apache.geode.distributed.internal.membership.api.MembershipConfigurationException;
 import org.apache.geode.distributed.internal.membership.api.MembershipLocator;
 import org.apache.geode.distributed.internal.membership.api.MembershipLocatorBuilder;
 import org.apache.geode.distributed.internal.membership.api.QuorumChecker;
+import org.apache.geode.distributed.internal.tcpserver.HostAddress;
+import org.apache.geode.distributed.internal.tcpserver.HostAndPort;
 import org.apache.geode.distributed.internal.tcpserver.InfoRequest;
 import org.apache.geode.distributed.internal.tcpserver.TcpHandler;
 import org.apache.geode.distributed.internal.tcpserver.TcpServer;
@@ -82,7 +87,6 @@ import org.apache.geode.internal.admin.remote.RemoteTransportConfig;
 import org.apache.geode.internal.cache.GemFireCacheImpl;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.InternalCacheBuilder;
-import org.apache.geode.internal.cache.client.protocol.ClientProtocolServiceLoader;
 import org.apache.geode.internal.cache.wan.WANServiceProvider;
 import org.apache.geode.internal.config.JAXBService;
 import org.apache.geode.internal.inet.LocalHostUtil;
@@ -203,15 +207,11 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
    */
   private InternalCache internalCache;
 
-  /**
-   * product use logging
-   */
-  private ProductUseLog productUseLog;
   private boolean peerLocator;
   private ServerLocator serverLocator;
   private Properties env;
 
-  private DistributionConfigImpl distributionConfig;
+  private final DistributionConfigImpl distributionConfig;
   private WanLocatorDiscoverer locatorDiscoverer;
   private InternalConfigurationPersistenceService configurationPersistenceService;
   private ClusterManagementService clusterManagementService;
@@ -219,7 +219,7 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
   // restart at a time
   private final Object servicesRestartLock = new Object();
 
-  public static InternalLocator getLocator() {
+  public static @Nullable InternalLocator getLocator() {
     synchronized (locatorLock) {
       return locator;
     }
@@ -262,13 +262,16 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
    * @param startDistributedSystem if true then this locator will also start its own ds
    *
    * @deprecated Please use
-   *             {@link #createLocator(int, LoggingSession, File, InternalLogWriter, InternalLogWriter, InetAddress, String, Properties, Path)}
+   *             {@link #createLocator(int, LoggingSession, File, InternalLogWriter, InternalLogWriter, HostAddress, String, Properties, Path)}
    *             instead.
    */
   @Deprecated
   public static InternalLocator createLocator(int port, LoggingSession loggingSession, File logFile,
-      InternalLogWriter logWriter, InternalLogWriter securityLogWriter, InetAddress bindAddress,
-      String hostnameForClients, Properties distributedSystemProperties,
+      InternalLogWriter logWriter,
+      InternalLogWriter securityLogWriter,
+      HostAddress bindAddress,
+      String hostnameForClients,
+      Properties distributedSystemProperties,
       boolean startDistributedSystem) {
     return createLocator(port, loggingSession, logFile, logWriter, securityLogWriter, bindAddress,
         hostnameForClients, distributedSystemProperties,
@@ -286,13 +289,18 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
    * @param logFile the file that log messages should be written to
    * @param logWriter a log writer that should be used (logFile parameter is ignored)
    * @param securityLogWriter the logWriter to be used for security related log messages
+   * @param bindAddress the bind address for the locator
    * @param distributedSystemProperties optional properties to configure the distributed system
    *        (e.g., mcast addr/port, other locators)
    * @param workingDirectory the working directory to use for any files
    */
   public static InternalLocator createLocator(int port, LoggingSession loggingSession, File logFile,
-      InternalLogWriter logWriter, InternalLogWriter securityLogWriter, InetAddress bindAddress,
-      String hostnameForClients, Properties distributedSystemProperties, Path workingDirectory) {
+      InternalLogWriter logWriter,
+      InternalLogWriter securityLogWriter,
+      HostAddress bindAddress,
+      String hostnameForClients,
+      Properties distributedSystemProperties,
+      Path workingDirectory) {
     synchronized (locatorLock) {
       if (hasLocator()) {
         throw new IllegalStateException(
@@ -336,7 +344,7 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
    * @param hostnameForClients the name to give to clients for connecting to this locator
    */
   public static InternalLocator startLocator(int port, File logFile, InternalLogWriter logWriter,
-      InternalLogWriter securityLogWriter, InetAddress bindAddress, boolean startDistributedSystem,
+      InternalLogWriter securityLogWriter, HostAddress bindAddress, boolean startDistributedSystem,
       Properties distributedSystemProperties, String hostnameForClients)
       throws IOException {
     return startLocator(port, logFile, logWriter, securityLogWriter, bindAddress,
@@ -355,6 +363,7 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
    * @param logFile the file that log messages should be written to
    * @param logWriter a log writer that should be used (logFile parameter is ignored)
    * @param securityLogWriter the logWriter to be used for security related log messages
+   * @param bindAddress the bind address for the locator
    * @param startDistributedSystem if true, a distributed system is started
    * @param distributedSystemProperties optional properties to configure the distributed system
    *        (e.g., mcast
@@ -363,8 +372,11 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
    * @param workingDirectory the working directory to use for any files
    */
   public static InternalLocator startLocator(int port, File logFile, InternalLogWriter logWriter,
-      InternalLogWriter securityLogWriter, InetAddress bindAddress, boolean startDistributedSystem,
-      Properties distributedSystemProperties, String hostnameForClients, Path workingDirectory)
+      InternalLogWriter securityLogWriter,
+      HostAddress bindAddress,
+      boolean startDistributedSystem,
+      Properties distributedSystemProperties,
+      String hostnameForClients, Path workingDirectory)
       throws IOException {
     System.setProperty(FORCE_LOCATOR_DM_TYPE, "true");
     InternalLocator newLocator = null;
@@ -469,11 +481,17 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
    */
   @VisibleForTesting
   InternalLocator(int port, LoggingSession loggingSession, File logFile,
-      InternalLogWriter logWriter, InternalLogWriter securityLogWriter, InetAddress bindAddress,
-      String hostnameForClients, Properties distributedSystemProperties,
+      InternalLogWriter logWriter, InternalLogWriter securityLogWriter,
+      HostAddress hostAddress, String hostnameForClients,
+      Properties distributedSystemProperties,
       DistributionConfigImpl distributionConfig, Path workingDirectory) {
     this.logFile = logFile;
-    this.bindAddress = bindAddress;
+    this.hostAddress = hostAddress;
+    // bindAddress is superceded by hostAddress but must be kept for Locator API backward
+    // compatibility
+    if (hostAddress != null) {
+      bindAddress = hostAddress.getAddress();
+    }
     this.hostnameForClients = hostnameForClients;
 
     this.workingDirectory = workingDirectory;
@@ -483,8 +501,8 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
 
     // set bind-address explicitly only if not wildcard and let any explicit
     // value in distributedSystemProperties take precedence
-    if (bindAddress != null && !bindAddress.isAnyLocalAddress()) {
-      env.setProperty(BIND_ADDRESS, bindAddress.getHostAddress());
+    if (hostAddress != null) {
+      env.setProperty(BIND_ADDRESS, hostAddress.getHostName());
     }
 
     if (distributedSystemProperties != null) {
@@ -535,6 +553,7 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
       // We defer setting the port until the handler is init'd - that way we'll have an actual port
       // in the case where we're starting with port = 0.
       locatorListener.setConfig(getConfig());
+      locatorListener.start();
     }
 
     locatorStats = new LocatorStats();
@@ -558,8 +577,8 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
               executor)
               .setConfig(config)
               .setPort(port)
-              .setBindAddress(bindAddress)
-              .setProtocolChecker(new ProtocolCheckerImpl(this, new ClientProtocolServiceLoader()))
+              .setBindAddress(hostAddress)
+              .setProtocolChecker(new ProtocolCheckerImpl())
               .setFallbackHandler(handler)
               .setLocatorsAreCoordinators(shouldLocatorsBeCoordinators())
               .setLocatorStats(locatorStats)
@@ -636,13 +655,7 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
     logger.info("Starting peer location for {}", this);
 
     peerLocator = true;
-    int boundPort =
-        membershipLocator
-            .start();
-    File productUseFile = workingDirectory.resolve("locator" + boundPort + "views.log").toFile();
-    productUseLog = new ProductUseLog(productUseFile);
-
-    return boundPort;
+    return membershipLocator.start();
   }
 
   private boolean shouldLocatorsBeCoordinators() {
@@ -678,7 +691,7 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
    */
   @Deprecated
   public static InternalLocator startLocator(int locatorPort, File logFile,
-      InternalLogWriter logWriter, InternalLogWriter securityLogWriter, InetAddress bindAddress,
+      InternalLogWriter logWriter, InternalLogWriter securityLogWriter, HostAddress bindAddress,
       Properties distributedSystemProperties, boolean peerLocator, boolean serverLocator,
       String hostnameForClients, boolean b1) throws IOException {
     return startLocator(locatorPort, logFile, logWriter, securityLogWriter, bindAddress, true,
@@ -698,71 +711,102 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
       // LOG: changed from config to info
       logger.info("Using existing distributed system: {}", existing);
       startCache(existing);
+      return;
+    }
+
+    HostAddress thisLocator = getHostAddress(hostAddress);
+    if (peerLocator) {
+      String existingLocators = distributionConfig.getLocators();
+      String newLocators = addLocatorIfMissing(existingLocators, thisLocator, getPort());
+      if (!newLocators.equals(existingLocators)) {
+        setLocatorProperties(newLocators);
+      }
+    }
+
+    Properties distributedSystemProperties = new Properties();
+    // LogWriterAppender is now shared via that class
+    // using a DistributionConfig earlier in this method
+    distributedSystemProperties.put(DistributionConfig.DS_CONFIG_NAME, distributionConfig);
+
+    logger.info("Starting distributed system");
+
+    internalDistributedSystem =
+        InternalDistributedSystem
+            .connectInternal(distributedSystemProperties, null,
+                new InternalDistributedSystemMetricsService.Builder(),
+                membershipLocator);
+
+    if (peerLocator) {
+      // We've created a peer location message handler - it needs to be connected to
+      // the membership service in order to get membership view notifications
+      membershipLocator
+          .setMembership(internalDistributedSystem.getDM()
+              .getDistribution().getMembership());
+    }
+
+    internalDistributedSystem.addDisconnectListener(sys -> stop(false, false, false));
+
+    startCache(internalDistributedSystem);
+
+    logger.info("Locator started on {}[{}]", thisLocator, getPort());
+
+  }
+
+  HostAddress getHostAddress(HostAddress hostAddress) throws UnknownHostException {
+    HostAddress thisLocator;
+    if (hostAddress != null && !StringUtils.isEmpty(hostAddress.getHostName())) {
+      thisLocator = hostAddress;
     } else {
+      thisLocator = new HostAddress(LocalHostUtil.getLocalHost());
+    }
+    return thisLocator;
+  }
 
-      StringBuilder sb = new StringBuilder(100);
-      if (bindAddress != null) {
-        sb.append(bindAddress.getHostAddress());
-      } else {
-        sb.append(LocalHostUtil.getLocalHost().getCanonicalHostName());
-      }
-      sb.append('[').append(getPort()).append(']');
-      String thisLocator = sb.toString();
+  /**
+   * add this locator to the locators list if not already in, note the locator's
+   * hostname is used, but if it resoves to be the same as what's already in the
+   * list, what's specified by the user is preserved
+   *
+   * @param existingLocators the existing configured locators
+   * @param thisLocator this locator's address
+   * @param port this locator's port
+   * @return the comma separated list of locators with this locator added
+   *         if this locator is not already in the list
+   */
+  String addLocatorIfMissing(String existingLocators, HostAddress thisLocator, int port)
+      throws IOException {
+    String thisLocatorHostnameAndPort = String.format("%s[%d]", thisLocator.getHostName(), port);
+    if (StringUtils.isBlank(existingLocators)) {
+      return thisLocatorHostnameAndPort;
+    }
 
-      if (peerLocator) {
-        // append this locator to the locators list from the config properties
-        boolean setLocatorsProp = false;
-        String locatorsConfigValue = distributionConfig.getLocators();
-        if (StringUtils.isNotBlank(locatorsConfigValue)) {
-          if (!locatorsConfigValue.contains(thisLocator)) {
-            locatorsConfigValue = locatorsConfigValue + ',' + thisLocator;
-            setLocatorsProp = true;
-          }
-        } else {
-          locatorsConfigValue = thisLocator;
-          setLocatorsProp = true;
-        }
-        if (setLocatorsProp) {
-          Properties updateEnv = new Properties();
-          updateEnv.setProperty(LOCATORS, locatorsConfigValue);
-          distributionConfig.setApiProps(updateEnv);
-          String locatorsPropertyName = GEMFIRE_PREFIX + LOCATORS;
-          if (System.getProperty(locatorsPropertyName) != null) {
-            System.setProperty(locatorsPropertyName, locatorsConfigValue);
-          }
-        }
-        // No longer default mcast-port to zero.
-      }
+    List<HostAndPort> hostAndPorts;
+    try {
+      hostAndPorts = LocatorConfigurationParser.parseLocators(existingLocators, (InetAddress) null);
+    } catch (MembershipConfigurationException e) {
+      throw new IOException(e.getMessage(), e);
+    }
 
-      Properties distributedSystemProperties = new Properties();
-      // LogWriterAppender is now shared via that class
-      // using a DistributionConfig earlier in this method
-      distributedSystemProperties.put(DistributionConfig.DS_CONFIG_NAME, distributionConfig);
+    if (hostAndPorts.stream().anyMatch(
+        (hp) -> thisLocator.getAddress().equals(hp.getAddress())
+            && port == hp.getPort())) {
+      return existingLocators;
+    }
+    // if not found in existing locators
+    return existingLocators + "," + thisLocatorHostnameAndPort;
+  }
 
-      logger.info("Starting distributed system");
-
-      internalDistributedSystem =
-          InternalDistributedSystem
-              .connectInternal(distributedSystemProperties, null,
-                  new InternalDistributedSystemMetricsService.Builder(),
-                  membershipLocator);
-
-      if (peerLocator) {
-        // We've created a peer location message handler - it needs to be connected to
-        // the membership service in order to get membership view notifications
-        membershipLocator
-            .setMembership(internalDistributedSystem.getDM()
-                .getDistribution().getMembership());
-      }
-
-      internalDistributedSystem.addDisconnectListener(sys -> stop(false, false, false));
-
-      startCache(internalDistributedSystem);
-
-      logger.info("Locator started on {}", thisLocator);
+  private void setLocatorProperties(String locatorsConfigValue) {
+    Properties updateEnv = new Properties();
+    updateEnv.setProperty(LOCATORS, locatorsConfigValue);
+    distributionConfig.setApiProps(updateEnv);
+    String locatorsPropertyName = GEMFIRE_PREFIX + LOCATORS;
+    if (System.getProperty(locatorsPropertyName) != null) {
+      System.setProperty(locatorsPropertyName, locatorsConfigValue);
     }
   }
 
+
   private void startCache(DistributedSystem system) throws IOException {
     InternalCache internalCache = GemFireCacheImpl.getInstance();
     if (internalCache == null) {
@@ -891,8 +935,9 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
       }
     }
 
-    ServerLocator serverLocator = new ServerLocator(getPort(), bindAddress, hostnameForClients,
-        logFile, productUseLog, getConfig().getName(), distributedSystem, locatorStats);
+    ServerLocator serverLocator =
+        new ServerLocator(getPort(), getBindAddressString(), hostnameForClients,
+            logFile, getConfig().getName(), distributedSystem, locatorStats);
     restartHandlers.add(serverLocator);
     membershipLocator.addHandler(LocatorListRequest.class, serverLocator);
     membershipLocator.addHandler(ClientConnectionRequest.class, serverLocator);
@@ -905,9 +950,6 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
     if (!membershipLocator.isAlive()) {
       startTcpServer();
     }
-    // the product use is not guaranteed to be initialized until the server is started, so
-    // the last thing we do is tell it to start logging
-    productUseLog.monitorUse(distributedSystem);
   }
 
   /**
@@ -993,9 +1035,6 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
       // already shutdown
       return;
     }
-    if (productUseLog != null) {
-      productUseLog.close();
-    }
     if (internalCache != null && !stoppedForReconnect && !forcedDisconnect) {
       logger.info("Closing locator's cache");
       try {
@@ -1011,6 +1050,7 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
 
     if (locatorListener != null) {
       locatorListener.clearLocatorInfo();
+      locatorListener.stop();
     }
 
     isSharedConfigurationStarted = false;
@@ -1195,10 +1235,6 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
       logger.info("Locator restart: initializing TcpServer peer location services");
       membershipLocator.restarting();
 
-      if (productUseLog.isClosed()) {
-        productUseLog.reopen();
-      }
-
       if (!membershipLocator.isAlive()) {
         logger.info("Locator restart: starting TcpServer");
         startTcpServer();
@@ -1229,11 +1265,6 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
       throw e;
     }
 
-    if (productUseLog.isClosed()) {
-      productUseLog.reopen();
-    }
-    productUseLog.monitorUse(newSystem);
-
     if (isSharedConfigurationEnabled()) {
       configurationPersistenceService =
           new InternalConfigurationPersistenceService(newCache, workingDirectory,
@@ -1347,20 +1378,18 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
    * Returns collection of locator strings representing every locator instance hosted by this
    * member.
    *
-   * @see #getLocators()
+   * @see #getLocator()
    */
-  public static Collection<String> getLocatorStrings() {
-    Collection<String> locatorStrings;
+  public static @Nullable Collection<String> getLocatorStrings() {
     try {
-      Collection<DistributionLocatorId> locatorIds = asDistributionLocatorIds(getLocators());
-      locatorStrings = DistributionLocatorId.asStrings(locatorIds);
+      final InternalLocator locator = getLocator();
+      if (null != locator) {
+        return singleton(
+            new DistributionLocatorId(LocalHostUtil.getLocalHost(), locator).marshal());
+      }
     } catch (UnknownHostException ignored) {
-      locatorStrings = null;
     }
-    if (locatorStrings == null || locatorStrings.isEmpty()) {
-      return null;
-    }
-    return locatorStrings;
+    return null;
   }
 
   private void startConfigurationPersistenceService() throws IOException {
@@ -1430,6 +1459,13 @@ public class InternalLocator extends Locator implements ConnectListener, LogConf
     return membershipLocator.isHandled(messageClass);
   }
 
+  public String getBindAddressString() {
+    if (hostAddress != null) {
+      return hostAddress.getHostName();
+    }
+    return null;
+  }
+
   class FetchSharedConfigStatus implements Callable<SharedConfigurationStatusResponse> {
 
     @Override
