@@ -65,7 +65,7 @@ public class LocatorLoadSnapshot {
    * a less loaded server until imbalance reaches this threshold. Then we aggressively move clients
    * until balance is achieved.
    */
-  private float loadImbalanceThreshold;
+  private final float loadImbalanceThreshold;
 
   /**
    * when the loadImbalanceThreshold is hit this variable will be true and it will remain true until
@@ -202,11 +202,10 @@ public class LocatorLoadSnapshot {
    * imbalance is greater than the loadImbalanceThreshold.
    * <p>
    * When the threshold is reached we report imbalance until proper balance is achieved.
-   * </p>
    * <p>
    * This method has the side-effect of setting the <code>rebalancing</code> instance variable
    * which, at the time of this writing, is only used by this method.
-   * </p>
+   * <p>
    */
   private synchronized boolean thresholdCheck(float bestLoad, float worstLoad,
       float largestLoadPerConnection, boolean balanced) {
