@@ -18,7 +18,6 @@ import java.net.UnknownHostException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
@@ -28,6 +27,9 @@ import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.TimeUnit;
 
+import org.jetbrains.annotations.NotNull;
+import org.jetbrains.annotations.Nullable;
+
 import org.apache.geode.CancelCriterion;
 import org.apache.geode.InternalGemFireError;
 import org.apache.geode.admin.GemFireHealthConfig;
@@ -81,19 +83,19 @@ public class LonerDistributionManager implements DistributionManager {
   public LonerDistributionManager(InternalDistributedSystem system, InternalLogWriter logger) {
     this.system = system;
     this.logger = logger;
-    this.localAddress = generateMemberId();
-    this.allIds = Collections.singleton(localAddress);
-    this.viewMembers = new ArrayList<>(allIds);
+    localAddress = generateMemberId();
+    allIds = Collections.singleton(localAddress);
+    viewMembers = new ArrayList<>(allIds);
     DistributionStats.enableClockStats = this.system.getConfig().getEnableTimeStatistics();
 
     DistributionConfig config = system.getConfig();
 
     if (config.getThreadMonitorEnabled()) {
-      this.threadMonitor = new ThreadsMonitoringImpl(system, config.getThreadMonitorInterval(),
+      threadMonitor = new ThreadsMonitoringImpl(system, config.getThreadMonitorInterval(),
           config.getThreadMonitorTimeLimit());
       logger.info("[ThreadsMonitor] New Monitor object and process were created.\n");
     } else {
-      this.threadMonitor = new ThreadsMonitoringImplDummy();
+      threadMonitor = new ThreadsMonitoringImplDummy();
       logger.info("[ThreadsMonitor] Monitoring is disabled and will not be run.\n");
     }
   }
@@ -114,7 +116,7 @@ public class LonerDistributionManager implements DistributionManager {
 
   private final Set<InternalDistributedMember> allIds;
   private final List<InternalDistributedMember> viewMembers;
-  private ConcurrentMap<InternalDistributedMember, InternalDistributedMember> canonicalIds =
+  private final ConcurrentMap<InternalDistributedMember, InternalDistributedMember> canonicalIds =
       new ConcurrentHashMap<>();
   @Immutable
   private static final DummyDMStats stats = new DummyDMStats();
@@ -125,7 +127,7 @@ public class LonerDistributionManager implements DistributionManager {
 
   @Override
   public long cacheTimeMillis() {
-    return this.system.getClock().cacheTimeMillis();
+    return system.getClock().cacheTimeMillis();
   }
 
   @Override
@@ -146,7 +148,7 @@ public class LonerDistributionManager implements DistributionManager {
   @Override
   public InternalDistributedMember getCanonicalId(DistributedMember dmid) {
     InternalDistributedMember iid = (InternalDistributedMember) dmid;
-    InternalDistributedMember result = this.canonicalIds.putIfAbsent(iid, iid);
+    InternalDistributedMember result = canonicalIds.putIfAbsent(iid, iid);
     if (result != null) {
       return result;
     }
@@ -184,23 +186,13 @@ public class LonerDistributionManager implements DistributionManager {
   @Override // DM method
   public void retainMembersWithSameOrNewerVersion(Collection<InternalDistributedMember> members,
       KnownVersion version) {
-    for (Iterator<InternalDistributedMember> it = members.iterator(); it.hasNext();) {
-      InternalDistributedMember id = it.next();
-      if (id.getVersion().compareTo(version) < 0) {
-        it.remove();
-      }
-    }
+    members.removeIf(id -> id.getVersion().compareTo(version) < 0);
   }
 
   @Override // DM method
   public void removeMembersWithSameOrNewerVersion(Collection<InternalDistributedMember> members,
       KnownVersion version) {
-    for (Iterator<InternalDistributedMember> it = members.iterator(); it.hasNext();) {
-      InternalDistributedMember id = it.next();
-      if (id.getVersion().compareTo(version) >= 0) {
-        it.remove();
-      }
-    }
+    members.removeIf(id -> id.getVersion().compareTo(version) >= 0);
   }
 
 
@@ -240,15 +232,15 @@ public class LonerDistributionManager implements DistributionManager {
   @Override
   public synchronized ElderState getElderState(boolean force) {
     // loners are always the elder
-    if (this.elderState == null) {
-      this.elderState = new ElderState(this);
+    if (elderState == null) {
+      elderState = new ElderState(this);
     }
-    return this.elderState;
+    return elderState;
   }
 
   @Override
   public InternalDistributedSystem getSystem() {
-    return this.system;
+    return system;
   }
 
   @Override
@@ -287,11 +279,11 @@ public class LonerDistributionManager implements DistributionManager {
       String reason) {}
 
   public LogWriterI18n getLoggerI18n() {
-    return this.logger;
+    return logger;
   }
 
   public InternalLogWriter getInternalLogWriter() {
-    return this.logger;
+    return logger;
   }
 
   @Override
@@ -317,7 +309,7 @@ public class LonerDistributionManager implements DistributionManager {
   public static class DummyDMStats implements DMStats {
     @Override
     public long getSentMessages() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -328,7 +320,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getSentCommitMessages() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -336,7 +328,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getCommitWaits() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -344,7 +336,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getSentMessagesTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -352,7 +344,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getBroadcastMessages() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -360,7 +352,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getBroadcastMessagesTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -368,7 +360,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getReceivedMessages() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -376,7 +368,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getReceivedBytes() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -387,7 +379,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long startUDPDispatchRequest() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -397,7 +389,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getProcessedMessages() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -405,7 +397,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getProcessedMessagesTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -413,47 +405,47 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getMessageProcessingScheduleTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
     public void incMessageProcessingScheduleTime(long nanos) {}
 
     @Override
-    public int getOverflowQueueSize() {
-      return 0;
+    public long getOverflowQueueSize() {
+      return 0L;
     }
 
     @Override
-    public void incOverflowQueueSize(int messages) {}
+    public void incOverflowQueueSize(long messages) {}
 
     @Override
-    public int getNumProcessingThreads() {
-      return 0;
+    public long getNumProcessingThreads() {
+      return 0L;
     }
 
     @Override
-    public void incNumProcessingThreads(int threads) {}
+    public void incNumProcessingThreads(long threads) {}
 
     @Override
-    public int getNumSerialThreads() {
-      return 0;
+    public long getNumSerialThreads() {
+      return 0L;
     }
 
     @Override
-    public void incNumSerialThreads(int threads) {}
+    public void incNumSerialThreads(long threads) {}
 
     @Override
     public void incMessageChannelTime(long val) {}
 
     @Override
     public long getUDPDispatchRequestTime() {
-      return 0;
-    };
+      return 0L;
+    }
 
     @Override
     public long getReplyMessageTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -461,41 +453,41 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getDistributeMessageTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
     public void incDistributeMessageTime(long val) {}
 
     @Override
-    public int getNodes() {
-      return 0;
+    public long getNodes() {
+      return 0L;
     }
 
     @Override
-    public void setNodes(int val) {}
+    public void setNodes(long val) {}
 
     @Override
-    public void incNodes(int val) {}
+    public void incNodes(long val) {}
 
     @Override
-    public int getReplyWaitsInProgress() {
-      return 0;
+    public long getReplyWaitsInProgress() {
+      return 0L;
     }
 
     @Override
-    public int getReplyWaitsCompleted() {
-      return 0;
+    public long getReplyWaitsCompleted() {
+      return 0L;
     }
 
     @Override
     public long getReplyWaitTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
     public long startReplyWait() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -506,7 +498,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getReplyTimeouts() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -525,8 +517,8 @@ public class LonerDistributionManager implements DistributionManager {
     public void incReconnectAttempts() {}
 
     @Override
-    public int getReconnectAttempts() {
-      return 0;
+    public long getReconnectAttempts() {
+      return 0L;
     }
 
     @Override
@@ -544,21 +536,21 @@ public class LonerDistributionManager implements DistributionManager {
     public void decSenders(boolean shared, boolean preserveOrder) {}
 
     @Override
-    public int getSendersSU() {
-      return 0;
+    public long getSendersSU() {
+      return 0L;
     }
 
     @Override
     public long startSocketWrite(boolean sync) {
-      return 0;
+      return 0L;
     }
 
     @Override
-    public void endSocketWrite(boolean sync, long start, int bytesWritten, int retries) {}
+    public void endSocketWrite(boolean sync, long start, long bytesWritten, long retries) {}
 
     @Override
     public long startSerialization() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -566,7 +558,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long startDeserialization() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -574,7 +566,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long startMsgSerialization() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -582,7 +574,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long startMsgDeserialization() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -601,10 +593,10 @@ public class LonerDistributionManager implements DistributionManager {
     public void incBatchFlushTime(long start) {}
 
     @Override
-    public void incUcastWriteBytes(int bytesWritten) {}
+    public void incUcastWriteBytes(long bytesWritten) {}
 
     @Override
-    public void incMcastWriteBytes(int bytesWritten) {}
+    public void incMcastWriteBytes(long bytesWritten) {}
 
     @Override
     public void incUcastRetransmits() {}
@@ -616,101 +608,101 @@ public class LonerDistributionManager implements DistributionManager {
     public void incMcastRetransmitRequests() {}
 
     @Override
-    public int getMcastRetransmits() {
-      return 0;
+    public long getMcastRetransmits() {
+      return 0L;
     }
 
     @Override
-    public int getMcastWrites() {
-      return 0;
+    public long getMcastWrites() {
+      return 0L;
     }
 
     @Override
-    public int getMcastReads() {
-      return 0;
+    public long getMcastReads() {
+      return 0L;
     }
 
     @Override
-    public void incUcastReadBytes(int amount) {}
+    public void incUcastReadBytes(long amount) {}
 
     @Override
-    public void incMcastReadBytes(int amount) {}
+    public void incMcastReadBytes(long amount) {}
 
     @Override
-    public int getAsyncSocketWritesInProgress() {
-      return 0;
+    public long getAsyncSocketWritesInProgress() {
+      return 0L;
     }
 
     @Override
-    public int getAsyncSocketWrites() {
-      return 0;
+    public long getAsyncSocketWrites() {
+      return 0L;
     }
 
     @Override
-    public int getAsyncSocketWriteRetries() {
-      return 0;
+    public long getAsyncSocketWriteRetries() {
+      return 0L;
     }
 
     @Override
     public long getAsyncSocketWriteBytes() {
-      return 0;
+      return 0L;
     }
 
     @Override
     public long getAsyncSocketWriteTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
-    public int getAsyncQueues() {
-      return 0;
+    public long getAsyncQueues() {
+      return 0L;
     }
 
     @Override
-    public void incAsyncQueues(int inc) {}
+    public void incAsyncQueues(long inc) {}
 
     @Override
-    public int getAsyncQueueFlushesInProgress() {
-      return 0;
+    public long getAsyncQueueFlushesInProgress() {
+      return 0L;
     }
 
     @Override
-    public int getAsyncQueueFlushesCompleted() {
-      return 0;
+    public long getAsyncQueueFlushesCompleted() {
+      return 0L;
     }
 
     @Override
     public long getAsyncQueueFlushTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
     public long startAsyncQueueFlush() {
-      return 0;
+      return 0L;
     }
 
     @Override
     public void endAsyncQueueFlush(long start) {}
 
     @Override
-    public int getAsyncQueueTimeouts() {
-      return 0;
+    public long getAsyncQueueTimeouts() {
+      return 0L;
     }
 
     @Override
-    public void incAsyncQueueTimeouts(int inc) {}
+    public void incAsyncQueueTimeouts(long inc) {}
 
     @Override
-    public int getAsyncQueueSizeExceeded() {
-      return 0;
+    public long getAsyncQueueSizeExceeded() {
+      return 0L;
     }
 
     @Override
-    public void incAsyncQueueSizeExceeded(int inc) {}
+    public void incAsyncQueueSizeExceeded(long inc) {}
 
     @Override
-    public int getAsyncDistributionTimeoutExceeded() {
-      return 0;
+    public long getAsyncDistributionTimeoutExceeded() {
+      return 0L;
     }
 
     @Override
@@ -718,7 +710,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getAsyncQueueSize() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -726,7 +718,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getAsyncQueuedMsgs() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -734,7 +726,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getAsyncDequeuedMsgs() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -742,38 +734,38 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getAsyncConflatedMsgs() {
-      return 0;
+      return 0L;
     }
 
     @Override
     public void incAsyncConflatedMsgs() {}
 
     @Override
-    public int getAsyncThreads() {
-      return 0;
+    public long getAsyncThreads() {
+      return 0L;
     }
 
     @Override
-    public void incAsyncThreads(int inc) {}
+    public void incAsyncThreads(long inc) {}
 
     @Override
-    public int getAsyncThreadInProgress() {
-      return 0;
+    public long getAsyncThreadInProgress() {
+      return 0L;
     }
 
     @Override
-    public int getAsyncThreadCompleted() {
-      return 0;
+    public long getAsyncThreadCompleted() {
+      return 0L;
     }
 
     @Override
     public long getAsyncThreadTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
     public long startAsyncThread() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -781,7 +773,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getAsyncQueueAddTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -789,21 +781,21 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getAsyncQueueRemoveTime() {
-      return 0;
+      return 0L;
     }
 
     @Override
     public void incAsyncQueueRemoveTime(long inc) {}
 
     @Override
-    public void incReceiverBufferSize(int inc, boolean direct) {}
+    public void incReceiverBufferSize(long inc, boolean direct) {}
 
     @Override
-    public void incSenderBufferSize(int inc, boolean direct) {}
+    public void incSenderBufferSize(long inc, boolean direct) {}
 
     @Override
     public long startSocketLock() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -811,54 +803,54 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long startBufferAcquire() {
-      return 0;
+      return 0L;
     }
 
     @Override
     public void endBufferAcquire(long start) {}
 
     @Override
-    public void incMessagesBeingReceived(boolean newMsg, int bytes) {}
+    public void incMessagesBeingReceived(boolean newMsg, long bytes) {}
 
     @Override
-    public void decMessagesBeingReceived(int bytes) {}
+    public void decMessagesBeingReceived(long bytes) {}
 
     @Override
     public void incReplyHandOffTime(long start) {}
 
     @Override
-    public int getElders() {
-      return 0;
+    public long getElders() {
+      return 0L;
     }
 
     @Override
-    public void incElders(int val) {}
+    public void incElders(long val) {}
 
     @Override
-    public int getInitialImageMessagesInFlight() {
-      return 0;
+    public long getInitialImageMessagesInFlight() {
+      return 0L;
     }
 
     @Override
-    public void incInitialImageMessagesInFlight(int val) {}
+    public void incInitialImageMessagesInFlight(long val) {}
 
     @Override
-    public int getInitialImageRequestsInProgress() {
-      return 0;
+    public long getInitialImageRequestsInProgress() {
+      return 0L;
     }
 
     @Override
-    public void incInitialImageRequestsInProgress(int val) {}
+    public void incInitialImageRequestsInProgress(long val) {}
 
     @Override
-    public void incPdxSerialization(int bytesWritten) {}
+    public void incPdxSerialization(long bytesWritten) {}
 
     @Override
-    public void incPdxDeserialization(int i) {}
+    public void incPdxDeserialization(long i) {}
 
     @Override
     public long startPdxInstanceDeserialization() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -868,11 +860,11 @@ public class LonerDistributionManager implements DistributionManager {
     public void incPdxInstanceCreations() {}
 
     @Override
-    public void incThreadOwnedReceivers(long value, int dominoCount) {}
+    public void incThreadOwnedReceivers(long value, long dominoCount) {}
 
     @Override
     public long getHeartbeatRequestsSent() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -880,7 +872,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getHeartbeatRequestsReceived() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -888,7 +880,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getHeartbeatsSent() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -896,7 +888,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getHeartbeatsReceived() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -904,7 +896,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getSuspectsSent() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -912,7 +904,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getSuspectsReceived() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -920,7 +912,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getFinalCheckRequestsSent() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -928,7 +920,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getFinalCheckRequestsReceived() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -936,7 +928,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getFinalCheckResponsesSent() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -944,7 +936,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getFinalCheckResponsesReceived() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -952,7 +944,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getTcpFinalCheckRequestsSent() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -960,7 +952,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getTcpFinalCheckRequestsReceived() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -968,7 +960,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getTcpFinalCheckResponsesSent() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -976,7 +968,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getTcpFinalCheckResponsesReceived() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -984,7 +976,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getUdpFinalCheckRequestsSent() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -992,7 +984,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long getUdpFinalCheckResponsesReceived() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -1000,7 +992,7 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long startUDPMsgEncryption() {
-      return 0;
+      return 0L;
     }
 
     @Override
@@ -1008,20 +1000,20 @@ public class LonerDistributionManager implements DistributionManager {
 
     @Override
     public long startUDPMsgDecryption() {
-      return 0;
+      return 0L;
     }
 
     @Override
     public void endUDPMsgDecryption(long start) {}
 
     @Override
-    public long getUDPMsgEncryptionTiime() {
-      return 0;
+    public long getUDPMsgEncryptionTime() {
+      return 0L;
     }
 
     @Override
     public long getUDPMsgDecryptionTime() {
-      return 0;
+      return 0L;
     }
   }
 
@@ -1050,16 +1042,15 @@ public class LonerDistributionManager implements DistributionManager {
 
   private int lonerPort = 0;
 
-  // private static final int CHARS_32KB = 16384;
   private InternalDistributedMember generateMemberId() {
-    InternalDistributedMember result = null;
+    InternalDistributedMember result;
     String host;
     try {
       // create string of the current millisecond clock time
-      StringBuffer sb = new StringBuffer();
+      StringBuilder sb = new StringBuilder();
       // use low four bytes for backward compatibility
       long time = System.currentTimeMillis() & 0xffffffffL;
-      for (int i = 0; i < 4; i++) {
+      for (long i = 0; i < 4; i++) {
         String hex = Integer.toHexString((int) (time & 0xff));
         if (hex.length() < 2) {
           sb.append('0');
@@ -1069,7 +1060,7 @@ public class LonerDistributionManager implements DistributionManager {
       }
       String uniqueString = sb.toString();
 
-      String name = this.system.getName();
+      String name = system.getName();
 
       host = SocketCreator.getClientHostName();
       DistributionConfig config = system.getConfig();
@@ -1097,11 +1088,11 @@ public class LonerDistributionManager implements DistributionManager {
    * @param newPort the new port to use
    */
   public void updateLonerPort(int newPort) {
-    this.logger.config(
+    logger.config(
         String.format("Updating membership port.  Port changed from %s to %s.  ID is now %s",
-            new Object[] {this.lonerPort, newPort, getId()}));
-    this.lonerPort = newPort;
-    this.getId().setPort(this.lonerPort);
+            lonerPort, newPort, getId()));
+    lonerPort = newPort;
+    getId().setPort(lonerPort);
   }
 
   @Override
@@ -1110,7 +1101,8 @@ public class LonerDistributionManager implements DistributionManager {
   }
 
   @Override
-  public Set<InternalDistributedMember> putOutgoing(DistributionMessage msg) {
+  @Nullable
+  public Set<InternalDistributedMember> putOutgoing(@NotNull DistributionMessage msg) {
     return null;
   }
 
@@ -1185,7 +1177,7 @@ public class LonerDistributionManager implements DistributionManager {
    */
   @Override
   public Set<InternalDistributedMember> getMembersInThisZone() {
-    return this.allIds;
+    return allIds;
   }
 
   @Override
@@ -1202,7 +1194,8 @@ public class LonerDistributionManager implements DistributionManager {
   @Override
   public boolean enforceUniqueZone() {
     return system.getConfig().getEnforceUniqueHost()
-        || system.getConfig().getRedundancyZone() != null;
+        || (system.getConfig().getRedundancyZone() != null
+            && !system.getConfig().getRedundancyZone().isEmpty());
   }
 
   @Override
@@ -1245,12 +1238,12 @@ public class LonerDistributionManager implements DistributionManager {
 
   @Override
   public Collection<String> getHostedLocators(InternalDistributedMember member) {
-    return Collections.<String>emptyList();
+    return Collections.emptyList();
   }
 
   @Override
   public Map<InternalDistributedMember, Collection<String>> getAllHostedLocators() {
-    return Collections.<InternalDistributedMember, Collection<String>>emptyMap();
+    return Collections.emptyMap();
   }
 
   @Override
@@ -1259,12 +1252,12 @@ public class LonerDistributionManager implements DistributionManager {
   }
 
   public Set<InternalDistributedMember> getLocatorDistributionManagerIds() {
-    return Collections.<InternalDistributedMember>emptySet();
+    return Collections.emptySet();
   }
 
   @Override
   public Map<InternalDistributedMember, Collection<String>> getAllHostedLocatorsWithSharedConfiguration() {
-    return Collections.<InternalDistributedMember, Collection<String>>emptyMap();
+    return Collections.emptyMap();
   }
 
   @Override
@@ -1284,17 +1277,17 @@ public class LonerDistributionManager implements DistributionManager {
 
   @Override
   public void setCache(InternalCache instance) {
-    this.cache = instance;
+    cache = instance;
   }
 
   @Override
   public InternalCache getCache() {
-    return this.cache;
+    return cache;
   }
 
   @Override
   public InternalCache getExistingCache() {
-    InternalCache result = this.cache;
+    InternalCache result = cache;
     if (result == null) {
       throw new CacheClosedException(
           "A cache has not yet been created.");
@@ -1338,7 +1331,7 @@ public class LonerDistributionManager implements DistributionManager {
   @Override
   /* returns the Threads Monitoring instance */
   public ThreadsMonitoring getThreadMonitoring() {
-    return this.threadMonitor;
+    return threadMonitor;
   }
 
   @Override
