@@ -28,6 +28,6 @@ public interface DLockLessorDepartureHandler {
 
   void handleDepartureOf(InternalDistributedMember owner, DLockGrantor grantor);
 
-  public void waitForInProcessDepartures() throws InterruptedException;
+  void waitForInProcessDepartures() throws InterruptedException;
 
 }
