@@ -48,9 +48,9 @@ public class ServiceConfig implements MembershipConfig {
   private final boolean locatorsPreferredAsCoordinators;
 
   public ServiceConfig(RemoteTransportConfig transport, DistributionConfig theConfig) {
-    this.dconfig = theConfig;
+    dconfig = theConfig;
     this.transport = transport;
-    this.isReconnecting = (transport.getOldDSMembershipInfo() != null);
+    isReconnecting = (transport.getOldDSMembershipInfo() != null);
 
     long defaultJoinTimeout = 24000;
     if (isReconnecting || theConfig.getLocators().length() > 0 && !Locator.hasLocator()) {
@@ -64,12 +64,11 @@ public class ServiceConfig implements MembershipConfig {
       defaultJoinTimeout = minimumJoinTimeout;
     }
 
-    joinTimeout = Long.getLong("p2p.joinTimeout", defaultJoinTimeout).longValue();
+    joinTimeout = Long.getLong("p2p.joinTimeout", defaultJoinTimeout);
 
-    // if network partition detection is enabled, we must connect to the locators
-    // more frequently in order to make sure we're not isolated from them
     SocketCreator.resolve_dns = true;
-    if (theConfig.getEnableNetworkPartitionDetection()) {
+    if (theConfig.getEnableNetworkPartitionDetection() &&
+        !theConfig.getSSLEndPointIdentificationEnabled()) {
       if (!SocketCreator.FORCE_DNS_USE) {
         SocketCreator.resolve_dns = false;
       }
