@@ -18,7 +18,6 @@ package org.apache.geode.internal;
 import java.io.File;
 import java.io.IOException;
 import java.net.InetAddress;
-import java.util.Properties;
 
 import org.apache.logging.log4j.Logger;
 
@@ -26,6 +25,7 @@ import org.apache.geode.SystemFailure;
 import org.apache.geode.annotations.internal.MakeNotStatic;
 import org.apache.geode.distributed.internal.InternalDistributedSystem;
 import org.apache.geode.distributed.internal.InternalLocator;
+import org.apache.geode.distributed.internal.tcpserver.HostAddress;
 import org.apache.geode.logging.internal.executors.LoggingThread;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.util.internal.GeodeGlossary;
@@ -90,7 +90,7 @@ public class DistributionLocator {
     logger.info("Locator stopped");
   }
 
-  public static void main(String args[]) {
+  public static void main(String[] args) {
     if (args.length == 0 || args.length > 6) {
       System.err.println(
           "Usage: port [bind-address] [peerLocator] [serverLocator] [hostname-for-clients]");
@@ -109,9 +109,7 @@ public class DistributionLocator {
     SystemFailure.loadEmergencyClasses();
 
     final int port = parsePort(args[0]);
-    InetAddress address = null;
-    boolean peerLocator = true;
-    boolean serverLocator = true;
+    HostAddress hostAddress = null;
     String hostnameForClients = null;
     try {
       if (args.length > 1 && !args[1].equals("")) {
@@ -121,43 +119,37 @@ public class DistributionLocator {
                   args[1]));
           ExitCode.FATAL.doSystemExit();
         }
-        address = InetAddress.getByName(args[1]);
+        hostAddress = new HostAddress(args[1]);
+        // do a look-up to ensure that the name can be resolved to an address
+        InetAddress.getByName(args[1]);
       } else {
         // address = null; // was InetAddress.getLocalHost(); (redundant assignment)
       }
-      if (args.length > 2) {
-        peerLocator = "true".equalsIgnoreCase(args[2]);
-      }
-      if (args.length > 3) {
-        serverLocator = "true".equalsIgnoreCase(args[3]);
-      }
       if (args.length > 4) {
         hostnameForClients = args[4];
       }
 
+      final InetAddress inetAddress = hostAddress == null ? null : hostAddress.getAddress();
       if (!Boolean.getBoolean(InternalDistributedSystem.DISABLE_SHUTDOWN_HOOK_PROPERTY)) {
-        final InetAddress faddress = address;
         Runtime.getRuntime()
             .addShutdownHook(new LoggingThread("LocatorShutdownThread", false, () -> {
               try {
-                DistributionLocator.shutdown(port, faddress);
+                DistributionLocator.shutdown(port, inetAddress);
               } catch (IOException e) {
                 e.printStackTrace();
               }
             }));
       }
 
-      lockFile = ManagerInfo.setLocatorStarting(directory, port, address);
+      lockFile = ManagerInfo.setLocatorStarting(directory, port, inetAddress);
       lockFile.deleteOnExit();
 
+      InetAddress address = hostAddress == null ? null : hostAddress.getAddress();
       try {
-
         InternalLocator locator = InternalLocator.startLocator(port, new File(DEFAULT_LOG_FILE),
-            null, null, address, true, (Properties) null, hostnameForClients);
-
+            null, null, hostAddress, true, null, hostnameForClients);
         ManagerInfo.setLocatorStarted(directory, port, address);
         locator.waitToStop();
-
       } finally {
         shutdown(port, address);
       }
@@ -168,7 +160,7 @@ public class DistributionLocator {
 
     } catch (java.net.BindException ex) {
       logger.fatal("Could not bind locator to {}[{}]",
-          new Object[] {address, port});
+          new Object[] {hostAddress, port});
       ExitCode.FATAL.doSystemExit();
 
     } catch (Exception ex) {
