@@ -31,8 +31,11 @@ import java.io.PrintStream;
 import java.io.PrintWriter;
 import java.io.StringWriter;
 import java.net.URL;
+import java.util.Map;
 import java.util.StringTokenizer;
 
+import org.jetbrains.annotations.NotNull;
+
 import org.apache.geode.annotations.Immutable;
 
 /**
@@ -145,4 +148,8 @@ public class GemFireVersion {
     }
     return csLoc;
   }
+
+  public static @NotNull Map<String, String> asMap() {
+    return description.asMap();
+  }
 }
