@@ -1156,13 +1156,13 @@ public class RemoteGfManagerAgent implements GfManagerAgent {
         try {
           SnapshotResultMessage msg = agent.snapshotResults.take();
           agent.callCacheCollector(msg.getSnapshot(), msg.getSender(), msg.getSnapshotId());
-          yield();
-        } catch (InterruptedException ignore) {
+          Thread.yield();
+        } catch (InterruptedException e) {
           // We'll just exit, no need to reset interrupt bit.
           if (shutDown) {
             break;
           }
-          logger.warn("Ignoring strange interrupt", ignore);
+          logger.warn("Ignoring strange interrupt", e);
         } catch (Exception ex) {
           logger.fatal(ex.getMessage(), ex);
         }
