@@ -14,6 +14,8 @@
  */
 package org.apache.geode.internal.admin.remote;
 
+import static java.util.Collections.emptySet;
+import static org.apache.commons.lang3.StringUtils.isBlank;
 import static org.apache.geode.distributed.ConfigurationProperties.BIND_ADDRESS;
 import static org.apache.geode.distributed.ConfigurationProperties.DISABLE_AUTO_RECONNECT;
 import static org.apache.geode.distributed.ConfigurationProperties.DISABLE_TCP;
@@ -48,14 +50,14 @@ public class RemoteTransportConfig implements TransportConfig {
   private final boolean tcpDisabled;
   private final boolean disableAutoReconnect;
   private final DistributionLocatorId mcastId;
-  private final Set ids;
+  private final Set<DistributionLocatorId> ids;
   private final String bindAddress;
   private final SSLConfig sslConfig;
   private final String membershipPortRange;
-  private int tcpPort;
+  private final int tcpPort;
   private boolean isReconnectingDS;
   private MembershipInformation oldDSMembershipInfo;
-  private int vmKind = -1;
+  private final int vmKind;
 
   // -------------------------------------------------------------------------
   // Constructor(s)
@@ -70,14 +72,14 @@ public class RemoteTransportConfig implements TransportConfig {
    */
   public RemoteTransportConfig(DistributionConfig config, int vmKind) {
     if (config.getBindAddress() == null) {
-      this.bindAddress = DistributionConfig.DEFAULT_BIND_ADDRESS;
+      bindAddress = DistributionConfig.DEFAULT_BIND_ADDRESS;
     } else {
-      this.bindAddress = config.getBindAddress();
+      bindAddress = config.getBindAddress();
     }
     this.vmKind = vmKind;
-    this.tcpPort = config.getTcpPort();
-    this.membershipPortRange = getMembershipPortRangeString(config.getMembershipPortRange());
-    this.sslConfig = new SSLConfig.Builder().build();
+    tcpPort = config.getTcpPort();
+    membershipPortRange = getMembershipPortRangeString(config.getMembershipPortRange());
+    sslConfig = new SSLConfig.Builder().build();
 
     String initialHosts = config.getLocators();
     if (initialHosts == null) {
@@ -86,39 +88,35 @@ public class RemoteTransportConfig implements TransportConfig {
     initialHosts = initialHosts.trim();
 
     if (config.getMcastPort() > 0) {
-      this.mcastId = new DistributionLocatorId(config.getMcastAddress(), config.getMcastPort(),
-          config.getBindAddress(), this.sslConfig);
-      this.mcastEnabled = true;
+      mcastId = new DistributionLocatorId(config.getMcastAddress(), config.getMcastPort(),
+          config.getBindAddress(), sslConfig);
+      mcastEnabled = true;
     } else {
-      this.mcastEnabled = false;
-      this.mcastId = null;
+      mcastEnabled = false;
+      mcastId = null;
     }
 
-    this.tcpDisabled = config.getDisableTcp();
-    this.disableAutoReconnect = config.getDisableAutoReconnect();
+    tcpDisabled = config.getDisableTcp();
+    disableAutoReconnect = config.getDisableAutoReconnect();
 
     // See what type of discovery is being used
     if (initialHosts.length() == 0) {
       // loner system
-      this.ids = Collections.EMPTY_SET;
-      return;
+      ids = emptySet();
     } else {
-      HashSet locators = new HashSet();
+      Set<DistributionLocatorId> locators = new HashSet<>();
       StringTokenizer stringTokenizer = new StringTokenizer(initialHosts, ",");
       while (stringTokenizer.hasMoreTokens()) {
         String locator = stringTokenizer.nextToken();
         if (StringUtils.isNotEmpty(locator)) {
-          locators.add(new DistributionLocatorId(locator));
+          locators.add(DistributionLocatorId.unmarshal(locator));
         }
       }
 
-      if (this.mcastEnabled) {
-        locators.add(this.mcastId);
-      }
-      this.ids = Collections.unmodifiableSet(locators);
-      if (this.mcastEnabled) {
-        Assert.assertTrue(this.mcastId != null);
+      if (mcastEnabled) {
+        locators.add(mcastId);
       }
+      ids = Collections.unmodifiableSet(locators);
     }
   }
 
@@ -126,9 +124,9 @@ public class RemoteTransportConfig implements TransportConfig {
    * Constructs a transport config given a collection of {@link DistributionLocatorId} instances.
    */
   public RemoteTransportConfig(boolean isMcastEnabled, boolean isTcpDisabled,
-      boolean isAutoReconnectDisabled, String bindAddress, SSLConfig sslConfig, Collection ids,
+      boolean isAutoReconnectDisabled, String bindAddress, SSLConfig sslConfig,
+      Collection<DistributionLocatorId> ids,
       String membershipPortRange, int tcpPort, int vmKind) {
-    DistributionLocatorId mid = null;
 
     if (bindAddress == null) {
       this.bindAddress = DistributionConfig.DEFAULT_BIND_ADDRESS;
@@ -138,29 +136,26 @@ public class RemoteTransportConfig implements TransportConfig {
 
     this.sslConfig = sslConfig;
 
-    this.mcastEnabled = isMcastEnabled;
-    this.tcpDisabled = isTcpDisabled;
-    this.disableAutoReconnect = isAutoReconnectDisabled;
+    mcastEnabled = isMcastEnabled;
+    tcpDisabled = isTcpDisabled;
+    disableAutoReconnect = isAutoReconnectDisabled;
+
+    DistributionLocatorId mid = null;
     if (isMcastEnabled) {
-      if (ids.size() < 1) {
-        throw new IllegalArgumentException(
-            "expected at least one host/port id");
+      if (ids.isEmpty()) {
+        throw new IllegalArgumentException("expected at least one host/port id");
       }
-      Iterator it = ids.iterator();
-      while (it.hasNext() && mid == null) {
-        DistributionLocatorId id = (DistributionLocatorId) it.next();
+      for (final DistributionLocatorId id : ids) {
         if (id.isMcastId()) {
           mid = id;
-          // System.out.println("mcast id: " + id);
-        } else {
-          // System.out.println("non-mcast id: " + id);
+          break;
         }
       }
     }
-    this.ids = Collections.unmodifiableSet(new HashSet(ids));
-    this.mcastId = mid;
-    if (this.mcastEnabled) {
-      Assert.assertTrue(this.mcastId != null);
+    this.ids = Collections.unmodifiableSet(new HashSet<>(ids));
+    mcastId = mid;
+    if (mcastEnabled) {
+      Assert.assertTrue(mcastId != null);
     }
     this.membershipPortRange = membershipPortRange;
     this.tcpPort = tcpPort;
@@ -185,8 +180,8 @@ public class RemoteTransportConfig implements TransportConfig {
    * Returns the set of DistributionLocatorId instances that define this transport. The set is
    * unmodifiable.
    */
-  public Set getIds() {
-    return this.ids;
+  public Set<DistributionLocatorId> getIds() {
+    return ids;
   }
 
   /**
@@ -194,35 +189,35 @@ public class RemoteTransportConfig implements TransportConfig {
    * use multicast discovery.
    */
   public boolean isMcastEnabled() {
-    return this.mcastEnabled;
+    return mcastEnabled;
   }
 
   public DistributionLocatorId getMcastId() {
-    return this.mcastId;
+    return mcastId;
   }
 
   public int getVmKind() {
-    return this.vmKind;
+    return vmKind;
   }
 
   public boolean isTcpDisabled() {
-    return this.tcpDisabled;
+    return tcpDisabled;
   }
 
   public String getBindAddress() {
-    return this.bindAddress;
+    return bindAddress;
   }
 
   public SSLConfig getSSLConfig() {
-    return this.sslConfig;
+    return sslConfig;
   }
 
   public String getMembershipPortRange() {
-    return this.membershipPortRange;
+    return membershipPortRange;
   }
 
   public int getTcpPort() {
-    return this.tcpPort;
+    return tcpPort;
   }
 
   public boolean getIsReconnectingDS() {
@@ -251,27 +246,27 @@ public class RemoteTransportConfig implements TransportConfig {
     Properties props = new Properties();
     props.setProperty(BIND_ADDRESS, bindAddress);
     // System.out.println("entering ds port range property of " + this.membershipPortRange);
-    if (this.membershipPortRange != null) {
-      props.setProperty(MEMBERSHIP_PORT_RANGE, this.membershipPortRange);
+    if (membershipPortRange != null) {
+      props.setProperty(MEMBERSHIP_PORT_RANGE, membershipPortRange);
     }
-    if (this.tcpPort != 0) {
-      props.setProperty(TCP_PORT, String.valueOf(this.tcpPort));
+    if (tcpPort != 0) {
+      props.setProperty(TCP_PORT, String.valueOf(tcpPort));
     }
-    if (this.mcastEnabled) {
+    if (mcastEnabled) {
       // Fix bug 32849
-      props.setProperty(MCAST_ADDRESS, this.mcastId.getHostName());
-      props.setProperty(MCAST_PORT, String.valueOf(this.mcastId.getPort()));
+      props.setProperty(MCAST_ADDRESS, mcastId.getHostName());
+      props.setProperty(MCAST_PORT, String.valueOf(mcastId.getPort()));
 
     } else {
       props.setProperty(MCAST_PORT, String.valueOf(0));
     }
     // Create locator string
-    StringBuffer locators = new StringBuffer();
-    for (Iterator iter = this.ids.iterator(); iter.hasNext();) {
-      DistributionLocatorId locator = (DistributionLocatorId) iter.next();
+    StringBuilder locators = new StringBuilder();
+    for (Iterator<DistributionLocatorId> iter = ids.iterator(); iter.hasNext();) {
+      DistributionLocatorId locator = iter.next();
       if (!locator.isMcastId()) {
         String baddr = locator.getBindAddress();
-        if (baddr != null && baddr.trim().length() > 0) {
+        if (!isBlank(baddr)) {
           locators.append(baddr);
         } else {
           locators.append(locator.getHostName());
@@ -292,22 +287,20 @@ public class RemoteTransportConfig implements TransportConfig {
 
     props.setProperty(LOCATORS, tempLocatorString);
 
-    this.sslConfig.toDSProperties(props);
+    sslConfig.toDSProperties(props);
 
-    props.setProperty(DISABLE_TCP, this.tcpDisabled ? "true" : "false");
+    props.setProperty(DISABLE_TCP, tcpDisabled ? "true" : "false");
 
-    props.setProperty(DISABLE_AUTO_RECONNECT, this.disableAutoReconnect ? "true" : "false");
+    props.setProperty(DISABLE_AUTO_RECONNECT, disableAutoReconnect ? "true" : "false");
 
     return props;
   }
 
   private String toString(boolean noMcast) {
-    StringBuffer result = new StringBuffer();
+    StringBuilder result = new StringBuilder();
     boolean first = true;
-    Iterator it = ids.iterator();
-    while (it.hasNext()) {
-      DistributionLocatorId dli = (DistributionLocatorId) it.next();
-      if (noMcast && dli.isMcastId()) {
+    for (final DistributionLocatorId id : ids) {
+      if (noMcast && id.isMcastId()) {
         continue;
       }
       if (!first) {
@@ -315,19 +308,11 @@ public class RemoteTransportConfig implements TransportConfig {
       } else {
         first = false;
       }
-      result.append(dli.toString());
+      result.append(id.toString());
     }
     return result.toString();
   }
 
-  /**
-   * returns a locators string suitable for use in locators= in gemfire.properties
-   */
-  public String locatorsString() {
-    return this.toString(true);
-  }
-
-
   // -------------------------------------------------------------------------
   // Methods overridden from java.lang.Object
   // -------------------------------------------------------------------------
@@ -339,16 +324,16 @@ public class RemoteTransportConfig implements TransportConfig {
 
   @Override
   public boolean equals(Object o) {
-    if (o != null && o instanceof RemoteTransportConfig) {
+    if (o instanceof RemoteTransportConfig) {
       RemoteTransportConfig other = (RemoteTransportConfig) o;
-      return (this.mcastEnabled == other.mcastEnabled) && this.ids.equals(other.ids);
+      return (mcastEnabled == other.mcastEnabled) && ids.equals(other.ids);
     }
     return false;
   }
 
   @Override
   public int hashCode() {
-    return this.ids.hashCode();
+    return ids.hashCode();
   }
 
 }
