@@ -275,7 +275,7 @@ public abstract class AbstractRegion implements InternalRegion, AttributesMutato
    * @see #getExtensionPoint()
    * @since GemFire 8.1
    */
-  private ExtensionPoint<Region<?, ?>> extensionPoint =
+  private final ExtensionPoint<Region<?, ?>> extensionPoint =
       new SimpleExtensionPoint<Region<?, ?>>(this, this);
 
   protected final InternalCache cache;
@@ -741,8 +741,8 @@ public abstract class AbstractRegion implements InternalRegion, AttributesMutato
         // This is for all regions except pdx Region
         if (!isPdxTypesRegion) {
           // Make sure we are distributing to only those senders whose id
-          // is available on this region
-          if (allGatewaySenderIds.contains(sender.getId())) {
+          // is available on this region and whose state is running
+          if (hasRunningGatewaySender(allGatewaySenders, sender)) {
             allRemoteDSIds.add(sender.getRemoteDSId());
           }
         } else { // this else is for PDX region
@@ -1899,6 +1899,10 @@ public abstract class AbstractRegion implements InternalRegion, AttributesMutato
     PoolImpl find(String poolName);
   }
 
+  static boolean hasRunningGatewaySender(Set<GatewaySender> senders, GatewaySender sender) {
+    return senders.contains(sender) && sender.isRunning();
+  }
+
   @VisibleForTesting
   ConcurrentHashMap<RegionEntry, EntryExpiryTask> getEntryExpiryTasks() {
     return entryExpiryTasks;
