@@ -22,6 +22,7 @@ import java.io.Serializable;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicLong;
@@ -32,11 +33,13 @@ import org.apache.logging.log4j.Logger;
 import org.apache.geode.CancelException;
 import org.apache.geode.CopyHelper;
 import org.apache.geode.DataSerializer;
+import org.apache.geode.Delta;
 import org.apache.geode.DeltaSerializationException;
 import org.apache.geode.InternalGemFireError;
 import org.apache.geode.InvalidDeltaException;
 import org.apache.geode.SystemFailure;
 import org.apache.geode.annotations.Immutable;
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.cache.CacheException;
 import org.apache.geode.cache.CacheWriter;
 import org.apache.geode.cache.CacheWriterException;
@@ -50,6 +53,7 @@ import org.apache.geode.cache.Operation;
 import org.apache.geode.cache.RegionAttributes;
 import org.apache.geode.cache.RegionDestroyedException;
 import org.apache.geode.cache.TimeoutException;
+import org.apache.geode.cache.TransactionId;
 import org.apache.geode.cache.partition.PartitionListener;
 import org.apache.geode.distributed.DistributedMember;
 import org.apache.geode.distributed.DistributedSystem;
@@ -110,6 +114,13 @@ import org.apache.geode.util.internal.GeodeGlossary;
 public class BucketRegion extends DistributedRegion implements Bucket {
   private static final Logger logger = LogService.getLogger();
 
+  /**
+   * Allows enabling older, buggy behavior where Tx operations might not create
+   * VMCachedDeserializable entries.
+   */
+  private static final boolean TX_PREFERS_NO_SERIALIZED_ENTRIES =
+      Boolean.getBoolean("gemfire.tx-prefers-no-serialized-entries");
+
   @Immutable
   private static final RawValue NULLVALUE = new RawValue(null);
   @Immutable
@@ -374,7 +385,7 @@ public class BucketRegion extends DistributedRegion implements Bucket {
   }
 
   @Override
-  void notifyClientsOfTombstoneGC(Map<VersionSource, Long> regionGCVersions,
+  void notifyClientsOfTombstoneGC(Map<VersionSource<?>, Long> regionGCVersions,
       Set<Object> removedKeys, EventID eventID, FilterInfo routing) {
     if (CacheClientNotifier.singletonHasClientProxies()) {
       // Only route the event to clients interested in the partitioned region.
@@ -574,6 +585,13 @@ public class BucketRegion extends DistributedRegion implements Bucket {
     return eventSeqNum.get();
   }
 
+  @Override
+  public void txHandleWANEvent(EntryEventImpl event) {
+    if (partitionedRegion.isParallelWanEnabled()) {
+      handleWANEvent(event);
+    }
+  }
+
   @Override
   public void handleWANEvent(EntryEventImpl event) {
     if (eventSeqNum == null) {
@@ -781,7 +799,7 @@ public class BucketRegion extends DistributedRegion implements Bucket {
   }
 
   /**
-   * lock this bucket and, if present, its colocated "parent"
+   * lock this bucket
    *
    * @param tryLock - whether to use tryLock (true) or a blocking lock (false)
    * @return true if locks were obtained and are still held
@@ -814,41 +832,20 @@ public class BucketRegion extends DistributedRegion implements Bucket {
 
   private boolean lockPrimaryStateReadLock(boolean tryLock) {
     Lock primaryMoveReadLock = getBucketAdvisor().getPrimaryMoveReadLock();
-    Lock parentLock = getBucketAdvisor().getParentPrimaryMoveReadLock();
     for (;;) {
       boolean interrupted = Thread.interrupted();
       try {
         // Get the lock. If we have to wait here, it's because
         // this VM is actively becoming "not primary". We don't want
         // to throw an exception until this VM is actually no longer
-        // primary, so we wait here for not primary to complete. See bug #39963
-        if (parentLock != null) {
-          if (tryLock) {
-            boolean locked = parentLock.tryLock();
-            if (!locked) {
-              return false;
-            }
-          } else {
-            parentLock.lockInterruptibly();
-          }
-          if (tryLock) {
-            boolean locked = primaryMoveReadLock.tryLock();
-            if (!locked) {
-              parentLock.unlock();
-              return false;
-            }
-          } else {
-            primaryMoveReadLock.lockInterruptibly();
+        // primary, so we wait here for not primary to complete.
+        if (tryLock) {
+          boolean locked = primaryMoveReadLock.tryLock();
+          if (!locked) {
+            return false;
           }
         } else {
-          if (tryLock) {
-            boolean locked = primaryMoveReadLock.tryLock();
-            if (!locked) {
-              return false;
-            }
-          } else {
-            primaryMoveReadLock.lockInterruptibly();
-          }
+          primaryMoveReadLock.lockInterruptibly();
         }
         break; // success
       } catch (InterruptedException e) {
@@ -868,10 +865,6 @@ public class BucketRegion extends DistributedRegion implements Bucket {
   public void doUnlockForPrimary() {
     Lock primaryMoveReadLock = getBucketAdvisor().getPrimaryMoveReadLock();
     primaryMoveReadLock.unlock();
-    Lock parentLock = getBucketAdvisor().getParentPrimaryMoveReadLock();
-    if (parentLock != null) {
-      parentLock.unlock();
-    }
   }
 
   /**
@@ -1224,7 +1217,7 @@ public class BucketRegion extends DistributedRegion implements Bucket {
   }
 
   public static class PrimaryMoveReadLockAcquired implements Serializable {
-  };
+  }
 
   private boolean wasPrimaryLockedPreviously(EntryEventImpl event) {
     return event.getCallbackArgument() instanceof PrimaryMoveReadLockAcquired;
@@ -1400,6 +1393,10 @@ public class BucketRegion extends DistributedRegion implements Bucket {
     return redundancy;
   }
 
+  public boolean hasLowRedundancy() {
+    return redundancy > getBucketAdvisor().getBucketRedundancy();
+  }
+
   @Override
   public boolean isPrimary() {
     throw new UnsupportedOperationException(
@@ -1654,10 +1651,7 @@ public class BucketRegion extends DistributedRegion implements Bucket {
     boolean needsPrEvent = (partitionedRegion.isInitialized() && callDispatchListenerEvent
         && partitionedRegion.shouldDispatchListenerEvent())
         || CacheClientNotifier.singletonHasClientProxies();
-    if (!needsPrEvent) {
-      return true;
-    }
-    return false;
+    return !needsPrEvent;
   }
 
   @Override
@@ -2483,4 +2477,62 @@ public class BucketRegion extends DistributedRegion implements Bucket {
   void checkSameSenderIdsAvailableOnAllNodes() {
     // nothing needed on a bucket region
   }
+
+  @Override
+  public void txApplyPut(Operation putOp, Object key, Object newValue, boolean didDestroy,
+      TransactionId transactionId, TXRmtEvent event, EventID eventId, Object aCallbackArgument,
+      List<EntryEventImpl> pendingCallbacks, FilterRoutingInfo filterRoutingInfo,
+      ClientProxyMembershipID bridgeContext, TXEntryState txEntryState, VersionTag versionTag,
+      long tailKey) {
+
+    Object wrappedNewValue;
+    if (TX_PREFERS_NO_SERIALIZED_ENTRIES) {
+      wrappedNewValue = newValue;
+    } else {
+      if (newValue instanceof CachedDeserializable || newValue instanceof byte[]
+          || Token.isInvalidOrRemoved(newValue)) {
+        wrappedNewValue = newValue;
+      } else if (newValue instanceof Delta) {
+        int vSize = CachedDeserializableFactory.calcMemSize(newValue,
+            getPartitionedRegion().getObjectSizer(), false);
+        wrappedNewValue = CachedDeserializableFactory.create(newValue, vSize, cache);
+      } else {
+        byte[] serializedBytes = null;
+        if (txEntryState != null) {
+          serializedBytes = txEntryState.getSerializedPendingValue();
+        }
+
+        if (serializedBytes == null) {
+          serializedBytes = EntryEventImpl.serialize(newValue);
+        }
+
+        wrappedNewValue = CachedDeserializableFactory.create(serializedBytes, cache);
+      }
+    }
+
+    superTxApplyPut(putOp, key, wrappedNewValue, didDestroy, transactionId, event, eventId,
+        aCallbackArgument, pendingCallbacks, filterRoutingInfo, bridgeContext, txEntryState,
+        versionTag, tailKey);
+  }
+
+  @VisibleForTesting
+  void superTxApplyPut(Operation putOp, Object key, Object wrappedNewValue, boolean didDestroy,
+      TransactionId transactionId, TXRmtEvent event, EventID eventId, Object aCallbackArgument,
+      List<EntryEventImpl> pendingCallbacks, FilterRoutingInfo filterRoutingInfo,
+      ClientProxyMembershipID bridgeContext, TXEntryState txEntryState, VersionTag versionTag,
+      long tailKey) {
+    super.txApplyPut(putOp, key, wrappedNewValue, didDestroy, transactionId, event, eventId,
+        aCallbackArgument, pendingCallbacks, filterRoutingInfo, bridgeContext, txEntryState,
+        versionTag, tailKey);
+  }
+
+  @Override
+  Set<InternalDistributedMember> getDestroyRegionRecipients() {
+    // For DestroyRegionMessage that only removes bucket profile, send it to all
+    // the other members including member that is in the process of creating the
+    // partitioned region, this is to avoid leaving stale bucket profile undeleted
+    // on the member that is still in the process of creating the partitioned region
+    return getSystem().getDistributionManager().getOtherDistributionManagerIds();
+  }
+
 }
