@@ -21,7 +21,6 @@ import java.io.DataInput;
 import java.io.DataOutput;
 import java.io.IOException;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.Set;
 import java.util.concurrent.RejectedExecutionException;
 
@@ -42,8 +41,8 @@ import org.apache.geode.distributed.internal.DistributionAdvisor;
 import org.apache.geode.distributed.internal.ReplyException;
 import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
 import org.apache.geode.internal.Assert;
+import org.apache.geode.internal.admin.remote.DestroyRegionMessage;
 import org.apache.geode.internal.cache.LocalRegion.InitializationLevel;
-import org.apache.geode.internal.cache.partitioned.PRLocallyDestroyedException;
 import org.apache.geode.internal.cache.tier.sockets.ClientProxyMembershipID;
 import org.apache.geode.internal.serialization.DeserializationContext;
 import org.apache.geode.internal.serialization.SerializationContext;
@@ -93,9 +92,8 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
   }
 
   @Override
-  protected Set getRecipients() {
-    CacheDistributionAdvisor advisor = getRegion().getCacheDistributionAdvisor();
-    return advisor.adviseDestroyRegion();
+  protected Set<InternalDistributedMember> getRecipients() {
+    return getRegion().getDestroyRegionRecipients();
   }
 
   @Override
@@ -106,22 +104,22 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
   @Override
   protected CacheOperationMessage createMessage() {
     DestroyRegionMessage mssg;
-    if (this.event instanceof ClientRegionEventImpl) {
+    if (event instanceof ClientRegionEventImpl) {
       mssg = new DestroyRegionWithContextMessage();
       ((DestroyRegionWithContextMessage) mssg).context =
-          ((ClientRegionEventImpl) this.event).getContext();
+          event.getContext();
     } else {
       mssg = new DestroyRegionMessage();
     }
 
-    mssg.notifyOfRegionDeparture = this.notifyOfRegionDeparture;
+    mssg.notifyOfRegionDeparture = notifyOfRegionDeparture;
     DistributedRegion rgn = getRegion();
     mssg.serialNum = rgn.getSerialNumber();
     Assert.assertTrue(mssg.serialNum != DistributionAdvisor.ILLEGAL_SERIAL);
 
     mssg.subregionSerialNumbers = rgn.getDestroyedSubregionSerialNumbers();
 
-    RegionEventImpl rei = (RegionEventImpl) this.event;
+    RegionEventImpl rei = (RegionEventImpl) event;
     mssg.eventID = rei.getEventId();
     return mssg;
   }
@@ -145,16 +143,16 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
     @Override
     protected InternalCacheEvent createEvent(DistributedRegion rgn) throws EntryNotFoundException {
       RegionEventImpl event = createRegionEvent(rgn);
-      if (this.filterRouting != null) {
+      if (filterRouting != null) {
         event.setLocalFilterInfo(
-            this.filterRouting.getFilterInfo((InternalDistributedMember) rgn.getMyId()));
+            filterRouting.getFilterInfo(rgn.getMyId()));
       }
-      event.setEventID(this.eventID);
+      event.setEventID(eventID);
       return event;
     }
 
     protected RegionEventImpl createRegionEvent(DistributedRegion rgn) {
-      return new RegionEventImpl(rgn, getOperation(), this.callbackArg, true /* originRemote */,
+      return new RegionEventImpl(rgn, getOperation(), callbackArg, true /* originRemote */,
           getSender());
     }
 
@@ -169,32 +167,23 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
           Throwable thr = null;
           try {
             if (lclRgn == null) {
-              // following block is specific to buckets...
-              // need to wait for queued bucket profiles to be processed
-              // or this destroy may do nothing and result in a stale profile
-              boolean waitForBucketInitializationToComplete = true;
-              CacheDistributionAdvisee advisee = null;
               try {
-                advisee = PartitionedRegionHelper.getProxyBucketRegion(dm.getCache(), regionPath,
-                    waitForBucketInitializationToComplete);
-              } catch (PRLocallyDestroyedException ignore) {
-                // region not found - it's been destroyed
+                PartitionedRegion partitionedRegion = PartitionedRegionHelper
+                    .getPartitionedRegionUsingBucketRegionName(dm.getCache(), regionPath);
+                if (partitionedRegion != null) {
+                  String bucketName = PartitionedRegionHelper.getBucketName(regionPath);
+                  int bucketId = PartitionedRegionHelper.getBucketId(bucketName);
+                  partitionedRegion.getRegionAdvisor().removeIdAndBucket(bucketId, getSender(),
+                      serialNum, op.isRegionDestroy() && !op.isClose());
+                }
               } catch (RegionDestroyedException ignore) {
-                // ditto
+                // nothing to do because Region is already destroyed
               } catch (PartitionedRegionException e) {
                 if (!e.getMessage().contains("destroyed")) {
                   throw e;
                 }
                 // region failed registration & is unusable
               }
-
-              if (advisee != null) {
-                boolean isDestroy = op.isRegionDestroy() && !op.isClose();
-                advisee.getDistributionAdvisor().removeIdWithSerial(getSender(), serialNum,
-                    isDestroy);
-              } else if (logger.isDebugEnabled()) {
-                logger.debug("{} region not found, nothing to do", this);
-              }
               return;
             } // lclRegion == null
 
@@ -218,7 +207,7 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
             DistributedRegion rgn = (DistributedRegion) lr;
 
             InternalCacheEvent event = createEvent(rgn);
-            if (DestroyRegionMessage.this.needsRouting
+            if (needsRouting
                 && lclRgn.cache.getCacheServers().size() > 0) {
               lclRgn.generateLocalFilterRouting(event);
             }
@@ -246,17 +235,17 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
           } finally {
             LocalRegion.setThreadInitLevelRequirement(oldLevel);
 
-            if (DestroyRegionMessage.this.lockRoot != null) {
-              DestroyRegionMessage.this.lockRoot.releaseDestroyLock();
+            if (lockRoot != null) {
+              lockRoot.releaseDestroyLock();
             }
 
             if (sendReply) {
-              if (DestroyRegionMessage.this.processorId != 0) {
+              if (processorId != 0) {
                 ReplyException rex = null;
                 if (thr != null) {
                   rex = new ReplyException(thr);
                 }
-                sendReply(getSender(), DestroyRegionMessage.this.processorId, rex,
+                sendReply(getSender(), processorId, rex,
                     getReplySender(dm));
               }
             } else if (thr != null) {
@@ -271,9 +260,9 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
     /** Return true if a reply should be sent */
     @Override
     protected void basicProcess(final ClusterDistributionManager dm, final LocalRegion lclRgn) {
-      Assert.assertTrue(this.serialNum != DistributionAdvisor.ILLEGAL_SERIAL);
+      Assert.assertTrue(serialNum != DistributionAdvisor.ILLEGAL_SERIAL);
       try {
-        this.lockRoot = null;
+        lockRoot = null;
         // may set lockRoot to the root region where destroyLock is acquired
 
         final boolean sendReply = true;
@@ -303,30 +292,30 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
       // this prevents us from getting a "stale" region
       if (getOperation().isDistributed()) {
         String rootName = GemFireCacheImpl.parsePath(path)[0];
-        this.lockRoot = (LocalRegion) cache.getRegion(rootName);
-        if (this.lockRoot == null) {
+        lockRoot = (LocalRegion) cache.getRegion(rootName);
+        if (lockRoot == null) {
           return null;
         }
-        this.lockRoot.acquireDestroyLock();
+        lockRoot.acquireDestroyLock();
       }
 
       return (LocalRegion) cache.getRegion(path);
     }
 
     private void disableRegionDepartureNotification() {
-      if (!this.notifyOfRegionDeparture) {
+      if (!notifyOfRegionDeparture) {
         regionDepartureNotificationDisabled.set(Boolean.TRUE);
       }
     }
 
     private void enableRegionDepartureNotification() {
-      if (!this.notifyOfRegionDeparture) {
+      if (!notifyOfRegionDeparture) {
         regionDepartureNotificationDisabled.remove();
       }
     }
 
     protected boolean doRegionDestroy(CacheEvent event) throws EntryNotFoundException {
-      this.appliedOperation = true;
+      appliedOperation = true;
       RegionEventImpl ev = (RegionEventImpl) event;
       final DistributedRegion rgn = (DistributedRegion) ev.region;
 
@@ -346,9 +335,9 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
         String fullPath = null;
         if (logger.isDebugEnabled()) {
           fullPath = rgn.getFullPath();
-          StringBuffer subregionNames = new StringBuffer();
-          for (Iterator itr = rgn.debugGetSubregionNames().iterator(); itr.hasNext();) {
-            subregionNames.append(itr.next());
+          StringBuilder subregionNames = new StringBuilder();
+          for (final Object o : rgn.debugGetSubregionNames()) {
+            subregionNames.append(o);
             subregionNames.append(", ");
           }
           logger.debug(
@@ -367,38 +356,33 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
           // Don't release the destroy lock until after we re-create
           rgn.reinitialize_destroy(ev);
 
-          final LocalRegion loc_lockRoot = this.lockRoot;
-          this.lockRoot = null; // spawned thread will release lock, not
-                                // basicProcess
+          final LocalRegion loc_lockRoot = lockRoot;
+          lockRoot = null; // spawned thread will release lock, not
+                           // basicProcess
 
           rgn.getDistributionManager().getExecutors().getWaitingThreadPool()
-              .execute(new Runnable() {
-                @Override
-                public void run() {
-                  try {
-                    rgn.reinitializeFromImageTarget(getSender());
-                  } catch (TimeoutException e) {
-                    // dlock timed out, log message
-                    logger.warn(String.format(
-                        "Got timeout when trying to recreate region during re-initialization: %s",
-                        rgn.getFullPath()),
-                        e);
-                  } catch (IOException e) {
-                    // only if loading snapshot, not here
-                    InternalGemFireError assErr = new InternalGemFireError(
-                        "unexpected exception");
-                    assErr.initCause(e);
-                    throw assErr;
-                  } catch (ClassNotFoundException e) {
-                    // only if loading snapshot, not here
-                    InternalGemFireError assErr = new InternalGemFireError(
-                        "unexpected exception");
-                    assErr.initCause(e);
-                    throw assErr;
-                  } finally {
-                    if (loc_lockRoot != null) {
-                      loc_lockRoot.releaseDestroyLock();
-                    }
+              .execute(() -> {
+                try {
+                  rgn.reinitializeFromImageTarget(getSender());
+                } catch (TimeoutException e) {
+                  // dlock timed out, log message
+                  logger.warn(String.format(
+                      "Got timeout when trying to recreate region during re-initialization: %s",
+                      rgn.getFullPath()),
+                      e);
+                } catch (IOException e) {
+                  // only if loading snapshot, not here
+                  InternalGemFireError assErr = new InternalGemFireError(
+                      "unexpected exception", e);
+                  throw assErr;
+                } catch (ClassNotFoundException e) {
+                  // only if loading snapshot, not here
+                  InternalGemFireError assErr = new InternalGemFireError(
+                      "unexpected exception", e);
+                  throw assErr;
+                } finally {
+                  if (loc_lockRoot != null) {
+                    loc_lockRoot.releaseDestroyLock();
                   }
                 }
               });
@@ -435,9 +419,9 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
     @Override
     protected void appendFields(StringBuilder buff) {
       super.appendFields(buff);
-      buff.append("; eventID=").append(this.eventID).append("; serialNum=").append(this.serialNum)
-          .append("; subregionSerialNumbers=").append(this.subregionSerialNumbers)
-          .append("; notifyOfRegionDeparture=").append(this.notifyOfRegionDeparture);
+      buff.append("; eventID=").append(eventID).append("; serialNum=").append(serialNum)
+          .append("; subregionSerialNumbers=").append(subregionSerialNumbers)
+          .append("; notifyOfRegionDeparture=").append(notifyOfRegionDeparture);
     }
 
     @Override
@@ -449,20 +433,20 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
     public void fromData(DataInput in,
         DeserializationContext context) throws IOException, ClassNotFoundException {
       super.fromData(in, context);
-      this.eventID = (EventID) DataSerializer.readObject(in);
-      this.serialNum = DataSerializer.readPrimitiveInt(in);
-      this.notifyOfRegionDeparture = DataSerializer.readPrimitiveBoolean(in);
-      this.subregionSerialNumbers = DataSerializer.readHashMap(in);
+      eventID = DataSerializer.readObject(in);
+      serialNum = DataSerializer.readPrimitiveInt(in);
+      notifyOfRegionDeparture = DataSerializer.readPrimitiveBoolean(in);
+      subregionSerialNumbers = DataSerializer.readHashMap(in);
     }
 
     @Override
     public void toData(DataOutput out,
         SerializationContext context) throws IOException {
       super.toData(out, context);
-      DataSerializer.writeObject(this.eventID, out);
-      DataSerializer.writePrimitiveInt(this.serialNum, out);
-      DataSerializer.writePrimitiveBoolean(this.notifyOfRegionDeparture, out);
-      DataSerializer.writeHashMap(this.subregionSerialNumbers, out);
+      DataSerializer.writeObject(eventID, out);
+      DataSerializer.writePrimitiveInt(serialNum, out);
+      DataSerializer.writePrimitiveBoolean(notifyOfRegionDeparture, out);
+      DataSerializer.writeHashMap(subregionSerialNumbers, out);
     }
   }
 
@@ -472,14 +456,14 @@ public class DestroyRegionOperation extends DistributedCacheOperation {
 
     @Override
     public RegionEventImpl createRegionEvent(DistributedRegion rgn) {
-      return new ClientRegionEventImpl(rgn, getOperation(), this.callbackArg,
-          true /* originRemote */, getSender(), (ClientProxyMembershipID) this.context);
+      return new ClientRegionEventImpl(rgn, getOperation(), callbackArg,
+          true /* originRemote */, getSender(), (ClientProxyMembershipID) context);
     }
 
     @Override
     protected void appendFields(StringBuilder buff) {
       super.appendFields(buff);
-      buff.append("; context=").append(this.context);
+      buff.append("; context=").append(context);
     }
 
     @Override
