@@ -16,6 +16,7 @@ package org.apache.geode.internal.cache;
 
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.RejectedExecutionException;
+import java.util.concurrent.TimeUnit;
 
 import org.apache.logging.log4j.Logger;
 import org.jgroups.annotations.GuardedBy;
@@ -54,7 +55,7 @@ public abstract class ExpiryTask extends SystemTimer.SystemTimerTask {
     int nThreads = Integer.getInteger(GeodeGlossary.GEMFIRE_PREFIX + "EXPIRY_THREADS", 0);
     if (nThreads > 0) {
       executor = CoreLoggingExecutors.newThreadPoolWithSynchronousFeed(nThreads, "Expiry ",
-          (Runnable command) -> doExpiryThread(command));
+          ExpiryTask::doExpiryThread);
     } else {
       executor = null;
     }
@@ -97,14 +98,40 @@ public abstract class ExpiryTask extends SystemTimer.SystemTimerTask {
     long ttl = getTTLAttributes().getTimeout();
     long tilt = 0;
     if (ttl > 0) {
-      if (getLocalRegion() != null && !getLocalRegion().EXPIRY_UNITS_MS) {
-        ttl *= 1000;
-      }
+      ttl = normalizeToMillis(ttl);
       tilt = getLastModifiedTime() + ttl;
     }
     return tilt;
   }
 
+  /** Return true if the expiration unit is seconds; false if milliseconds */
+  public boolean isExpiryUnitSeconds() {
+    boolean isSeconds = getLocalRegion() == null || !getLocalRegion().isExpiryUnitsMilliseconds();
+    return isSeconds;
+  }
+
+  /**
+   * Return the given timestamp as milliseconds.
+   * If the given secondsOrMillis is already millis then no conversion is needed.
+   */
+  public long normalizeToMillis(long secondsOrMillis) {
+    if (isExpiryUnitSeconds()) {
+      return TimeUnit.SECONDS.toMillis(secondsOrMillis);
+    }
+    return secondsOrMillis;
+  }
+
+  private static final long HALF_A_SECOND_IN_MILLIS = TimeUnit.SECONDS.toMillis(1) / 2;
+
+  public boolean hasExpired(long now, long expireTime) {
+    if (isExpiryUnitSeconds()) {
+      // Units are seconds but the internal timestamps are milliseconds.
+      // To prevent a needless reschedule, bump now by half a second.
+      now += HALF_A_SECOND_IN_MILLIS;
+    }
+    return now >= expireTime;
+  }
+
   /** Return the absolute time when idle expiration occurs, or 0 if not used */
   public long getIdleExpirationTime() throws EntryNotFoundException {
     long idle = getIdleTimeoutInMillis();
@@ -117,9 +144,7 @@ public abstract class ExpiryTask extends SystemTimer.SystemTimerTask {
   protected long getIdleTimeoutInMillis() {
     long idle = getIdleAttributes().getTimeout();
     if (idle > 0) {
-      if (getLocalRegion() != null && !getLocalRegion().EXPIRY_UNITS_MS) {
-        idle *= 1000;
-      }
+      idle = normalizeToMillis(idle);
     }
     return idle;
   }
@@ -144,15 +169,13 @@ public abstract class ExpiryTask extends SystemTimer.SystemTimerTask {
     long expTime = getExpirationTime();
     if (expTime > 0L) {
       long now = getNow();
-      if (now >= expTime) {
+      if (hasExpired(now, expTime)) {
         if (isIdleExpiredOnOthers()) {
           return true;
         } else {
           // our last access time was reset so recheck
           expTime = getExpirationTime();
-          if (expTime > 0L && now >= expTime) {
-            return true;
-          }
+          return expTime > 0L && hasExpired(now, expTime);
         }
       }
     }
@@ -178,7 +201,7 @@ public abstract class ExpiryTask extends SystemTimer.SystemTimerTask {
 
   protected void performTimeout() throws CacheException {
     if (logger.isDebugEnabled()) {
-      logger.debug("{}.performTimeout(): getExpirationTime() returns {}", this.toString(),
+      logger.debug("{}.performTimeout(): getExpirationTime() returns {}", toString(),
           getExpirationTime());
     }
 
@@ -285,7 +308,7 @@ public abstract class ExpiryTask extends SystemTimer.SystemTimerTask {
   }
 
   LocalRegion getLocalRegion() {
-    return this.region;
+    return region;
   }
 
 
@@ -315,7 +338,7 @@ public abstract class ExpiryTask extends SystemTimer.SystemTimerTask {
     LocalRegion lr = getLocalRegion();
     if (lr != null) {
       if (superCancel) {
-        this.region = null; // this is the only place it is nulled
+        region = null; // this is the only place it is nulled
       }
     }
     return superCancel;
@@ -330,12 +353,7 @@ public abstract class ExpiryTask extends SystemTimer.SystemTimerTask {
   public void run2() {
     try {
       if (executor != null) {
-        executor.execute(new Runnable() {
-          @Override
-          public void run() {
-            runInThreadPool();
-          }
-        });
+        executor.execute(this::runInThreadPool);
       } else {
         // inline
         runInThreadPool();
@@ -473,7 +491,7 @@ public abstract class ExpiryTask extends SystemTimer.SystemTimerTask {
 
   public abstract Object getKey();
 
-  private static final ThreadLocal<Long> now = new ThreadLocal<Long>();
+  private static final ThreadLocal<Long> now = new ThreadLocal<>();
 
   /**
    * To reduce the number of times we need to call calculateNow, you can call this method to set now
@@ -498,7 +516,7 @@ public abstract class ExpiryTask extends SystemTimer.SystemTimerTask {
     long result;
     Long tl = now.get();
     if (tl != null) {
-      result = tl.longValue();
+      result = tl;
     } else {
       result = calculateNow();
     }
