@@ -1070,11 +1070,6 @@ public class InternalCacheForClientAccess implements InternalCache {
     return delegate.getDistributionAdvisor();
   }
 
-  @Override
-  public void setQueryMonitorRequiredForResourceManager(boolean required) {
-    delegate.setQueryMonitorRequiredForResourceManager(required);
-  }
-
   @Override
   public boolean isQueryMonitorDisabledForLowMemory() {
     return delegate.isQueryMonitorDisabledForLowMemory();
