@@ -254,20 +254,16 @@ public class PartitionedRegionHelper {
               throw new CacheWriterException(
                   String.format(
                       "New PartitionedRegionConfig %s does not have newer version than previous %s",
-                      new Object[] {newConf, oldConf}));
+                      newConf, oldConf));
             }
           }
         });
       }
 
       // Create anonymous stats holder for Partitioned Region meta data
-      final HasCachePerfStats prMetaStatsHolder = new HasCachePerfStats() {
-        @Override
-        public CachePerfStats getCachePerfStats() {
-          return new CachePerfStats(cache.getDistributedSystem(), "RegionStats-partitionMetaData",
+      final HasCachePerfStats prMetaStatsHolder =
+          () -> new CachePerfStats(cache.getDistributedSystem(), "RegionStats-partitionMetaData",
               cache.getStatisticsClock());
-        }
-      };
 
       factory.setIsUsedForPartitionedRegionAdmin(true);
       factory.setInternalRegion(true);
@@ -320,7 +316,7 @@ public class PartitionedRegionHelper {
         return;
       }
 
-      final ArrayList<String> ks = new ArrayList<String>(rootReg.keySet());
+      final ArrayList<String> ks = new ArrayList<>(rootReg.keySet());
       if (ks.size() > 1) {
         Collections.shuffle(ks, PartitionedRegion.RANDOM);
       }
@@ -376,13 +372,10 @@ public class PartitionedRegionHelper {
           // we have determined the node to remove (Which includes the
           // serial number).
           cache.getDistributionManager().getExecutors().getPrMetaDataCleanupThreadPool()
-              .execute(new Runnable() {
-                @Override
-                public void run() {
-                  cleanPartitionedRegionMetaDataForNode(cache, node1, prConf, prName);
-                  if (postCleanupTask != null) {
-                    postCleanupTask.run();
-                  }
+              .execute(() -> {
+                cleanPartitionedRegionMetaDataForNode(cache, node1, prConf, prName);
+                if (postCleanupTask != null) {
+                  postCleanupTask.run();
                 }
               });
           runPostCleanUp = false;
@@ -678,11 +671,10 @@ public class PartitionedRegionHelper {
    * Find a ProxyBucketRegion by parsing the region fullPath
    *
    * @param fullPath full region path to parse
-   * @param postInit true if caller should wait for bucket initialization to complete
    * @return ProxyBucketRegion as Bucket or null if not found
    * @throws PRLocallyDestroyedException if the PartitionRegion is locally destroyed
    */
-  public static Bucket getProxyBucketRegion(Cache cache, String fullPath, boolean postInit)
+  public static Bucket getProxyBucketRegion(Cache cache, String fullPath)
       throws PRLocallyDestroyedException {
     if (cache == null) {
       // No cache
@@ -713,9 +705,7 @@ public class PartitionedRegionHelper {
 
     int bid = getBucketId(bucketName);
     RegionAdvisor ra = (RegionAdvisor) pr.getDistributionAdvisor();
-    if (postInit) {
-      return ra.getBucketPostInit(bid);
-    } else if (!ra.areBucketsInitialized()) {
+    if (!ra.areBucketsInitialized()) {
       // While the RegionAdvisor may be available, it's bucket meta-data may not be constructed yet
       return null;
     } else {
@@ -724,6 +714,31 @@ public class PartitionedRegionHelper {
 
   }
 
+  public static PartitionedRegion getPartitionedRegionUsingBucketRegionName(Cache cache,
+      String fullPath) {
+    if (cache == null) {
+      // No cache
+      return null;
+    }
+    // fullPath = /__PR/_B_1_10
+    String bucketName = getBucketName(fullPath);
+    if (bucketName == null) {
+      return null;
+    }
+    String prid = getPRPath(bucketName);
+    Region region;
+    final InitializationLevel oldLevel = LocalRegion.setThreadInitLevelRequirement(ANY_INIT);
+    try {
+      region = cache.getRegion(prid);
+    } finally {
+      LocalRegion.setThreadInitLevelRequirement(oldLevel);
+    }
+    if (!(region instanceof PartitionedRegion)) {
+      return null;
+    }
+    return (PartitionedRegion) region;
+  }
+
   private static final String BUCKET_FULL_PATH_PREFIX =
       PR_ROOT_REGION_NAME + SEPARATOR + BUCKET_REGION_PREFIX;
 
@@ -768,9 +783,11 @@ public class PartitionedRegionHelper {
 
 
   public static final String TWO_SEPARATORS = SEPARATOR + SEPARATOR;
+  public static final String THREE_SEPARATORS = TWO_SEPARATORS + SEPARATOR;
 
   public static String unescapePRPath(String escapedPath) {
     String path = escapedPath.replace('_', SEPARATOR_CHAR);
+    path = path.replace(THREE_SEPARATORS, SEPARATOR + "_");
     path = path.replace(TWO_SEPARATORS, "_");
     return path;
   }
@@ -902,7 +919,7 @@ public class PartitionedRegionHelper {
   }
 
   private static Set<String> getAllAvailablePartitions(PartitionedRegion region) {
-    Set<String> partitionSet = new HashSet<String>();
+    Set<String> partitionSet = new HashSet<>();
     List<FixedPartitionAttributesImpl> localFPAs = region.getFixedPartitionAttributesImpl();
     if (localFPAs != null) {
       for (FixedPartitionAttributesImpl fpa : localFPAs) {
@@ -920,7 +937,7 @@ public class PartitionedRegionHelper {
 
   public static Set<FixedPartitionAttributes> getAllFixedPartitionAttributes(
       PartitionedRegion region) {
-    Set<FixedPartitionAttributes> fpaSet = new HashSet<FixedPartitionAttributes>();
+    Set<FixedPartitionAttributes> fpaSet = new HashSet<>();
     List<FixedPartitionAttributesImpl> localFPAs = region.getFixedPartitionAttributesImpl();
     if (localFPAs != null) {
       fpaSet.addAll(localFPAs);
