@@ -17,29 +17,31 @@ package org.apache.geode.internal.cache;
 
 import java.io.DataInput;
 import java.io.DataOutput;
+import java.io.Externalizable;
 import java.io.IOException;
-import java.net.InetAddress;
+import java.io.ObjectInput;
+import java.io.ObjectOutput;
 import java.net.InetSocketAddress;
-import java.net.UnknownHostException;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Objects;
+import java.util.stream.Collectors;
 
 import org.apache.logging.log4j.Logger;
 
-import org.apache.geode.DataSerializable;
 import org.apache.geode.DataSerializer;
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.cache.CacheException;
 import org.apache.geode.cache.client.Pool;
 import org.apache.geode.cache.client.PoolFactory;
+import org.apache.geode.cache.client.SocketFactory;
 import org.apache.geode.cache.client.internal.LocatorDiscoveryCallback;
 import org.apache.geode.cache.client.internal.PoolImpl;
 import org.apache.geode.cache.query.QueryService;
 import org.apache.geode.cache.wan.GatewaySender;
 import org.apache.geode.distributed.internal.InternalDistributedSystem;
-import org.apache.geode.distributed.internal.tcpserver.LocatorAddress;
+import org.apache.geode.distributed.internal.tcpserver.HostAndPort;
 import org.apache.geode.internal.monitoring.ThreadsMonitoring;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.pdx.internal.TypeRegistry;
@@ -49,7 +51,7 @@ import org.apache.geode.pdx.internal.TypeRegistry;
  *
  * @since GemFire 5.7
  */
-public class PoolFactoryImpl implements PoolFactory {
+public class PoolFactoryImpl implements InternalPoolFactory {
   private static final Logger logger = LogService.getLogger();
 
   /**
@@ -57,7 +59,7 @@ public class PoolFactoryImpl implements PoolFactory {
    */
   private PoolAttributes attributes = new PoolAttributes();
 
-  private final List<LocatorAddress> locatorAddresses = new ArrayList<>();
+  private final List<HostAndPort> locatorAddresses = new ArrayList<>();
 
   /**
    * The cache that created this factory
@@ -86,6 +88,16 @@ public class PoolFactoryImpl implements PoolFactory {
     return this;
   }
 
+  @Override
+  public PoolFactory setServerConnectionTimeout(int serverConnectionTimeout) {
+    if (serverConnectionTimeout < 0) {
+      throw new IllegalArgumentException(
+          "serverConnectionTimeout must be greater than or equal to 0");
+    }
+    attributes.serverConnectionTimeout = serverConnectionTimeout;
+    return this;
+  }
+
   @Override
   public PoolFactory setLoadConditioningInterval(int connectionLifetime) {
     if (connectionLifetime < -1) {
@@ -212,6 +224,12 @@ public class PoolFactoryImpl implements PoolFactory {
     return this;
   }
 
+  @Override
+  public PoolFactory setSocketFactory(SocketFactory socketFactory) {
+    attributes.socketFactory = socketFactory;
+    return this;
+  }
+
   public PoolFactory setStartDisabled(boolean disable) {
     attributes.startDisabled = disable;
     return this;
@@ -247,28 +265,6 @@ public class PoolFactoryImpl implements PoolFactory {
     return this;
   }
 
-  private InetSocketAddress getInetSocketAddress(String host, int port) {
-    if (port == 0) {
-      throw new IllegalArgumentException("port must be greater than 0 but was " + port);
-      // the rest of the port validation is done by InetSocketAddress
-    }
-    InetSocketAddress sockAddr;
-    try {
-      InetAddress hostAddr = InetAddress.getByName(host);
-      sockAddr = new InetSocketAddress(hostAddr, port);
-    } catch (UnknownHostException ignore) {
-      // IllegalArgumentException ex = new IllegalArgumentException("Unknown host " + host);
-      // ex.initCause(cause);
-      // throw ex;
-      // Fix for #45348
-      logger.warn(
-          "Hostname is unknown: {}. Creating pool with unknown host in case the host becomes known later.",
-          host);
-      sockAddr = new InetSocketAddress(host, port);
-    }
-    return sockAddr;
-  }
-
   @Override
   public PoolFactory setSubscriptionAckInterval(int ackInterval) {
     if (ackInterval <= 0) {
@@ -285,9 +281,10 @@ public class PoolFactoryImpl implements PoolFactory {
       throw new IllegalStateException(
           "A server has already been added. You can only add locators or servers; not both.");
     }
-    InetSocketAddress isa = getInetSocketAddress(host, port);
-    attributes.locators.add(isa);
-    locatorAddresses.add(new LocatorAddress(isa, host));
+    validatePort(port);
+    HostAndPort address = new HostAndPort(host, port);
+    attributes.locators.add(address);
+    locatorAddresses.add(address);
     return this;
   }
 
@@ -297,10 +294,17 @@ public class PoolFactoryImpl implements PoolFactory {
       throw new IllegalStateException(
           "A locator has already been added. You can only add locators or servers; not both.");
     }
-    attributes.servers.add(getInetSocketAddress(host, port));
+    validatePort(port);
+    attributes.servers.add(new HostAndPort(host, port));
     return this;
   }
 
+  private void validatePort(int port) {
+    if (port <= 0) {
+      throw new IllegalArgumentException("port must be greater than 0 but was " + port);
+    }
+  }
+
   @Override
   public PoolFactory reset() {
     // preserve the startDisabled across resets
@@ -310,13 +314,11 @@ public class PoolFactoryImpl implements PoolFactory {
     return this;
   }
 
-
-  /**
-   * Initializes the state of this factory for the given pool's state.
-   */
+  @Override
   public void init(Pool cp) {
     setSocketConnectTimeout(cp.getSocketConnectTimeout());
     setFreeConnectionTimeout(cp.getFreeConnectionTimeout());
+    setServerConnectionTimeout(cp.getServerConnectionTimeout());
     setLoadConditioningInterval(cp.getLoadConditioningInterval());
     setSocketBufferSize(cp.getSocketBufferSize());
     setReadTimeout(cp.getReadTimeout());
@@ -334,10 +336,12 @@ public class PoolFactoryImpl implements PoolFactory {
     setSubscriptionAckInterval(cp.getSubscriptionAckInterval());
     setServerGroup(cp.getServerGroup());
     setMultiuserAuthentication(cp.getMultiuserAuthentication());
-    for (InetSocketAddress inetSocketAddress : cp.getLocators()) {
-      addLocator(inetSocketAddress.getHostName(), inetSocketAddress.getPort());
+    setSocketFactory(cp.getSocketFactory());
+    for (InetSocketAddress address : cp.getLocators()) {
+      addLocator(address.getHostString(), address.getPort());
     }
-    attributes.servers.addAll(cp.getServers());
+    attributes.servers.addAll(cp.getServers().stream()
+        .map(x -> new HostAndPort(x.getHostString(), x.getPort())).collect(Collectors.toList()));
   }
 
   public void init(GatewaySender sender) {
@@ -380,9 +384,8 @@ public class PoolFactoryImpl implements PoolFactory {
     return GemFireCacheImpl.getInstance();
   }
 
-  /**
-   * Needed by test framework.
-   */
+  @Override
+  @VisibleForTesting
   public PoolAttributes getPoolAttributes() {
     return attributes;
   }
@@ -408,12 +411,14 @@ public class PoolFactoryImpl implements PoolFactory {
   /**
    * Not a true pool just the attributes. Serialization is used by unit tests
    */
-  public static class PoolAttributes implements Pool, DataSerializable {
+  public static class PoolAttributes implements Pool, Externalizable {
 
     private static final long serialVersionUID = 1L; // for findbugs
 
     int socketConnectTimeout = DEFAULT_SOCKET_CONNECT_TIMEOUT;
+    SocketFactory socketFactory = DEFAULT_SOCKET_FACTORY;
     int connectionTimeout = DEFAULT_FREE_CONNECTION_TIMEOUT;
+    int serverConnectionTimeout = DEFAULT_SERVER_CONNECTION_TIMEOUT;
     int connectionLifetime = DEFAULT_LOAD_CONDITIONING_INTERVAL;
     public int socketBufferSize = DEFAULT_SOCKET_BUFFER_SIZE;
     @Deprecated
@@ -433,8 +438,8 @@ public class PoolFactoryImpl implements PoolFactory {
     int subscriptionTimeoutMultipler = DEFAULT_SUBSCRIPTION_TIMEOUT_MULTIPLIER;
     public String serverGroup = DEFAULT_SERVER_GROUP;
     boolean multiuserSecureModeEnabled = DEFAULT_MULTIUSER_AUTHENTICATION;
-    public ArrayList<InetSocketAddress> locators = new ArrayList<>();
-    public ArrayList<InetSocketAddress> servers = new ArrayList<>();
+    public ArrayList<HostAndPort> locators = new ArrayList<>();
+    public ArrayList<HostAndPort> servers = new ArrayList<>();
     public transient boolean startDisabled = false; // only used by junit tests
     public transient LocatorDiscoveryCallback locatorCallback = null; // only used by tests
     public GatewaySender gatewaySender = null;
@@ -453,6 +458,11 @@ public class PoolFactoryImpl implements PoolFactory {
       return connectionTimeout;
     }
 
+    @Override
+    public int getServerConnectionTimeout() {
+      return serverConnectionTimeout;
+    }
+
     @Override
     public int getLoadConditioningInterval() {
       return connectionLifetime;
@@ -564,13 +574,18 @@ public class PoolFactoryImpl implements PoolFactory {
       return subscriptionTimeoutMultipler;
     }
 
+    @Override
+    public SocketFactory getSocketFactory() {
+      return socketFactory;
+    }
+
     @Override
     public List<InetSocketAddress> getLocators() {
       if (locators.size() == 0 && servers.size() == 0) {
         throw new IllegalStateException(
             "At least one locator or server must be added before a connection pool can be created.");
       }
-      return Collections.unmodifiableList(new ArrayList<>(locators));
+      return locators.stream().map(x -> x.getSocketInetAddress()).collect(Collectors.toList());
     }
 
     @Override
@@ -585,7 +600,7 @@ public class PoolFactoryImpl implements PoolFactory {
             "At least one locator or server must be added before a connection pool can be created.");
       }
       // needs to return a copy.
-      return Collections.unmodifiableList(new ArrayList<>(servers));
+      return servers.stream().map(x -> x.getSocketInetAddress()).collect(Collectors.toList());
     }
 
     @Override
@@ -619,9 +634,9 @@ public class PoolFactoryImpl implements PoolFactory {
     }
 
 
-    @Override
     public void toData(DataOutput out) throws IOException {
       DataSerializer.writePrimitiveInt(connectionTimeout, out);
+      DataSerializer.writePrimitiveInt(serverConnectionTimeout, out);
       DataSerializer.writePrimitiveInt(connectionLifetime, out);
       DataSerializer.writePrimitiveInt(socketBufferSize, out);
       DataSerializer.writePrimitiveInt(readTimeout, out);
@@ -642,9 +657,9 @@ public class PoolFactoryImpl implements PoolFactory {
       DataSerializer.writePrimitiveInt(socketConnectTimeout, out);
     }
 
-    @Override
     public void fromData(DataInput in) throws IOException, ClassNotFoundException {
       connectionTimeout = DataSerializer.readPrimitiveInt(in);
+      serverConnectionTimeout = DataSerializer.readPrimitiveInt(in);
       connectionLifetime = DataSerializer.readPrimitiveInt(in);
       socketBufferSize = DataSerializer.readPrimitiveInt(in);
       readTimeout = DataSerializer.readPrimitiveInt(in);
@@ -668,12 +683,13 @@ public class PoolFactoryImpl implements PoolFactory {
     @Override
     public int hashCode() {
       return Objects
-          .hash(socketConnectTimeout, connectionTimeout, connectionLifetime, socketBufferSize,
+          .hash(socketConnectTimeout, connectionTimeout, serverConnectionTimeout,
+              connectionLifetime, socketBufferSize,
               threadLocalConnections, readTimeout, minConnections, maxConnections, idleTimeout,
               retryAttempts, pingInterval, statisticInterval, queueEnabled, prSingleHopEnabled,
               queueRedundancyLevel, queueMessageTrackingTimeout, queueAckInterval,
               subscriptionTimeoutMultipler, serverGroup, multiuserSecureModeEnabled, locators,
-              servers, startDisabled, locatorCallback, gatewaySender, gateway);
+              servers, startDisabled, locatorCallback, gatewaySender, gateway, socketFactory);
     }
 
     @Override
@@ -687,6 +703,7 @@ public class PoolFactoryImpl implements PoolFactory {
       PoolAttributes that = (PoolAttributes) o;
       return socketConnectTimeout == that.socketConnectTimeout
           && connectionTimeout == that.connectionTimeout
+          && serverConnectionTimeout == that.serverConnectionTimeout
           && connectionLifetime == that.connectionLifetime
           && socketBufferSize == that.socketBufferSize
           && threadLocalConnections == that.threadLocalConnections
@@ -704,7 +721,18 @@ public class PoolFactoryImpl implements PoolFactory {
           && Objects.equals(new HashSet<>(locators), new HashSet<>(that.locators))
           && Objects.equals(new HashSet<>(servers), new HashSet<>(that.servers))
           && Objects.equals(locatorCallback, that.locatorCallback)
-          && Objects.equals(gatewaySender, that.gatewaySender);
+          && Objects.equals(gatewaySender, that.gatewaySender)
+          && Objects.equals(socketFactory, that.socketFactory);
+    }
+
+    @Override
+    public void writeExternal(ObjectOutput out) throws IOException {
+      toData(out);
+    }
+
+    @Override
+    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
+      fromData(in);
     }
   }
 }
