@@ -101,7 +101,7 @@ public class ThreadIdentifier implements DataSerializable {
     /** the field width */
     private final int width;
 
-    private Bits(int position, int width) {
+    Bits(int position, int width) {
       this.position = position;
       this.width = width;
     }
@@ -141,8 +141,8 @@ public class ThreadIdentifier implements DataSerializable {
   public ThreadIdentifier() {}
 
   public ThreadIdentifier(final byte[] mid, long threadId) {
-    this.membershipID = mid;
-    this.threadID = threadId;
+    membershipID = mid;
+    threadID = threadId;
   }
 
   @Override
@@ -151,8 +151,8 @@ public class ThreadIdentifier implements DataSerializable {
       return false;
     }
     ThreadIdentifier other = (ThreadIdentifier) obj;
-    return (this.threadID == other.threadID
-        && EventID.equalMembershipIds(this.membershipID, other.membershipID));
+    return (threadID == other.threadID
+        && EventID.equalMembershipIds(membershipID, other.membershipID));
   }
 
   @Override
@@ -160,8 +160,8 @@ public class ThreadIdentifier implements DataSerializable {
     final int mult = 37;
 
     int result = EventID.hashCodeMemberId(membershipID);
-    result = mult * result + (int) this.threadID;
-    result = mult * result + (int) (this.threadID >>> 32);
+    result = mult * result + (int) threadID;
+    result = mult * result + (int) (threadID >>> 32);
 
     return result;
   }
@@ -189,14 +189,11 @@ public class ThreadIdentifier implements DataSerializable {
 
   @Override
   public String toString() {
-    StringBuilder sb = new StringBuilder();
 
-    sb.append("ThreadId[");
-    sb.append("id=").append(membershipID.length).append("bytes; ");
-    sb.append(toDisplayString(threadID));
-    sb.append("]");
-
-    return sb.toString();
+    return "ThreadId["
+        + "id=" + membershipID.length + "bytes; "
+        + toDisplayString(threadID)
+        + "]";
   }
 
   public String expensiveToString() {
@@ -247,7 +244,7 @@ public class ThreadIdentifier implements DataSerializable {
    * @return whether the thread id is generated by ParallelGatewaySender
    */
   public static boolean isParallelWANThreadID(long tid) {
-    return WanType.matches(tid) ? true : tid / MAX_THREAD_PER_CLIENT > (MAX_BUCKET_PER_PR + 2);
+    return WanType.matches(tid) || tid / MAX_THREAD_PER_CLIENT > (MAX_BUCKET_PER_PR + 2);
   }
 
   /**
@@ -304,7 +301,7 @@ public class ThreadIdentifier implements DataSerializable {
    * @return whether the two IDs are from the same member
    */
   public boolean isSameMember(ThreadIdentifier other) {
-    return Arrays.equals(this.membershipID, other.membershipID);
+    return Arrays.equals(membershipID, other.membershipID);
   }
 
   @Override
