@@ -35,6 +35,7 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.Semaphore;
 import java.util.concurrent.atomic.AtomicLong;
+import java.util.function.Predicate;
 
 import org.apache.logging.log4j.Logger;
 
@@ -101,7 +102,7 @@ public class RegionAdvisor extends CacheDistributionAdvisor {
   protected Queue<QueuedBucketProfile> preInitQueue;
   private final Object preInitQueueMonitor = new Object();
 
-  private ConcurrentHashMap<Integer, Set<ServerBucketProfile>> clientBucketProfilesMap;
+  private final ConcurrentHashMap<Integer, Set<ServerBucketProfile>> clientBucketProfilesMap;
 
   @VisibleForTesting
   protected RegionAdvisor(PartitionedRegion region) {
@@ -180,19 +181,23 @@ public class RegionAdvisor extends CacheDistributionAdvisor {
               logger.trace(LogMarker.DISTRIBUTION_ADVISOR_VERBOSE,
                   "applying queued profile removal for all buckets for {}", qbp.memberId);
             }
-            for (int i = 0; i < buckets.length; i++) {
-              BucketAdvisor ba = buckets[i].getBucketAdvisor();
-              int serial = qbp.serials[i];
-              if (serial != ILLEGAL_SERIAL) {
-                ba.removeIdWithSerial(qbp.memberId, serial, qbp.destroyed);
-              }
-            } // for
+            if (qbp.serials.length == 1 && qbp.serials[0] != ILLEGAL_SERIAL) {
+              buckets[qbp.bucketId].getBucketAdvisor().removeIdWithSerial(qbp.memberId,
+                  qbp.serials[0], qbp.destroyed);
+            } else {
+              for (int i = 0; i < buckets.length; i++) {
+                BucketAdvisor ba = buckets[i].getBucketAdvisor();
+                int serial = qbp.serials[i];
+                if (serial != ILLEGAL_SERIAL) {
+                  ba.removeIdWithSerial(qbp.memberId, serial, qbp.destroyed);
+                }
+              } // for
+            }
           } // apply removal for member still in the view
         } // while
         finishedInitQueue = true;
       } finally {
         preInitQueue = null; // prevent further additions to the queue
-        preInitQueueMonitor.notifyAll();
         if (!finishedInitQueue && !getAdvisee().getCancelCriterion().isCancelInProgress()) {
           logger.error("Failed to process all queued BucketProfiles for {}",
               getAdvisee());
@@ -426,6 +431,23 @@ public class RegionAdvisor extends CacheDistributionAdvisor {
     }
   }
 
+  public void removeIdAndBucket(int bucketId, InternalDistributedMember memberId, int serial,
+      boolean regionDestroyed) {
+    synchronized (preInitQueueMonitor) {
+      if (preInitQueue != null) {
+        // Queue profile during pre-initialization
+        QueuedBucketProfile qbf =
+            new QueuedBucketProfile(bucketId, memberId, serial, regionDestroyed);
+        preInitQueue.add(qbf);
+        return;
+      }
+    }
+
+    if (buckets != null) {
+      buckets[bucketId].getBucketAdvisor().removeIdWithSerial(memberId, serial, regionDestroyed);
+    }
+  }
+
   /**
    * Iterates over all buckets and marks them sick if the given member hosts the bucket.
    *
@@ -850,7 +872,7 @@ public class RegionAdvisor extends CacheDistributionAdvisor {
   }
 
   @Immutable
-  private static final Filter prServerWithInterestFilter = profile -> {
+  private static final Predicate<Profile> prServerWithInterestFilter = profile -> {
     CacheProfile prof = (CacheProfile) profile;
     return prof.isPartitioned && prof.hasCacheServer && prof.filterProfile != null
         && prof.filterProfile.hasInterest();
@@ -1001,36 +1023,6 @@ public class RegionAdvisor extends CacheDistributionAdvisor {
     return result;
   }
 
-  /**
-   * Returns the bucket identified by bucketId after waiting for initialization to finish processing
-   * queued profiles. Call synchronizes and waits on {@link #preInitQueueMonitor}.
-   *
-   * @param bucketId the bucket identifier
-   * @return the bucket identified by bucketId
-   * @throws org.apache.geode.distributed.DistributedSystemDisconnectedException if interrupted for
-   *         shutdown cancellation
-   */
-  public Bucket getBucketPostInit(int bucketId) {
-    synchronized (preInitQueueMonitor) {
-      boolean interrupted = false;
-      try {
-        while (preInitQueue != null) {
-          try {
-            preInitQueueMonitor.wait(); // spurious wakeup ok
-          } catch (InterruptedException e) {
-            interrupted = true;
-            getAdvisee().getCancelCriterion().checkCancelInProgress(e);
-          }
-        }
-      } finally {
-        if (interrupted) {
-          Thread.currentThread().interrupt();
-        }
-      }
-    }
-    return getBucket(bucketId);
-  }
-
   /**
    * Get the most recent primary node for the bucketId. Returns null if no primary can be found
    * within {@link DistributionConfig#getMemberTimeout}.
@@ -1462,6 +1454,19 @@ public class RegionAdvisor extends CacheDistributionAdvisor {
       this.destroyed = destroyed;
       fromMembershipListener = false;
     }
+
+    QueuedBucketProfile(int bucketId, InternalDistributedMember mbr, int serial,
+        boolean destroyed) {
+      this.bucketId = bucketId;
+      bucketProfile = null;
+      isRemoval = true;
+      crashed = false;
+      memberDeparted = false;
+      memberId = mbr;
+      this.serials = new int[] {serial};
+      this.destroyed = destroyed;
+      fromMembershipListener = false;
+    }
   }
 
   public Set<InternalDistributedMember> adviseBucketProfileExchange() {
