@@ -28,7 +28,9 @@ import java.util.Map.Entry;
 import java.util.Set;
 
 import org.apache.logging.log4j.Logger;
+import org.jetbrains.annotations.TestOnly;
 
+import org.apache.geode.CancelException;
 import org.apache.geode.annotations.Immutable;
 import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.annotations.internal.MutableForTesting;
@@ -510,18 +512,18 @@ public class PersistenceAdvisorImpl implements InternalPersistenceAdvisor {
   public boolean checkMyStateOnMembers(Set<InternalDistributedMember> replicates)
       throws ReplyException {
     PersistentStateQueryResults remoteStates = getMyStateOnMembers(replicates);
+    Set<InternalDistributedMember> copyOfReplicates = null;
 
     persistenceAdvisorObserver.observe(regionPath);
 
     boolean equal = false;
+    PersistentMemberID myId = getPersistentID();
     for (Map.Entry<InternalDistributedMember, PersistentMemberState> entry : remoteStates
         .getStateOnPeers().entrySet()) {
       InternalDistributedMember member = entry.getKey();
       PersistentMemberID remoteId = remoteStates.getPersistentIds().get(member);
 
-      PersistentMemberID myId = getPersistentID();
       PersistentMemberState stateOnPeer = entry.getValue();
-
       if (PersistentMemberState.REVOKED.equals(stateOnPeer)) {
         throw new RevokedPersistentDataException(
             String.format(
@@ -533,7 +535,19 @@ public class PersistenceAdvisorImpl implements InternalPersistenceAdvisor {
         String message = String.format(
             "Region %s remote member %s with persistent data %s was not part of the same distributed system as the local data from %s",
             regionPath, member, remoteId, myId);
-        throw new ConflictingPersistentDataException(message);
+        // Conceptually the removed member due to not knowing current member, should be equal to
+        // existing replicates.
+        // It can still be used as GII provider candidate. Use a copyOfReplicates to avoid modifying
+        // the replicates.
+        if (copyOfReplicates == null) {
+          copyOfReplicates = new HashSet<>(replicates);
+        }
+        copyOfReplicates.remove(member);
+        if (copyOfReplicates.isEmpty()) {
+          throw new ConflictingPersistentDataException(message);
+        } else {
+          logger.info(message);
+        }
       }
 
       if (myId != null && stateOnPeer == PersistentMemberState.EQUAL) {
@@ -709,12 +723,20 @@ public class PersistenceAdvisorImpl implements InternalPersistenceAdvisor {
   @Override
   public void removeListener(PersistentStateListener listener) {
     synchronized (this) {
+      if (!persistentStateListeners.contains(listener)) {
+        return;
+      }
       Set<PersistentStateListener> tmpListeners = new HashSet<>(persistentStateListeners);
       tmpListeners.remove(listener);
       persistentStateListeners = Collections.unmodifiableSet(tmpListeners);
     }
   }
 
+  @TestOnly
+  Set<PersistentStateListener> getPersistentStateListenerSet() {
+    return persistentStateListeners;
+  }
+
   private void notifyListenersMemberOnline(InternalDistributedMember member,
       PersistentMemberID persistentID) {
     for (PersistentStateListener listener : persistentStateListeners) {
@@ -1140,10 +1162,19 @@ public class PersistenceAdvisorImpl implements InternalPersistenceAdvisor {
 
   @Override
   public void close() {
-    isClosed = true;
-    persistentMemberManager.removeRevocationListener(profileChangeListener);
-    cacheDistributionAdvisor.removeProfileChangeListener(profileChangeListener);
-    releaseTieLock();
+    try {
+      synchronized (this) {
+        isClosed = true;
+        persistentMemberManager.removeRevocationListener(profileChangeListener);
+        cacheDistributionAdvisor.removeProfileChangeListener(profileChangeListener);
+        persistentStateListeners = Collections.emptySet();
+        releaseTieLock();
+      }
+    } catch (CancelException e) {
+      logger.debug("persistence advisor close abridged due to shutdown", e);
+    } catch (Exception ex) {
+      logger.warn("persistence advisor close has failed.", ex);
+    }
   }
 
   /**
