@@ -61,6 +61,11 @@ public class CacheClientProxyStats implements MessageStats {
   /** Name of the CQ count statistic */
   private static final String CQ_COUNT = "cqCount";
 
+  /** Name of the messages currently being queued statistic */
+  private static final String MESSAGES_BEING_QUEUED_IN_PROGRESS = "messagesBeingQueuedInProgress";
+  /** Name of the messages queueing time statistic */
+  private static final String MESSAGES_BEING_QUEUED_TIME = "messagesBeingQueuedTime";
+
   /** Id of the messages received statistic */
   private static final int _messagesReceivedId;
   /** Id of the messages queued statistic */
@@ -85,6 +90,12 @@ public class CacheClientProxyStats implements MessageStats {
   private static final int _cqCountId;
   private static final int _sentBytesId;
 
+  /** Id of the messages currently being queued statistic */
+  private static final int _messagesBeingQueuedInProgressId;
+  /** Id of the messages queueing time statistic */
+  private static final int _messagesBeingQueuedTimeId;
+
+
   /*
    * Static initializer to create and initialize the <code>StatisticsType</code>
    */
@@ -128,7 +139,14 @@ public class CacheClientProxyStats implements MessageStats {
             "operations"),
 
         f.createLongCounter(CQ_COUNT, "Number of CQs on the client.", "operations"),
-        f.createLongCounter("sentBytes", "Total number of bytes sent to client.", "bytes"),});
+        f.createLongCounter("sentBytes", "Total number of bytes sent to client.", "bytes"),
+
+        f.createLongGauge(MESSAGES_BEING_QUEUED_IN_PROGRESS,
+            "Threads currently adding a message to the queue. Consistently high values indicate that the queue is full and adds are being delayed.",
+            "threads"),
+        f.createLongCounter(MESSAGES_BEING_QUEUED_TIME,
+            "Total time spent while message is put in queue.", "nanoseconds"),
+    });
 
     // Initialize id fields
     _messagesReceivedId = _type.nameToId(MESSAGES_RECEIVED);
@@ -143,6 +161,9 @@ public class CacheClientProxyStats implements MessageStats {
     _deltaFullMessagesSentId = _type.nameToId(DELTA_FULL_MESSAGES_SENT);
     _cqCountId = _type.nameToId(CQ_COUNT);
     _sentBytesId = _type.nameToId("sentBytes");
+    _messagesBeingQueuedInProgressId = _type.nameToId(MESSAGES_BEING_QUEUED_IN_PROGRESS);
+    _messagesBeingQueuedTimeId = _type.nameToId(MESSAGES_BEING_QUEUED_TIME);
+
   }
 
   ////////////////////// Instance Fields //////////////////////
@@ -160,7 +181,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @param name The name of the <code>Statistics</code>
    */
   public CacheClientProxyStats(StatisticsFactory factory, String name) {
-    this._stats = factory.createAtomicStatistics(_type, "cacheClientProxyStats-" + name);
+    _stats = factory.createAtomicStatistics(_type, "cacheClientProxyStats-" + name);
   }
 
   ///////////////////// Instance Methods /////////////////////
@@ -169,7 +190,7 @@ public class CacheClientProxyStats implements MessageStats {
    * Closes the <code>CacheClientProxyStats</code>.
    */
   public void close() {
-    this._stats.close();
+    _stats.close();
   }
 
   /**
@@ -178,7 +199,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @return the current value of the "messagesReceived" stat
    */
   public int getMessagesReceived() {
-    return this._stats.getInt(_messagesReceivedId);
+    return _stats.getInt(_messagesReceivedId);
   }
 
   /**
@@ -187,7 +208,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @return the current value of the "messagesQueued" stat
    */
   public int getMessagesQueued() {
-    return this._stats.getInt(_messagesQueuedId);
+    return _stats.getInt(_messagesQueuedId);
   }
 
   /**
@@ -196,7 +217,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @return the current value of the "messagesNotQueuedOriginator" stat
    */
   public int getMessagesNotQueuedOriginator() {
-    return this._stats.getInt(_messagesNotQueuedOriginatorId);
+    return _stats.getInt(_messagesNotQueuedOriginatorId);
   }
 
   /**
@@ -205,7 +226,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @return the current value of the "messagesNotQueuedNotInterested" stat
    */
   public int getMessagesNotQueuedNotInterested() {
-    return this._stats.getInt(_messagesNotQueuedNotInterestedId);
+    return _stats.getInt(_messagesNotQueuedNotInterestedId);
   }
 
   /**
@@ -214,7 +235,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @return the current value of the "messagesFailedQueued" stat
    */
   public int getMessagesFailedQueued() {
-    return this._stats.getInt(_messagesFailedQueuedId);
+    return _stats.getInt(_messagesFailedQueuedId);
   }
 
   /**
@@ -223,7 +244,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @return the current value of the "messageQueueSize" stat
    */
   public int getMessageQueueSize() {
-    return this._stats.getInt(_messageQueueSizeId);
+    return _stats.getInt(_messageQueueSizeId);
   }
 
   /**
@@ -232,7 +253,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @return the current value of the messagesProcessed" stat
    */
   public int getMessagesProcessed() {
-    return this._stats.getInt(_messagesProcessedId);
+    return _stats.getInt(_messagesProcessedId);
   }
 
   /**
@@ -241,7 +262,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @return the current value of the "messageProcessingTime" stat
    */
   public long getMessageProcessingTime() {
-    return this._stats.getLong(_messageProcessingTimeId);
+    return _stats.getLong(_messageProcessingTimeId);
   }
 
   /**
@@ -250,7 +271,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @return the current value of the "deltaMessagesSent" stat
    */
   public int getDeltaMessagesSent() {
-    return this._stats.getInt(_deltaMessagesSentId);
+    return _stats.getInt(_deltaMessagesSentId);
   }
 
   /**
@@ -259,7 +280,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @return the current value of the "deltaFullMessagesSent" stat
    */
   public int getDeltaFullMessagesSent() {
-    return this._stats.getInt(_deltaFullMessagesSentId);
+    return _stats.getInt(_deltaFullMessagesSentId);
   }
 
   /**
@@ -268,56 +289,89 @@ public class CacheClientProxyStats implements MessageStats {
    * @return the current value of the "cqCount" stat
    */
   public int getCqCount() {
-    return this._stats.getInt(_cqCountId);
+    return _stats.getInt(_cqCountId);
   }
 
+  /**
+   * Returns the current value of the "_messagesBeingQueuedInProgress" stat.
+   *
+   * @return the current value of the "_messagesBeingQueuedInProgress" stat
+   */
+  public long getMessagesBeingQueuedInProgress() {
+    return _stats.getLong(_messagesBeingQueuedInProgressId);
+  }
+
+  /**
+   * Returns the current value of the "_messagesBeingQueuedTime" stat.
+   *
+   * @return the current value of the "_messagesBeingQueuedTime" stat
+   */
+  public long getMessagesBeingQueuedTime() {
+    return _stats.getLong(_messagesBeingQueuedTimeId);
+  }
+
+
   /**
    * Increments the "messagesReceived" stat.
    */
   public void incMessagesReceived() {
-    this._stats.incInt(_messagesReceivedId, 1);
+    _stats.incInt(_messagesReceivedId, 1);
   }
 
   /**
    * Increments the "messagesQueued" stat.
    */
   public void incMessagesQueued() {
-    this._stats.incInt(_messagesQueuedId, 1);
+    _stats.incInt(_messagesQueuedId, 1);
   }
 
   /**
    * Increments the "messagesNotQueuedOriginator" stat.
    */
   public void incMessagesNotQueuedOriginator() {
-    this._stats.incInt(_messagesNotQueuedOriginatorId, 1);
+    _stats.incInt(_messagesNotQueuedOriginatorId, 1);
   }
 
   /**
    * Increments the "messagesNotQueuedNotInterested" stat.
    */
   public void incMessagesNotQueuedNotInterested() {
-    this._stats.incInt(_messagesNotQueuedNotInterestedId, 1);
+    _stats.incInt(_messagesNotQueuedNotInterestedId, 1);
   }
 
   /**
    * Increments the "messagesFailedQueued" stat.
    */
   public void incMessagesFailedQueued() {
-    this._stats.incInt(_messagesFailedQueuedId, 1);
+    _stats.incInt(_messagesFailedQueuedId, 1);
   }
 
   /**
    * Increments the "cqCount" stat.
    */
   public void incCqCount() {
-    this._stats.incInt(_cqCountId, 1);
+    _stats.incInt(_cqCountId, 1);
+  }
+
+  /**
+   * Increments the "messagesBeingQueuedInProgress" stat.
+   */
+  public void incMessagesBeingQueuedInProgress() {
+    _stats.incLong(_messagesBeingQueuedInProgressId, 1);
   }
 
   /**
    * Decrements the "cqCount" stat.
    */
   public void decCqCount() {
-    this._stats.incInt(_cqCountId, -1);
+    _stats.incInt(_cqCountId, -1);
+  }
+
+  /**
+   * Decrements the "messagesBeingQueuedInProgress" stat.
+   */
+  public void decMessagesBeingQueuedInProgress() {
+    _stats.incLong(_messagesBeingQueuedInProgressId, -1);
   }
 
   /**
@@ -326,7 +380,7 @@ public class CacheClientProxyStats implements MessageStats {
    * @param size The size of the queue
    */
   public void setQueueSize(int size) {
-    this._stats.setInt(_messageQueueSizeId, size);
+    _stats.setInt(_messageQueueSizeId, size);
   }
 
   /**
@@ -348,25 +402,25 @@ public class CacheClientProxyStats implements MessageStats {
     long ts = DistributionStats.getStatTime();
 
     // Increment number of notifications
-    this._stats.incInt(_messagesProcessedId, 1);
+    _stats.incInt(_messagesProcessedId, 1);
 
     // Increment notification time
     long elapsed = ts - start;
-    this._stats.incLong(_messageProcessingTimeId, elapsed);
+    _stats.incLong(_messageProcessingTimeId, elapsed);
   }
 
   /**
    * Increments the "deltaMessagesSent" stats.
    */
   public void incDeltaMessagesSent() {
-    this._stats.incInt(_deltaMessagesSentId, 1);
+    _stats.incInt(_deltaMessagesSentId, 1);
   }
 
   /**
    * Increments the "deltaFullMessagesSent" stats.
    */
   public void incDeltaFullMessagesSent() {
-    this._stats.incInt(_deltaFullMessagesSentId, 1);
+    _stats.incInt(_deltaFullMessagesSentId, 1);
   }
 
   @Override
@@ -376,7 +430,7 @@ public class CacheClientProxyStats implements MessageStats {
 
   @Override
   public void incSentBytes(long v) {
-    this._stats.incLong(_sentBytesId, v);
+    _stats.incLong(_sentBytesId, v);
   }
 
   @Override
@@ -388,4 +442,18 @@ public class CacheClientProxyStats implements MessageStats {
   public void decMessagesBeingReceived(int bytes) {
     // noop since we never receive
   }
+
+  public long startMessageQueueStats() {
+    incMessagesBeingQueuedInProgress();
+    return startTime();
+  }
+
+  public void endMessageQueueStats(long startTime) {
+    long ts = DistributionStats.getStatTime();
+
+    decMessagesBeingQueuedInProgress();
+
+    long elapsed = ts - startTime;
+    _stats.incLong(_messagesBeingQueuedTimeId, elapsed);
+  }
 }
