@@ -154,7 +154,7 @@ public class CacheServerHelper {
                 "UTF-8 Exception malformed input",
                 new UTFDataFormatException("malformed input: partial character at end"));
           }
-          char2 = (int) bytearr[count - 1];
+          char2 = bytearr[count - 1];
           if ((char2 & 0xC0) != 0x80) {
             throw new RuntimeException("malformed input around byte " + count);
           }
@@ -168,8 +168,8 @@ public class CacheServerHelper {
                 "UTF-8 Exception malformed input",
                 new UTFDataFormatException("malformed input: partial character at end"));
           }
-          char2 = (int) bytearr[count - 2];
-          char3 = (int) bytearr[count - 1];
+          char2 = bytearr[count - 2];
+          char3 = bytearr[count - 1];
           if (((char2 & 0xC0) != 0x80) || ((char3 & 0xC0) != 0x80)) {
             throw new RuntimeException(
                 "UTF-8 Exception malformed input",
