@@ -30,12 +30,12 @@ import org.apache.logging.log4j.Logger;
 
 import org.apache.geode.DataSerializer;
 import org.apache.geode.InternalGemFireException;
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.annotations.internal.MakeNotStatic;
 import org.apache.geode.distributed.DistributedMember;
 import org.apache.geode.distributed.DistributedSystem;
 import org.apache.geode.distributed.DurableClientAttributes;
 import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
-import org.apache.geode.internal.Assert;
 import org.apache.geode.internal.HeapDataOutputStream;
 import org.apache.geode.internal.net.SocketCreator;
 import org.apache.geode.internal.serialization.ByteArrayDataInput;
@@ -49,9 +49,6 @@ import org.apache.geode.util.internal.GeodeGlossary;
 
 /**
  * This class represents a ConnectionProxy of the CacheClient
- *
- *
- *
  */
 public class ClientProxyMembershipID
     implements DataSerializableFixedID, Serializable, Externalizable {
@@ -59,7 +56,7 @@ public class ClientProxyMembershipID
 
   private static final Logger logger = LogService.getLogger();
 
-  private static final ThreadLocal<String> POOL_NAME = new ThreadLocal<String>();
+  private static final ThreadLocal<String> POOL_NAME = new ThreadLocal<>();
 
   public static void setPoolName(String poolName) {
     POOL_NAME.set(poolName);
@@ -69,8 +66,6 @@ public class ClientProxyMembershipID
     return POOL_NAME.get();
   }
 
-  private static final int BYTES_32KB = 32768;
-
   @MakeNotStatic
   public static volatile DistributedSystem system = null;
 
@@ -91,10 +86,14 @@ public class ClientProxyMembershipID
 
   protected byte[] identity;
 
-  /** cached membership identifier */
+  /**
+   * cached membership identifier
+   */
   private transient DistributedMember memberId;
 
-  /** cached tostring of the memberID */
+  /**
+   * cached tostring of the memberID
+   */
   private transient String memberIdString;
 
   protected int uniqueId;
@@ -106,9 +105,9 @@ public class ClientProxyMembershipID
     if (isDurable()) {
       result = mult * result + getDurableId().hashCode();
     } else {
-      if (this.identity != null && this.identity.length > 0) {
-        for (int i = 0; i < this.identity.length; i++) {
-          result = mult * result + this.identity[i];
+      if (identity != null && identity.length > 0) {
+        for (final byte b : identity) {
+          result = mult * result + b;
         }
       }
     }
@@ -124,21 +123,21 @@ public class ClientProxyMembershipID
     if (this == obj) {
       return true;
     }
-    if ((obj == null) || !(obj instanceof ClientProxyMembershipID)) {
+    if (!(obj instanceof ClientProxyMembershipID)) {
       return false;
     }
     ClientProxyMembershipID that = (ClientProxyMembershipID) obj;
-    if (this.uniqueId != that.uniqueId) {
+    if (uniqueId != that.uniqueId) {
       return false;
     }
-    boolean isDurable = this.isDurable();
+    boolean isDurable = isDurable();
     if (isDurable && !that.isDurable()) {
       return false;
     }
     if (isDurable) {
-      return this.getDurableId().equals(that.getDurableId());
+      return getDurableId().equals(that.getDurableId());
     }
-    return Arrays.equals(this.identity, that.identity);
+    return Arrays.equals(identity, that.identity);
   }
 
   /**
@@ -148,10 +147,10 @@ public class ClientProxyMembershipID
     if (this == that) {
       return true;
     }
-    if (this.uniqueId != that.uniqueId) {
+    if (uniqueId != that.uniqueId) {
       return false;
     }
-    return Arrays.equals(this.identity, that.identity);
+    return Arrays.equals(identity, that.identity);
   }
 
   boolean isSameDSMember(ClientProxyMembershipID that) {
@@ -159,14 +158,16 @@ public class ClientProxyMembershipID
       // Test whether:
       // - the durable ids are equal (if durable) or
       // - the identities are equal (if non-durable)
-      return isDurable() ? this.getDurableId().equals(that.getDurableId())
-          : Arrays.equals(this.identity, that.identity);
+      return isDurable() ? getDurableId().equals(that.getDurableId())
+          : Arrays.equals(identity, that.identity);
     } else {
       return false;
     }
   }
 
-  /** method to obtain ClientProxyMembership for client side */
+  /**
+   * method to obtain ClientProxyMembership for client side
+   */
   public static synchronized ClientProxyMembershipID getNewProxyMembership(DistributedSystem sys) {
     byte[] ba = initializeAndGetDSIdentity(sys);
     return new ClientProxyMembershipID(++synch_counter, ba);
@@ -176,149 +177,114 @@ public class ClientProxyMembershipID
     return new ClientProxyMembershipID(member);
   }
 
-  public static byte[] initializeAndGetDSIdentity(DistributedSystem sys) {
-    byte[] client_side_identity = null;
+  public static byte[] initializeAndGetDSIdentity(final DistributedSystem sys) {
+    final byte[] client_side_identity;
     if (sys == null) {
-      // DistributedSystem is required now before handshaking -Kirk
+      // DistributedSystem is required now before handshaking
       throw new IllegalStateException(
           "Attempting to handshake with CacheServer before creating DistributedSystem and Cache.");
     }
-    {
-      systemMemberId = sys.getDistributedMember();
-      try (HeapDataOutputStream hdos = new HeapDataOutputStream(256, KnownVersion.CURRENT)) {
-        if (systemMemberId != null) {
-          // update the durable id of the member identifier before serializing in case
-          // a pool name has been established
-          DurableClientAttributes attributes = systemMemberId.getDurableClientAttributes();
-          if (attributes != null && attributes.getId().length() > 0) {
-            ((InternalDistributedMember) systemMemberId).setDurableId(attributes.getId());
-          }
+    systemMemberId = sys.getDistributedMember();
+    try (HeapDataOutputStream hdos = new HeapDataOutputStream(256, KnownVersion.CURRENT)) {
+      if (systemMemberId != null) {
+        // update the durable id of the member identifier before serializing in case
+        // a pool name has been established
+        DurableClientAttributes attributes = systemMemberId.getDurableClientAttributes();
+        if (attributes != null && attributes.getId().length() > 0) {
+          ((InternalDistributedMember) systemMemberId).setDurableId(attributes.getId());
         }
-        DataSerializer.writeObject(systemMemberId, hdos);
-        client_side_identity = hdos.toByteArray();
-      } catch (IOException ioe) {
-        throw new InternalGemFireException(
-            "Unable to serialize identity",
-            ioe);
       }
-
-      system = sys;
+      DataSerializer.writeObject(systemMemberId, hdos);
+      client_side_identity = hdos.toByteArray();
+    } catch (IOException ioe) {
+      throw new InternalGemFireException("Unable to serialize identity", ioe);
     }
+    system = sys;
     return client_side_identity;
-
   }
 
   private ClientProxyMembershipID(int id, byte[] clientSideIdentity) {
-    boolean specialCase = Boolean.getBoolean(GeodeGlossary.GEMFIRE_PREFIX + "SPECIAL_DURABLE");
-    String durableID = this.system.getProperties().getProperty(DURABLE_CLIENT_ID);
+    this(clientSideIdentity, getUniqueId(id), systemMemberId);
+  }
+
+  private static int getUniqueId(final int id) {
+    final boolean specialCase =
+        Boolean.getBoolean(GeodeGlossary.GEMFIRE_PREFIX + "SPECIAL_DURABLE");
+    final String durableID = system.getProperties().getProperty(DURABLE_CLIENT_ID);
     if (specialCase && durableID != null && (!durableID.equals(""))) {
-      this.uniqueId = durable_synch_counter;
+      return durable_synch_counter;
     } else {
-      this.uniqueId = id;
+      return id;
     }
-    this.identity = clientSideIdentity;
-    this.memberId = systemMemberId;
   }
 
   public ClientProxyMembershipID() {}
 
-  public ClientProxyMembershipID(DistributedMember member) {
-    this.uniqueId = 1;
-    this.memberId = member;
+  public ClientProxyMembershipID(final DistributedMember member) {
+    this(null, 1, member);
     updateID(member);
   }
 
+  @VisibleForTesting
+  ClientProxyMembershipID(final byte[] identity, final int uniqueId,
+      final DistributedMember memberId) {
+    this.identity = identity;
+    this.uniqueId = uniqueId;
+    this.memberId = memberId;
+  }
 
   private transient String _toString;
 
-  // private transient int transientPort; // variable for debugging member ID issues
-
   @Override
   public String toString() {
-    if (this.identity != null
+    if (identity != null
         && ((InternalDistributedMember) getDistributedMember()).getMembershipPort() == 0) {
-      return this.toStringNoCache();
+      return toStringNoCache();
     }
-    if (this._toString == null) {
-      this._toString = this.toStringNoCache();
+    if (_toString == null) {
+      _toString = toStringNoCache();
     }
-    return this._toString;
+    return _toString;
   }
 
   /**
    * returns a string representation of this identifier, ignoring the toString cache
    */
   public String toStringNoCache() {
-    StringBuffer sb = new StringBuffer("identity(").append(getDSMembership()).append(",connection=")
-        .append(uniqueId);
+    StringBuilder sb =
+        new StringBuilder("identity(").append(getDSMembership()).append(",connection=")
+            .append(uniqueId);
     if (identity != null) {
       DurableClientAttributes dca = getDurableAttributes();
       if (dca.getId().length() > 0) {
-        sb.append(",durableAttributes=").append(dca).append(')').toString();
+        sb.append(",durableAttributes=").append(dca).append(')');
       }
     }
     return sb.toString();
   }
 
-  /**
-   * For Externalizable
-   *
-   * @see Externalizable
-   */
   @Override
   public void writeExternal(ObjectOutput out) throws IOException {
-    // if (this.transientPort == 0) {
-    // InternalDistributedSystem.getLogger().warning(
-    // String.format("%s",
-    // "externalizing a client ID with zero port: " + this.toString(),
-    // new Exception("Stack trace")));
-    // }
-    Assert.assertTrue(this.identity.length <= BYTES_32KB);
-    out.writeShort(this.identity.length);
-    out.write(this.identity);
-    out.writeInt(this.uniqueId);
+    if (identity.length > Short.MAX_VALUE) {
+      throw new IOException("HandShake identity length is too big");
+    }
 
+    out.writeShort(identity.length);
+    out.write(identity);
+    out.writeInt(uniqueId);
   }
 
-  /** returns the externalized size of this object */
-  public int getSerializedSize() {
-    return 4 + identity.length + 4;
-  }
-
-  /**
-   * For Externalizable
-   *
-   * @see Externalizable
-   */
   @Override
   public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
     int identityLength = in.readShort();
-    if (identityLength > BYTES_32KB) {
-      throw new IOException(
-          "HandShake identity length is too big");
+    if (identityLength < 0) {
+      throw new IOException("HandShake identity length is too small");
     }
-    this.identity = new byte[identityLength];
-    read(in, this.identity);
-    this.uniqueId = in.readInt();
-    if (this.uniqueId == -1) {
-      throw new IOException(
-          "Unexpected EOF reached. Unique ID could not be read");
-    }
-    // {toString(); this.transientPort = ((InternalDistributedMember)this.memberId).getPort();}
-  }
-
-  private void read(ObjectInput dis, byte[] toFill) throws IOException {
-
-    int idBytes = 0;
-    int toFillLength = toFill.length;
-    while (idBytes < toFillLength) {
-      // idBytes += dis.read(toFill, idBytes, (toFillLength - idBytes));
-      int dataRead = dis.read(toFill, idBytes, (toFillLength - idBytes));
-      if (dataRead == -1) {
-        throw new IOException(
-            "Unexpected EOF reached. Distributed MembershipID could not be read");
-      }
-      idBytes += dataRead;
+    identity = new byte[identityLength];
+    in.readFully(identity);
+    uniqueId = in.readInt();
+    if (uniqueId == -1) {
+      throw new IOException("Unexpected EOF reached. Unique ID could not be read");
     }
   }
 
@@ -328,31 +294,22 @@ public class ClientProxyMembershipID
   }
 
   @Override
-  public void toData(DataOutput out,
-      SerializationContext context) throws IOException {
-    // if (this.transientPort == 0) {
-    // InternalDistributedSystem.getLogger().warning(
-    // String.format("%s",
-    // "serializing a client ID with zero port: " + this.toString(),
-    // new Exception("Stack trace")));
-    // }
-    DataSerializer.writeByteArray(this.identity, out);
-    out.writeInt(this.uniqueId);
+  public void toData(final DataOutput out, final SerializationContext context) throws IOException {
+    DataSerializer.writeByteArray(identity, out);
+    out.writeInt(uniqueId);
   }
 
   @Override
-  public void fromData(DataInput in,
-      DeserializationContext context) throws IOException, ClassNotFoundException {
-    this.identity = DataSerializer.readByteArray(in);
-    this.uniqueId = in.readInt();
-    // {toString(); this.transientPort = ((InternalDistributedMember)this.memberId).getPort();}
+  public void fromData(final DataInput in, final DeserializationContext context)
+      throws IOException, ClassNotFoundException {
+    identity = DataSerializer.readByteArray(in);
+    uniqueId = in.readInt();
   }
 
   public KnownVersion getClientVersion() {
-    return Versioning
-        .getKnownVersionOrDefault(
-            ((InternalDistributedMember) getDistributedMember()).getVersion(),
-            KnownVersion.CURRENT);
+    return Versioning.getKnownVersionOrDefault(
+        ((InternalDistributedMember) getDistributedMember()).getVersion(),
+        KnownVersion.CURRENT);
   }
 
   public String getDSMembership() {
@@ -371,7 +328,7 @@ public class ClientProxyMembershipID
   }
 
   private String getMemberIdAsString() {
-    String memberIdAsString = null;
+    final String memberIdAsString;
     InternalDistributedMember idm = (InternalDistributedMember) getDistributedMember();
     if (getClientVersion().isOlderThan(KnownVersion.GFE_90)) {
       memberIdAsString = idm.toString();
@@ -392,7 +349,7 @@ public class ClientProxyMembershipID
     if (ccn != null) {
       CacheClientProxy cp = ccn.getClientProxy(this, true);
       if (cp != null) {
-        if (this.isCanonicalEquals(cp.getProxyID())) {
+        if (isCanonicalEquals(cp.getProxyID())) {
           return cp.getProxyID();
         }
       }
@@ -416,16 +373,10 @@ public class ClientProxyMembershipID
     return memberId;
   }
 
-  /** Returns the byte-array for membership identity */
-  byte[] getMembershipByteArray() {
-    return this.identity;
-  }
-
   /**
    * Returns whether this <code>ClientProxyMembershipID</code> is durable.
    *
    * @return whether this <code>ClientProxyMembershipID</code> is durable
-   *
    * @since GemFire 5.5
    */
   public boolean isDurable() {
@@ -437,7 +388,6 @@ public class ClientProxyMembershipID
    * Returns this <code>ClientProxyMembershipID</code>'s durable attributes.
    *
    * @return this <code>ClientProxyMembershipID</code>'s durable attributes
-   *
    * @since GemFire 5.5
    */
   protected DurableClientAttributes getDurableAttributes() {
@@ -448,7 +398,6 @@ public class ClientProxyMembershipID
    * Returns this <code>ClientProxyMembershipID</code>'s durable id.
    *
    * @return this <code>ClientProxyMembershipID</code>'s durable id
-   *
    * @since GemFire 5.5
    */
   public String getDurableId() {
@@ -460,7 +409,6 @@ public class ClientProxyMembershipID
    * Returns this <code>ClientProxyMembershipID</code>'s durable timeout.
    *
    * @return this <code>ClientProxyMembershipID</code>'s durable timeout
-   *
    * @since GemFire 5.5
    */
   protected int getDurableTimeout() {
@@ -483,28 +431,20 @@ public class ClientProxyMembershipID
       value = "ST_WRITE_TO_STATIC_FROM_INSTANCE_METHOD",
       justification = "Only applicable in client DS and in that case too multiple instances do not modify it at the same time.")
   public void updateID(DistributedMember idm) {
-    // this.transientPort = ((InternalDistributedMember)this.memberId).getPort();
-    // if (this.transientPort == 0) {
-    // InternalDistributedSystem.getLogger().warning(
-    // String.format("%s",
-    // "updating client ID when member port is zero: " + this.memberId,
-    // new Exception("stack trace")
-    // ));
-    // }
     try (HeapDataOutputStream hdos = new HeapDataOutputStream(256, KnownVersion.CURRENT)) {
       try {
         DataSerializer.writeObject(idm, hdos);
       } catch (IOException e) {
-        throw new InternalGemFireException("Unable to serialize member: " + this.memberId, e);
+        throw new InternalGemFireException("Unable to serialize member: " + memberId, e);
       }
-      this.identity = hdos.toByteArray();
+      identity = hdos.toByteArray();
     }
-    if (this.memberId != null && this.memberId == systemMemberId) {
+    if (memberId != null && memberId == systemMemberId) {
       systemMemberId = idm;
       // client_side_identity = this.identity;
     }
-    this.memberId = idm;
-    this._toString = null; // make sure we don't retain the old ID representation in toString
+    memberId = idm;
+    _toString = null; // make sure we don't retain the old ID representation in toString
   }
 
 
@@ -515,7 +455,6 @@ public class ClientProxyMembershipID
    * the<code>DistributedMember</code> string is used.
    *
    * @return the name of the <code>HARegion</code> queueing this proxy's messages.
-   *
    * @since GemFire 5.5
    */
   protected String getHARegionName() {
@@ -526,7 +465,6 @@ public class ClientProxyMembershipID
    * Return the name of the region used for communicating interest changes between servers.
    *
    * @return the name of the region used for communicating interest changes between servers
-   *
    * @since GemFire 5.6
    */
   protected String getInterestRegionName() {
@@ -534,13 +472,13 @@ public class ClientProxyMembershipID
   }
 
   private String getBaseRegionName() {
-    String id = isDurable() ? getDurableId() : getDSMembership();
-    if (id.indexOf(SEPARATOR_CHAR) >= 0) {
-      id = id.replace(SEPARATOR_CHAR, ':');
-    }
-    StringBuffer buffer = new StringBuffer().append("_gfe_").append(isDurable() ? "" : "non_")
-        .append("durable_client_").append("with_id_" + id).append("_").append(this.uniqueId);
-    return buffer.toString();
+    return "_gfe_" +
+        (isDurable() ? "" : "non_") +
+        "durable_client_" +
+        "with_id_" +
+        (isDurable() ? getDurableId() : getDSMembership()).replace(SEPARATOR_CHAR, ':') +
+        "_" +
+        uniqueId;
   }
 
   /**
@@ -581,8 +519,8 @@ public class ClientProxyMembershipID
       final int mult = 37;
       byte[] idBytes = getMemberIdBytes();
       if (idBytes != null && idBytes.length > 0) {
-        for (int i = 0; i < idBytes.length; i++) {
-          result = mult * result + idBytes[i];
+        for (final byte idByte : idBytes) {
+          result = mult * result + idByte;
         }
       }
       result = mult * result + uniqueId;
@@ -591,7 +529,7 @@ public class ClientProxyMembershipID
 
     @Override
     public boolean equals(Object obj) {
-      if ((obj == null) || !(obj instanceof ClientProxyMembershipID.Identity)) {
+      if (!(obj instanceof Identity)) {
         return false;
       }
       ClientProxyMembershipID.Identity that = (ClientProxyMembershipID.Identity) obj;
@@ -599,10 +537,6 @@ public class ClientProxyMembershipID
           && Arrays.equals(getMemberIdBytes(), that.getMemberIdBytes()));
     }
 
-    public ClientProxyMembershipID getClientProxyID() {
-      return ClientProxyMembershipID.this;
-    }
-
   }
 
   @Override
