@@ -28,13 +28,15 @@ import org.apache.logging.log4j.Logger;
 
 import org.apache.geode.DataSerializer;
 import org.apache.geode.LogWriter;
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.annotations.internal.MutableForTesting;
+import org.apache.geode.cache.CacheClosedException;
 import org.apache.geode.cache.client.PoolFactory;
 import org.apache.geode.cache.client.ServerRefusedConnectionException;
 import org.apache.geode.cache.client.internal.ClientSideHandshakeImpl;
 import org.apache.geode.distributed.DistributedMember;
 import org.apache.geode.distributed.DistributedSystem;
-import org.apache.geode.internal.ClassLoadUtil;
+import org.apache.geode.internal.ClassLoadUtils;
 import org.apache.geode.internal.HeapDataOutputStream;
 import org.apache.geode.internal.cache.tier.ConnectionProxy;
 import org.apache.geode.internal.logging.InternalLogWriter;
@@ -44,6 +46,7 @@ import org.apache.geode.internal.security.SecurityService;
 import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.security.AuthInitialize;
+import org.apache.geode.security.AuthenticationExpiredException;
 import org.apache.geode.security.AuthenticationFailedException;
 import org.apache.geode.security.AuthenticationRequiredException;
 import org.apache.geode.security.Authenticator;
@@ -144,19 +147,19 @@ public abstract class Handshake {
    * Clone a HandShake to be used in creating other connections
    */
   protected Handshake(Handshake handshake) {
-    this.clientConflation = handshake.clientConflation;
-    this.clientReadTimeout = handshake.clientReadTimeout;
-    this.credentials = handshake.credentials;
-    this.overrides = handshake.overrides;
-    this.system = handshake.system;
-    this.id = handshake.id;
-    this.securityService = handshake.securityService;
-    this.encryptor = new EncryptorImpl(handshake.encryptor);
+    clientConflation = handshake.clientConflation;
+    clientReadTimeout = handshake.clientReadTimeout;
+    credentials = handshake.credentials;
+    overrides = handshake.overrides;
+    system = handshake.system;
+    id = handshake.id;
+    securityService = handshake.securityService;
+    encryptor = new EncryptorImpl(handshake.encryptor);
   }
 
   protected void setClientConflation(byte value) {
-    this.clientConflation = value;
-    switch (this.clientConflation) {
+    clientConflation = value;
+    switch (clientConflation) {
       case CONFLATION_DEFAULT:
       case CONFLATION_OFF:
       case CONFLATION_ON:
@@ -341,7 +344,7 @@ public abstract class Handshake {
   }
 
   public int getClientReadTimeout() {
-    return this.clientReadTimeout;
+    return clientReadTimeout;
   }
 
   /**
@@ -360,18 +363,14 @@ public abstract class Handshake {
     }
     final Handshake that = (Handshake) other;
 
-    if (this.id.isSameDSMember(that.id) && getReplyCode() == that.getReplyCode()) {
-      return true;
-    } else {
-      return false;
-    }
+    return id.isSameDSMember(that.id) && getReplyCode() == that.getReplyCode();
   }
 
   @Override
   public int hashCode() {
     final int mult = 37;
 
-    int result = this.id.hashCode();
+    int result = id.hashCode();
     result = mult * result + getReplyCode();
 
     return result;
@@ -379,17 +378,18 @@ public abstract class Handshake {
 
   @Override
   public String toString() {
-    StringBuffer buf = new StringBuffer().append("HandShake@").append(System.identityHashCode(this))
-        .append(" code: ").append(getReplyCode());
-    if (this.id != null) {
+    StringBuilder buf =
+        new StringBuilder().append("HandShake@").append(System.identityHashCode(this))
+            .append(" code: ").append(getReplyCode());
+    if (id != null) {
       buf.append(" identity: ");
-      buf.append(this.id.toString());
+      buf.append(id);
     }
     return buf.toString();
   }
 
   public ClientProxyMembershipID getMembershipId() {
-    return this.id;
+    return id;
   }
 
   public static Properties getCredentials(String authInitMethod, Properties securityProperties,
@@ -424,11 +424,10 @@ public abstract class Handshake {
   }
 
   protected Properties getCredentials(DistributedMember member) {
-
-    String authInitMethod = this.system.getProperties().getProperty(SECURITY_CLIENT_AUTH_INIT);
-    return getCredentials(authInitMethod, this.system.getSecurityProperties(), member, false,
-        (InternalLogWriter) this.system.getLogWriter(),
-        (InternalLogWriter) this.system.getSecurityLogWriter());
+    String authInitMethod = system.getProperties().getProperty(SECURITY_CLIENT_AUTH_INIT);
+    return getCredentials(authInitMethod, system.getSecurityProperties(), member, false,
+        system.getLogWriter(),
+        system.getSecurityLogWriter());
   }
 
   /**
@@ -477,23 +476,33 @@ public abstract class Handshake {
       Properties securityProperties, InternalLogWriter logWriter,
       InternalLogWriter securityLogWriter, DistributedMember member,
       SecurityService securityService)
-      throws AuthenticationRequiredException, AuthenticationFailedException {
+      throws AuthenticationRequiredException, AuthenticationFailedException, CacheClosedException {
 
     if (!AcceptorImpl.isAuthenticationRequired()) {
       return null;
     }
+    return authenticate(authenticatorMethod, credentials, securityProperties, logWriter,
+        securityLogWriter,
+        member, securityService);
+  }
 
+  @VisibleForTesting
+  static Object authenticate(String authenticatorMethod, Properties credentials,
+      Properties securityProperties, InternalLogWriter logWriter,
+      InternalLogWriter securityLogWriter, DistributedMember member,
+      SecurityService securityService) {
     Authenticator auth = null;
     try {
       if (securityService.isIntegratedSecurity()) {
         return securityService.login(credentials);
       } else {
-        Method instanceGetter = ClassLoadUtil.methodFromName(authenticatorMethod);
+        Method instanceGetter = ClassLoadUtils.methodFromName(authenticatorMethod);
         auth = (Authenticator) instanceGetter.invoke(null, (Object[]) null);
         auth.init(securityProperties, logWriter, securityLogWriter);
         return auth.authenticate(credentials, member);
       }
-    } catch (AuthenticationFailedException ex) {
+    } catch (AuthenticationFailedException | AuthenticationExpiredException
+        | CacheClosedException ex) {
       throw ex;
     } catch (Exception ex) {
       throw new AuthenticationFailedException(ex.getMessage(), ex);
@@ -507,23 +516,23 @@ public abstract class Handshake {
   public Object verifyCredentials()
       throws AuthenticationRequiredException, AuthenticationFailedException {
 
-    String methodName = this.system.getProperties().getProperty(SECURITY_CLIENT_AUTHENTICATOR);
-    return verifyCredentials(methodName, this.credentials, this.system.getSecurityProperties(),
-        (InternalLogWriter) this.system.getLogWriter(),
-        (InternalLogWriter) this.system.getSecurityLogWriter(), this.id.getDistributedMember(),
-        this.securityService);
+    String methodName = system.getProperties().getProperty(SECURITY_CLIENT_AUTHENTICATOR);
+    return verifyCredentials(methodName, credentials, system.getSecurityProperties(),
+        (InternalLogWriter) system.getLogWriter(),
+        (InternalLogWriter) system.getSecurityLogWriter(), id.getDistributedMember(),
+        securityService);
   }
 
   private void checkIfAuthenticWanSite(DataInputStream dis, DataOutputStream dos,
       DistributedMember member) throws GemFireSecurityException, IOException {
 
-    if (this.credentials == null) {
+    if (credentials == null) {
       return;
     }
-    String authenticator = this.system.getProperties().getProperty(SECURITY_CLIENT_AUTHENTICATOR);
-    Properties peerWanProps = readCredentials(dis, dos, this.system, this.securityService);
-    verifyCredentials(authenticator, peerWanProps, this.system.getSecurityProperties(),
-        (InternalLogWriter) this.system.getLogWriter(),
-        (InternalLogWriter) this.system.getSecurityLogWriter(), member, this.securityService);
+    String authenticator = system.getProperties().getProperty(SECURITY_CLIENT_AUTHENTICATOR);
+    Properties peerWanProps = readCredentials(dis, dos, system, securityService);
+    verifyCredentials(authenticator, peerWanProps, system.getSecurityProperties(),
+        (InternalLogWriter) system.getLogWriter(),
+        (InternalLogWriter) system.getSecurityLogWriter(), member, securityService);
   }
 }
