@@ -14,11 +14,14 @@
  */
 package org.apache.geode.internal.cache.tier.sockets;
 
+import static org.apache.geode.internal.cache.tier.sockets.ClientReAuthenticateMessage.RE_AUTHENTICATION_START_VERSION;
+import static org.apache.geode.internal.lang.SystemPropertyHelper.RE_AUTHENTICATE_WAIT_TIME;
 import static org.apache.geode.util.internal.UncheckedUtils.uncheckedCast;
 
 import java.io.IOException;
 import java.net.Socket;
 import java.nio.ByteBuffer;
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Iterator;
@@ -28,6 +31,8 @@ import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 
 import org.apache.logging.log4j.Logger;
+import org.apache.shiro.subject.Subject;
+import org.jetbrains.annotations.NotNull;
 
 import org.apache.geode.CancelException;
 import org.apache.geode.DataSerializer;
@@ -39,16 +44,22 @@ import org.apache.geode.cache.query.internal.cq.InternalCqQuery;
 import org.apache.geode.internal.cache.ClientServerObserver;
 import org.apache.geode.internal.cache.ClientServerObserverHolder;
 import org.apache.geode.internal.cache.Conflatable;
+import org.apache.geode.internal.cache.EventID;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.ha.HAContainerWrapper;
 import org.apache.geode.internal.cache.ha.HARegionQueue;
 import org.apache.geode.internal.cache.ha.HARegionQueueAttributes;
 import org.apache.geode.internal.cache.ha.HARegionQueueStats;
+import org.apache.geode.internal.lang.SystemProperty;
 import org.apache.geode.internal.logging.log4j.LogMarker;
+import org.apache.geode.internal.security.SecurityService;
 import org.apache.geode.internal.serialization.ByteArrayDataInput;
 import org.apache.geode.internal.statistics.StatisticsClock;
 import org.apache.geode.logging.internal.executors.LoggingThread;
 import org.apache.geode.logging.internal.log4j.api.LogService;
+import org.apache.geode.security.AuthenticationExpiredException;
+import org.apache.geode.security.NotAuthorizedException;
+import org.apache.geode.security.ResourcePermission;
 
 /**
  * Class <code>MessageDispatcher</code> is a <code>Thread</code> that processes messages bound for
@@ -68,6 +79,12 @@ public class MessageDispatcher extends LoggingThread {
    */
   private static final String KEY_SLOW_START_TIME_FOR_TESTING = "slowStartTimeForTesting";
 
+
+  /**
+   * Default value in milliseconds for waiting for re-authentication
+   */
+  private static final long DEFAULT_RE_AUTHENTICATE_WAIT_TIME = Duration.ofMinutes(1).toMillis();
+
   /**
    * The queue of messages to be sent to the client
    */
@@ -95,6 +112,9 @@ public class MessageDispatcher extends LoggingThread {
    */
   private volatile boolean _isStopped = true;
 
+  private volatile long waitForReAuthenticationStartTime = -1;
+  private final Object reAuthenticationLock = new Object();
+
   /**
    * A lock object used to control pausing this dispatcher
    */
@@ -123,20 +143,17 @@ public class MessageDispatcher extends LoggingThread {
    */
   protected MessageDispatcher(CacheClientProxy proxy, String name,
       StatisticsClock statisticsClock) throws CacheException {
-    super(name);
+    this(proxy, name, getMessageQueue(proxy, statisticsClock));
+  }
 
-    _proxy = proxy;
-
-    // Create the event conflator
-    // this._eventConflator = new BridgeEventConflator
-
-    // Create the message queue
+  private static HARegionQueue getMessageQueue(CacheClientProxy proxy,
+      StatisticsClock statisticsClock) {
     try {
       HARegionQueueAttributes harq = new HARegionQueueAttributes();
       harq.setBlockingQueueCapacity(proxy._maximumMessageCount);
       harq.setExpiryTime(proxy._messageTimeToLive);
       ((HAContainerWrapper) proxy._cacheClientNotifier.getHaContainer())
-          .putProxy(HARegionQueue.createRegionName(getProxy().getHARegionName()), getProxy());
+          .putProxy(HARegionQueue.createRegionName(proxy.getHARegionName()), proxy);
       boolean createDurableQueue = proxy.proxyID.isDurable();
       boolean canHandleDelta =
           proxy.getCache().getInternalDistributedSystem().getConfig().getDeltaPropagation()
@@ -146,18 +163,14 @@ public class MessageDispatcher extends LoggingThread {
             createDurableQueue ? "durable" : "non-durable",
             proxy.getProxyID());
       }
-      _messageQueue = HARegionQueue.getHARegionQueueInstance(getProxy().getHARegionName(),
-          getCache(), harq, HARegionQueue.BLOCKING_HA_QUEUE, createDurableQueue,
+      return HARegionQueue.getHARegionQueueInstance(proxy.getHARegionName(),
+          proxy.getCache(), harq, HARegionQueue.BLOCKING_HA_QUEUE, createDurableQueue,
           proxy._cacheClientNotifier.getHaContainer(), proxy.getProxyID(),
-          _proxy.clientConflation, _proxy.isPrimary(), canHandleDelta, statisticsClock);
-      // Check if interests were registered during HARegion GII.
-      if (_proxy.hasRegisteredInterested()) {
-        _messageQueue.setHasRegisteredInterest(true);
-      }
+          proxy.clientConflation, proxy.isPrimary(), canHandleDelta, statisticsClock);
     } catch (CancelException | RegionExistsException e) {
       throw e;
     } catch (Exception e) {
-      getCache().getCancelCriterion().checkCancelInProgress(e);
+      proxy.getCache().getCancelCriterion().checkCancelInProgress(e);
       throw new CacheException(
           "Exception occurred while trying to create a message queue.",
           e) {
@@ -166,6 +179,30 @@ public class MessageDispatcher extends LoggingThread {
     }
   }
 
+  protected MessageDispatcher(CacheClientProxy proxy, String name, HARegionQueue messageQueue)
+      throws CacheException {
+    super(name);
+    _proxy = proxy;
+    _messageQueue = messageQueue;
+    // Check if interests were registered during HARegion GII.
+    if (proxy.hasRegisteredInterested()) {
+      _messageQueue.setHasRegisteredInterest(true);
+    }
+  }
+
+  public boolean isWaitingForReAuthentication() {
+    return waitForReAuthenticationStartTime > 0;
+  }
+
+  private boolean subjectUpdated = false;
+
+  public void notifyReAuthentication() {
+    synchronized (reAuthenticationLock) {
+      subjectUpdated = true;
+      reAuthenticationLock.notifyAll();
+    }
+  }
+
   private CacheClientProxy getProxy() {
     return _proxy;
   }
@@ -335,9 +372,10 @@ public class MessageDispatcher extends LoggingThread {
     }
 
     ClientMessage clientMessage = null;
+
     while (!isStopped()) {
       // SystemFailure.checkFailure(); DM's stopper does this
-      if (_proxy._cache.getCancelCriterion().isCancelInProgress()) {
+      if (getCache().getCancelCriterion().isCancelInProgress()) {
         break;
       }
       try {
@@ -361,31 +399,48 @@ public class MessageDispatcher extends LoggingThread {
           }
           waitForResumption();
         }
-        try {
-          clientMessage = (ClientMessage) _messageQueue.peek();
-        } catch (RegionDestroyedException skipped) {
-          break;
+
+        // if message is not delivered due to authentication expiation, continue to try to
+        // deliver the same message. Always retrieve a new message from the queue if we are not
+        // waiting for the re-auth to happen.
+        if (waitForReAuthenticationStartTime == -1) {
+          try {
+            clientMessage = (ClientMessage) _messageQueue.peek();
+          } catch (RegionDestroyedException skipped) {
+            break;
+          }
         }
+
         getStatistics().setQueueSize(_messageQueue.size());
         if (isStopped()) {
           break;
         }
-        if (clientMessage != null) {
-          // Process the message
-          long start = getStatistics().startTime();
-          //// BUGFIX for BUG#38206 and BUG#37791
-          boolean isDispatched = dispatchMessage(clientMessage);
-          getStatistics().endMessage(start);
-          if (isDispatched) {
+
+        if (clientMessage == null) {
+          _messageQueue.remove();
+          continue;
+        }
+
+        // Process the message
+        long start = getStatistics().startTime();
+        try {
+          if (dispatchMessage(clientMessage)) {
+            getStatistics().endMessage(start);
             _messageQueue.remove();
             if (clientMessage instanceof ClientMarkerMessageImpl) {
               getProxy().setMarkerEnqueued(false);
             }
           }
-        } else {
+          clientMessage = null;
+          waitForReAuthenticationStartTime = -1;
+        } catch (NotAuthorizedException notAuthorized) {
+          // behave as if the message is dispatched, remove from the queue
+          logger.warn("skip delivering message: " + clientMessage, notAuthorized);
           _messageQueue.remove();
+          clientMessage = null;
+        } catch (AuthenticationExpiredException expired) {
+          exceptionOccurred = handleAuthenticationExpiredException(expired);
         }
-        clientMessage = null;
       } catch (MessageTooLargeException e) {
         logger.warn("Message too large to send to client: {}, {}", clientMessage, e.getMessage());
       } catch (IOException e) {
@@ -419,7 +474,6 @@ public class MessageDispatcher extends LoggingThread {
             // Let the CacheClientNotifier discover the proxy is not alive.
             // See isAlive().
             // getProxy().close(false);
-
             pauseOrUnregisterProxy(e);
           } // _isStopped
         } // synchronized
@@ -468,58 +522,134 @@ public class MessageDispatcher extends LoggingThread {
 
     // Processing gets here if isStopped=true. What is this code below doing?
     if (!exceptionOccurred) {
-      List<ClientMessage> list = new ArrayList<>();
-      try {
-        // Clear the interrupt status if any,
-        Thread.interrupted();
-        int size = _messageQueue.size();
-        list.addAll(uncheckedCast(_messageQueue.peek(size)));
-        if (logger.isDebugEnabled()) {
-          logger.debug(
-              "{}: After flagging the dispatcher to stop , the residual List of messages to be dispatched={} size={}",
-              this, list, list.size());
-        }
-        if (list.size() > 0) {
-          long start = getStatistics().startTime();
-          Iterator<ClientMessage> itr = list.iterator();
-          while (itr.hasNext()) {
-            dispatchMessage(itr.next());
-            getStatistics().endMessage(start);
-            itr.remove();
-          }
-          _messageQueue.remove();
-        }
-      } catch (CancelException e) {
-        if (logger.isDebugEnabled()) {
-          logger.debug("CacheClientNotifier stopped due to cancellation");
-        }
-      } catch (Exception e) {
-        String extraMsg = null;
-
-        if ("Broken pipe".equals(e.getMessage())) {
-          extraMsg = "Problem caused by broken pipe on socket.";
-        } else if (e instanceof RegionDestroyedException) {
-          extraMsg = "Problem caused by message queue being closed.";
-        }
-        if (extraMsg == null) {
-          extraMsg = "Problem caused by: " + e.getMessage();
-        }
-        logger.info(String.format(
-            "%s Possibility of not being able to send some or all of the messages to clients. Total messages currently present in the list %s.",
-            (!isStopped()) ? toString() + ": " : "", list.size()));
-        logger.info(extraMsg);
-      }
-
-      if (!list.isEmpty() && logger.isTraceEnabled()) {
-        logger.trace("Messages remaining in the list are: {}", list);
-      }
+      dispatchResidualMessages();
     }
     if (logger.isTraceEnabled()) {
       logger.trace("{}: Dispatcher thread is ending", this);
     }
   }
 
-  private void pauseOrUnregisterProxy(Throwable t) {
+  private boolean handleAuthenticationExpiredException(AuthenticationExpiredException expired)
+      throws InterruptedException {
+    if (unregisterUnsupportedClient(expired)) {
+      return true;
+    }
+
+    long reAuthenticateWaitTime =
+        getSystemProperty(RE_AUTHENTICATE_WAIT_TIME, DEFAULT_RE_AUTHENTICATE_WAIT_TIME);
+    synchronized (reAuthenticationLock) {
+      // turn on the "isWaitingForReAuthentication" flag before we send the re-auth message
+      // if we do it the other way around, the re-auth might be finished before we turn on the
+      // flag for the notification to happen.
+      waitForReAuthenticationStartTime = System.currentTimeMillis();
+      subjectUpdated = false;
+      EventID eventId = createEventId();
+      sendMessageDirectly(new ClientReAuthenticateMessage(eventId));
+
+      long waitFinishTime = waitForReAuthenticationStartTime + reAuthenticateWaitTime;
+      long remainingWaitTime = waitFinishTime - System.currentTimeMillis();
+      while (!subjectUpdated && remainingWaitTime > 0) {
+        reAuthenticationLock.wait(remainingWaitTime);
+        remainingWaitTime = waitFinishTime - System.currentTimeMillis();
+      }
+    }
+    // the above wait timed out
+    if (!subjectUpdated) {
+      long elapsedTime = System.currentTimeMillis() - waitForReAuthenticationStartTime;
+      // reset the timer here since we are no longer waiting for re-auth to happen anymore
+      waitForReAuthenticationStartTime = -1;
+      synchronized (_stopDispatchingLock) {
+        logger.warn(
+            "Client did not re-authenticate back successfully in {} ms. Unregister this client proxy.",
+            elapsedTime);
+        pauseOrUnregisterProxy(expired);
+      }
+      return true;
+    }
+    return false;
+  }
+
+  /**
+   * for old client, don't wait for re-auth but unregister this proxy completely.
+   */
+  private boolean unregisterUnsupportedClient(AuthenticationExpiredException expired) {
+    if (getProxy().getVersion().isNewerThanOrEqualTo(RE_AUTHENTICATION_START_VERSION)) {
+      return false;
+    }
+
+    logger.warn(
+        "Authentication expired for a client with a version less than Geode 1.15. Cannot re-authenticate an older client "
+            + "that has a server to client queue for CQs or interest registrations. "
+            + "Please upgrade your client to Geode 1.15 or greater to allow re-authentication.");
+    synchronized (_stopDispatchingLock) {
+      pauseOrUnregisterProxy(expired);
+    }
+    return true;
+  }
+
+  @VisibleForTesting
+  void dispatchResidualMessages() {
+    List<ClientMessage> list = new ArrayList<>();
+    try {
+      // Clear the interrupt status if any,
+      Thread.interrupted();
+      int size = _messageQueue.size();
+      list.addAll(uncheckedCast(_messageQueue.peek(size)));
+      if (logger.isDebugEnabled()) {
+        logger.debug(
+            "{}: After flagging the dispatcher to stop , the residual List of messages to be dispatched={} size={}",
+            this, list, list.size());
+      }
+      if (list.size() > 0) {
+        long start = getStatistics().startTime();
+        Iterator<ClientMessage> itr = list.iterator();
+        while (itr.hasNext()) {
+          dispatchMessage(itr.next());
+          getStatistics().endMessage(start);
+          itr.remove();
+        }
+        _messageQueue.remove();
+      }
+    } catch (CancelException e) {
+      if (logger.isDebugEnabled()) {
+        logger.debug("CacheClientNotifier stopped due to cancellation");
+      }
+    } catch (Exception e) {
+      String extraMsg = null;
+
+      if ("Broken pipe".equals(e.getMessage())) {
+        extraMsg = "Problem caused by broken pipe on socket.";
+      } else if (e instanceof RegionDestroyedException) {
+        extraMsg = "Problem caused by message queue being closed.";
+      }
+      if (extraMsg == null) {
+        extraMsg = "Problem caused by: " + e.getMessage();
+      }
+      logger.info(String.format(
+          "%s Possibility of not being able to send some or all of the messages to clients. Total messages currently present in the list %s.",
+          (!isStopped()) ? this + ": " : "", list.size()));
+      logger.info(extraMsg);
+    }
+
+    if (!list.isEmpty() && logger.isTraceEnabled()) {
+      logger.trace("Messages remaining in the list are: {}", list);
+    }
+  }
+
+  @NotNull
+  @VisibleForTesting
+  protected Long getSystemProperty(String key, long defaultValue) {
+    return SystemProperty.getProductLongProperty(key, defaultValue);
+  }
+
+  @NotNull
+  @VisibleForTesting
+  protected EventID createEventId() {
+    return new EventID(getCache().getDistributedSystem());
+  }
+
+  @VisibleForTesting
+  protected void pauseOrUnregisterProxy(Throwable t) {
     if (getProxy().isDurable()) {
       try {
         getProxy().pauseDispatching();
@@ -567,11 +697,12 @@ public class MessageDispatcher extends LoggingThread {
 
     final Message message;
     if (clientMessage instanceof ClientUpdateMessage) {
-      byte[] latestValue = (byte[]) ((ClientUpdateMessage) clientMessage).getValue();
+      ClientUpdateMessage clientUpdateMessage = (ClientUpdateMessage) clientMessage;
+      byte[] latestValue = (byte[]) clientUpdateMessage.getValue();
       if (logger.isTraceEnabled()) {
         StringBuilder msg = new StringBuilder(100);
         msg.append(this).append(": Using latest value: ").append(Arrays.toString(latestValue));
-        if (((ClientUpdateMessage) clientMessage).valueIsObject()) {
+        if (clientUpdateMessage.valueIsObject()) {
           if (latestValue != null) {
             msg.append(" (").append(deserialize(latestValue)).append(")");
           }
@@ -580,6 +711,28 @@ public class MessageDispatcher extends LoggingThread {
         logger.trace(msg.toString());
       }
 
+      // authorize the message before dispatching
+      SecurityService securityService = getCache().getSecurityService();
+      // for legacy security, we don't support auth expiration
+      if (securityService.isIntegratedSecurity()) {
+        if (getProxy().getSubject() != null) {
+          securityService.authorize(getResourcePermission(clientUpdateMessage),
+              getProxy().getSubject());
+        } else {
+          // if it's multi-user mode
+          ClientUpdateMessageImpl.CqNameToOp clientCq =
+              clientUpdateMessage.getClientCq(getProxy().getProxyID());
+          if (clientCq != null) {
+            String[] names = clientCq.getNames();
+            for (String cqName : names) {
+              Subject subject = getProxy().getSubject(cqName);
+              if (subject != null) {
+                securityService.authorize(getResourcePermission(clientUpdateMessage), subject);
+              }
+            }
+          }
+        }
+      }
       message = ((ClientUpdateMessageImpl) clientMessage).getMessage(getProxy(), latestValue);
 
       if (CacheClientProxy.AFTER_MESSAGE_CREATION_FLAG) {
@@ -608,7 +761,17 @@ public class MessageDispatcher extends LoggingThread {
     return isDispatched;
   }
 
-  private void sendMessage(Message message) throws IOException {
+  @NotNull
+  private ResourcePermission getResourcePermission(ClientUpdateMessage message) {
+    String regionName = message.getRegionName();
+    Object key = message.getKeyOfInterest();
+    return new ResourcePermission(ResourcePermission.Resource.DATA,
+        ResourcePermission.Operation.READ,
+        regionName, key == null ? null : key.toString());
+  }
+
+  @VisibleForTesting
+  protected void sendMessage(Message message) throws IOException {
     if (message == null) {
       return;
     }
@@ -632,7 +795,11 @@ public class MessageDispatcher extends LoggingThread {
    */
   protected void enqueueMessage(Conflatable clientMessage) {
     try {
+      long startTime = _proxy._statistics.startMessageQueueStats();
       _messageQueue.put(clientMessage);
+      _proxy._statistics.endMessageQueueStats(startTime);
+      _proxy._statistics.setQueueSize(_messageQueue.size());
+
       if (_proxy.isPaused() && _proxy.isDurable()) {
         _proxy._cacheClientNotifier.statistics.incEventEnqueuedWhileClientAwayCount();
         if (logger.isDebugEnabled()) {
@@ -659,7 +826,10 @@ public class MessageDispatcher extends LoggingThread {
         logger.debug("{}: Queueing marker message. <{}>. The queue contains {} entries.", this,
             message, getQueueSize());
       }
+      long startTime = _proxy._statistics.startMessageQueueStats();
       _messageQueue.put(message);
+      _proxy._statistics.endMessageQueueStats(startTime);
+      _proxy._statistics.setQueueSize(_messageQueue.size());
       if (logger.isDebugEnabled()) {
         logger.debug("{}: Queued marker message. The queue contains {} entries.", this,
             getQueueSize());
