@@ -16,6 +16,8 @@ package org.apache.geode.internal.cache.tier.sockets.command;
 
 import java.io.IOException;
 
+import org.jetbrains.annotations.NotNull;
+
 import org.apache.geode.annotations.Immutable;
 import org.apache.geode.distributed.internal.DistributionStats;
 import org.apache.geode.internal.cache.tier.Command;
@@ -39,8 +41,9 @@ public class CloseConnection extends BaseCommand {
   private CloseConnection() {}
 
   @Override
-  public void cmdExecute(final Message clientMessage, final ServerConnection serverConnection,
-      final SecurityService securityService, long start) throws IOException {
+  public void cmdExecute(final @NotNull Message clientMessage,
+      final @NotNull ServerConnection serverConnection,
+      final @NotNull SecurityService securityService, long start) throws IOException {
     CacheServerStats stats = serverConnection.getCacheServerStats();
     long oldStart = start;
     boolean respondToClient =
@@ -64,7 +67,7 @@ public class CloseConnection extends BaseCommand {
 
       Part keepalivePart = clientMessage.getPart(0);
       byte[] keepaliveByte = keepalivePart.getSerializedForm();
-      boolean keepalive = (keepaliveByte == null || keepaliveByte[0] == 0) ? false : true;
+      boolean keepalive = keepaliveByte != null && keepaliveByte[0] != 0;
 
       serverConnection.getAcceptor().getCacheClientNotifier()
           .setKeepAlive(serverConnection.getProxyID(), keepalive);
