@@ -17,6 +17,8 @@ package org.apache.geode.internal.cache.tier.sockets.command;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 
+import org.jetbrains.annotations.NotNull;
+
 import org.apache.geode.InvalidDeltaException;
 import org.apache.geode.annotations.Immutable;
 import org.apache.geode.cache.DynamicRegionFactory;
@@ -58,8 +60,9 @@ public class Put70 extends BaseCommand {
   private Put70() {}
 
   @Override
-  public void cmdExecute(final Message clientMessage, final ServerConnection serverConnection,
-      final SecurityService securityService, long p_start)
+  public void cmdExecute(final @NotNull Message clientMessage,
+      final @NotNull ServerConnection serverConnection,
+      final @NotNull SecurityService securityService, long p_start)
       throws IOException, InterruptedException {
     long start = p_start;
     final CacheServerStats stats = serverConnection.getCacheServerStats();
@@ -212,8 +215,8 @@ public class Put70 extends BaseCommand {
     }
 
     final ByteBuffer eventIdPartsBuffer = ByteBuffer.wrap(eventPart.getSerializedForm());
-    final long threadId = EventID.readEventIdPartsFromOptmizedByteArray(eventIdPartsBuffer);
-    final long sequenceId = EventID.readEventIdPartsFromOptmizedByteArray(eventIdPartsBuffer);
+    final long threadId = EventID.readEventIdPartsFromOptimizedByteArray(eventIdPartsBuffer);
+    final long sequenceId = EventID.readEventIdPartsFromOptimizedByteArray(eventIdPartsBuffer);
 
     final EventIDHolder clientEvent = new EventIDHolder(
         new EventID(serverConnection.getEventMemberIDByteArray(), threadId, sequenceId));
@@ -379,7 +382,7 @@ public class Put70 extends BaseCommand {
               serverConnection.getProxyID(), true, clientEvent, true);
         } else {
           result = region.basicBridgePut(key, value, delta, isObject, callbackArg,
-              serverConnection.getProxyID(), true, clientEvent);
+              serverConnection.getProxyID(), clientEvent, true);
         }
         if (clientMessage.isRetry() && clientEvent.isConcurrencyConflict()
             && clientEvent.getVersionTag() != null) {
@@ -465,8 +468,7 @@ public class Put70 extends BaseCommand {
     if (region.getAttributes().getConcurrencyChecksEnabled()) {
       // recover the version tag from other servers
       clientEvent.setRegion(region);
-      boolean withPersistence = region.getAttributes().getDataPolicy().withPersistence();
-      if (!recoverVersionTagForRetriedOperation(clientEvent) && !withPersistence) {
+      if (!isRegionWithPersistence(region) && !recoverVersionTagForRetriedOperation(clientEvent)) {
         // For persistent region, it is possible that all persistent copies went offline.
         // Do not reset possible duplicate in this case, as persistent data
         // can be recovered during the retry after recover of version tag failed.
@@ -476,6 +478,20 @@ public class Put70 extends BaseCommand {
     return shouldSetPossibleDuplicate;
   }
 
+  boolean isRegionWithPersistence(LocalRegion region) {
+    if (region.getAttributes().getDataPolicy().withPersistence()) {
+      return true;
+    }
+    if (region instanceof PartitionedRegion) {
+      PartitionedRegion partitionedRegion = (PartitionedRegion) region;
+      if (!partitionedRegion.isDataStore()) {
+        // if is accessor, find if region persist on other members.
+        return partitionedRegion.getRegionAdvisor().advisePersistentMembers().size() > 0;
+      }
+    }
+    return false;
+  }
+
   protected void writeReply(Message origMsg, ServerConnection servConn, boolean sendOldValue,
       boolean oldValueIsObject, Object oldValue, VersionTag<?> versionTag) throws IOException {
     Message replyMsg = servConn.getReplyMessage();
