@@ -162,6 +162,7 @@ import org.apache.geode.internal.cache.wan.AbstractGatewaySender;
 import org.apache.geode.internal.cache.wan.InternalGatewaySenderFactory;
 import org.apache.geode.internal.cache.wan.WANServiceProvider;
 import org.apache.geode.internal.jndi.JNDIInvoker;
+import org.apache.geode.internal.lang.SystemProperty;
 import org.apache.geode.internal.lang.SystemPropertyHelper;
 import org.apache.geode.internal.logging.InternalLogWriter;
 import org.apache.geode.internal.logging.LocalLogWriter;
@@ -193,7 +194,7 @@ public class CacheCreation implements InternalCache {
   private static final RegionAttributes defaults = new AttributesFactory().create();
 
   @Immutable
-  private static final Optional<Boolean> parallelDiskStoreRecovery = SystemPropertyHelper
+  private static final Optional<Boolean> parallelDiskStoreRecovery = SystemProperty
       .getProductBooleanProperty(SystemPropertyHelper.PARALLEL_DISK_STORE_RECOVERY);
 
   /**
@@ -1350,11 +1351,6 @@ public class CacheCreation implements InternalCache {
     throw new UnsupportedOperationException("Should not be invoked");
   }
 
-  @Override
-  public void setQueryMonitorRequiredForResourceManager(final boolean required) {
-    throw new UnsupportedOperationException("Should not be invoked");
-  }
-
   @Override
   public boolean isQueryMonitorDisabledForLowMemory() {
     throw new UnsupportedOperationException("Should not be invoked");
