@@ -54,7 +54,7 @@ import org.apache.geode.unsafe.internal.sun.misc.Unsafe;
  * <p>
  * This is the original javadoc describing ConcurrentHashMap. This class is actually a Set based on
  * Doug Lea's CHM implementation (see the source file for full attribution).
- * </p>
+ * <p>
  * A hash map supporting full concurrency of retrievals and high expected concurrency for updates.
  * This class obeys the same functional specification as {@link java.util.HashMap}, and includes
  * versions of methods corresponding to each method of {@code HashMap}. However, even though all
@@ -421,12 +421,12 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
         return c;
       }
       if ((ts = c.getGenericInterfaces()) != null) {
-        for (int i = 0; i < ts.length; ++i) {
-          if (((t = ts[i]) instanceof ParameterizedType)
+        for (final Type type : ts) {
+          if (((t = type) instanceof ParameterizedType)
               && ((p = (ParameterizedType) t).getRawType() == Comparable.class)
               && (as = p.getActualTypeArguments()) != null && as.length == 1 && as[0] == c) // type
-                                                                                            // arg
-                                                                                            // is c
+          // arg
+          // is c
           {
             return c;
           }
@@ -534,7 +534,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
     }
     int cap = ((initialCapacity >= (MAXIMUM_CAPACITY >>> 1)) ? MAXIMUM_CAPACITY
         : tableSizeFor(initialCapacity + (initialCapacity >>> 1) + 1));
-    this.sizeCtl = cap;
+    sizeCtl = cap;
   }
 
   /**
@@ -543,7 +543,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
    * @param m the map
    */
   public CompactConcurrentHashSet2(Collection<? extends V> m) {
-    this.sizeCtl = DEFAULT_CAPACITY;
+    sizeCtl = DEFAULT_CAPACITY;
     addAll(m);
   }
 
@@ -586,7 +586,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
     }
     long size = (long) (1.0 + (long) initialCapacity / loadFactor);
     int cap = (size >= (long) MAXIMUM_CAPACITY) ? MAXIMUM_CAPACITY : tableSizeFor((int) size);
-    this.sizeCtl = cap;
+    sizeCtl = cap;
   }
 
   // Original (since JDK1.2) Map methods
@@ -652,7 +652,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
       if (tab == null || (n = tab.length) == 0) {
         tab = initTable();
       } else if ((f = tabAt(tab, i = (n - 1) & hash)) == null) {
-        if (casTabAt(tab, i, null, new Node<V>(hash, key, null))) {
+        if (casTabAt(tab, i, null, new Node<>(hash, key, null))) {
           break; // no lock when adding to empty bin
         }
       } else if ((fh = f.hash) == MOVED) {
@@ -671,7 +671,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
                 }
                 Node<V> pred = e;
                 if ((e = e.next) == null) {
-                  pred.next = new Node<V>(hash, key, null);
+                  pred.next = new Node<>(hash, key, null);
                   break;
                 }
               }
@@ -707,9 +707,8 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
    */
   public void addAll(Set<? extends V> m) {
     tryPresize(m.size());
-    Iterator<? extends V> it = m.iterator();
-    while (it.hasNext()) {
-      putKey(it.next(), false);
+    for (final V v : m) {
+      putKey(v, false);
     }
   }
 
@@ -813,7 +812,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
   // int h = 0;
   // Node<V>[] t;
   // if ((t = table) != null) {
-  // Traverser<V> it = new Traverser<V>(t, t.length, 0, t.length);
+  // Traverser<V> it = new Traverser<>(t, t.length, 0, t.length);
   // for (Node<V> p; (p = it.advance()) != null; )
   // h += p.key.hashCode();
   // }
@@ -832,7 +831,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
   public String toString() {
     Node<V>[] t;
     int f = (t = table) == null ? 0 : t.length;
-    Traverser<V> it = new Traverser<V>(t, f, 0, f);
+    Traverser<V> it = new Traverser<>(t, f, 0, f);
     StringBuilder sb = new StringBuilder();
     sb.append('{');
     Node<V> p;
@@ -856,7 +855,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
   // Set<?> m = (Set<?>) o;
   // Node<V>[] t;
   // int f = (t = table) == null ? 0 : t.length;
-  // Traverser<V> it = new Traverser<V>(t, f, 0, f);
+  // Traverser<V> it = new Traverser<>(t, f, 0, f);
   // for (Node<V> p; (p = it.advance()) != null; ) {
   // if (!m.contains(p.key)) {
   // return false;
@@ -881,7 +880,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
     final float loadFactor;
 
     Segment(float lf) {
-      this.loadFactor = lf;
+      loadFactor = lf;
     }
   }
 
@@ -907,7 +906,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
     @SuppressWarnings("unchecked")
     Segment<V>[] segments = (Segment<V>[]) new Segment<?>[DEFAULT_CONCURRENCY_LEVEL];
     for (int i = 0; i < segments.length; ++i) {
-      segments[i] = new Segment<V>(LOAD_FACTOR);
+      segments[i] = new Segment<>(LOAD_FACTOR);
     }
     java.io.ObjectOutputStream.PutField streamFields = s.putFields();
     streamFields.put("segments", segments);
@@ -917,7 +916,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
 
     Node<V>[] t;
     if ((t = table) != null) {
-      Traverser<V> it = new Traverser<V>(t, t.length, 0, t.length);
+      Traverser<V> it = new Traverser<>(t, t.length, 0, t.length);
       for (Node<V> p; (p = it.advance()) != null;) {
         s.writeObject(p.key);
       }
@@ -947,7 +946,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
       @SuppressWarnings("unchecked")
       V k = (V) s.readObject();
       if (k != null) {
-        p = new Node<V>(spread(k.hashCode()), k, p);
+        p = new Node<>(spread(k.hashCode()), k, p);
         ++size;
       } else {
         break;
@@ -999,7 +998,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
               p.next = first;
               TreeNode<V> hd = null, tl = null;
               for (q = p; q != null; q = q.next) {
-                TreeNode<V> t = new TreeNode<V>(q.hash, q.key, null, null);
+                TreeNode<V> t = new TreeNode<>(q.hash, q.key, null, null);
                 if ((t.prev = tl) == null) {
                   hd = t;
                 } else {
@@ -1007,7 +1006,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
                 }
                 tl = t;
               }
-              setTabAt(tab, j, new TreeBin<V>(hd));
+              setTabAt(tab, j, new TreeBin<>(hd));
             }
           }
         }
@@ -1035,7 +1034,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
     Node<V>[] t;
     CompactConcurrentHashSet2<V> m = this;
     int f = (t = m.table) == null ? 0 : t.length;
-    return new KeyIterator<V>(t, f, 0, f, m);
+    return new KeyIterator<>(t, f, 0, f, m);
   }
 
   // CompactConcurrentHashSet2-only methods
@@ -1065,7 +1064,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
 
     ForwardingNode(Node<K>[] tab) {
       super(MOVED, null, null);
-      this.nextTable = tab;
+      nextTable = tab;
     }
 
     @Override
@@ -1274,7 +1273,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
       transferIndex = n;
     }
     int nextn = nextTab.length;
-    ForwardingNode<V> fwd = new ForwardingNode<V>(nextTab);
+    ForwardingNode<V> fwd = new ForwardingNode<>(nextTab);
     boolean advance = true;
     boolean finishing = false; // to ensure sweep before committing nextTab
     for (int i = 0, bound = 0;;) {
@@ -1338,9 +1337,9 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
                 int ph = p.hash;
                 V pk = p.key;
                 if ((ph & n) == 0) {
-                  ln = new Node<V>(ph, pk, ln);
+                  ln = new Node<>(ph, pk, ln);
                 } else {
-                  hn = new Node<V>(ph, pk, hn);
+                  hn = new Node<>(ph, pk, hn);
                 }
               }
               setTabAt(nextTab, i, ln);
@@ -1354,7 +1353,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
               int lc = 0, hc = 0;
               for (Node<V> e = t.first; e != null; e = e.next) {
                 int h = e.hash;
-                TreeNode<V> p = new TreeNode<V>(h, e.key, null, null);
+                TreeNode<V> p = new TreeNode<>(h, e.key, null, null);
                 if ((h & n) == 0) {
                   if ((p.prev = loTail) == null) {
                     lo = p;
@@ -1373,8 +1372,8 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
                   ++hc;
                 }
               }
-              ln = (lc <= UNTREEIFY_THRESHOLD) ? untreeify(lo) : (hc != 0) ? new TreeBin<V>(lo) : t;
-              hn = (hc <= UNTREEIFY_THRESHOLD) ? untreeify(hi) : (lc != 0) ? new TreeBin<V>(hi) : t;
+              ln = (lc <= UNTREEIFY_THRESHOLD) ? untreeify(lo) : (hc != 0) ? new TreeBin<>(lo) : t;
+              hn = (hc <= UNTREEIFY_THRESHOLD) ? untreeify(hi) : (lc != 0) ? new TreeBin<>(hi) : t;
               setTabAt(nextTab, i, ln);
               setTabAt(nextTab, i + n, hn);
               setTabAt(tab, i, fwd);
@@ -1403,7 +1402,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
           if (tabAt(tab, index) == b) {
             TreeNode<V> hd = null, tl = null;
             for (Node<V> e = b; e != null; e = e.next) {
-              TreeNode<V> p = new TreeNode<V>(e.hash, e.key, null, null);
+              TreeNode<V> p = new TreeNode<>(e.hash, e.key, null, null);
               if ((p.prev = tl) == null) {
                 hd = p;
               } else {
@@ -1411,7 +1410,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
               }
               tl = p;
             }
-            setTabAt(tab, index, new TreeBin<V>(hd));
+            setTabAt(tab, index, new TreeBin<>(hd));
           }
         }
       }
@@ -1424,7 +1423,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
   static <K> Node<K> untreeify(Node<K> b) {
     Node<K> hd = null, tl = null;
     for (Node<K> q = b; q != null; q = q.next) {
-      Node<K> p = new Node<K>(q.hash, q.key, null);
+      Node<K> p = new Node<>(q.hash, q.key, null);
       if (tl == null) {
         hd = p;
       } else {
@@ -1530,7 +1529,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
      */
     TreeBin(TreeNode<K> b) {
       super(TREEBIN, null, null);
-      this.first = b;
+      first = b;
       TreeNode<K> r = null;
       for (TreeNode<K> x = b, next; x != null; x = next) {
         next = (TreeNode<K>) x.next;
@@ -1568,7 +1567,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
           }
         }
       }
-      this.root = r;
+      root = r;
       assert checkInvariants(root);
     }
 
@@ -1660,7 +1659,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
         int dir, ph;
         K pk;
         if (p == null) {
-          first = root = new TreeNode<K>(h, k, null, null);
+          first = root = new TreeNode<>(h, k, null, null);
           break;
         } else if ((ph = p.hash) > h) {
           dir = -1;
@@ -1684,7 +1683,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
         TreeNode<K> xp = p;
         if ((p = (dir <= 0) ? p.left : p.right) == null) {
           TreeNode<K> x, f = first;
-          first = x = new TreeNode<K>(h, k, f, xp);
+          first = x = new TreeNode<>(h, k, f, xp);
           if (f != null) {
             f.prev = x;
           }
@@ -1952,7 +1951,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
                 xpr = (xp = x.parent) == null ? null : xp.right;
               }
               if (xpr != null) {
-                xpr.red = (xp == null) ? false : xp.red;
+                xpr.red = xp != null && xp.red;
                 if ((sr = xpr.right) != null) {
                   sr.red = false;
                 }
@@ -1988,7 +1987,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
                 xpl = (xp = x.parent) == null ? null : xp.left;
               }
               if (xpl != null) {
-                xpl.red = (xp == null) ? false : xp.red;
+                xpl.red = xp != null && xp.red;
                 if ((sl = xpl.left) != null) {
                   sl.red = false;
                 }
@@ -2030,10 +2029,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
       if (tl != null && !checkInvariants(tl)) {
         return false;
       }
-      if (tr != null && !checkInvariants(tr)) {
-        return false;
-      }
-      return true;
+      return tr == null || checkInvariants(tr);
     }
 
     @Immutable
@@ -2088,10 +2084,10 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
 
     Traverser(Node<K>[] tab, int size, int index, int limit) {
       this.tab = tab;
-      this.baseSize = size;
-      this.baseIndex = this.index = index;
-      this.baseLimit = limit;
-      this.next = null;
+      baseSize = size;
+      baseIndex = this.index = index;
+      baseLimit = limit;
+      next = null;
     }
 
     /**
@@ -2139,7 +2135,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
       if (s != null) {
         spare = s.next;
       } else {
-        s = new TableStack<K>();
+        s = new TableStack<>();
       }
       s.tab = t;
       s.length = n;
@@ -2181,7 +2177,7 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
 
     BaseIterator(Node<K>[] tab, int size, int index, int limit, CompactConcurrentHashSet2<K> map) {
       super(tab, size, index, limit);
-      this.set = map;
+      set = map;
       advance();
     }
 
@@ -2266,15 +2262,15 @@ public class CompactConcurrentHashSet2<V> extends AbstractSet<V> implements Set<
    * Per-thread counter hash codes. Shared across all instances.
    */
   static final ThreadLocal<CounterHashCode> threadCounterHashCode =
-      new ThreadLocal<CounterHashCode>();
+      new ThreadLocal<>();
 
   long sumCount() {
     CounterCell[] as = counterCells;
     CounterCell a;
     long sum = baseCount;
     if (as != null) {
-      for (int i = 0; i < as.length; ++i) {
-        if ((a = as[i]) != null) {
+      for (final CounterCell counterCell : as) {
+        if ((a = counterCell) != null) {
           sum += a.value;
         }
       }
