@@ -42,7 +42,7 @@ import org.apache.geode.annotations.Immutable;
 import org.apache.geode.annotations.internal.MakeNotStatic;
 import org.apache.geode.annotations.internal.MutableForTesting;
 import org.apache.geode.distributed.DistributedSystem;
-import org.apache.geode.internal.ClassPathLoader;
+import org.apache.geode.internal.classloader.ClassPathLoader;
 import org.apache.geode.internal.datasource.ClientConnectionFactoryWrapper;
 import org.apache.geode.internal.datasource.ConfigProperty;
 import org.apache.geode.internal.datasource.DataSourceCreateException;
@@ -51,7 +51,7 @@ import org.apache.geode.internal.datasource.GemFireTransactionDataSource;
 import org.apache.geode.internal.jta.TransactionManagerImpl;
 import org.apache.geode.internal.jta.TransactionUtils;
 import org.apache.geode.internal.jta.UserTransactionImpl;
-import org.apache.geode.internal.util.DriverJarUtil;
+import org.apache.geode.internal.util.DriverJarUtils;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.util.internal.GeodeGlossary;
 
@@ -59,11 +59,9 @@ import org.apache.geode.util.internal.GeodeGlossary;
  * <p>
  * Utility class for binding DataSources and Transactional resources to JNDI Tree. If there is a
  * pre-existing JNDI tree in the system, the GemFire JNDI tree is not not generated.
- * </p>
  * <p>
  * Datasources are bound to jndi tree after getting initialised. The initialisation parameters are
  * read from cache.xml.
- * </p>
  * <p>
  * If there is a pre-existing TransactionManager/UserTransaction (possible in presence of
  * application server scenerio), the GemFire TransactionManager and UserTransaction will not be
@@ -71,7 +69,7 @@ import org.apache.geode.util.internal.GeodeGlossary;
  * transactional activity. But even in this case the datasource element will be bound to the
  * available JNDI tree. The transactional datasource (XADataSource) will make use of available
  * TransactionManager.
- * </p>
+ * <p>
  *
  */
 public class JNDIInvoker {
@@ -138,7 +136,7 @@ public class JNDIInvoker {
    * already bound, GemFire will make use of these resources, but if TransactionManager /
    * UserTransaction is not available, the GemFire TransactionManager / UserTransaction will be
    * bound to the JNDI tree.
-   * </p>
+   * <p>
    *
    */
   public static void mapTransactions(DistributedSystem distSystem) {
@@ -260,12 +258,12 @@ public class JNDIInvoker {
   private static void doTransactionLookup() throws NamingException {
     Object jndiObject = null;
     LogWriter writer = TransactionUtils.getLogWriter();
-    for (int i = 0; i < knownJNDIManagers.length; i++) {
+    for (final String[] knownJNDIManager : knownJNDIManagers) {
       try {
-        jndiObject = ctx.lookup(knownJNDIManagers[i][0]);
+        jndiObject = ctx.lookup(knownJNDIManager[0]);
       } catch (NamingException e) {
         String exception = "JNDIInvoker::doTransactionLookup::Couldn't lookup ["
-            + knownJNDIManagers[i][0] + " (" + knownJNDIManagers[i][1] + ")]";
+            + knownJNDIManager[0] + " (" + knownJNDIManager[1] + ")]";
         if (writer.finerEnabled()) {
           writer.finer(exception);
         }
@@ -273,7 +271,7 @@ public class JNDIInvoker {
       if (jndiObject instanceof TransactionManager) {
         transactionManager = (TransactionManager) jndiObject;
         String exception = "JNDIInvoker::doTransactionLookup::Found TransactionManager for "
-            + knownJNDIManagers[i][1];
+            + knownJNDIManager[1];
         if (writer.fineEnabled()) {
           writer.fine(exception);
         }
@@ -338,7 +336,7 @@ public class JNDIInvoker {
       throw new NameNotFoundException(
           String.format(
               "JNDIInvoker::doTransactionLookup::Found WebSphere TransactionManager factory class [%s], but could not invoke its static 'getTransactionManager' method",
-              new Object[] {clazz.getName()}));
+              clazz.getName()));
     }
   }
 
@@ -373,7 +371,7 @@ public class JNDIInvoker {
     String driverClassName = null;
     if (map != null) {
       driverClassName = (String) map.get("jdbc-driver-class");
-      DriverJarUtil util = new DriverJarUtil();
+      DriverJarUtils util = new DriverJarUtils();
       if (driverClassName != null) {
         util.registerDriver(driverClassName);
       }
@@ -413,6 +411,7 @@ public class JNDIInvoker {
     try (Connection connection = getConnection(dataSource, props)) {
     } catch (SQLException sqlEx) {
       closeDataSource(dataSource);
+      logger.warn("Failed DataSource validation for JNDI name {}", jndiName, sqlEx);
       throw new DataSourceCreateException(
           "Failed to connect to \"" + jndiName + "\". See log for details", sqlEx);
     }
@@ -446,12 +445,8 @@ public class JNDIInvoker {
   public static boolean isValidDataSource(String name) {
     Object dataSource = dataSourceMap.get(name);
 
-    if (dataSource == null || (dataSource instanceof DataSource
-        && !(dataSource instanceof GemFireTransactionDataSource))) {
-      return true;
-    }
-
-    return false;
+    return dataSource == null || (dataSource instanceof DataSource
+        && !(dataSource instanceof GemFireTransactionDataSource));
   }
 
   /**
