@@ -49,12 +49,12 @@ public class TransactionImpl implements Transaction {
   /**
    * The transaction manager that owns this transaction.
    */
-  private TransactionManagerImpl tm = TransactionManagerImpl.getTransactionManager();
+  private final TransactionManagerImpl tm = TransactionManagerImpl.getTransactionManager();
 
   /**
    * List of registered Synchronization objects.
    */
-  private List syncList = new ArrayList();
+  private final List syncList = new ArrayList();
 
   /**
    * Constructs an instance of a Transaction
@@ -278,9 +278,8 @@ public class TransactionImpl implements Transaction {
    * @param status int The status of the Global transaction associated with the transaction
    */
   void notifyAfterCompletion(int status) throws SystemException {
-    Iterator iterator = syncList.iterator();
-    while (iterator.hasNext()) {
-      sync = ((Synchronization) iterator.next());
+    for (final Object o : syncList) {
+      sync = ((Synchronization) o);
       sync.afterCompletion(status);
     }
   }
