@@ -14,8 +14,9 @@
  */
 package org.apache.geode.internal.lang;
 
-import java.util.Optional;
+import static org.apache.geode.internal.lang.SystemProperty.getProductBooleanProperty;
 
+import org.apache.geode.internal.cache.eviction.LRUListWithAsyncSorting;
 
 /**
  * The SystemPropertyHelper class is an helper class for accessing system properties used in geode.
@@ -25,12 +26,9 @@ import java.util.Optional;
  */
 public class SystemPropertyHelper {
 
-  public static final String GEODE_PREFIX = "geode.";
-  public static final String GEMFIRE_PREFIX = "gemfire.";
-
   /**
    * When set to "true" enables asynchronous eviction algorithm (defaults to true). For more details
-   * see {@link org.apache.geode.internal.cache.eviction.LRUListWithAsyncSorting}.
+   * see {@link LRUListWithAsyncSorting}.
    *
    * @since Geode 1.4.0
    */
@@ -39,7 +37,7 @@ public class SystemPropertyHelper {
   /**
    * This property allows the maximum number of threads used for asynchronous eviction scanning to
    * be configured. It defaults to "Math.max((Runtime.getRuntime().availableProcessors() / 4), 1)".
-   * For more details see {@link org.apache.geode.internal.cache.eviction.LRUListWithAsyncSorting}.
+   * For more details see {@link LRUListWithAsyncSorting}.
    *
    * @since Geode 1.4.0
    */
@@ -50,7 +48,7 @@ public class SystemPropertyHelper {
    * started. If the number of entries that have been recently used since the previous scan divided
    * by total number of entries exceeds the threshold then a scan is started. The default threshold
    * is 25. If the threshold is less than 0 or greater than 100 then the default threshold is used.
-   * For more details see {@link org.apache.geode.internal.cache.eviction.LRUListWithAsyncSorting}.
+   * For more details see {@link LRUListWithAsyncSorting}.
    *
    * @since Geode 1.4.0
    */
@@ -71,9 +69,23 @@ public class SystemPropertyHelper {
 
   public static final String USE_HTTP_SYSTEM_PROPERTY = "useHTTP";
 
+  /**
+   * This property allows users to enable retrying when client application encounters
+   * PdxSerializationException. The default setting is false, and PdxSerializationException will not
+   * be retried. It will cause client application to throw ServerOperationException. When the
+   * property is set to true, the client application will automatically retry the operation to
+   * another server if encountered PdxSerializationException.
+   *
+   * @since Geode 1.15.0
+   */
+  public static final String ENABLE_QUERY_RETRY_ON_PDX_SERIALIZATION_EXCEPTION =
+      "enableQueryRetryOnPdxSerializationException";
+
   /**
    * a comma separated string to list out the packages to scan. If not specified, the entire
    * classpath is scanned.
+   *
+   * <p>
    * This is used by the FastPathScanner to scan for:
    * 1. XSDRootElement annotation
    *
@@ -88,69 +100,28 @@ public class SystemPropertyHelper {
   public static final String PARALLEL_DISK_STORE_RECOVERY = "parallelDiskStoreRecovery";
 
   /**
-   * This method will try to look up "geode." and "gemfire." versions of the system property. It
-   * will check and prefer "geode." setting first, then try to check "gemfire." setting.
-   *
-   * @param name system property name set in Geode
-   * @return an Optional containing the Boolean value of the system property
+   * Milliseconds to wait before retrying to get events for a transaction from the
+   * gateway sender queue when group-transaction-events is true.
    */
-  public static Optional<Boolean> getProductBooleanProperty(String name) {
-    String property = getProperty(name);
-    return property != null ? Optional.of(Boolean.parseBoolean(property)) : Optional.empty();
-  }
+  public static final String GET_TRANSACTION_EVENTS_FROM_QUEUE_WAIT_TIME_MS =
+      "get-transaction-events-from-queue-wait-time-ms";
 
   /**
-   * This method will try to look up "geode." and "gemfire." versions of the system property. It
-   * will check and prefer "geode." setting first, then try to check "gemfire." setting.
-   *
-   * @param name system property name set in Geode
-   * @return an Optional containing the Integer value of the system property
+   * Milliseconds to wait for the client to re-authenticate back before unregister this client
+   * proxy. If client re-authenticate back successfully within this period, messages will continue
+   * to be delivered to the client
    */
-  public static Optional<Integer> getProductIntegerProperty(String name) {
-    Integer propertyValue = Integer.getInteger(GEODE_PREFIX + name);
-    if (propertyValue == null) {
-      propertyValue = Integer.getInteger(GEMFIRE_PREFIX + name);
-    }
-
-    if (propertyValue != null) {
-      return Optional.of(propertyValue);
-    } else {
-      return Optional.empty();
-    }
-  }
-
-  /**
-   * This method will try to look up "geode." and "gemfire." versions of the system property. It
-   * will check and prefer "geode." setting first, then try to check "gemfire." setting.
-   *
-   * @param name system property name set in Geode
-   * @return an Optional containing the String value of the system property
-   */
-  public static Optional<String> getProductStringProperty(String name) {
-    String property = getProperty(name);
-    return property != null ? Optional.of(property) : Optional.empty();
-  }
-
-  public static String getProperty(String name) {
-    String property = getGeodeProperty(name);
-    return property != null ? property : getGemfireProperty(name);
-  }
-
-  private static String getGeodeProperty(String name) {
-    return System.getProperty(GEODE_PREFIX + name);
-  }
-
-  private static String getGemfireProperty(String name) {
-    return System.getProperty(GEMFIRE_PREFIX + name);
-  }
+  public static final String RE_AUTHENTICATE_WAIT_TIME = "reauthenticate.wait.time";
 
   /**
    * As of Geode 1.4.0, a region set operation will be in a transaction even if it is the first
    * operation in the transaction.
    *
+   * <p>
    * In previous releases, a region set operation is not in a transaction if it is the first
    * operation of the transaction.
    *
+   * <p>
    * Setting this system property to true will restore the previous behavior.
    *
    * @since Geode 1.4.0
@@ -163,6 +134,7 @@ public class SystemPropertyHelper {
    * As of Geode 1.4.0, idle expiration on a replicate or partitioned region will now do a
    * distributed check for a more recent last access time on one of the other copies of the region.
    *
+   * <p>
    * This system property can be set to true to turn off this new check and restore the previous
    * behavior of only using the local last access time as the basis for expiration.
    *
@@ -171,4 +143,5 @@ public class SystemPropertyHelper {
   public static boolean restoreIdleExpirationBehavior() {
     return getProductBooleanProperty("restoreIdleExpirationBehavior").orElse(false);
   }
+
 }
