@@ -25,6 +25,7 @@ import static org.apache.geode.internal.logging.Banner.BannerHeader.LOG4J2_CONFI
 import static org.apache.geode.internal.logging.Banner.BannerHeader.PROCESS_ID;
 import static org.apache.geode.internal.logging.Banner.BannerHeader.SYSTEM_PROPERTIES;
 import static org.apache.geode.internal.logging.Banner.BannerHeader.USER;
+import static org.apache.geode.internal.util.ProductVersionUtil.getFullVersion;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;
@@ -40,7 +41,7 @@ import java.util.StringTokenizer;
 import java.util.TreeMap;
 
 import org.apache.geode.SystemFailure;
-import org.apache.geode.internal.GemFireVersion;
+import org.apache.geode.internal.SystemDescription;
 import org.apache.geode.internal.VersionDescription;
 import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.internal.util.ArgumentRedactor;
@@ -105,7 +106,7 @@ public class Banner {
    *
    * @param args possibly null list of command line arguments
    */
-  private void print(PrintWriter out, String args[]) {
+  private void print(PrintWriter out, String[] args) {
     // Copy the system properties for printing. Some are given explicit lines, and
     // others are suppressed. Remove these keys, keeping those we want.
     Map sp = new TreeMap((Properties) System.getProperties().clone()); // fix for 46822
@@ -141,7 +142,9 @@ public class Banner {
     out.println(SEPARATOR);
     printASFLicense(out);
     out.println(SEPARATOR);
-    GemFireVersion.print(out);
+    out.println(getFullVersion());
+    out.println(SystemDescription.RUNNING_ON + ": " + SystemDescription.getRunningOnInfo());
+    out.println(SEPARATOR);
     out.println(COMMUNICATIONS_VERSION.displayValue() + ": " + currentOrdinal);
     out.println(PROCESS_ID.displayValue() + ": " + processId);
     out.println(USER.displayValue() + ": " + userName);
@@ -234,7 +237,7 @@ public class Banner {
     SOURCE_DATE(VersionDescription.SOURCE_DATE),
     SOURCE_REPOSITORY(VersionDescription.SOURCE_REPOSITORY),
     SOURCE_REVISION(VersionDescription.SOURCE_REVISION),
-    RUNNING_ON(VersionDescription.RUNNING_ON),
+    RUNNING_ON(SystemDescription.RUNNING_ON),
     COMMUNICATIONS_VERSION("Communications version"),
     PROCESS_ID("Process ID"),
     USER("User"),
