@@ -14,16 +14,13 @@
  */
 package org.apache.geode.internal.monitoring.executor;
 
-import org.apache.geode.internal.monitoring.ThreadsMonitoring;
-
 public class FunctionExecutionPooledExecutorGroup extends AbstractExecutor {
 
   public static final String GROUPNAME = "FunctionExecutionPooledExecutor";
 
 
-  public FunctionExecutionPooledExecutorGroup(ThreadsMonitoring tMonitoring) {
-    super(tMonitoring);
-    setGroupName(GROUPNAME);
+  public FunctionExecutionPooledExecutorGroup() {
+    super(GROUPNAME);
   }
 
 }
