@@ -14,16 +14,19 @@
  */
 package org.apache.geode.internal.net;
 
+import static org.apache.commons.lang3.StringUtils.isEmpty;
 import static org.apache.geode.distributed.ConfigurationProperties.CLUSTER_SSL_CIPHERS;
 import static org.apache.geode.distributed.ConfigurationProperties.CLUSTER_SSL_ENABLED;
 import static org.apache.geode.distributed.ConfigurationProperties.CLUSTER_SSL_PROTOCOLS;
 import static org.apache.geode.distributed.ConfigurationProperties.CLUSTER_SSL_REQUIRE_AUTHENTICATION;
 
 import java.security.KeyStore;
-import java.util.Iterator;
 import java.util.Properties;
 
+import org.apache.commons.lang3.ArrayUtils;
 import org.apache.commons.lang3.StringUtils;
+import org.jetbrains.annotations.NotNull;
+import org.jetbrains.annotations.Nullable;
 
 import org.apache.geode.annotations.Immutable;
 import org.apache.geode.distributed.internal.DistributionConfig;
@@ -46,6 +49,8 @@ public class SSLConfig {
   private final boolean useDefaultSSLContext;
   private final boolean enabled;
   private final String protocols;
+  private final String serverProtocols;
+  private final String clientProtocols;
   private final String ciphers;
   private final boolean requireAuth;
   private final String keystore;
@@ -68,26 +73,30 @@ public class SSLConfig {
   @Immutable
   private final SSLParameterExtension sslParameterExtension;
 
-  private SSLConfig(boolean endpointIdentification,
-      boolean useDefaultSSLContext,
-      boolean enabled,
-      String protocols,
-      String ciphers,
-      boolean requireAuth,
-      String keystore,
-      String keystoreType,
-      String keystorePassword,
-      String truststore,
-      String truststorePassword,
-      String truststoreType,
-      String alias,
-      SecurableCommunicationChannel securableCommunicationChannel,
-      Properties properties,
-      SSLParameterExtension sslParameterExtension) {
+  private SSLConfig(final boolean endpointIdentification,
+      final boolean useDefaultSSLContext,
+      final boolean enabled,
+      final @NotNull String protocols,
+      final @Nullable String clientProtocols,
+      final @Nullable String serverProtocols,
+      final String ciphers,
+      final boolean requireAuth,
+      final String keystore,
+      final String keystoreType,
+      final String keystorePassword,
+      final String truststore,
+      final String truststorePassword,
+      final String truststoreType,
+      final String alias,
+      final SecurableCommunicationChannel securableCommunicationChannel,
+      final Properties properties,
+      final SSLParameterExtension sslParameterExtension) {
     this.endpointIdentification = endpointIdentification;
     this.useDefaultSSLContext = useDefaultSSLContext;
     this.enabled = enabled;
     this.protocols = protocols;
+    this.clientProtocols = isEmpty(clientProtocols) ? protocols : clientProtocols;
+    this.serverProtocols = isEmpty(serverProtocols) ? protocols : serverProtocols;
     this.ciphers = ciphers;
     this.requireAuth = requireAuth;
     this.keystore = keystore;
@@ -107,7 +116,7 @@ public class SSLConfig {
   }
 
   public boolean doEndpointIdentification() {
-    return this.endpointIdentification;
+    return endpointIdentification;
   }
 
   public String getKeystore() {
@@ -131,31 +140,39 @@ public class SSLConfig {
   }
 
   public boolean isEnabled() {
-    return this.enabled;
+    return enabled;
   }
 
   public boolean useDefaultSSLContext() {
-    return this.useDefaultSSLContext;
+    return useDefaultSSLContext;
   }
 
-  public String getProtocols() {
-    return this.protocols;
+  public String getClientProtocols() {
+    return clientProtocols;
   }
 
-  public String[] getProtocolsAsStringArray() {
-    return SSLUtil.readArray(this.protocols);
+  public @NotNull String[] getClientProtocolsAsStringArray() {
+    return SSLUtil.split(clientProtocols);
+  }
+
+  public String getServerProtocols() {
+    return serverProtocols;
+  }
+
+  public @NotNull String[] getServerProtocolsAsStringArray() {
+    return SSLUtil.split(serverProtocols);
   }
 
   public String getCiphers() {
-    return this.ciphers;
+    return ciphers;
   }
 
-  public String[] getCiphersAsStringArray() {
-    return SSLUtil.readArray(this.ciphers);
+  public @NotNull String[] getCiphersAsStringArray() {
+    return SSLUtil.split(ciphers);
   }
 
   public boolean isRequireAuth() {
-    return this.requireAuth;
+    return requireAuth;
   }
 
   public String getTruststoreType() {
@@ -163,7 +180,7 @@ public class SSLConfig {
   }
 
   public Properties getProperties() {
-    return this.properties;
+    return properties;
   }
 
   public SecurableCommunicationChannel getSecuredCommunicationChannel() {
@@ -174,12 +191,67 @@ public class SSLConfig {
     return sslParameterExtension;
   }
 
+  /**
+   * Checks if "any" cipher is specified in {@link #getCiphers()}
+   *
+   * @return {@code true} if ciphers is either {@code null}, empty or is set to "any"
+   *         (ignoring case), otherwise {@code false}.
+   */
+  public boolean isAnyCiphers() {
+    return isAnyCiphers(ciphers);
+  }
+
+  /**
+   * Checks if "any" cipher is specified in {@code ciphers}.
+   *
+   * @param ciphers Comma or space separated list of cipher names.
+   * @return {@code true} if {@code ciphers} is either {@code null}, empty or is set to "any"
+   *         (ignoring case), otherwise {@code false}.
+   */
+  public static boolean isAnyCiphers(final String ciphers) {
+    return StringUtils.isBlank(ciphers) || "any".equalsIgnoreCase(ciphers);
+  }
+
+  /**
+   * Checks if "any" cipher is specified in {@code ciphers}.
+   *
+   * @param ciphers Array of cipher names.
+   * @return {@code true} if {@code ciphers} is either {@code null}, empty or first entry is "any"
+   *         (ignoring case), otherwise {@code false}.
+   */
+  public static boolean isAnyCiphers(final String... ciphers) {
+    return ArrayUtils.isEmpty(ciphers) || "any".equalsIgnoreCase(ciphers[0]);
+  }
+
+  /**
+   * Checks if "any" protocol is specified in {@code protocols}.
+   *
+   * @param protocols Comma or space separated list of protocol names.
+   * @return {@code true} if {@code protocols} is either {@code null}, empty or is set to "any"
+   *         (ignoring case), otherwise {@code false}.
+   */
+  public static boolean isAnyProtocols(final String protocols) {
+    return StringUtils.isBlank(protocols) || "any".equalsIgnoreCase(protocols);
+  }
+
+  /**
+   * Checks if "any" protocol is specified in {@code protocols}.
+   *
+   * @param protocols Array of protocol names.
+   * @return {@code true} if {@code protocols} is either {@code null}, empty or first entry is "any"
+   *         (ignoring case), otherwise {@code false}.
+   */
+  public static boolean isAnyProtocols(final String... protocols) {
+    return ArrayUtils.isEmpty(protocols) || "any".equalsIgnoreCase(protocols[0]);
+  }
+
   @Override
   public String toString() {
-    return "SSLConfig{" + "enabled=" + enabled + ", protocols='" + protocols + '\'' + ", ciphers='"
-        + ciphers + '\'' + ", requireAuth=" + requireAuth + ", keystore='" + keystore + '\''
-        + ", keystoreType='" + keystoreType + '\'' + ", keystorePassword='" + keystorePassword
-        + '\'' + ", truststore='" + truststore + '\'' + ", truststorePassword='"
+    return "SSLConfig{" + "enabled=" + enabled + ", protocols='" + protocols + '\''
+        + ", clientProtocols='" + clientProtocols + '\'' + ", serverProtocols='" + serverProtocols
+        + '\'' + ", ciphers='" + ciphers + '\'' + ", requireAuth=" + requireAuth + ", keystore='"
+        + keystore + '\'' + ", keystoreType='" + keystoreType + '\'' + ", keystorePassword='"
+        + keystorePassword + '\'' + ", truststore='" + truststore + '\'' + ", truststorePassword='"
         + truststorePassword + '\'' + ", truststoreType='" + truststoreType + '\'' + ", alias='"
         + alias + '\'' + ", securableCommunicationChannel=" + securableCommunicationChannel
         + ", properties=" + properties + '\'' + ", sslParameterExtension=" + sslParameterExtension
@@ -193,15 +265,19 @@ public class SSLConfig {
    * @since GemFire 4.0
    */
   public void toDSProperties(Properties props) {
-    props.setProperty(CLUSTER_SSL_ENABLED, String.valueOf(this.enabled));
+    props.setProperty(CLUSTER_SSL_ENABLED, String.valueOf(enabled));
 
-    if (this.enabled) {
-      props.setProperty(CLUSTER_SSL_PROTOCOLS, this.protocols);
-      props.setProperty(CLUSTER_SSL_CIPHERS, this.ciphers);
-      props.setProperty(CLUSTER_SSL_REQUIRE_AUTHENTICATION, String.valueOf(this.requireAuth));
+    if (enabled) {
+      props.setProperty(CLUSTER_SSL_PROTOCOLS, protocols);
+      props.setProperty(CLUSTER_SSL_CIPHERS, ciphers);
+      props.setProperty(CLUSTER_SSL_REQUIRE_AUTHENTICATION, String.valueOf(requireAuth));
     }
   }
 
+  public static Builder builder() {
+    return new Builder();
+  }
+
   /**
    * Builder class to be used to construct SSLConfig instances.
    * In order to build an {@link SSLConfig} instance an instance of this
@@ -221,6 +297,8 @@ public class SSLConfig {
     private boolean useDefaultSSLContext = DistributionConfig.DEFAULT_SSL_USE_DEFAULT_CONTEXT;
     private boolean enabled = DistributionConfig.DEFAULT_SSL_ENABLED;
     private String protocols = DistributionConfig.DEFAULT_SSL_PROTOCOLS;
+    private String clientProtocols = DistributionConfig.DEFAULT_SSL_CLIENT_PROTOCOLS;
+    private String serverProtocols = DistributionConfig.DEFAULT_SSL_SERVER_PROTOCOLS;
     private String ciphers = DistributionConfig.DEFAULT_SSL_CIPHERS;
     private boolean requireAuth = DistributionConfig.DEFAULT_SSL_REQUIRE_AUTHENTICATION;
     private String keystore = DistributionConfig.DEFAULT_SSL_KEYSTORE;
@@ -238,9 +316,9 @@ public class SSLConfig {
 
     public SSLConfig build() {
       return new SSLConfig(endpointIdentification, useDefaultSSLContext, enabled,
-          protocols, ciphers, requireAuth, keystore, keystoreType, keystorePassword,
-          truststore, truststorePassword, truststoreType, alias, securableCommunicationChannel,
-          properties, sslParameterExtension);
+          protocols, clientProtocols, serverProtocols, ciphers, requireAuth, keystore, keystoreType,
+          keystorePassword, truststore, truststorePassword, truststoreType, alias,
+          securableCommunicationChannel, properties, sslParameterExtension);
     }
 
     public Builder setAlias(final String alias) {
@@ -293,6 +371,16 @@ public class SSLConfig {
       return this;
     }
 
+    public Builder setClientProtocols(String clientProtocols) {
+      this.clientProtocols = clientProtocols;
+      return this;
+    }
+
+    public Builder setServerProtocols(String serverProtocols) {
+      this.serverProtocols = serverProtocols;
+      return this;
+    }
+
     public Builder setCiphers(String ciphers) {
       this.ciphers = ciphers;
       return this;
@@ -309,10 +397,10 @@ public class SSLConfig {
     }
 
     public Builder setProperties(Properties newProps) {
-      this.properties = new Properties();
-      for (Iterator iter = newProps.keySet().iterator(); iter.hasNext();) {
-        String key = (String) iter.next();
-        this.properties.setProperty(key, newProps.getProperty(key));
+      properties = new Properties();
+      for (final Object o : newProps.keySet()) {
+        String key = (String) o;
+        properties.setProperty(key, newProps.getProperty(key));
       }
       return this;
     }
@@ -326,20 +414,19 @@ public class SSLConfig {
     public Builder setSSLParameterExtension(
         final String sslParameterExtensionConfig) {
       if (StringUtils.isBlank(sslParameterExtensionConfig)) {
-        this.sslParameterExtension = null;
+        sslParameterExtension = null;
         return this;
       }
       InternalDistributedSystem ids = InternalDistributedSystem.getAnyInstance();
 
       if (ids == null) {
-        this.sslParameterExtension = null;
+        sslParameterExtension = null;
         return this;
       }
 
       SSLParameterExtension sslParameterExtension =
           CallbackInstantiator.getObjectOfTypeFromClassName(sslParameterExtensionConfig,
               SSLParameterExtension.class);
-      ids.getConfig().getDistributedSystemId();
 
       sslParameterExtension.init(
           new SSLParameterExtensionContextImpl(ids.getConfig().getDistributedSystemId()));
