@@ -12,11 +12,14 @@
  * or implied. See the License for the specific language governing permissions and limitations under
  * the License.
  */
+
 package org.apache.geode.internal.net;
 
+import static org.apache.commons.lang3.ObjectUtils.getIfNull;
+import static org.apache.geode.internal.net.filewatch.FileWatchingX509ExtendedKeyManager.newFileWatchingKeyManager;
+import static org.apache.geode.internal.net.filewatch.FileWatchingX509ExtendedTrustManager.newFileWatchingTrustManager;
 
 import java.io.Console;
-import java.io.FileInputStream;
 import java.io.IOException;
 import java.net.BindException;
 import java.net.InetAddress;
@@ -29,14 +32,6 @@ import java.net.UnknownHostException;
 import java.nio.ByteBuffer;
 import java.nio.channels.SocketChannel;
 import java.security.GeneralSecurityException;
-import java.security.KeyStore;
-import java.security.KeyStoreException;
-import java.security.NoSuchAlgorithmException;
-import java.security.Principal;
-import java.security.PrivateKey;
-import java.security.UnrecoverableKeyException;
-import java.security.cert.CertificateException;
-import java.security.cert.X509Certificate;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
@@ -45,7 +40,6 @@ import java.util.Properties;
 import java.util.concurrent.ConcurrentHashMap;
 
 import javax.net.ssl.KeyManager;
-import javax.net.ssl.KeyManagerFactory;
 import javax.net.ssl.SNIHostName;
 import javax.net.ssl.SNIServerName;
 import javax.net.ssl.SSLContext;
@@ -58,11 +52,7 @@ import javax.net.ssl.SSLProtocolException;
 import javax.net.ssl.SSLSocket;
 import javax.net.ssl.StandardConstants;
 import javax.net.ssl.TrustManager;
-import javax.net.ssl.TrustManagerFactory;
-import javax.net.ssl.X509ExtendedKeyManager;
 
-import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.validator.routines.InetAddressValidator;
 import org.apache.logging.log4j.Logger;
 
 import org.apache.geode.GemFireConfigException;
@@ -78,17 +68,15 @@ import org.apache.geode.distributed.internal.DistributionConfigImpl;
 import org.apache.geode.distributed.internal.tcpserver.AdvancedSocketCreatorImpl;
 import org.apache.geode.distributed.internal.tcpserver.HostAndPort;
 import org.apache.geode.distributed.internal.tcpserver.TcpSocketCreatorImpl;
-import org.apache.geode.internal.ClassPathLoader;
 import org.apache.geode.internal.cache.wan.TransportFilterServerSocket;
 import org.apache.geode.internal.cache.wan.TransportFilterSocketFactory;
+import org.apache.geode.internal.classloader.ClassPathLoader;
 import org.apache.geode.internal.inet.LocalHostUtil;
 import org.apache.geode.internal.util.ArgumentRedactor;
-import org.apache.geode.internal.util.PasswordUtil;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.net.SSLParameterExtension;
 import org.apache.geode.util.internal.GeodeGlossary;
 
-
 /**
  * SocketCreators are built using a SocketCreatorFactory using Geode distributed-system properties.
  * They know how to properly configure sockets for TLS (SSL) communications and perform
@@ -127,17 +115,16 @@ public class SocketCreator extends TcpSocketCreatorImpl {
    * Only print this SocketCreator's config once
    */
   private boolean configShown = false;
+
   /**
    * Only print hostname validation disabled log once
    */
   private boolean hostnameValidationDisabledLogShown = false;
 
-
   private SSLContext sslContext;
 
   private final SSLConfig sslConfig;
 
-
   private ClientSocketFactory clientSocketFactory;
 
   /**
@@ -148,10 +135,6 @@ public class SocketCreator extends TcpSocketCreatorImpl {
   public static final boolean ENABLE_TCP_KEEP_ALIVE =
       AdvancedSocketCreatorImpl.ENABLE_TCP_KEEP_ALIVE;
 
-  // -------------------------------------------------------------------------
-  // Static instance accessors
-  // -------------------------------------------------------------------------
-
   /**
    * This method has migrated to LocalHostUtil but is kept in place here for
    * backward-compatibility testing.
@@ -164,16 +147,15 @@ public class SocketCreator extends TcpSocketCreatorImpl {
     return LocalHostUtil.getLocalHost();
   }
 
-
   /**
    * returns the host name for the given inet address, using a local cache of names to avoid dns
    * hits and duplicate strings
    */
-  public static String getHostName(InetAddress addr) {
-    String result = hostNames.get(addr);
+  public static String getHostName(InetAddress address) {
+    String result = hostNames.get(address);
     if (result == null) {
-      result = addr.getHostName();
-      hostNames.put(addr, result);
+      result = address.getHostName();
+      hostNames.put(address, result);
     }
     return result;
   }
@@ -185,11 +167,6 @@ public class SocketCreator extends TcpSocketCreatorImpl {
     hostNames.clear();
   }
 
-
-  // -------------------------------------------------------------------------
-  // Constructor
-  // -------------------------------------------------------------------------
-
   /**
    * Constructs new SocketCreator instance.
    */
@@ -206,15 +183,11 @@ public class SocketCreator extends TcpSocketCreatorImpl {
 
   /** returns the hostname or address for this client */
   public static String getClientHostName() throws UnknownHostException {
-    InetAddress hostAddr = LocalHostUtil.getLocalHost();
-    return SocketCreator.use_client_host_name ? hostAddr.getCanonicalHostName()
-        : hostAddr.getHostAddress();
+    InetAddress address = LocalHostUtil.getLocalHost();
+    return SocketCreator.use_client_host_name ? address.getCanonicalHostName()
+        : address.getHostAddress();
   }
 
-  // -------------------------------------------------------------------------
-  // Initializers (change SocketCreator state)
-  // -------------------------------------------------------------------------
-
   protected void initializeCreators() {
     clusterSocketCreator = new SCClusterSocketCreator(this);
     clientSocketCreator = new SCClientSocketCreator(this);
@@ -229,7 +202,7 @@ public class SocketCreator extends TcpSocketCreatorImpl {
   private void initialize() {
     try {
       try {
-        if (this.sslConfig.isEnabled() && getSslContext() == null) {
+        if (sslConfig.isEnabled() && getSslContext() == null) {
           sslContext = createAndConfigureSSLContext();
         }
       } catch (Exception e) {
@@ -267,17 +240,24 @@ public class SocketCreator extends TcpSocketCreatorImpl {
    * @return new SSLContext configured using the given protocols & properties
    *
    * @throws GeneralSecurityException if security information can not be found
-   * @throws IOException if information can not be loaded
    */
-  private SSLContext createAndConfigureSSLContext() throws GeneralSecurityException, IOException {
+  private SSLContext createAndConfigureSSLContext() throws GeneralSecurityException {
 
     if (sslConfig.useDefaultSSLContext()) {
       return SSLContext.getDefault();
     }
 
-    SSLContext newSSLContext = SSLUtil.getSSLContextInstance(sslConfig);
-    KeyManager[] keyManagers = getKeyManagers();
-    TrustManager[] trustManagers = getTrustManagers();
+    SSLContext newSSLContext = SSLUtil.getSSLContextInstance();
+
+    KeyManager[] keyManagers = null;
+    if (sslConfig.getKeystore() != null) {
+      keyManagers = new KeyManager[] {newFileWatchingKeyManager(sslConfig)};
+    }
+
+    TrustManager[] trustManagers = null;
+    if (sslConfig.getTruststore() != null) {
+      trustManagers = new TrustManager[] {newFileWatchingTrustManager(sslConfig)};
+    }
 
     newSSLContext.init(keyManagers, trustManagers, null /* use the default secure random */);
     return newSSLContext;
@@ -326,106 +306,6 @@ public class SocketCreator extends TcpSocketCreatorImpl {
     }
   }
 
-  private TrustManager[] getTrustManagers()
-      throws KeyStoreException, NoSuchAlgorithmException, CertificateException, IOException {
-    TrustManager[] trustManagers;
-
-    String trustStoreType = sslConfig.getTruststoreType();
-    if (StringUtils.isEmpty(trustStoreType)) {
-      trustStoreType = KeyStore.getDefaultType();
-    }
-
-    KeyStore ts = KeyStore.getInstance(trustStoreType);
-    String trustStorePath = sslConfig.getTruststore();
-    char[] password = null;
-    try (FileInputStream fis = new FileInputStream(trustStorePath)) {
-      String passwordString = sslConfig.getTruststorePassword();
-      if (passwordString != null) {
-        if (passwordString.trim().equals("")) {
-          if (!StringUtils.isEmpty(passwordString)) {
-            String toDecrypt = "encrypted(" + passwordString + ")";
-            passwordString = PasswordUtil.decrypt(toDecrypt);
-            password = passwordString.toCharArray();
-          }
-        } else {
-          password = passwordString.toCharArray();
-        }
-      }
-      ts.load(fis, password);
-    }
-
-    // default algorithm can be changed by setting property "ssl.TrustManagerFactory.algorithm" in
-    // security properties
-    TrustManagerFactory tmf =
-        TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
-    tmf.init(ts);
-    trustManagers = tmf.getTrustManagers();
-    // follow the security tip in java doc
-    if (password != null) {
-      java.util.Arrays.fill(password, ' ');
-    }
-
-    return trustManagers;
-  }
-
-  private KeyManager[] getKeyManagers() throws KeyStoreException, IOException,
-      NoSuchAlgorithmException, CertificateException, UnrecoverableKeyException {
-    if (sslConfig.getKeystore() == null) {
-      return null;
-    }
-
-    KeyManager[] keyManagers;
-    String keyStoreType = sslConfig.getKeystoreType();
-    if (StringUtils.isEmpty(keyStoreType)) {
-      keyStoreType = KeyStore.getDefaultType();
-    }
-    KeyStore keyStore = KeyStore.getInstance(keyStoreType);
-    String keyStoreFilePath = sslConfig.getKeystore();
-    if (StringUtils.isEmpty(keyStoreFilePath)) {
-      keyStoreFilePath =
-          System.getProperty("user.home") + System.getProperty("file.separator") + ".keystore";
-    }
-
-
-    char[] password = null;
-    try (FileInputStream fileInputStream = new FileInputStream(keyStoreFilePath)) {
-      String passwordString = sslConfig.getKeystorePassword();
-      if (passwordString != null) {
-        if (passwordString.trim().equals("")) {
-          String encryptedPass = System.getenv("javax.net.ssl.keyStorePassword");
-          if (!StringUtils.isEmpty(encryptedPass)) {
-            String toDecrypt = "encrypted(" + encryptedPass + ")";
-            passwordString = PasswordUtil.decrypt(toDecrypt);
-            password = passwordString.toCharArray();
-          }
-        } else {
-          password = passwordString.toCharArray();
-        }
-      }
-      keyStore.load(fileInputStream, password);
-    }
-    // default algorithm can be changed by setting property "ssl.KeyManagerFactory.algorithm" in
-    // security properties
-    KeyManagerFactory keyManagerFactory =
-        KeyManagerFactory.getInstance(KeyManagerFactory.getDefaultAlgorithm());
-    keyManagerFactory.init(keyStore, password);
-    keyManagers = keyManagerFactory.getKeyManagers();
-    // follow the security tip in java doc
-    if (password != null) {
-      java.util.Arrays.fill(password, ' ');
-    }
-
-    KeyManager[] extendedKeyManagers = new KeyManager[keyManagers.length];
-
-    for (int i = 0; i < keyManagers.length; i++)
-
-    {
-      extendedKeyManagers[i] = new ExtendedAliasKeyManager(keyManagers[i], sslConfig.getAlias());
-    }
-
-    return extendedKeyManagers;
-  }
-
   /**
    * context for SSL socket factories
    */
@@ -445,112 +325,14 @@ public class SocketCreator extends TcpSocketCreatorImpl {
     return sslConfig;
   }
 
-  /**
-   * ExtendedAliasKeyManager supports use of certificate aliases in distributed system
-   * properties.
-   */
-  private static class ExtendedAliasKeyManager extends X509ExtendedKeyManager {
-
-    private final X509ExtendedKeyManager delegate;
-
-    private final String keyAlias;
-
-    /**
-     * Constructor.
-     *
-     * @param mgr The X509KeyManager used as a delegate
-     * @param keyAlias The alias name of the server's keypair and supporting certificate chain
-     */
-    ExtendedAliasKeyManager(KeyManager mgr, String keyAlias) {
-      this.delegate = (X509ExtendedKeyManager) mgr;
-      this.keyAlias = keyAlias;
-    }
-
-
-    @Override
-    public String[] getClientAliases(final String s, final Principal[] principals) {
-      return delegate.getClientAliases(s, principals);
-    }
-
-    @Override
-    public String chooseClientAlias(final String[] strings, final Principal[] principals,
-        final Socket socket) {
-      if (!StringUtils.isEmpty(this.keyAlias)) {
-        return keyAlias;
-      }
-      return delegate.chooseClientAlias(strings, principals, socket);
-    }
-
-    @Override
-    public String[] getServerAliases(final String s, final Principal[] principals) {
-      return delegate.getServerAliases(s, principals);
-    }
-
-    @Override
-    public String chooseServerAlias(String keyType, Principal[] issuers, Socket socket) {
-      if (!StringUtils.isEmpty(this.keyAlias)) {
-        PrivateKey key = this.delegate.getPrivateKey(this.keyAlias);
-        return getKeyAlias(keyType, key);
-      }
-      return this.delegate.chooseServerAlias(keyType, issuers, socket);
-
-    }
-
-    @Override
-    public X509Certificate[] getCertificateChain(final String s) {
-      if (!StringUtils.isEmpty(this.keyAlias)) {
-        return delegate.getCertificateChain(keyAlias);
-      }
-      return delegate.getCertificateChain(s);
-    }
-
-    @Override
-    public PrivateKey getPrivateKey(final String alias) {
-      return delegate.getPrivateKey(alias);
-    }
-
-    @Override
-    public String chooseEngineClientAlias(String[] keyTypes, Principal[] principals,
-        SSLEngine sslEngine) {
-      return delegate.chooseEngineClientAlias(keyTypes, principals, sslEngine);
-    }
-
-    @Override
-    public String chooseEngineServerAlias(final String keyType, final Principal[] principals,
-        final SSLEngine sslEngine) {
-      if (!StringUtils.isEmpty(this.keyAlias)) {
-        PrivateKey key = this.delegate.getPrivateKey(this.keyAlias);
-        return getKeyAlias(keyType, key);
-      }
-      return this.delegate.chooseEngineServerAlias(keyType, principals, sslEngine);
-
-    }
-
-    private String getKeyAlias(final String keyType, final PrivateKey key) {
-      if (key != null) {
-        if (key.getAlgorithm().equals(keyType)) {
-          return this.keyAlias;
-        } else {
-          return null;
-        }
-      } else {
-        return null;
-      }
-    }
-  }
-
   /**
    * Returns true if this SocketCreator is configured to use SSL.
    */
   @Override
   protected boolean useSSL() {
-    return this.sslConfig.isEnabled();
+    return sslConfig.isEnabled();
   }
 
-  // -------------------------------------------------------------------------
-  // Public methods
-  // -------------------------------------------------------------------------
-
   /**
    * Returns an SSLEngine that can be used to perform TLS handshakes and communication
    */
@@ -561,52 +343,42 @@ public class SocketCreator extends TcpSocketCreatorImpl {
   }
 
   @VisibleForTesting
-  void configureSSLEngine(SSLEngine engine, String hostName, int port, boolean clientSocket) {
-    SSLParameters parameters = engine.getSSLParameters();
-    boolean updateEngineWithParameters = false;
+  void configureSSLEngine(final SSLEngine engine, final String hostName, final int port,
+      final boolean clientSocket) {
+    engine.setUseClientMode(clientSocket);
+    final SSLParameters parameters = engine.getSSLParameters();
+    configureSSLParameters(parameters, hostName, port, clientSocket);
+    engine.setSSLParameters(parameters);
+  }
+
+  @VisibleForTesting
+  void configureSSLParameters(final SSLParameters parameters, final String hostName,
+      final int port, final boolean clientSocket) {
     if (sslConfig.doEndpointIdentification()) {
       // set server-names so that endpoint identification algorithms can find what's expected
-      if (setServerNames(parameters, new HostAndPort(hostName, port))) {
-        updateEngineWithParameters = true;
-      }
-    }
-
-    engine.setUseClientMode(clientSocket);
-    if (!clientSocket) {
-      engine.setNeedClientAuth(sslConfig.isRequireAuth());
+      addServerNameIfNotSet(parameters, new HostAndPort(hostName, port));
     }
 
     if (clientSocket) {
-      if (checkAndEnableHostnameValidation(parameters)) {
-        updateEngineWithParameters = true;
-      }
+      checkAndEnableHostnameValidation(parameters);
+    } else {
+      parameters.setNeedClientAuth(sslConfig.isRequireAuth());
     }
 
-    String[] protocols = this.sslConfig.getProtocolsAsStringArray();
+    configureProtocols(clientSocket, parameters);
 
-    if (protocols != null && !"any".equalsIgnoreCase(protocols[0])) {
-      engine.setEnabledProtocols(protocols);
-    }
-
-    String[] ciphers = this.sslConfig.getCiphersAsStringArray();
-    if (ciphers != null && !"any".equalsIgnoreCase(ciphers[0])) {
-      engine.setEnabledCipherSuites(ciphers);
-    }
-
-    if (updateEngineWithParameters) {
-      engine.setSSLParameters(parameters);
-    }
+    configureCipherSuites(parameters);
   }
 
   /**
-   * @see <a
-   *      href=https://docs.oracle.com/javase/8/docs/technotes/guides/security/jsse/JSSERefGuide.html#SSLENG">JSSE
+   * @see <a href=
+   *      "https://docs.oracle.com/javase/8/docs/technotes/guides/security/jsse/JSSERefGuide.html#SSLENG">JSSE
    *      Reference Guide</a>
    *
    * @param socketChannel the socket's NIO channel
    * @param engine the sslEngine (see createSSLEngine)
    * @param timeout handshake timeout in milliseconds. No timeout if <= 0
-   * @param peerNetBuffer the buffer to use in reading data fron socketChannel. This should also be
+   * @param peerNetBuffer the buffer to use in reading data from socketChannel. This should also be
    *        used in subsequent I/O operations
    * @return The SSLEngine to be used in processing data for sending/receiving from the channel
    */
@@ -654,13 +426,10 @@ public class SocketCreator extends TcpSocketCreatorImpl {
     return nioSslEngine;
   }
 
-  /**
-   * @return true if the parameters have been modified by this method
-   */
-  private boolean checkAndEnableHostnameValidation(SSLParameters sslParameters) {
+  void checkAndEnableHostnameValidation(final SSLParameters sslParameters) {
     if (sslConfig.doEndpointIdentification()) {
       sslParameters.setEndpointIdentificationAlgorithm("HTTPS");
-      return true;
+      return;
     }
     if (!hostnameValidationDisabledLogShown) {
       logger.info("Your SSL configuration disables hostname validation. "
@@ -668,7 +437,6 @@ public class SocketCreator extends TcpSocketCreatorImpl {
           + "Please refer to the Apache GEODE SSL Documentation for SSL Property: ssl‑endpoint‑identification‑enabled");
       hostnameValidationDisabledLogShown = true;
     }
-    return false;
   }
 
   /**
@@ -687,7 +455,7 @@ public class SocketCreator extends TcpSocketCreatorImpl {
     try {
       sslSocket.startHandshake();
     } catch (SSLPeerUnverifiedException ex) {
-      if (this.sslConfig.isRequireAuth()) {
+      if (sslConfig.isRequireAuth()) {
         logger.fatal(String.format("SSL Error in authenticating peer %s[%s].",
             socket.getInetAddress(), socket.getPort()), ex);
         throw ex;
@@ -716,11 +484,11 @@ public class SocketCreator extends TcpSocketCreatorImpl {
    * client/server/advanced interfaces because it references WAN classes that aren't
    * available to them.
    */
-  public ServerSocket createServerSocket(int nport, int backlog, InetAddress bindAddr,
+  public ServerSocket createServerSocket(int port, int backlog, InetAddress bindAddress,
       List<GatewayTransportFilter> transportFilters, int socketBufferSize) throws IOException {
     if (transportFilters.isEmpty()) {
       return ((SCClusterSocketCreator) forCluster())
-          .createServerSocket(nport, backlog, bindAddr, socketBufferSize, useSSL());
+          .createServerSocket(port, backlog, bindAddress, socketBufferSize, useSSL());
     } else {
       printConfig();
       ServerSocket result = new TransportFilterServerSocket(transportFilters);
@@ -730,10 +498,10 @@ public class SocketCreator extends TcpSocketCreatorImpl {
       // java.net.ServerSocket.setReceiverBufferSize javadocs)
       result.setReceiveBufferSize(socketBufferSize);
       try {
-        result.bind(new InetSocketAddress(bindAddr, nport), backlog);
+        result.bind(new InetSocketAddress(bindAddress, port), backlog);
       } catch (BindException e) {
         BindException throwMe = new BindException(
-            String.format("Failed to create server socket on %s[%s]", bindAddr, nport));
+            String.format("Failed to create server socket on %s[%s]", bindAddress, port));
         throwMe.initCause(e);
         throw throwMe;
       }
@@ -741,52 +509,24 @@ public class SocketCreator extends TcpSocketCreatorImpl {
     }
   }
 
-
-  // -------------------------------------------------------------------------
-  // Private implementation methods
-  // -------------------------------------------------------------------------
-
-
   /**
    * When a socket is connected to a server socket, it should be passed to this method for SSL
    * configuration.
    */
-  void configureClientSSLSocket(Socket socket, HostAndPort addr, int timeout) throws IOException {
+  void configureClientSSLSocket(final Socket socket, final HostAndPort address, int timeout)
+      throws IOException {
     if (socket instanceof SSLSocket) {
-      SSLSocket sslSocket = (SSLSocket) socket;
+      final SSLSocket sslSocket = (SSLSocket) socket;
 
       sslSocket.setUseClientMode(true);
       sslSocket.setEnableSessionCreation(true);
 
-      SSLParameters parameters = sslSocket.getSSLParameters();
-      boolean updateSSLParameters =
-          checkAndEnableHostnameValidation(parameters);
-
-      if (setServerNames(parameters, addr)) {
-        updateSSLParameters = true;
-      } ;
-
-      SSLParameterExtension sslParameterExtension = this.sslConfig.getSSLParameterExtension();
-      if (sslParameterExtension != null) {
-        parameters =
-            sslParameterExtension.modifySSLClientSocketParameters(parameters);
-        updateSSLParameters = true;
-      }
-
-      if (updateSSLParameters) {
-        sslSocket.setSSLParameters(parameters);
-      }
-
-      String[] protocols = this.sslConfig.getProtocolsAsStringArray();
-
-      // restrict cyphers
-      if (protocols != null && !"any".equalsIgnoreCase(protocols[0])) {
-        sslSocket.setEnabledProtocols(protocols);
-      }
-      String[] ciphers = this.sslConfig.getCiphersAsStringArray();
-      if (ciphers != null && !"any".equalsIgnoreCase(ciphers[0])) {
-        sslSocket.setEnabledCipherSuites(ciphers);
-      }
+      final SSLParameters parameters = sslSocket.getSSLParameters();
+      checkAndEnableHostnameValidation(parameters);
+      addServerNameIfNotSet(parameters, address);
+      configureProtocols(true, parameters);
+      configureCipherSuites(parameters);
+      sslSocket.setSSLParameters(applySSLParameterExtensions(parameters));
 
       try {
         if (timeout > 0) {
@@ -804,11 +544,14 @@ public class SocketCreator extends TcpSocketCreatorImpl {
           throw ex;
         }
       } catch (SSLHandshakeException ex) {
-        logger.fatal(String.format("Problem forming SSL connection to %s[%s].",
-            socket.getInetAddress(), socket.getPort()), ex);
+        String message = ex.getMessage();
+        if (message != null && !message.contains("Remote host terminated the handshake")) {
+          logger.fatal(String.format("Problem forming SSL connection to %s[%s].",
+              socket.getInetAddress(), socket.getPort()), ex);
+        }
         throw ex;
       } catch (SSLPeerUnverifiedException ex) {
-        if (this.sslConfig.isRequireAuth()) {
+        if (sslConfig.isRequireAuth()) {
           logger.fatal("SSL authentication exception.", ex);
           throw ex;
         }
@@ -816,36 +559,43 @@ public class SocketCreator extends TcpSocketCreatorImpl {
     }
   }
 
-  /**
-   * returns true if the SSLParameters are altered, false if not
-   */
-  private boolean setServerNames(SSLParameters modifiedParams, HostAndPort addr) {
-    List<SNIServerName> oldNames = modifiedParams.getServerNames();
-    oldNames = oldNames == null ? Collections.emptyList() : oldNames;
-    final List<SNIServerName> serverNames = new ArrayList<>(oldNames);
+  SSLParameters applySSLParameterExtensions(final SSLParameters parameters) {
+    final SSLParameterExtension sslParameterExtension = sslConfig.getSSLParameterExtension();
+    if (sslParameterExtension != null) {
+      return sslParameterExtension.modifySSLClientSocketParameters(parameters);
+    }
+    return parameters;
+  }
+
+  void configureProtocols(final boolean clientSocket, final SSLParameters parameters) {
+    final String[] protocols = clientSocket ? sslConfig.getClientProtocolsAsStringArray()
+        : sslConfig.getServerProtocolsAsStringArray();
+    if (!SSLConfig.isAnyProtocols(protocols)) {
+      parameters.setProtocols(protocols);
+    }
+  }
+
+  void configureCipherSuites(final SSLParameters parameters) {
+    final String[] ciphers = sslConfig.getCiphersAsStringArray();
+    if (!SSLConfig.isAnyCiphers(ciphers)) {
+      parameters.setCipherSuites(ciphers);
+    }
+  }
+
+  static void addServerNameIfNotSet(final SSLParameters parameters,
+      final HostAndPort address) {
+    final List<SNIServerName> serverNames =
+        new ArrayList<>(getIfNull(parameters.getServerNames(), Collections::emptyList));
 
     if (serverNames.stream()
         .mapToInt(SNIServerName::getType)
         .anyMatch(type -> type == StandardConstants.SNI_HOST_NAME)) {
       // we already have a SNI hostname set. Do nothing.
-      return false;
+      return;
     }
 
-    String hostName = addr.getHostName();
-    if (this.sslConfig.doEndpointIdentification()
-        && InetAddressValidator.getInstance().isValid(hostName)) {
-      // endpoint validation typically uses a hostname in the sniServer parameter that the handshake
-      // will compare against the subject alternative addresses in the server's certificate. Here
-      // we attempt to get a hostname instead of the proffered numeric address
-      try {
-        hostName = InetAddress.getByName(hostName).getCanonicalHostName();
-      } catch (UnknownHostException e) {
-        // ignore - we'll see what happens with endpoint validation using a numeric address...
-      }
-    }
-    serverNames.add(new SNIHostName(hostName));
-    modifiedParams.setServerNames(serverNames);
-    return true;
+    serverNames.add(new SNIHostName(address.getHostName()));
+    parameters.setServerNames(serverNames);
   }
 
   /**
@@ -856,7 +606,7 @@ public class SocketCreator extends TcpSocketCreatorImpl {
       configShown = true;
       StringBuilder sb = new StringBuilder();
       sb.append("SSL Configuration: \n");
-      sb.append("  ssl-enabled = ").append(this.sslConfig.isEnabled()).append("\n");
+      sb.append("  ssl-enabled = ").append(sslConfig.isEnabled()).append("\n");
       // add other options here....
       for (String key : System.getProperties().stringPropertyNames()) { // fix for 46822
         if (key.startsWith("javax.net.ssl")) {
@@ -870,13 +620,13 @@ public class SocketCreator extends TcpSocketCreatorImpl {
   }
 
   protected void initializeClientSocketFactory() {
-    this.clientSocketFactory = null;
+    clientSocketFactory = null;
     String className =
         System.getProperty(GeodeGlossary.GEMFIRE_PREFIX + "clientSocketFactory");
     if (className != null) {
       Object o;
       try {
-        Class c = ClassPathLoader.getLatest().forName(className);
+        Class<?> c = ClassPathLoader.getLatest().forName(className);
         o = c.newInstance();
       } catch (Exception e) {
         // No cache exists yet, so this can't be logged.
@@ -884,7 +634,7 @@ public class SocketCreator extends TcpSocketCreatorImpl {
         throw new IllegalArgumentException(s);
       }
       if (o instanceof ClientSocketFactory) {
-        this.clientSocketFactory = (ClientSocketFactory) o;
+        clientSocketFactory = (ClientSocketFactory) o;
       } else {
         String s = "Class \"" + className + "\" is not a ClientSocketFactory";
         throw new IllegalArgumentException(s);
@@ -893,7 +643,7 @@ public class SocketCreator extends TcpSocketCreatorImpl {
   }
 
   public void initializeTransportFilterClientSocketFactory(GatewaySender sender) {
-    this.clientSocketFactory = new TransportFilterSocketFactory()
+    clientSocketFactory = new TransportFilterSocketFactory()
         .setGatewayTransportFilters(sender.getGatewayTransportFilters());
   }
 }
