@@ -18,7 +18,6 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.Comparator;
 import java.util.List;
 import java.util.NavigableSet;
 import java.util.concurrent.ConcurrentSkipListSet;
@@ -47,11 +46,11 @@ public class FreeListManager {
   private final long totalSlabSize;
 
   private final AtomicReferenceArray<OffHeapStoredObjectAddressStack> tinyFreeLists =
-      new AtomicReferenceArray<OffHeapStoredObjectAddressStack>(TINY_FREE_LIST_COUNT);
+      new AtomicReferenceArray<>(TINY_FREE_LIST_COUNT);
   // hugeChunkSet is sorted by chunk size in ascending order. It will only contain chunks larger
   // than MAX_TINY.
   private final ConcurrentSkipListSet<OffHeapStoredObject> hugeChunkSet =
-      new ConcurrentSkipListSet<OffHeapStoredObject>();
+      new ConcurrentSkipListSet<>();
   private final AtomicLong allocatedSize = new AtomicLong(0L);
 
   private int getNearestTinyMultiple(int size) {
@@ -59,9 +58,9 @@ public class FreeListManager {
   }
 
   List<OffHeapStoredObject> getLiveChunks() {
-    ArrayList<OffHeapStoredObject> result = new ArrayList<OffHeapStoredObject>();
-    for (int i = 0; i < slabs.length; i++) {
-      getLiveChunks(slabs[i], result);
+    ArrayList<OffHeapStoredObject> result = new ArrayList<>();
+    for (final Slab slab : slabs) {
+      getLiveChunks(slab, result);
     }
     return result;
   }
@@ -75,7 +74,7 @@ public class FreeListManager {
         addr = f.getAddress() + f.getSize();
       } else {
         int curChunkSize = OffHeapStoredObject.getSize(addr);
-        int refCount = OffHeapStoredObject.getRefCount(addr);
+        int refCount = ReferenceCounter.getRefCount(addr);
         if (refCount > 0) {
           result.add(new OffHeapStoredObject(addr));
         }
@@ -88,7 +87,7 @@ public class FreeListManager {
    * If addr is in the free space of a fragment then return that fragment; otherwise return null.
    */
   private Fragment isAddrInFragmentFreeSpace(long addr) {
-    for (Fragment f : this.fragmentList) {
+    for (Fragment f : fragmentList) {
       if (addr >= (f.getAddress() + f.getFreeIndex()) && addr < (f.getAddress() + f.getSize())) {
         return f;
       }
@@ -97,7 +96,7 @@ public class FreeListManager {
   }
 
   public long getUsedMemory() {
-    return this.allocatedSize.get();
+    return allocatedSize.get();
   }
 
   public long getFreeMemory() {
@@ -106,7 +105,7 @@ public class FreeListManager {
 
   long getFreeFragmentMemory() {
     long result = 0;
-    for (Fragment f : this.fragmentList) {
+    for (Fragment f : fragmentList) {
       int freeSpace = f.freeSpace();
       if (freeSpace >= OffHeapStoredObject.MIN_CHUNK_SIZE) {
         result += freeSpace;
@@ -117,8 +116,8 @@ public class FreeListManager {
 
   long getFreeTinyMemory() {
     long tinyFree = 0;
-    for (int i = 0; i < this.tinyFreeLists.length(); i++) {
-      OffHeapStoredObjectAddressStack cl = this.tinyFreeLists.get(i);
+    for (int i = 0; i < tinyFreeLists.length(); i++) {
+      OffHeapStoredObjectAddressStack cl = tinyFreeLists.get(i);
       if (cl != null) {
         tinyFree += cl.computeTotalSize();
       }
@@ -128,7 +127,7 @@ public class FreeListManager {
 
   long getFreeHugeMemory() {
     long hugeFree = 0;
-    for (OffHeapStoredObject c : this.hugeChunkSet) {
+    for (OffHeapStoredObject c : hugeChunkSet) {
       hugeFree += c.getSize();
     }
     return hugeFree;
@@ -150,8 +149,8 @@ public class FreeListManager {
       tmp[i] = createFragment(slabs[i].getMemoryAddress(), slabs[i].getSize());
       total += slabs[i].getSize();
     }
-    this.fragmentList = new CopyOnWriteArrayList<Fragment>(tmp);
-    this.totalSlabSize = total;
+    fragmentList = new CopyOnWriteArrayList<>(tmp);
+    totalSlabSize = total;
 
     fillFragments();
   }
@@ -168,10 +167,10 @@ public class FreeListManager {
    * enabled.
    */
   private void fillFragments() {
-    if (!this.validateMemoryWithFill) {
+    if (!validateMemoryWithFill) {
       return;
     }
-    for (Fragment fragment : this.fragmentList) {
+    for (Fragment fragment : fragmentList) {
       fragment.fill();
     }
   }
@@ -197,7 +196,7 @@ public class FreeListManager {
     OffHeapStoredObject result = basicAllocate(size, true);
 
     result.setDataSize(size);
-    this.allocatedSize.addAndGet(result.getSize());
+    allocatedSize.addAndGet(result.getSize());
     result.initializeUseCount();
 
     return result;
@@ -220,8 +219,8 @@ public class FreeListManager {
 
   private OffHeapStoredObject allocateFromFragments(int chunkSize) {
     do {
-      final int lastAllocationId = this.lastFragmentAllocation.get();
-      for (int i = lastAllocationId; i < this.fragmentList.size(); i++) {
+      final int lastAllocationId = lastFragmentAllocation.get();
+      for (int i = lastAllocationId; i < fragmentList.size(); i++) {
         OffHeapStoredObject result = allocateFromFragment(i, chunkSize);
         if (result != null) {
           return result;
@@ -241,7 +240,7 @@ public class FreeListManager {
     try {
       throw failure;
     } finally {
-      this.ma.getOutOfOffHeapMemoryListener().outOfOffHeapMemory(failure);
+      ma.getOutOfOffHeapMemoryListener().outOfOffHeapMemory(failure);
     }
   }
 
@@ -250,11 +249,13 @@ public class FreeListManager {
   }
 
   void logOffHeapState(Logger lw, int chunkSize) {
-    OffHeapMemoryStats stats = this.ma.getStats();
+    OffHeapMemoryStats stats = ma.getStats();
     lw.info("OutOfOffHeapMemory allocating size of " + chunkSize + ". allocated="
-        + this.allocatedSize.get() + " defragmentations=" + this.defragmentationCount.get()
-        + " objects=" + stats.getObjects() + " free=" + stats.getFreeMemory() + " fragments="
-        + stats.getFragments() + " largestFragment=" + stats.getLargestFragment()
+        + allocatedSize.get() + " defragmentations=" + defragmentationCount.get()
+        + " objects=" + stats.getObjects() + " free=" + stats.getFreeMemory()
+        + " freedChunks=" + stats.getFreedChunks()
+        + " fragments=" + stats.getFragments()
+        + " largestFragment=" + stats.getLargestFragment()
         + " fragmentation=" + stats.getFragmentation());
     logFragmentState(lw);
     logTinyState(lw);
@@ -262,14 +263,14 @@ public class FreeListManager {
   }
 
   private void logHugeState(Logger lw) {
-    for (OffHeapStoredObject c : this.hugeChunkSet) {
+    for (OffHeapStoredObject c : hugeChunkSet) {
       lw.info("Free huge of size " + c.getSize());
     }
   }
 
   private void logTinyState(Logger lw) {
-    for (int i = 0; i < this.tinyFreeLists.length(); i++) {
-      OffHeapStoredObjectAddressStack cl = this.tinyFreeLists.get(i);
+    for (int i = 0; i < tinyFreeLists.length(); i++) {
+      OffHeapStoredObjectAddressStack cl = tinyFreeLists.get(i);
       if (cl != null) {
         cl.logSizes(lw, "Free tiny of size ");
       }
@@ -277,7 +278,7 @@ public class FreeListManager {
   }
 
   private void logFragmentState(Logger lw) {
-    for (Fragment f : this.fragmentList) {
+    for (Fragment f : fragmentList) {
       int freeSpace = f.freeSpace();
       if (freeSpace > 0) {
         lw.info("Fragment at " + f.getAddress() + " of size " + f.getSize() + " has " + freeSpace
@@ -336,7 +337,7 @@ public class FreeListManager {
       int combinedSize = lowSize + highSize;
       if (isSmallEnough(combinedSize)) {
         // append the highAddr chunk to lowAddr
-        OffHeapStoredObject.setSize(lowAddr, (int) combinedSize);
+        OffHeapStoredObject.setSize(lowAddr, combinedSize);
         return true;
       }
     }
@@ -363,12 +364,12 @@ public class FreeListManager {
    * returns false;
    */
   boolean defragment(int chunkSize) {
-    final long startDefragmentationTime = this.ma.getStats().startDefragmentation();
-    final int countPreSync = this.defragmentationCount.get();
+    final long startDefragmentationTime = ma.getStats().startDefragmentation();
+    final int countPreSync = defragmentationCount.get();
     afterDefragmentationCountFetched();
     try {
       synchronized (this) {
-        if (this.defragmentationCount.get() != countPreSync) {
+        if (defragmentationCount.get() != countPreSync) {
           // someone else did a defragmentation while we waited on the sync.
           // So just return true causing the caller to retry the allocation.
           return true;
@@ -376,12 +377,12 @@ public class FreeListManager {
         boolean result = doDefragment(chunkSize);
 
         // Signal any waiters that a defragmentation happened.
-        this.defragmentationCount.incrementAndGet();
+        defragmentationCount.incrementAndGet();
 
         return result;
       } // sync
     } finally {
-      this.ma.getStats().endDefragmentation(startDefragmentationTime);
+      ma.getStats().endDefragmentation(startDefragmentationTime);
     }
   }
 
@@ -453,7 +454,7 @@ public class FreeListManager {
    */
   boolean doDefragment(int chunkSize) {
     boolean result = false;
-    ArrayList<LongStack> freeChunks = new ArrayList<LongStack>();
+    ArrayList<LongStack> freeChunks = new ArrayList<>();
     collectFreeChunks(freeChunks);
     ResizableLongArray sorted = new ResizableLongArray();
     for (LongStack l : freeChunks) {
@@ -492,8 +493,8 @@ public class FreeListManager {
     }
 
     int largestFragment = 0;
-    this.lastFragmentAllocation.set(0);
-    ArrayList<Fragment> tmp = new ArrayList<Fragment>();
+    lastFragmentAllocation.set(0);
+    ArrayList<Fragment> tmp = new ArrayList<>();
     for (int i = sorted.size() - 1; i >= 0; i--) {
       long addr = sorted.get(i);
       if (addr == 0L) {
@@ -512,17 +513,58 @@ public class FreeListManager {
         tmp.add(f);
       }
     }
-    this.fragmentList.addAll(tmp);
+    fragmentList.addAll(tmp);
 
     fillFragments();
 
-    this.ma.getStats().setLargestFragment(largestFragment);
-    this.ma.getStats().setFragments(tmp.size());
-    this.ma.getStats().setFragmentation(getFragmentation());
+    ma.getStats().setLargestFragment(largestFragment);
+    ma.getStats().setFragments(tmp.size());
+    ma.getStats().setFragmentation(getFragmentation());
+    ma.getStats().setFreedChunks(0);
 
     return result;
   }
 
+  public void updateNonRealTimeStats() {
+    ma.getStats().setLargestFragment(largestFragmentSize());
+    ma.getStats().setFreedChunks(getFreedChunks());
+  }
+
+  public int getFreedChunks() {
+    int elementCountFromTinyFreeLists =
+        getElementCountFromTinyFreeLists();
+    int elementCountFromHugeFreeLists =
+        getElementCountFromHugeFreeLists();
+
+    return elementCountFromTinyFreeLists + elementCountFromHugeFreeLists;
+  }
+
+  private int getElementCountFromTinyFreeLists() {
+    int fragmentCount = 0;
+    for (int i = 0; i < tinyFreeLists.length(); i++) {
+      OffHeapStoredObjectAddressStack cl = tinyFreeLists.get(i);
+      if (cl != null) {
+        fragmentCount += cl.size();
+      }
+    }
+    return fragmentCount;
+  }
+
+  private int getElementCountFromHugeFreeLists() {
+    return hugeChunkSet.size();
+  }
+
+  private int largestFragmentSize() {
+    int largestFreeSpaceFromFragments = 0;
+    for (Fragment f : fragmentList) {
+      int fragmentFreeSpace = f.freeSpace();
+      if (fragmentFreeSpace > largestFreeSpaceFromFragments) {
+        largestFreeSpaceFromFragments = fragmentFreeSpace;
+      }
+    }
+    return largestFreeSpaceFromFragments;
+  }
+
   /**
    * Unit tests override this method to get better test coverage
    */
@@ -556,7 +598,7 @@ public class FreeListManager {
   }
 
   protected int getFragmentCount() {
-    return this.fragmentList.size();
+    return fragmentList.size();
   }
 
   protected int getFragmentation() {
@@ -589,15 +631,15 @@ public class FreeListManager {
   }
 
   List<Fragment> getFragmentList() {
-    return this.fragmentList;
+    return fragmentList;
   }
 
   private void collectFreeFragmentChunks(List<LongStack> l) {
-    if (this.fragmentList.size() == 0) {
+    if (fragmentList.size() == 0) {
       return;
     }
     OffHeapStoredObjectAddressStack result = new OffHeapStoredObjectAddressStack();
-    for (Fragment f : this.fragmentList) {
+    for (Fragment f : fragmentList) {
       int offset;
       int diff;
       do {
@@ -618,15 +660,15 @@ public class FreeListManager {
     }
     // All the fragments have been turned in to chunks so now clear them
     // The defragmentation will create new fragments.
-    this.fragmentList.clear();
+    fragmentList.clear();
     if (!result.isEmpty()) {
       l.add(result);
     }
   }
 
   private void collectFreeTinyChunks(List<LongStack> l) {
-    for (int i = 0; i < this.tinyFreeLists.length(); i++) {
-      OffHeapStoredObjectAddressStack cl = this.tinyFreeLists.get(i);
+    for (int i = 0; i < tinyFreeLists.length(); i++) {
+      OffHeapStoredObjectAddressStack cl = tinyFreeLists.get(i);
       if (cl != null) {
         long head = cl.clear();
         if (head != 0L) {
@@ -637,7 +679,7 @@ public class FreeListManager {
   }
 
   private void collectFreeHugeChunks(List<LongStack> l) {
-    OffHeapStoredObject c = this.hugeChunkSet.pollFirst();
+    OffHeapStoredObject c = hugeChunkSet.pollFirst();
     OffHeapStoredObjectAddressStack result = null;
     while (c != null) {
       if (result == null) {
@@ -645,17 +687,17 @@ public class FreeListManager {
         l.add(result);
       }
       result.offer(c.getAddress());
-      c = this.hugeChunkSet.pollFirst();
+      c = hugeChunkSet.pollFirst();
     }
   }
 
   OffHeapStoredObject allocateFromFragment(final int fragIdx, final int chunkSize) {
-    if (fragIdx >= this.fragmentList.size()) {
+    if (fragIdx >= fragmentList.size()) {
       return null;
     }
     final Fragment fragment;
     try {
-      fragment = this.fragmentList.get(fragIdx);
+      fragment = fragmentList.get(fragIdx);
     } catch (IndexOutOfBoundsException ignore) {
       // A concurrent defragmentation can cause this.
       return null;
@@ -680,7 +722,7 @@ public class FreeListManager {
         }
         if (fragment.allocate(oldOffset, newOffset)) {
           // We did the allocate!
-          this.lastFragmentAllocation.set(fragIdx);
+          lastFragmentAllocation.set(fragIdx);
           OffHeapStoredObject result =
               new OffHeapStoredObject(fragment.getAddress() + oldOffset, chunkSize + extraSize);
           checkDataIntegrity(result);
@@ -702,7 +744,7 @@ public class FreeListManager {
   }
 
   private OffHeapStoredObject allocateTiny(int size, boolean useFragments) {
-    return basicAllocate(getNearestTinyMultiple(size), TINY_MULTIPLE, 0, this.tinyFreeLists,
+    return basicAllocate(getNearestTinyMultiple(size), TINY_MULTIPLE, 0, tinyFreeLists,
         useFragments);
   }
 
@@ -728,7 +770,7 @@ public class FreeListManager {
   private OffHeapStoredObject allocateHuge(int size, boolean useFragments) {
     // sizeHolder is a fake Chunk used to search our sorted hugeChunkSet.
     OffHeapStoredObject sizeHolder = new SearchMarker(size);
-    NavigableSet<OffHeapStoredObject> ts = this.hugeChunkSet.tailSet(sizeHolder);
+    NavigableSet<OffHeapStoredObject> ts = hugeChunkSet.tailSet(sizeHolder);
     OffHeapStoredObject result = ts.pollFirst();
     if (result != null) {
       if (result.getSize() - (HUGE_MULTIPLE - OffHeapStoredObject.HEADER_SIZE) < size) {
@@ -737,7 +779,7 @@ public class FreeListManager {
         result.readyForAllocation();
         return result;
       } else {
-        this.hugeChunkSet.add(result);
+        hugeChunkSet.add(result);
       }
     }
     if (useFragments) {
@@ -750,7 +792,7 @@ public class FreeListManager {
   }
 
   private void checkDataIntegrity(OffHeapStoredObject data) {
-    if (this.validateMemoryWithFill) {
+    if (validateMemoryWithFill) {
       data.validateFill();
     }
   }
@@ -769,13 +811,13 @@ public class FreeListManager {
 
     @Override
     public int getSize() {
-      return this.size;
+      return size;
     }
   }
 
   @SuppressWarnings("synthetic-access")
   public void free(long addr) {
-    if (this.validateMemoryWithFill) {
+    if (validateMemoryWithFill) {
       OffHeapStoredObject.fill(addr);
     }
 
@@ -785,12 +827,12 @@ public class FreeListManager {
   private void free(long addr, boolean updateStats) {
     int cSize = OffHeapStoredObject.getSize(addr);
     if (updateStats) {
-      OffHeapMemoryStats stats = this.ma.getStats();
+      OffHeapMemoryStats stats = ma.getStats();
       stats.incObjects(-1);
-      this.allocatedSize.addAndGet(-cSize);
+      allocatedSize.addAndGet(-cSize);
       stats.incUsedMemory(-cSize);
       stats.incFreeMemory(cSize);
-      this.ma.notifyListeners();
+      ma.notifyListeners();
     }
     if (cSize <= MAX_TINY) {
       freeTiny(addr, cSize);
@@ -800,7 +842,7 @@ public class FreeListManager {
   }
 
   private void freeTiny(long addr, int cSize) {
-    basicFree(addr, getNearestTinyMultiple(cSize), this.tinyFreeLists);
+    basicFree(addr, getNearestTinyMultiple(cSize), tinyFreeLists);
   }
 
   private void basicFree(long addr, int idx,
@@ -827,50 +869,45 @@ public class FreeListManager {
   }
 
   private void freeHuge(long addr, int cSize) {
-    this.hugeChunkSet.add(new OffHeapStoredObject(addr)); // TODO make this a collection of longs
+    hugeChunkSet.add(new OffHeapStoredObject(addr)); // TODO make this a collection of longs
   }
 
   List<MemoryBlock> getOrderedBlocks() {
-    final List<MemoryBlock> value = new ArrayList<MemoryBlock>();
-    addBlocksFromFragments(this.fragmentList, value); // unused fragments
+    final List<MemoryBlock> value = new ArrayList<>();
+    addBlocksFromFragments(fragmentList, value); // unused fragments
     addBlocksFromChunks(getLiveChunks(), value); // used chunks
-    addBlocksFromChunks(this.hugeChunkSet, value); // huge free chunks
+    addBlocksFromChunks(hugeChunkSet, value); // huge free chunks
     addMemoryBlocks(getTinyFreeBlocks(), value); // tiny free chunks
-    Collections.sort(value, new Comparator<MemoryBlock>() {
-      @Override
-      public int compare(MemoryBlock o1, MemoryBlock o2) {
-        return Long.compare(o1.getAddress(), o2.getAddress());
-      }
-    });
+    Collections.sort(value, (o1, o2) -> Long.compare(o1.getAddress(), o2.getAddress()));
     return value;
   }
 
   private void addBlocksFromFragments(Collection<Fragment> src, List<MemoryBlock> dest) {
     for (MemoryBlock block : src) {
-      dest.add(new MemoryBlockNode(this.ma, block));
+      dest.add(new MemoryBlockNode(ma, block));
     }
   }
 
   private void addBlocksFromChunks(Collection<OffHeapStoredObject> src, List<MemoryBlock> dest) {
     for (OffHeapStoredObject chunk : src) {
-      dest.add(new MemoryBlockNode(this.ma, chunk));
+      dest.add(new MemoryBlockNode(ma, chunk));
     }
   }
 
   private void addMemoryBlocks(Collection<MemoryBlock> src, List<MemoryBlock> dest) {
     for (MemoryBlock block : src) {
-      dest.add(new MemoryBlockNode(this.ma, block));
+      dest.add(new MemoryBlockNode(ma, block));
     }
   }
 
   private List<MemoryBlock> getTinyFreeBlocks() {
-    final List<MemoryBlock> value = new ArrayList<MemoryBlock>();
-    final MemoryAllocatorImpl sma = this.ma;
-    for (int i = 0; i < this.tinyFreeLists.length(); i++) {
-      if (this.tinyFreeLists.get(i) == null) {
+    final List<MemoryBlock> value = new ArrayList<>();
+    final MemoryAllocatorImpl sma = ma;
+    for (int i = 0; i < tinyFreeLists.length(); i++) {
+      if (tinyFreeLists.get(i) == null) {
         continue;
       }
-      long addr = this.tinyFreeLists.get(i).getTopAddress();
+      long addr = tinyFreeLists.get(i).getTopAddress();
       while (addr != 0L) {
         value.add(new MemoryBlockNode(sma, new TinyMemoryBlock(addr, i)));
         addr = OffHeapStoredObject.getNext(addr);
@@ -880,14 +917,9 @@ public class FreeListManager {
   }
 
   List<MemoryBlock> getAllocatedBlocks() {
-    final List<MemoryBlock> value = new ArrayList<MemoryBlock>();
+    final List<MemoryBlock> value = new ArrayList<>();
     addBlocksFromChunks(getLiveChunks(), value); // used chunks
-    Collections.sort(value, new Comparator<MemoryBlock>() {
-      @Override
-      public int compare(MemoryBlock o1, MemoryBlock o2) {
-        return Long.compare(o1.getAddress(), o2.getAddress());
-      }
-    });
+    Collections.sort(value, (o1, o2) -> Long.compare(o1.getAddress(), o2.getAddress()));
     return value;
   }
 
@@ -968,18 +1000,18 @@ public class FreeListManager {
 
     @Override
     public int hashCode() {
-      long value = this.getAddress();
+      long value = getAddress();
       return (int) (value ^ (value >>> 32));
     }
   }
 
   long getTotalMemory() {
-    return this.totalSlabSize;
+    return totalSlabSize;
   }
 
   void freeSlabs() {
-    for (int i = 0; i < slabs.length; i++) {
-      slabs[i].free();
+    for (final Slab slab : slabs) {
+      slab.free();
     }
   }
 
@@ -990,16 +1022,16 @@ public class FreeListManager {
    * contents of the arrays.
    */
   boolean okToReuse(Slab[] newSlabs) {
-    return newSlabs == null || newSlabs == this.slabs;
+    return newSlabs == null || newSlabs == slabs;
   }
 
   int getLargestSlabSize() {
-    return this.slabs[0].getSize();
+    return slabs[0].getSize();
   }
 
   int findSlab(long addr) {
-    for (int i = 0; i < this.slabs.length; i++) {
-      Slab slab = this.slabs[i];
+    for (int i = 0; i < slabs.length; i++) {
+      Slab slab = slabs[i];
       long slabAddr = slab.getMemoryAddress();
       if (addr >= slabAddr) {
         if (addr < slabAddr + slab.getSize()) {
@@ -1011,22 +1043,22 @@ public class FreeListManager {
   }
 
   void getSlabDescriptions(StringBuilder sb) {
-    for (int i = 0; i < slabs.length; i++) {
-      long startAddr = slabs[i].getMemoryAddress();
-      long endAddr = startAddr + slabs[i].getSize();
+    for (final Slab slab : slabs) {
+      long startAddr = slab.getMemoryAddress();
+      long endAddr = startAddr + slab.getSize();
       sb.append("[").append(Long.toString(startAddr, 16)).append("..")
           .append(Long.toString(endAddr, 16)).append("] ");
     }
   }
 
   boolean validateAddressAndSizeWithinSlab(long addr, int size) {
-    for (int i = 0; i < slabs.length; i++) {
-      if (slabs[i].getMemoryAddress() <= addr
-          && addr < (slabs[i].getMemoryAddress() + slabs[i].getSize())) {
+    for (final Slab slab : slabs) {
+      if (slab.getMemoryAddress() <= addr
+          && addr < (slab.getMemoryAddress() + slab.getSize())) {
         // validate addr + size is within the same slab
         if (size != -1) { // skip this check if size is -1
-          if (!(slabs[i].getMemoryAddress() <= (addr + size - 1)
-              && (addr + size - 1) < (slabs[i].getMemoryAddress() + slabs[i].getSize()))) {
+          if (!(slab.getMemoryAddress() <= (addr + size - 1)
+              && (addr + size - 1) < (slab.getMemoryAddress() + slab.getSize()))) {
             throw new IllegalStateException(" address 0x" + Long.toString(addr + size - 1, 16)
                 + " does not address the original slab memory");
           }
