@@ -106,7 +106,7 @@ public class OffHeapStoredObject extends AbstractStoredObject
    * Should only be used by FakeChunk subclass
    */
   protected OffHeapStoredObject() {
-    this.memoryAddress = 0L;
+    memoryAddress = 0L;
   }
 
   /**
@@ -119,7 +119,7 @@ public class OffHeapStoredObject extends AbstractStoredObject
   }
 
   protected OffHeapStoredObject(OffHeapStoredObject chunk) {
-    this.memoryAddress = chunk.memoryAddress;
+    memoryAddress = chunk.memoryAddress;
   }
 
   @Override
@@ -163,7 +163,7 @@ public class OffHeapStoredObject extends AbstractStoredObject
     MemoryAllocatorImpl.getAllocator().getStats().incReads();
     MemoryAllocatorImpl.getAllocator().getStats().incReads();
     for (i = 0; i < mySize - (dataCache1.length - 1); i += dataCache1.length) {
-      this.readDataBytes(i, dataCache1);
+      readDataBytes(i, dataCache1);
       other.readDataBytes(i, dataCache2);
       for (int j = 0; j < dataCache1.length; j++) {
         if (dataCache1[j] != dataCache2[j]) {
@@ -174,7 +174,7 @@ public class OffHeapStoredObject extends AbstractStoredObject
     int bytesToRead = mySize - i;
     if (bytesToRead > 0) {
       // need to do one more read which will be less than dataCache.length
-      this.readDataBytes(i, dataCache1, 0, bytesToRead);
+      readDataBytes(i, dataCache1, 0, bytesToRead);
       other.readDataBytes(i, dataCache2, 0, bytesToRead);
       for (int j = 0; j < bytesToRead; j++) {
         if (dataCache1[j] != dataCache2[j]) {
@@ -199,9 +199,9 @@ public class OffHeapStoredObject extends AbstractStoredObject
     int i;
     MemoryAllocatorImpl.getAllocator().getStats().incReads();
     for (i = 0; i < mySize - (dataCache.length - 1); i += dataCache.length) {
-      this.readDataBytes(i, dataCache);
-      for (int j = 0; j < dataCache.length; j++) {
-        if (dataCache[j] != serializedObj[idx++]) {
+      readDataBytes(i, dataCache);
+      for (final byte b : dataCache) {
+        if (b != serializedObj[idx++]) {
           return false;
         }
       }
@@ -209,7 +209,7 @@ public class OffHeapStoredObject extends AbstractStoredObject
     int bytesToRead = mySize - i;
     if (bytesToRead > 0) {
       // need to do one more read which will be less than dataCache.length
-      this.readDataBytes(i, dataCache, 0, bytesToRead);
+      readDataBytes(i, dataCache, 0, bytesToRead);
       for (int j = 0; j < bytesToRead; j++) {
         if (dataCache[j] != serializedObj[idx++]) {
           return false;
@@ -225,7 +225,7 @@ public class OffHeapStoredObject extends AbstractStoredObject
    */
   public void checkIsAllocated() {
     int originalBits =
-        AddressableMemoryManager.readIntVolatile(this.memoryAddress + REF_COUNT_OFFSET);
+        AddressableMemoryManager.readIntVolatile(memoryAddress + REF_COUNT_OFFSET);
     if ((originalBits & MAGIC_MASK) != MAGIC_NUMBER) {
       throw new IllegalStateException(
           "It looks like this off heap memory was already freed. rawBits="
@@ -243,32 +243,25 @@ public class OffHeapStoredObject extends AbstractStoredObject
 
   @Override
   public int getSize() {
-    return getSize(this.memoryAddress);
+    return getSize(memoryAddress);
   }
 
   public void setSize(int size) {
-    setSize(this.memoryAddress, size);
+    setSize(memoryAddress, size);
   }
 
   @Override
   public long getAddress() {
-    return this.memoryAddress;
+    return memoryAddress;
   }
 
   @Override
   public int getDataSize() {
-    return getDataSize(this.memoryAddress);
-  }
-
-  protected static int getDataSize(long memoryAdress) {
-    int dataSizeDelta = AddressableMemoryManager.readInt(memoryAdress + REF_COUNT_OFFSET);
-    dataSizeDelta &= DATA_SIZE_DELTA_MASK;
-    dataSizeDelta >>= DATA_SIZE_SHIFT;
-    return getSize(memoryAdress) - dataSizeDelta;
+    return getDataSize(memoryAddress);
   }
 
   protected long getBaseDataAddress() {
-    return this.memoryAddress + HEADER_SIZE;
+    return memoryAddress + HEADER_SIZE;
   }
 
   protected int getBaseDataOffset() {
@@ -283,11 +276,11 @@ public class OffHeapStoredObject extends AbstractStoredObject
 
   @Override
   public void sendTo(DataOutput out) throws IOException {
-    if (!this.isCompressed() && out instanceof HeapDataOutputStream) {
+    if (!isCompressed() && out instanceof HeapDataOutputStream) {
       ByteBuffer bb = createDirectByteBuffer();
       if (bb != null) {
         HeapDataOutputStream hdos = (HeapDataOutputStream) out;
-        if (this.isSerialized()) {
+        if (isSerialized()) {
           hdos.write(bb);
         } else {
           hdos.writeByte(DSCODE.BYTE_ARRAY.toByte());
@@ -370,7 +363,7 @@ public class OffHeapStoredObject extends AbstractStoredObject
 
   @Override
   public void release() {
-    release(this.memoryAddress);
+    ReferenceCounter.release(memoryAddress);
   }
 
   @Override
@@ -394,7 +387,7 @@ public class OffHeapStoredObject extends AbstractStoredObject
 
   @Override
   public int hashCode() {
-    long value = this.getAddress();
+    long value = getAddress();
     return (int) (value ^ (value >>> 32));
   }
 
@@ -469,56 +462,24 @@ public class OffHeapStoredObject extends AbstractStoredObject
 
   @Override
   public boolean isSerialized() {
-    return (AddressableMemoryManager.readInt(this.memoryAddress + REF_COUNT_OFFSET)
+    return (AddressableMemoryManager.readInt(memoryAddress + REF_COUNT_OFFSET)
         & IS_SERIALIZED_BIT) != 0;
   }
 
   @Override
   public boolean isCompressed() {
-    return (AddressableMemoryManager.readInt(this.memoryAddress + REF_COUNT_OFFSET)
+    return (AddressableMemoryManager.readInt(memoryAddress + REF_COUNT_OFFSET)
         & IS_COMPRESSED_BIT) != 0;
   }
 
   @Override
   public boolean retain() {
-    return retain(this.memoryAddress);
+    return ReferenceCounter.retain(memoryAddress);
   }
 
   @Override
   public int getRefCount() {
-    return getRefCount(this.memoryAddress);
-  }
-
-  public static int getSize(long memAddr) {
-    MemoryAllocatorImpl.validateAddress(memAddr);
-    return AddressableMemoryManager.readInt(memAddr + CHUNK_SIZE_OFFSET);
-  }
-
-  public static void setSize(long memAddr, int size) {
-    MemoryAllocatorImpl.validateAddressAndSize(memAddr, size);
-    AddressableMemoryManager.writeInt(memAddr + CHUNK_SIZE_OFFSET, size);
-  }
-
-  public static long getNext(long memAddr) {
-    MemoryAllocatorImpl.validateAddress(memAddr);
-    return AddressableMemoryManager.readLong(memAddr + HEADER_SIZE);
-  }
-
-  public static void setNext(long memAddr, long next) {
-    MemoryAllocatorImpl.validateAddress(memAddr);
-    AddressableMemoryManager.writeLong(memAddr + HEADER_SIZE, next);
-  }
-
-  /**
-   * Fills the chunk with a repeated byte fill pattern.
-   *
-   * @param baseAddress the starting address for a {@link OffHeapStoredObject}.
-   */
-  public static void fill(long baseAddress) {
-    long startAddress = baseAddress + MIN_CHUNK_SIZE;
-    int size = getSize(baseAddress) - MIN_CHUNK_SIZE;
-
-    AddressableMemoryManager.fill(startAddress, size, FILL_BYTE);
+    return ReferenceCounter.getRefCount(memoryAddress);
   }
 
   /**
@@ -547,14 +508,14 @@ public class OffHeapStoredObject extends AbstractStoredObject
       int originalBits;
       do {
         originalBits =
-            AddressableMemoryManager.readIntVolatile(this.memoryAddress + REF_COUNT_OFFSET);
+            AddressableMemoryManager.readIntVolatile(memoryAddress + REF_COUNT_OFFSET);
         if ((originalBits & MAGIC_MASK) != MAGIC_NUMBER) {
           throw new IllegalStateException(
               "It looks like this off heap memory was already freed. rawBits="
                   + Integer.toHexString(originalBits));
         }
         bits = originalBits | IS_SERIALIZED_BIT;
-      } while (!AddressableMemoryManager.writeIntVolatile(this.memoryAddress + REF_COUNT_OFFSET,
+      } while (!AddressableMemoryManager.writeIntVolatile(memoryAddress + REF_COUNT_OFFSET,
           originalBits, bits));
     }
   }
@@ -565,14 +526,14 @@ public class OffHeapStoredObject extends AbstractStoredObject
       int originalBits;
       do {
         originalBits =
-            AddressableMemoryManager.readIntVolatile(this.memoryAddress + REF_COUNT_OFFSET);
+            AddressableMemoryManager.readIntVolatile(memoryAddress + REF_COUNT_OFFSET);
         if ((originalBits & MAGIC_MASK) != MAGIC_NUMBER) {
           throw new IllegalStateException(
               "It looks like this off heap memory was already freed. rawBits="
                   + Integer.toHexString(originalBits));
         }
         bits = originalBits | IS_COMPRESSED_BIT;
-      } while (!AddressableMemoryManager.writeIntVolatile(this.memoryAddress + REF_COUNT_OFFSET,
+      } while (!AddressableMemoryManager.writeIntVolatile(memoryAddress + REF_COUNT_OFFSET,
           originalBits, bits));
     }
   }
@@ -586,7 +547,7 @@ public class OffHeapStoredObject extends AbstractStoredObject
     int originalBits;
     do {
       originalBits =
-          AddressableMemoryManager.readIntVolatile(this.memoryAddress + REF_COUNT_OFFSET);
+          AddressableMemoryManager.readIntVolatile(memoryAddress + REF_COUNT_OFFSET);
       if ((originalBits & MAGIC_MASK) != MAGIC_NUMBER) {
         throw new IllegalStateException(
             "It looks like this off heap memory was already freed. rawBits="
@@ -595,14 +556,14 @@ public class OffHeapStoredObject extends AbstractStoredObject
       bits = originalBits;
       bits &= ~DATA_SIZE_DELTA_MASK; // clear the old dataSizeDelta bits
       bits |= delta; // set the dataSizeDelta bits to the new delta value
-    } while (!AddressableMemoryManager.writeIntVolatile(this.memoryAddress + REF_COUNT_OFFSET,
+    } while (!AddressableMemoryManager.writeIntVolatile(memoryAddress + REF_COUNT_OFFSET,
         originalBits, bits));
   }
 
   public void initializeUseCount() {
     int rawBits;
     do {
-      rawBits = AddressableMemoryManager.readIntVolatile(this.memoryAddress + REF_COUNT_OFFSET);
+      rawBits = AddressableMemoryManager.readIntVolatile(memoryAddress + REF_COUNT_OFFSET);
       if ((rawBits & MAGIC_MASK) != MAGIC_NUMBER) {
         throw new IllegalStateException(
             "It looks like this off heap memory was already freed. rawBits="
@@ -613,102 +574,10 @@ public class OffHeapStoredObject extends AbstractStoredObject
         throw new IllegalStateException("Expected use count to be zero but it was: " + uc
             + " rawBits=0x" + Integer.toHexString(rawBits));
       }
-    } while (!AddressableMemoryManager.writeIntVolatile(this.memoryAddress + REF_COUNT_OFFSET,
+    } while (!AddressableMemoryManager.writeIntVolatile(memoryAddress + REF_COUNT_OFFSET,
         rawBits, rawBits + 1));
   }
 
-  public static int getRefCount(long memAddr) {
-    return AddressableMemoryManager.readInt(memAddr + REF_COUNT_OFFSET) & REF_COUNT_MASK;
-  }
-
-  public static boolean retain(long memAddr) {
-    MemoryAllocatorImpl.validateAddress(memAddr);
-    int uc;
-    int rawBits;
-    int retryCount = 0;
-    do {
-      rawBits = AddressableMemoryManager.readIntVolatile(memAddr + REF_COUNT_OFFSET);
-      if ((rawBits & MAGIC_MASK) != MAGIC_NUMBER) {
-        // same as uc == 0
-        // TODO MAGIC_NUMBER rethink its use and interaction with compactor fragments
-        return false;
-      }
-      uc = rawBits & REF_COUNT_MASK;
-      if (uc == MAX_REF_COUNT) {
-        throw new IllegalStateException(
-            "Maximum use count exceeded. rawBits=" + Integer.toHexString(rawBits));
-      } else if (uc == 0) {
-        return false;
-      }
-      retryCount++;
-      if (retryCount > 1000) {
-        throw new IllegalStateException("tried to write " + (rawBits + 1) + " to @"
-            + Long.toHexString(memAddr) + " 1,000 times.");
-      }
-    } while (!AddressableMemoryManager.writeIntVolatile(memAddr + REF_COUNT_OFFSET, rawBits,
-        rawBits + 1));
-    // debugLog("use inced ref count " + (uc+1) + " @" + Long.toHexString(memAddr), true);
-    if (ReferenceCountHelper.trackReferenceCounts()) {
-      ReferenceCountHelper.refCountChanged(memAddr, false, uc + 1);
-    }
-
-    return true;
-  }
-
-  public static void release(final long memAddr) {
-    release(memAddr, null);
-  }
-
-  static void release(final long memAddr, FreeListManager freeListManager) {
-    MemoryAllocatorImpl.validateAddress(memAddr);
-    int newCount;
-    int rawBits;
-    boolean returnToAllocator;
-    do {
-      returnToAllocator = false;
-      rawBits = AddressableMemoryManager.readIntVolatile(memAddr + REF_COUNT_OFFSET);
-      if ((rawBits & MAGIC_MASK) != MAGIC_NUMBER) {
-        String msg = "It looks like off heap memory @" + Long.toHexString(memAddr)
-            + " was already freed. rawBits=" + Integer.toHexString(rawBits) + " history="
-            + ReferenceCountHelper.getFreeRefCountInfo(memAddr);
-        // debugLog(msg, true);
-        throw new IllegalStateException(msg);
-      }
-      int curCount = rawBits & REF_COUNT_MASK;
-      if ((curCount) == 0) {
-        // debugLog("too many frees @" + Long.toHexString(memAddr), true);
-        throw new IllegalStateException(
-            "Memory has already been freed." + " history=" + ReferenceCountHelper
-                .getFreeRefCountInfo(memAddr) /* + System.identityHashCode(this) */);
-      }
-      if (curCount == 1) {
-        newCount = 0; // clear the use count, bits, and the delta size since it will be freed.
-        returnToAllocator = true;
-      } else {
-        newCount = rawBits - 1;
-      }
-    } while (!AddressableMemoryManager.writeIntVolatile(memAddr + REF_COUNT_OFFSET, rawBits,
-        newCount));
-    // debugLog("free deced ref count " + (newCount&USE_COUNT_MASK) + " @" +
-    // Long.toHexString(memAddr), true);
-    if (returnToAllocator) {
-      if (ReferenceCountHelper.trackReferenceCounts()) {
-        if (ReferenceCountHelper.trackFreedReferenceCounts()) {
-          ReferenceCountHelper.refCountChanged(memAddr, true, newCount & REF_COUNT_MASK);
-        }
-        ReferenceCountHelper.freeRefCountInfo(memAddr);
-      }
-      if (freeListManager == null) {
-        freeListManager = MemoryAllocatorImpl.getAllocator().getFreeListManager();
-      }
-      freeListManager.free(memAddr);
-    } else {
-      if (ReferenceCountHelper.trackReferenceCounts()) {
-        ReferenceCountHelper.refCountChanged(memAddr, true, newCount & REF_COUNT_MASK);
-      }
-    }
-  }
-
   @Override
   public String toString() {
     return super.toString() + ":<dataSize=" + getDataSize() + " refCount=" + getRefCount()
@@ -763,4 +632,45 @@ public class OffHeapStoredObject extends AbstractStoredObject
   public boolean hasRefCount() {
     return true;
   }
+
+  // ---------------------------------- STATICS --------------------------------------
+
+  protected static int getDataSize(long memoryAdress) {
+    int dataSizeDelta = AddressableMemoryManager.readInt(memoryAdress + REF_COUNT_OFFSET);
+    dataSizeDelta &= DATA_SIZE_DELTA_MASK;
+    dataSizeDelta >>= DATA_SIZE_SHIFT;
+    return getSize(memoryAdress) - dataSizeDelta;
+  }
+
+  public static int getSize(long memAddr) {
+    MemoryAllocatorImpl.validateAddress(memAddr);
+    return AddressableMemoryManager.readInt(memAddr + CHUNK_SIZE_OFFSET);
+  }
+
+  public static void setSize(long memAddr, int size) {
+    MemoryAllocatorImpl.validateAddressAndSize(memAddr, size);
+    AddressableMemoryManager.writeInt(memAddr + CHUNK_SIZE_OFFSET, size);
+  }
+
+  public static long getNext(long memAddr) {
+    MemoryAllocatorImpl.validateAddress(memAddr);
+    return AddressableMemoryManager.readLong(memAddr + HEADER_SIZE);
+  }
+
+  public static void setNext(long memAddr, long next) {
+    MemoryAllocatorImpl.validateAddress(memAddr);
+    AddressableMemoryManager.writeLong(memAddr + HEADER_SIZE, next);
+  }
+
+  /**
+   * Fills the chunk with a repeated byte fill pattern.
+   *
+   * @param baseAddress the starting address for a {@link OffHeapStoredObject}.
+   */
+  public static void fill(long baseAddress) {
+    long startAddress = baseAddress + MIN_CHUNK_SIZE;
+    int size = getSize(baseAddress) - MIN_CHUNK_SIZE;
+
+    AddressableMemoryManager.fill(startAddress, size, FILL_BYTE);
+  }
 }
