@@ -41,10 +41,10 @@ import org.apache.geode.logging.internal.log4j.api.LogService;
  * ResourceTypes and Statistics instances to ResourceInstances, each of which contains the actual
  * stat values of the sample. The {@link #sample(long)} operation determines what stats have
  * changed, adds in new types and instances, and updates the sampled stat values.
- * <p/>
+ * <p>
  * SampleHandlers are registered with the SampleCollector. The handlers are notified of any changes
  * to statistics.
- * <p/>
+ * <p>
  * Extracted from StatArchiveWriter.
  *
  * @since GemFire 7.0
@@ -74,13 +74,13 @@ public class SampleCollector {
    * Map of StatisticsType to ResourceType. Contains all currently known statistics types.
    */
   private final Map<StatisticsType, ResourceType> resourceTypeMap =
-      new HashMap<StatisticsType, ResourceType>();
+      new HashMap<>();
 
   /**
    * Map of Statistics to ResourceInstance. Contains all currently known statistics resources.
    */
   private final Map<Statistics, ResourceInstance> resourceInstMap =
-      new HashMap<Statistics, ResourceInstance>();
+      new HashMap<>();
 
   /**
    * Incremented to use as unique identifier to construct new ResourceType
@@ -115,9 +115,9 @@ public class SampleCollector {
   public SampleCollector(StatisticsSampler sampler) {
     this.sampler = sampler;
     if (sampler.getStatisticsModCount() == 0) {
-      this.statResourcesModCount = -1;
+      statResourcesModCount = -1;
     } else {
-      this.statResourcesModCount = 0;
+      statResourcesModCount = 0;
     }
   }
 
@@ -159,10 +159,10 @@ public class SampleCollector {
       final RollingFileHandler rollingFileHandler) {
     synchronized (SampleCollector.class) {
       instance = this;
-      synchronized (this.sampleHandlers) {
+      synchronized (sampleHandlers) {
         StatArchiveHandler newStatArchiveHandler =
             new StatArchiveHandler(config, this, rollingFileHandler);
-        this.statArchiveHandler = newStatArchiveHandler;
+        statArchiveHandler = newStatArchiveHandler;
         addSampleHandler(newStatArchiveHandler);
         newStatArchiveHandler.initialize(nanosTimeStamp);
       }
@@ -171,7 +171,7 @@ public class SampleCollector {
 
   public boolean isInitialized() {
     synchronized (SampleCollector.class) {
-      synchronized (this.sampleHandlers) {
+      synchronized (sampleHandlers) {
         return instance == this;
       }
     }
@@ -183,7 +183,7 @@ public class SampleCollector {
    * @param handler the SampleHandler to add
    */
   public void addSampleHandler(SampleHandler handler) {
-    this.sampleHandlers.addSampleHandler(handler);
+    sampleHandlers.addSampleHandler(handler);
   }
 
   /**
@@ -192,20 +192,20 @@ public class SampleCollector {
    * @param handler the SampleHandler to remove
    */
   public void removeSampleHandler(SampleHandler handler) {
-    this.sampleHandlers.removeSampleHandler(handler);
+    sampleHandlers.removeSampleHandler(handler);
   }
 
   /**
    * Returns true if the specified SampleHandler is registered
    */
   public boolean containsSampleHandler(SampleHandler handler) {
-    return this.sampleHandlers.contains(handler);
+    return sampleHandlers.contains(handler);
   }
 
   /**
    * Collect a sample of all statistics. Adds new statistics resources, removes destroyed statistics
    * resources, collects the latest stat values, and notifies SamplerHandlers of the sample.
-   * <p/>
+   * <p>
    * The timeStamp is an arbitrary nanoseconds time stamp only used for archiving to stats files.
    * The initial time in system milliseconds and the first NanoTimer timeStamp are both written to
    * the archive file. Thereafter only the NanoTimer timeStamp is written to the archive file for
@@ -221,14 +221,14 @@ public class SampleCollector {
       logger.trace(LogMarker.STATISTICS_VERBOSE, "SampleCollector#sample nanosTimeStamp={}",
           nanosTimeStamp);
     }
-    List<MarkableSampleHandler> handlers = this.sampleHandlers.currentHandlers();
+    List<MarkableSampleHandler> handlers = sampleHandlers.currentHandlers();
     if (isDebugEnabled_STATISTICS) {
       logger.trace(LogMarker.STATISTICS_VERBOSE, "SampleCollector#sample handlers={}", handlers);
     }
     sampleResources(handlers);
 
-    List<ResourceInstance> updatedResources = new ArrayList<ResourceInstance>();
-    for (ResourceInstance ri : this.resourceInstMap.values()) {
+    List<ResourceInstance> updatedResources = new ArrayList<>();
+    for (ResourceInstance ri : resourceInstMap.values()) {
       StatisticDescriptor[] stats = ri.getResourceType().getStatisticDescriptors();
       if (ri.getStatistics().isClosed()) {
         continue;
@@ -274,27 +274,29 @@ public class SampleCollector {
     }
 
     for (ResourceInstance ri : updatedResources) {
-      ri.setPreviousStatValues(ri.getLatestStatValues());
+      if (ri.getStatValuesNotified()) {
+        ri.setPreviousStatValues(ri.getLatestStatValues());
+      }
     }
   }
 
   public void close() {
     // sync SampleCollector.class and then this.sampleHandlers
     synchronized (SampleCollector.class) {
-      synchronized (this.sampleHandlers) {
+      synchronized (sampleHandlers) {
         if (logger.isTraceEnabled(LogMarker.STATISTICS_VERBOSE)) {
           logger.trace(LogMarker.STATISTICS_VERBOSE, "SampleCollector#close");
         }
         try {
-          StatArchiveHandler handler = this.statArchiveHandler;
+          StatArchiveHandler handler = statArchiveHandler;
           if (handler != null) {
             handler.close();
           }
-        } catch (GemFireException ignore) {
+        } catch (GemFireException e) {
           logger.warn(LogMarker.STATISTICS_MARKER, "Statistic archiver shutdown failed because: {}",
-              ignore.getMessage());
+              e.getMessage());
         }
-        StatMonitorHandler handler = this.statMonitorHandler;
+        StatMonitorHandler handler = statMonitorHandler;
         if (handler != null) {
           handler.close();
         }
@@ -306,12 +308,12 @@ public class SampleCollector {
   }
 
   public void changeArchive(File newFile, long nanosTimeStamp) {
-    synchronized (this.sampleHandlers) {
+    synchronized (sampleHandlers) {
       if (logger.isTraceEnabled(LogMarker.STATISTICS_VERBOSE)) {
         logger.trace(LogMarker.STATISTICS_VERBOSE,
             "SampleCollector#changeArchive newFile={}, nanosTimeStamp={}", newFile, nanosTimeStamp);
       }
-      StatArchiveHandler handler = this.statArchiveHandler;
+      StatArchiveHandler handler = statArchiveHandler;
       if (handler != null) {
         handler.changeArchiveFile(newFile, nanosTimeStamp);
       }
@@ -320,29 +322,27 @@ public class SampleCollector {
 
   @Override
   public String toString() {
-    final StringBuilder sb = new StringBuilder(getClass().getName());
-    sb.append("@").append(System.identityHashCode(this)).append("{");
-    sb.append("sampler=").append(this.sampler);
-    sb.append(", statResourcesModCount=").append(this.statResourcesModCount);
-    sb.append(", resourceTypeId=").append(this.resourceTypeId);
-    sb.append(", resourceInstId=").append(this.resourceInstId);
-    sb.append(", resourceTypeMap.size()=").append(this.resourceTypeMap.size());
-    sb.append(", resourceInstMap.size()=").append(this.resourceInstMap.size());
-    sb.append("}");
-    return sb.toString();
+    return getClass().getName() + "@" + System.identityHashCode(this) + "{"
+        + "sampler=" + sampler
+        + ", statResourcesModCount=" + statResourcesModCount
+        + ", resourceTypeId=" + resourceTypeId
+        + ", resourceInstId=" + resourceInstId
+        + ", resourceTypeMap.size()=" + resourceTypeMap.size()
+        + ", resourceInstMap.size()=" + resourceInstMap.size()
+        + "}";
   }
 
   /**
    * For testing only
    */
   StatArchiveHandler getStatArchiveHandler() {
-    synchronized (this.sampleHandlers) {
-      return this.statArchiveHandler;
+    synchronized (sampleHandlers) {
+      return statArchiveHandler;
     }
   }
 
   protected List<MarkableSampleHandler> currentHandlersForTesting() {
-    return this.sampleHandlers.currentHandlers();
+    return sampleHandlers.currentHandlers();
   }
 
   /**
@@ -354,18 +354,16 @@ public class SampleCollector {
       logger.trace(LogMarker.STATISTICS_VERBOSE, "SampleCollector#sampleResources handlers={}",
           handlers);
     }
-    int newModCount = this.sampler.getStatisticsModCount();
+    int newModCount = sampler.getStatisticsModCount();
     // TODO: what if one is deleted and one is added
-    if (this.statResourcesModCount != newModCount) {
-      this.statResourcesModCount = newModCount;
+    if (statResourcesModCount != newModCount) {
+      statResourcesModCount = newModCount;
       int ignoreCount = 0;
 
-      Statistics[] resources = this.sampler.getStatistics();
-      for (int i = 0; i < resources.length; i++) {
-        Statistics statistics = resources[i];
-
+      Statistics[] resources = sampler.getStatistics();
+      for (Statistics statistics : resources) {
         // only notify marked/old handlers of new types or resources
-        if (!this.resourceInstMap.containsKey(statistics)) {
+        if (!resourceInstMap.containsKey(statistics)) {
           try {
             ResourceType type = getResourceType(handlers, statistics);
             ResourceInstance resource = allocateResourceInstance(type, statistics);
@@ -386,8 +384,8 @@ public class SampleCollector {
     }
 
     // notify unmarked/new handlers but not marked/old handlers
-    notifyNewHandlersOfResources(handlers, this.resourceTypeMap.values(),
-        this.resourceInstMap.values());
+    notifyNewHandlersOfResources(handlers, resourceTypeMap.values(),
+        resourceInstMap.values());
   }
 
   private ResourceType getResourceType(List<MarkableSampleHandler> handlers, Statistics statistics)
@@ -408,7 +406,7 @@ public class SampleCollector {
     }
     ResourceType resourceType = null;
     try {
-      resourceType = (ResourceType) this.resourceTypeMap.get(type);
+      resourceType = resourceTypeMap.get(type);
     } catch (NullPointerException ex) {
       // bug 30716
       if (isDebugEnabled_STATISTICS) {
@@ -430,9 +428,9 @@ public class SampleCollector {
       logger.trace(LogMarker.STATISTICS_VERBOSE, "SampleCollector#allocateResourceType type={}",
           type);
     }
-    ResourceType resourceType = new ResourceType(this.resourceTypeId, type);
-    this.resourceTypeMap.put(type, resourceType);
-    this.resourceTypeId++;
+    ResourceType resourceType = new ResourceType(resourceTypeId, type);
+    resourceTypeMap.put(type, resourceType);
+    resourceTypeId++;
     return resourceType;
   }
 
@@ -441,9 +439,9 @@ public class SampleCollector {
       logger.trace(LogMarker.STATISTICS_VERBOSE,
           "SampleCollector#allocateResourceInstance type={}, s={}", type, s);
     }
-    ResourceInstance resourceInstance = new ResourceInstance(this.resourceInstId, s, type);
-    this.resourceInstMap.put(s, resourceInstance);
-    this.resourceInstId++;
+    ResourceInstance resourceInstance = new ResourceInstance(resourceInstId, s, type);
+    resourceInstMap.put(s, resourceInstance);
+    resourceInstId++;
     return resourceInstance;
   }
 
@@ -454,27 +452,27 @@ public class SampleCollector {
           "SampleCollector#cleanupResources resources.length={}, ignoreCount={}", resources.length,
           ignoreCount);
     }
-    int resourcesToDelete = this.resourceInstMap.size() - (resources.length - ignoreCount);
+    int resourcesToDelete = resourceInstMap.size() - (resources.length - ignoreCount);
     if (isDebugEnabled_STATISTICS) {
       logger.trace(LogMarker.STATISTICS_VERBOSE,
           "SampleCollector#cleanupResources resourcesToDelete={}", resourcesToDelete);
     }
     if (resourcesToDelete == 0) {
-      return Collections.<ResourceInstance>emptyList();
+      return Collections.emptyList();
     }
 
     // some resource instances need to be removed
-    List<ResourceInstance> resourcesRemoved = new ArrayList<ResourceInstance>();
+    List<ResourceInstance> resourcesRemoved = new ArrayList<>();
     List<Statistics> resourceList = Arrays.asList(resources);
     Iterator<Map.Entry<Statistics, ResourceInstance>> it =
-        this.resourceInstMap.entrySet().iterator();
+        resourceInstMap.entrySet().iterator();
 
     while (it.hasNext() && resourcesToDelete > 0) {
       Map.Entry<Statistics, ResourceInstance> e = it.next();
-      Statistics key = (Statistics) e.getKey();
+      Statistics key = e.getKey();
       if (!resourceList.contains(key)) {
         key.close();
-        ResourceInstance inst = (ResourceInstance) e.getValue();
+        ResourceInstance inst = e.getValue();
         resourcesRemoved.add(inst);
         resourcesToDelete--;
         it.remove();
@@ -514,7 +512,7 @@ public class SampleCollector {
     int count = 0;
     for (MarkableSampleHandler handler : handlers) {
       if (!handler.isMarked()) {
-        List<ResourceType> allocatedResourceTypes = new ArrayList<ResourceType>();
+        List<ResourceType> allocatedResourceTypes = new ArrayList<>();
         for (ResourceInstance resourceInstance : resources) {
           ResourceType resourceType = resourceInstance.getResourceType();
           if (!allocatedResourceTypes.contains(resourceType)) {
@@ -604,8 +602,8 @@ public class SampleCollector {
    * For testing only
    */
   StatMonitorHandler getStatMonitorHandlerSnapshot() {
-    synchronized (this.sampleHandlers) {
-      return this.statMonitorHandler;
+    synchronized (sampleHandlers) {
+      return statMonitorHandler;
     }
   }
 
@@ -627,47 +625,47 @@ public class SampleCollector {
     public boolean isMarked() {
       if (logger.isTraceEnabled(LogMarker.STATISTICS_VERBOSE)) {
         logger.trace(LogMarker.STATISTICS_VERBOSE,
-            "MarkableSampleHandler#isMarked returning {} for {}", this.mark, this);
+            "MarkableSampleHandler#isMarked returning {} for {}", mark, this);
       }
-      return this.mark;
+      return mark;
     }
 
     public void mark() {
       if (logger.isTraceEnabled(LogMarker.STATISTICS_VERBOSE)) {
         logger.trace(LogMarker.STATISTICS_VERBOSE, "MarkableSampleHandler#mark marking {}", this);
       }
-      this.mark = true;
+      mark = true;
     }
 
     public SampleHandler getSampleHandler() {
-      return this.sampleHandler;
+      return sampleHandler;
     }
 
     @Override
     public void sampled(long nanosTimeStamp, List<ResourceInstance> resourceInstances) {
-      this.sampleHandler.sampled(nanosTimeStamp, resourceInstances);
+      sampleHandler.sampled(nanosTimeStamp, resourceInstances);
     }
 
     @Override
     public void allocatedResourceType(ResourceType resourceType) {
-      this.sampleHandler.allocatedResourceType(resourceType);
+      sampleHandler.allocatedResourceType(resourceType);
     }
 
     @Override
     public void allocatedResourceInstance(ResourceInstance resourceInstance) {
-      this.sampleHandler.allocatedResourceInstance(resourceInstance);
+      sampleHandler.allocatedResourceInstance(resourceInstance);
     }
 
     @Override
     public void destroyedResourceInstance(ResourceInstance resourceInstance) {
-      this.sampleHandler.destroyedResourceInstance(resourceInstance);
+      sampleHandler.destroyedResourceInstance(resourceInstance);
     }
 
     @Override
     public int hashCode() {
       final int prime = 31;
       int result = 1;
-      result = prime * result + this.sampleHandler.hashCode();
+      result = prime * result + sampleHandler.hashCode();
       return result;
     }
 
@@ -683,16 +681,14 @@ public class SampleCollector {
         return false;
       }
       MarkableSampleHandler other = (MarkableSampleHandler) obj;
-      return this.sampleHandler == other.sampleHandler;
+      return sampleHandler == other.sampleHandler;
     }
 
     @Override
     public String toString() {
-      final StringBuilder sb = new StringBuilder(getClass().getName());
-      sb.append("@").append(System.identityHashCode(this)).append("{");
-      sb.append("mark=").append(this.mark);
-      sb.append(", sampleHandler=").append(this.sampleHandler);
-      return sb.toString();
+      return getClass().getName() + "@" + System.identityHashCode(this) + "{"
+          + "mark=" + mark
+          + ", sampleHandler=" + sampleHandler;
     }
   }
 
@@ -702,7 +698,7 @@ public class SampleCollector {
   public class SampleHandlers implements Iterable<MarkableSampleHandler> {
 
     private volatile List<MarkableSampleHandler> currentHandlers =
-        Collections.<MarkableSampleHandler>emptyList();
+        Collections.emptyList();
 
     public SampleHandlers() {}
 
@@ -722,18 +718,18 @@ public class SampleCollector {
 
     public boolean contains(SampleHandler handler) {
       MarkableSampleHandler markableHandler = new MarkableSampleHandler(handler);
-      return this.currentHandlers.contains(markableHandler);
+      return currentHandlers.contains(markableHandler);
     }
 
     public List<MarkableSampleHandler> currentHandlers() {
       // optimized for read (no copy and unmodifiable)
-      return this.currentHandlers;
+      return currentHandlers;
     }
 
     @Override
     public Iterator<MarkableSampleHandler> iterator() {
       // optimized for read (no copy and unmodifiable)
-      return this.currentHandlers.iterator();
+      return currentHandlers.iterator();
     }
 
     public Iterator<MarkableSampleHandler> markedIterator() {
@@ -748,16 +744,16 @@ public class SampleCollector {
       synchronized (this) {
         boolean added = false;
         MarkableSampleHandler markableHandler = new MarkableSampleHandler(handler);
-        List<MarkableSampleHandler> oldHandlers = this.currentHandlers;
+        List<MarkableSampleHandler> oldHandlers = currentHandlers;
         if (!oldHandlers.contains(markableHandler)) {
           if (logger.isTraceEnabled(LogMarker.STATISTICS_VERBOSE)) {
             logger.trace(LogMarker.STATISTICS_VERBOSE,
                 "SampleHandlers#addSampleHandler adding markableHandler to {}", this);
           }
           List<MarkableSampleHandler> newHandlers =
-              new ArrayList<MarkableSampleHandler>(oldHandlers);
+              new ArrayList<>(oldHandlers);
           added = newHandlers.add(markableHandler);
-          this.currentHandlers = Collections.unmodifiableList(newHandlers);
+          currentHandlers = Collections.unmodifiableList(newHandlers);
         }
         return added;
       }
@@ -767,16 +763,16 @@ public class SampleCollector {
       synchronized (this) {
         boolean removed = false;
         MarkableSampleHandler markableHandler = new MarkableSampleHandler(handler);
-        List<MarkableSampleHandler> oldHandlers = this.currentHandlers;
+        List<MarkableSampleHandler> oldHandlers = currentHandlers;
         if (oldHandlers.contains(markableHandler)) {
           if (logger.isTraceEnabled(LogMarker.STATISTICS_VERBOSE)) {
             logger.trace(LogMarker.STATISTICS_VERBOSE,
                 "SampleHandlers#removeSampleHandler removing markableHandler from {}", this);
           }
           List<MarkableSampleHandler> newHandlers =
-              new ArrayList<MarkableSampleHandler>(oldHandlers);
+              new ArrayList<>(oldHandlers);
           removed = newHandlers.remove(markableHandler);
-          this.currentHandlers = Collections.unmodifiableList(newHandlers);
+          currentHandlers = Collections.unmodifiableList(newHandlers);
         }
         return removed;
       }
@@ -795,10 +791,8 @@ public class SampleCollector {
 
     @Override
     public String toString() {
-      final StringBuilder sb = new StringBuilder(getClass().getName());
-      sb.append("@").append(System.identityHashCode(this)).append("{");
-      sb.append("currentHandlers=").append(this.currentHandlers);
-      return sb.toString();
+      return getClass().getName() + "@" + System.identityHashCode(this) + "{"
+          + "currentHandlers=" + currentHandlers;
     }
 
     private class MarkableIterator implements Iterator<MarkableSampleHandler> {
@@ -806,24 +800,24 @@ public class SampleCollector {
       private final Iterator<MarkableSampleHandler> iterator;
 
       public MarkableIterator(boolean marked) {
-        List<MarkableSampleHandler> matchingHandlers = new ArrayList<MarkableSampleHandler>();
-        List<MarkableSampleHandler> handlers = SampleHandlers.this.currentHandlers();
+        List<MarkableSampleHandler> matchingHandlers = new ArrayList<>();
+        List<MarkableSampleHandler> handlers = currentHandlers();
         for (MarkableSampleHandler handler : handlers) {
           if (handler.isMarked() == marked) {
             matchingHandlers.add(handler);
           }
         }
-        this.iterator = matchingHandlers.iterator();
+        iterator = matchingHandlers.iterator();
       }
 
       @Override
       public boolean hasNext() {
-        return this.iterator.hasNext();
+        return iterator.hasNext();
       }
 
       @Override
       public MarkableSampleHandler next() {
-        return this.iterator.next();
+        return iterator.next();
       }
 
       @Override
