@@ -269,6 +269,7 @@ public class ConnectionTable {
    * @param startTime the ms clock start time for the operation
    * @param ackThreshold the ms ack-wait-threshold, or zero
    * @param ackSAThreshold the ms ack-severe_alert-threshold, or zero
+   * @param doNotRetry whether we should perform reattempt to create connection
    * @return the Connection, or null if someone else already created or closed it
    * @throws IOException if unable to connect
    */
@@ -276,13 +277,14 @@ public class ConnectionTable {
       boolean sharedResource,
       boolean preserveOrder, Map<DistributedMember, Object> m, PendingConnection pc, long startTime,
       long ackThreshold,
-      long ackSAThreshold) throws IOException, DistributedSystemDisconnectedException {
+      long ackSAThreshold, boolean doNotRetry)
+      throws IOException, DistributedSystemDisconnectedException {
     // handle new pending connection
     Connection con = null;
     try {
       long senderCreateStartTime = owner.getStats().startSenderCreate();
       con = Connection.createSender(owner.getMembership(), this, preserveOrder, id,
-          sharedResource, startTime, ackThreshold, ackSAThreshold);
+          sharedResource, startTime, ackThreshold, ackSAThreshold, doNotRetry);
       owner.getStats().incSenders(sharedResource, preserveOrder, senderCreateStartTime);
     } finally {
       // our connection failed to notify anyone waiting for our pending con
@@ -350,11 +352,14 @@ public class ConnectionTable {
    * @param startTime the ms clock start time for the operation
    * @param ackTimeout the ms ack-wait-threshold, or zero
    * @param ackSATimeout the ms ack-severe-alert-threshold, or zero
+   * @param doNotRetryWaitForConnection whether we should perform reattempt (or wait) to create
+   *        connection
    * @return the new Connection, or null if an error
    * @throws IOException if unable to create the connection
    */
   private Connection getSharedConnection(InternalDistributedMember id, boolean scheduleTimeout,
-      boolean preserveOrder, long startTime, long ackTimeout, long ackSATimeout)
+      boolean preserveOrder, long startTime, long ackTimeout, long ackSATimeout,
+      boolean doNotRetryWaitForConnection)
       throws IOException, DistributedSystemDisconnectedException {
 
     final Map<DistributedMember, Object> m =
@@ -387,7 +392,7 @@ public class ConnectionTable {
         logger.debug("created PendingConnection {}", pc);
       }
       result = handleNewPendingConnection(id, true, preserveOrder, m, pc,
-          startTime, ackTimeout, ackSATimeout);
+          startTime, ackTimeout, ackSATimeout, doNotRetryWaitForConnection);
       if (!preserveOrder && scheduleTimeout) {
         scheduleIdleTimeout(result);
       }
@@ -400,6 +405,10 @@ public class ConnectionTable {
           throw new IOException("Cannot form connection to alert listener " + id);
         }
 
+        if (doNotRetryWaitForConnection) {
+          return null;
+        }
+
         result = ((PendingConnection) mEntry).waitForConnect(owner.getMembership(),
             startTime, ackTimeout, ackSATimeout);
         if (logger.isDebugEnabled()) {
@@ -425,11 +434,13 @@ public class ConnectionTable {
    * @param startTime the ms clock start time for the operation
    * @param ackTimeout the ms ack-wait-threshold, or zero
    * @param ackSATimeout the ms ack-severe-alert-threshold, or zero
+   * @param doNotRetry whether we should perform reattempt to create connection
    * @return the connection, or null if an error
    * @throws IOException if the connection could not be created
    */
   Connection getThreadOwnedConnection(InternalDistributedMember id, long startTime, long ackTimeout,
-      long ackSATimeout) throws IOException, DistributedSystemDisconnectedException {
+      long ackSATimeout, boolean doNotRetry)
+      throws IOException, DistributedSystemDisconnectedException {
     Connection result;
 
     // Look for result in the thread local
@@ -449,7 +460,7 @@ public class ConnectionTable {
     // OK, we have to create a new connection.
     long senderCreateStartTime = owner.getStats().startSenderCreate();
     result = Connection.createSender(owner.getMembership(), this, true, id, false, startTime,
-        ackTimeout, ackSATimeout);
+        ackTimeout, ackSATimeout, doNotRetry);
     owner.getStats().incSenders(false, true, senderCreateStartTime);
     if (logger.isDebugEnabled()) {
       logger.debug("ConnectionTable: created an ordered connection: {}", result);
@@ -521,11 +532,12 @@ public class ConnectionTable {
    * @param startTime the ms clock start time
    * @param ackTimeout the ms ack-wait-threshold, or zero
    * @param ackSATimeout the ms ack-severe-alert-threshold, or zero
+   * @param doNotRetry whether we should perform reattempt to create connection
    * @return the new Connection, or null if a problem
    * @throws IOException if the connection could not be created
    */
   protected Connection get(InternalDistributedMember id, boolean preserveOrder, long startTime,
-      long ackTimeout, long ackSATimeout)
+      long ackTimeout, long ackSATimeout, boolean doNotRetry)
       throws IOException, DistributedSystemDisconnectedException {
     if (closed) {
       owner.getCancelCriterion().checkCancelInProgress(null);
@@ -535,9 +547,9 @@ public class ConnectionTable {
     boolean threadOwnsResources = threadOwnsResources();
     if (!preserveOrder || !threadOwnsResources) {
       result = getSharedConnection(id, threadOwnsResources, preserveOrder, startTime, ackTimeout,
-          ackSATimeout);
+          ackSATimeout, doNotRetry);
     } else {
-      result = getThreadOwnedConnection(id, startTime, ackTimeout, ackSATimeout);
+      result = getThreadOwnedConnection(id, startTime, ackTimeout, ackSATimeout, doNotRetry);
     }
     if (result != null) {
       Assert.assertTrue(result.getPreserveOrder() == preserveOrder);
