@@ -68,43 +68,43 @@ public class MsgDestreamer {
 
   public MsgDestreamer(DMStats stats, CancelCriterion stopper, KnownVersion v) {
     this.stopper = stopper;
-    this.t = new DestreamerThread(stats, stopper);
-    this.version = v;
+    t = new DestreamerThread(stats, stopper);
+    version = v;
     init();
   }
 
   private void init() {
-    this.t.start();
+    t.start();
   }
 
   public void close() {
     reset();
-    this.t.close();
+    t.close();
   }
 
   public void reset() {
     synchronized (this) {
-      this.failure = null;
-      this.result = null;
+      failure = null;
+      result = null;
     }
-    this.size = 0;
-    this.t.setName("IDLE p2pDestreamer");
+    size = 0;
+    t.setName("IDLE p2pDestreamer");
   }
 
   public void setName(String name) {
-    this.t.setName("p2pDestreamer for " + name);
+    t.setName("p2pDestreamer for " + name);
   }
 
   private void waitUntilDone() throws InterruptedException {
-    if (this.t.isClosed() || Thread.interrupted()) {
+    if (t.isClosed() || Thread.interrupted()) {
       throw new InterruptedException();
     }
     synchronized (this) {
-      while (this.failure == null && this.result == null) {
-        if (this.t.isClosed() || Thread.interrupted()) {
+      while (failure == null && result == null) {
+        if (t.isClosed() || Thread.interrupted()) {
           throw new InterruptedException();
         }
-        this.wait(); // spurious wakeup ok
+        wait(); // spurious wakeup ok
       }
     }
   }
@@ -137,10 +137,10 @@ public class MsgDestreamer {
    */
   public void addChunk(ByteBuffer bb, int length) throws IOException {
     // if this destreamer has failed or this chunk is empty just return
-    if (this.failure == null && length > 0) {
+    if (failure == null && length > 0) {
       // logit("addChunk bb length=" + length);
-      this.t.addChunk(bb, length);
-      this.size += length;
+      t.addChunk(bb, length);
+      size += length;
     }
   }
 
@@ -148,7 +148,7 @@ public class MsgDestreamer {
    * Returns the number of bytes added to this destreamer.
    */
   public int size() {
-    return this.size;
+    return size;
   }
 
   /**
@@ -164,21 +164,20 @@ public class MsgDestreamer {
     // waitUntilDone
     // this.t.join();
     waitUntilDone();
-    if (this.failure != null) {
+    if (failure != null) {
       // logit("failed with" + this.failure);
-      if (this.failure instanceof ClassNotFoundException) {
-        throw (ClassNotFoundException) this.failure;
-      } else if (this.failure instanceof IOException) {
-        throw (IOException) this.failure;
+      if (failure instanceof ClassNotFoundException) {
+        throw (ClassNotFoundException) failure;
+      } else if (failure instanceof IOException) {
+        throw (IOException) failure;
       } else {
         IOException io =
-            new IOException("failure during message deserialization");
-        io.initCause(this.failure);
+            new IOException("failure during message deserialization", failure);
         throw io;
       }
     } else {
       // logit("result =" + this.result);
-      return this.result;
+      return result;
     }
   }
 
@@ -187,22 +186,22 @@ public class MsgDestreamer {
    * one. Note this method should only be called after getMessage has thrown an exception.
    */
   public int getRPid() {
-    return this.RPid;
+    return RPid;
   }
 
   protected void setFailure(Throwable ex, int RPid) {
     synchronized (this) {
-      this.failure = ex;
+      failure = ex;
       this.RPid = RPid;
-      this.notify();
+      notify();
     }
   }
 
   protected void setResult(DistributionMessage msg) {
     synchronized (this) {
-      this.result = msg;
-      this.RPid = 0;
-      this.notify();
+      result = msg;
+      RPid = 0;
+      notify();
     }
   }
 
@@ -217,7 +216,7 @@ public class MsgDestreamer {
     public DestreamerThread(DMStats stats, CancelCriterion stopper) {
       setDaemon(true);
       super.setName("IDLE p2pDestreamer");
-      this.is = new DestreamerIS(this, stopper);
+      is = new DestreamerIS(this, stopper);
       this.stats = stats;
     }
     // private final String me = "DestreamerThread<" + System.identityHashCode(this) + ">";
@@ -228,7 +227,7 @@ public class MsgDestreamer {
     public void addChunk(ByteBuffer chunk, int bbLength) throws IOException {
       ByteBuffer bb = chunk.slice();
       bb.limit(bbLength);
-      this.is.addChunk(bb);
+      is.addChunk(bb);
     }
 
     @Override
@@ -241,11 +240,11 @@ public class MsgDestreamer {
           ReplyProcessor21.initMessageRPId();
           final KnownVersion v = version;
           DataInputStream dis =
-              v == null ? new DataInputStream(this.is)
-                  : new VersionedDataInputStream(this.is, v);
-          long startSer = this.stats.startMsgDeserialization();
+              v == null ? new DataInputStream(is)
+                  : new VersionedDataInputStream(is, v);
+          long startSer = stats.startMsgDeserialization();
           setResult((DistributionMessage) InternalDataSerializer.readDSFID(dis));
-          this.stats.endMsgDeserialization(startSer);
+          stats.endMsgDeserialization(startSer);
         } catch (VirtualMachineError err) {
           SystemFailure.initiateFailure(err);
           // If this ever returns, rethrow the error. We're poisoned
@@ -260,19 +259,19 @@ public class MsgDestreamer {
           SystemFailure.checkFailure();
           setFailure(ex, ReplyProcessor21.getMessageRPId());
         } finally {
-          this.is.close();
+          is.close();
           ReplyProcessor21.clearMessageRPId();
         }
       }
     }
 
     public void close() {
-      this.closed = true;
+      closed = true;
       interrupt();
     }
 
     public boolean isClosed() {
-      return this.closed;
+      return closed;
     }
   }
   /**
@@ -331,8 +330,8 @@ public class MsgDestreamer {
     }
 
     public DestreamerIS(DestreamerThread t, CancelCriterion stopper) {
-      this.owner = t;
-      this.data = null;
+      owner = t;
+      data = null;
       this.stopper = new Stopper(stopper);
     }
 
@@ -356,40 +355,40 @@ public class MsgDestreamer {
     // }
 
     private boolean isClosed() {
-      return this.owner.isClosed();
+      return owner.isClosed();
     }
 
     private ByteBuffer waitForData() throws InterruptedException {
       if (isClosed() || Thread.interrupted()) {
         throw new InterruptedException();
       }
-      synchronized (this.dataMon) {
-        ByteBuffer result = this.data;
+      synchronized (dataMon) {
+        ByteBuffer result = data;
         while (result == null) {
           if (isClosed() || Thread.interrupted()) {
             throw new InterruptedException();
           }
           // logit("about to dataMon wait");
-          this.dataMon.wait(); // spurious wakeup ok
+          dataMon.wait(); // spurious wakeup ok
           // logit("after dataMon wait");
           if (isClosed() || Thread.interrupted()) {
             throw new InterruptedException();
           }
-          result = this.data;
+          result = data;
         }
         return result;
       }
     }
 
     private void provideData(ByteBuffer bb) {
-      synchronized (this.dataMon) {
+      synchronized (dataMon) {
         // if (bb != null) {
         // logit("MDIS: providing bb with " +
         // bb.remaining() + " bytes");
         // }
-        this.data = bb;
+        data = bb;
         // logit("dataMon notify bb=" + bb);
-        this.dataMon.notify();
+        dataMon.notify();
       }
     }
 
@@ -397,13 +396,13 @@ public class MsgDestreamer {
       if (isClosed() || Thread.interrupted()) {
         throw new InterruptedException();
       }
-      synchronized (this.doneMon) {
-        while (this.data != null) {
+      synchronized (doneMon) {
+        while (data != null) {
           if (isClosed() || Thread.interrupted()) {
             throw new InterruptedException();
           }
           // logit("about to doneMon wait");
-          this.doneMon.wait(); // spurious wakeup ok
+          doneMon.wait(); // spurious wakeup ok
           // logit("after doneMon wait");
           if (isClosed() || Thread.interrupted()) {
             throw new InterruptedException();
@@ -413,10 +412,10 @@ public class MsgDestreamer {
     }
 
     private void signalDone() {
-      synchronized (this.doneMon) {
-        this.data = null;
+      synchronized (doneMon) {
+        data = null;
         // logit("doneMon notify");
-        this.doneMon.notify();
+        doneMon.notify();
       }
     }
 
@@ -444,7 +443,7 @@ public class MsgDestreamer {
       do {
         // only the thread that sets data to null ever does this check
         // so I believe it is ok to do this check outside of sync.
-        myData = this.data;
+        myData = data;
         if (myData == null) {
           for (;;) {
             if (isClosed()) {
@@ -506,7 +505,7 @@ public class MsgDestreamer {
      * BufferUnderflowException
      */
     @Override
-    public int read(byte b[], int off, int len) throws IOException {
+    public int read(byte[] b, int off, int len) throws IOException {
       ByteBuffer bb = waitForAvailableData();
       int remaining = bb.remaining();
       int bytesToRead = len;
@@ -520,7 +519,7 @@ public class MsgDestreamer {
 
     @Override
     public int available() throws IOException {
-      ByteBuffer bb = this.data;
+      ByteBuffer bb = data;
       if (bb == null) {
         return 0;
       } else {
