@@ -41,7 +41,7 @@ import org.apache.geode.annotations.internal.MutableForTesting;
 import org.apache.geode.distributed.DistributedMember;
 import org.apache.geode.distributed.internal.InternalDistributedSystem;
 import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
-import org.apache.geode.internal.ClassLoadUtil;
+import org.apache.geode.internal.ClassLoadUtils;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.management.AsyncEventQueueMXBean;
 import org.apache.geode.management.CacheServerMXBean;
@@ -78,7 +78,7 @@ public class MBeanJMXAdapter implements ManagementConstants {
    * public constructor
    */
   public MBeanJMXAdapter(DistributedMember distMember) {
-    this.localGemFireMBean = new ConcurrentHashMap<>();
+    localGemFireMBean = new ConcurrentHashMap<>();
     this.distMember = distMember;
   }
 
@@ -108,7 +108,7 @@ public class MBeanJMXAdapter implements ManagementConstants {
       }
 
       mbeanServer.registerMBean(object, newObjectName);
-      this.localGemFireMBean.put(newObjectName, object);
+      localGemFireMBean.put(newObjectName, object);
 
     } catch (InstanceAlreadyExistsException | NullPointerException | MalformedObjectNameException
         | NotCompliantMBeanException | MBeanRegistrationException e) {
@@ -129,7 +129,7 @@ public class MBeanJMXAdapter implements ManagementConstants {
       }
       ObjectInstance instance = mbeanServer.getObjectInstance(objectName);
       String className = instance.getClassName();
-      Class cls = ClassLoadUtil.classFromName(className);
+      Class cls = ClassLoadUtils.classFromName(className);
       Type[] intfTyps = cls.getGenericInterfaces();
       for (Type intfTyp1 : intfTyps) {
         Class intfTyp = (Class) intfTyp1;
@@ -537,17 +537,16 @@ public class MBeanJMXAdapter implements ManagementConstants {
   }
 
   public Map<ObjectName, Object> getLocalGemFireMBean() {
-    return this.localGemFireMBean;
+    return localGemFireMBean;
   }
 
   public static String getUniqueIDForMember(InternalDistributedMember member) {
-    final StringBuilder sb = new StringBuilder();
-    sb.append(member.getInetAddress().getHostAddress());
-    // View ID will be 0 for Loner, but in that case no federation as well
-    sb.append("<v").append(member.getVmViewId()).append(">");
-    sb.append(member.getMembershipPort());
+    final String sb = member.getInetAddress().getHostAddress()
+        // View ID will be 0 for Loner, but in that case no federation as well
+        + "<v" + member.getVmViewId() + ">"
+        + member.getMembershipPort();
     // Lower case to handle IPv6
-    return makeCompliantName(sb.toString().toLowerCase());
+    return makeCompliantName(sb.toLowerCase());
   }
 
   public static boolean isAttributeAvailable(String attributeName, String objectName) {
