@@ -45,6 +45,8 @@ import org.apache.geode.distributed.internal.ResourceEvent;
 import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.InternalCacheForClientAccess;
+import org.apache.geode.internal.serialization.filter.FilterConfiguration;
+import org.apache.geode.internal.serialization.filter.SystemPropertyJmxSerialFilterConfigurationFactory;
 import org.apache.geode.internal.statistics.StatisticsClock;
 import org.apache.geode.logging.internal.executors.LoggingExecutors;
 import org.apache.geode.logging.internal.log4j.api.LogService;
@@ -178,9 +180,12 @@ public class SystemManagementService extends BaseManagementService {
     repo = new ManagementResourceRepo();
     notificationHub = notificationHubFactory.apply(repo);
 
+
     if (system.getConfig().getJmxManager()) {
-      agent = managementAgentFactory.create(system.getConfig(), cache,
-          new JmxRmiOpenTypesSerialFilter());
+      FilterConfiguration filterConfiguration =
+          new SystemPropertyJmxSerialFilterConfigurationFactory().create();
+
+      agent = managementAgentFactory.create(system.getConfig(), cache, filterConfiguration);
     } else {
       agent = null;
     }
