@@ -37,7 +37,7 @@ import org.apache.geode.management.internal.util.ManagementUtils;
  */
 public class MemberMBean extends NotificationBroadcasterSupport implements MemberMXBean {
 
-  private MemberMBeanBridge bridge;
+  private final MemberMBeanBridge bridge;
 
   public MemberMBean(MemberMBeanBridge bridge) {
     this.bridge = bridge;
@@ -696,6 +696,18 @@ public class MemberMBean extends NotificationBroadcasterSupport implements Membe
     return bridge.getOffHeapFragmentation();
   }
 
+  public long getOffHeapFragments() {
+    return bridge.getOffHeapFragments();
+  }
+
+  public long getOffHeapFreedChunks() {
+    return bridge.getOffHeapFreedChunks();
+  }
+
+  public int getOffHeapLargestFragment() {
+    return bridge.getOffHeapLargestFragment();
+  }
+
   @Override
   public long getOffHeapCompactionTime() {
     return bridge.getOffHeapCompactionTime();
