@@ -14,7 +14,7 @@
  */
 package org.apache.geode.management.internal.beans;
 
-import static org.apache.geode.internal.lang.SystemUtils.getLineSeparator;
+import static java.lang.System.lineSeparator;
 
 import java.io.IOException;
 import java.lang.management.ManagementFactory;
@@ -767,9 +767,9 @@ public class MemberMBeanBridge {
     StringBuilder result = new StringBuilder();
     result.append(mainTail);
     if (childTail != null) {
-      result.append(getLineSeparator())
+      result.append(lineSeparator())
           .append("-------------------- tail of child log --------------------")
-          .append(getLineSeparator());
+          .append(lineSeparator());
       result.append(childTail);
     }
     return result.toString();
@@ -1352,6 +1352,36 @@ public class MemberMBeanBridge {
     return 0;
   }
 
+  long getOffHeapFragments() {
+    OffHeapMemoryStats stats = getOffHeapStats();
+
+    if (null != stats) {
+      return stats.getFragments();
+    }
+
+    return 0;
+  }
+
+  long getOffHeapFreedChunks() {
+    OffHeapMemoryStats stats = getOffHeapStats();
+
+    if (null != stats) {
+      return stats.getFreedChunks();
+    }
+
+    return 0;
+  }
+
+  int getOffHeapLargestFragment() {
+    OffHeapMemoryStats stats = getOffHeapStats();
+
+    if (null != stats) {
+      return stats.getLargestFragment();
+    }
+
+    return 0;
+  }
+
   long getOffHeapCompactionTime() {
     OffHeapMemoryStats stats = getOffHeapStats();
 
@@ -1392,7 +1422,7 @@ public class MemberMBeanBridge {
   }
 
   int getRebalancesInProgress() {
-    return resourceManagerStats.getRebalancesInProgress();
+    return (int) resourceManagerStats.getRebalancesInProgress();
   }
 
   public int getReplyWaitsInProgress() {
