@@ -59,11 +59,12 @@ public class DeploymentManager implements ConfigurationManager<Deployment> {
     }
 
     return configuration.getDeployments().stream()
-        .filter(deploymentsForJarName(filter.getFileName()))
+        .filter(deploymentsForName(filter.getFileName()))
         .collect(toList());
   }
 
-  private static Predicate<Deployment> deploymentsForJarName(String jarFileName) {
-    return jarFileName == null ? d -> true : d -> d.getFileName().equals(jarFileName);
+  private static Predicate<Deployment> deploymentsForName(String jarName) {
+    return jarName == null ? deployment -> true
+        : deployment -> deployment.getFileName().equals(jarName);
   }
 }
