@@ -15,49 +15,52 @@
 
 package org.apache.geode.management.internal.configuration.realizers;
 
-import java.io.File;
-import java.io.IOException;
-import java.time.Instant;
-import java.util.Map;
-
 import org.apache.commons.lang3.NotImplementedException;
+import org.apache.logging.log4j.Logger;
 
+import org.apache.geode.annotations.Immutable;
 import org.apache.geode.annotations.VisibleForTesting;
-import org.apache.geode.internal.ClassPathLoader;
-import org.apache.geode.internal.DeployedJar;
-import org.apache.geode.internal.JarDeployer;
 import org.apache.geode.internal.cache.InternalCache;
+import org.apache.geode.internal.classloader.ClassPathLoader;
+import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.management.api.RealizationResult;
 import org.apache.geode.management.configuration.Deployment;
 import org.apache.geode.management.runtime.DeploymentInfo;
+import org.apache.geode.services.result.ServiceResult;
 
 public class DeploymentRealizer
     implements ConfigurationRealizer<Deployment, DeploymentInfo> {
 
+  @Immutable
+  private static final Logger logger = LogService.getLogger();
+
   static final String JAR_NOT_DEPLOYED = "Jar file not deployed on the server.";
 
   @Override
   public RealizationResult create(Deployment config, InternalCache cache) throws Exception {
+    ServiceResult<Deployment> deploy = deploy(config);
     RealizationResult result = new RealizationResult();
-    DeployedJar deployedJar = deploy(config.getFile());
-    if (deployedJar == null) {
-      result.setMessage("Already deployed");
+    if (deploy.isFailure()) {
+      result.setSuccess(false);
+      result.setMessage(deploy.getErrorMessage());
     } else {
-      result.setMessage(deployedJar.getFileCanonicalPath());
+      Deployment deployment = deploy.getMessage();
+      if (deployment == null) {
+        result.setMessage("Already deployed");
+      } else {
+        result.setMessage(deployment.getFilePath());
+      }
     }
     return result;
   }
 
   @Override
   public DeploymentInfo get(Deployment config, InternalCache cache) {
-    Map<String, DeployedJar> deployedJars = getDeployedJars();
     DeploymentInfo info = new DeploymentInfo();
-    String artifactId = JarDeployer.getArtifactId(config.getFileName());
-    DeployedJar deployedJar = deployedJars.get(artifactId);
-    if (deployedJar != null) {
-      File file = deployedJar.getFile();
-      info.setLastModified(getDateString(file.lastModified()));
-      info.setJarLocation(file.getAbsolutePath());
+    ServiceResult<Deployment> deployed = getDeployed(config.getFileName());
+    if (deployed.isSuccessful()) {
+      info.setLastModified(deployed.getMessage().getDeployedTime());
+      info.setJarLocation(deployed.getMessage().getFile().getAbsolutePath());
     } else {
       info.setJarLocation(JAR_NOT_DEPLOYED);
     }
@@ -80,18 +83,12 @@ public class DeploymentRealizer
   }
 
   @VisibleForTesting
-  String getDateString(long milliseconds) {
-    return Instant.ofEpochMilli(milliseconds).toString();
+  ServiceResult<Deployment> getDeployed(String name) {
+    return ClassPathLoader.getLatest().getJarDeploymentService().getDeployed(name);
   }
 
   @VisibleForTesting
-  Map<String, DeployedJar> getDeployedJars() {
-    JarDeployer jarDeployer = ClassPathLoader.getLatest().getJarDeployer();
-    return jarDeployer.getDeployedJars();
-  }
-
-  @VisibleForTesting
-  DeployedJar deploy(File jarFile) throws IOException, ClassNotFoundException {
-    return ClassPathLoader.getLatest().getJarDeployer().deploy(jarFile);
+  ServiceResult<Deployment> deploy(Deployment deployment) {
+    return ClassPathLoader.getLatest().getJarDeploymentService().deploy(deployment);
   }
 }
