@@ -112,6 +112,7 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
    *        they should be serialized
    * @deprecated as of 6.6.2 use ReflectionBasedAutoSerializer(String...) instead.
    */
+  @Deprecated
   public ReflectionBasedAutoSerializer(List<String> classes) {
     this(listToArray(classes));
   }
@@ -208,7 +209,7 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
     // We allow this class to escape its constructor so that our delegate can
     // call back to us when needed. Callbacks will not happen until this instance
     // is fully constructed and registered with the Cache.
-    this.manager = AutoSerializableManager.create(this, checkPortability, patterns);
+    manager = AutoSerializableManager.create(this, checkPortability, patterns);
   }
 
   /**
@@ -248,6 +249,7 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
    * @param patterns the list of definitions to apply
    * @deprecated as of 6.6.2 use {@link #reconfigure(String...)} instead.
    */
+  @Deprecated
   public void setSerializableClasses(List<String> patterns) {
     reconfigure(listToArray(patterns));
   }
@@ -332,7 +334,7 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
    * @since GemFire 6.6.2
    */
   public void reconfigure(boolean checkPortability, String... patterns) {
-    this.manager.reconfigure(checkPortability, patterns);
+    manager.reconfigure(checkPortability, patterns);
   }
 
   /**
@@ -368,14 +370,16 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
    * fields. See {@link ReflectionBasedAutoSerializer#reconfigure(String...) reconfigure} for
    * specifics.</li>
    * <li><b>check-portability</b> - if true then an exception will be thrown if an attempt to
-   * serialize data that is not portable to .NET is made.
+   * serialize data that is not portable to .NET is made.</li>
+   * </ul>
    *
    * @param props properties used to configure the auto serializer
    * @deprecated as of Geode 1.5 use initialize instead
    */
+  @Deprecated
   @Override
   public void init(Properties props) {
-    this.manager.init(props);
+    manager.init(props);
   }
 
   /**
@@ -387,7 +391,8 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
    * fields. See {@link ReflectionBasedAutoSerializer#reconfigure(String...) reconfigure} for
    * specifics.</li>
    * <li><b>check-portability</b> - if true then an exception will be thrown if an attempt to
-   * serialize data that is not portable to .NET is made.
+   * serialize data that is not portable to .NET is made.</li>
+   * </ul>
    *
    * @param cache the cache that owns this serializer
    * @param props properties used to configure the auto serializer
@@ -395,8 +400,8 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
    */
   @Override
   public void initialize(Cache cache, Properties props) {
-    this.manager.setRegionService(cache);
-    this.manager.init(props);
+    manager.setRegionService(cache);
+    manager.init(props);
   }
 
   /**
@@ -408,7 +413,7 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
    * @return a <code>Properties</code> object
    */
   public Properties getConfig() {
-    return this.manager.getConfig();
+    return manager.getConfig();
   }
 
   /**
@@ -436,7 +441,7 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
    * @since GemFire 6.6.2
    */
   public boolean isClassAutoSerialized(Class<?> clazz) {
-    return this.manager.defaultIsClassAutoSerialized(clazz);
+    return manager.defaultIsClassAutoSerialized(clazz);
   }
 
   /**
@@ -462,7 +467,7 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
    * @since GemFire 6.6.2
    */
   public boolean isFieldIncluded(Field f, Class<?> clazz) {
-    return this.manager.defaultIsFieldIncluded(f, clazz);
+    return manager.defaultIsFieldIncluded(f, clazz);
   }
 
   /**
@@ -508,7 +513,7 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
    * @since GemFire 6.6.2
    */
   public boolean isIdentityField(Field f, Class<?> clazz) {
-    return this.manager.defaultIsIdentityField(f, clazz);
+    return manager.defaultIsIdentityField(f, clazz);
   }
 
   /**
@@ -529,7 +534,7 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
    * @since GemFire 6.6.2
    */
   public FieldType getFieldType(Field f, Class<?> clazz) {
-    return this.manager.defaultGetFieldType(f, clazz);
+    return manager.defaultGetFieldType(f, clazz);
   }
 
   /**
@@ -591,22 +596,24 @@ public class ReflectionBasedAutoSerializer implements PdxSerializer, Declarable
   }
 
   /**
-   * Returns the cache that this serializer is installed on. Returns null if it is not installed.
+   * @return the cache that this serializer is installed on. Returns null if it is not installed.
    *
    * @since GemFire 6.6.2
    */
   public RegionService getRegionService() {
-    return this.manager.getRegionService();
+    return manager.getRegionService();
   }
 
   /**
    * For internal use only.
    *
+   * @return the manager associated with this serializer
+   *
    * @since GemFire 8.2
    */
   public Object getManager() {
     // The result is not AutoSerializableManager because
     // that class is not part of our public APIs.
-    return this.manager;
+    return manager;
   }
 }
