@@ -36,11 +36,11 @@ public class PdxOutputStream implements ByteBufferWriter {
   private final HeapDataOutputStream hdos;
 
   public PdxOutputStream() {
-    this.hdos = new HeapDataOutputStream(KnownVersion.CURRENT);
+    hdos = new HeapDataOutputStream(KnownVersion.CURRENT);
   }
 
   public PdxOutputStream(int allocSize) {
-    this.hdos = new HeapDataOutputStream(allocSize, KnownVersion.CURRENT);
+    hdos = new HeapDataOutputStream(allocSize, KnownVersion.CURRENT);
   }
 
   /**
@@ -53,7 +53,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeDate(Date date) {
     try {
-      DataSerializer.writeDate(date, this.hdos);
+      DataSerializer.writeDate(date, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -61,7 +61,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeString(String value) {
     try {
-      DataSerializer.writeString(value, this.hdos);
+      DataSerializer.writeString(value, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -69,7 +69,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeObject(Object object, boolean ensureCompatibility) {
     try {
-      InternalDataSerializer.basicWriteObject(object, this.hdos, ensureCompatibility);
+      InternalDataSerializer.basicWriteObject(object, hdos, ensureCompatibility);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -77,7 +77,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeBooleanArray(boolean[] array) {
     try {
-      DataSerializer.writeBooleanArray(array, this.hdos);
+      DataSerializer.writeBooleanArray(array, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -85,7 +85,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeCharArray(char[] array) {
     try {
-      DataSerializer.writeCharArray(array, this.hdos);
+      DataSerializer.writeCharArray(array, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -93,7 +93,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeByteArray(byte[] array) {
     try {
-      DataSerializer.writeByteArray(array, this.hdos);
+      DataSerializer.writeByteArray(array, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -101,7 +101,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeShortArray(short[] array) {
     try {
-      DataSerializer.writeShortArray(array, this.hdos);
+      DataSerializer.writeShortArray(array, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -109,7 +109,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeIntArray(int[] array) {
     try {
-      DataSerializer.writeIntArray(array, this.hdos);
+      DataSerializer.writeIntArray(array, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -117,7 +117,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeLongArray(long[] array) {
     try {
-      DataSerializer.writeLongArray(array, this.hdos);
+      DataSerializer.writeLongArray(array, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -125,7 +125,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeFloatArray(float[] array) {
     try {
-      DataSerializer.writeFloatArray(array, this.hdos);
+      DataSerializer.writeFloatArray(array, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -133,7 +133,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeDoubleArray(double[] array) {
     try {
-      DataSerializer.writeDoubleArray(array, this.hdos);
+      DataSerializer.writeDoubleArray(array, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -141,7 +141,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeStringArray(String[] array) {
     try {
-      DataSerializer.writeStringArray(array, this.hdos);
+      DataSerializer.writeStringArray(array, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -149,7 +149,7 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeObjectArray(Object[] array, boolean ensureCompatibility) {
     try {
-      InternalDataSerializer.writeObjectArray(array, this.hdos, ensureCompatibility);
+      InternalDataSerializer.writeObjectArray(array, hdos, ensureCompatibility);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
@@ -157,78 +157,78 @@ public class PdxOutputStream implements ByteBufferWriter {
 
   public void writeArrayOfByteArrays(byte[][] array) {
     try {
-      DataSerializer.writeArrayOfByteArrays(array, this.hdos);
+      DataSerializer.writeArrayOfByteArrays(array, hdos);
     } catch (IOException e) {
       throw new PdxSerializationException("Exception while serializing a PDX field", e);
     }
   }
 
   public int size() {
-    return this.hdos.size();
+    return hdos.size();
   }
 
   public void writeChar(char value) {
-    this.hdos.writeChar(value);
+    hdos.writeChar(value);
   }
 
   public void writeByte(int value) {
-    this.hdos.writeByte(value);
+    hdos.writeByte(value);
   }
 
   public void writeShort(short value) {
-    this.hdos.writeShort(value);
+    hdos.writeShort(value);
   }
 
   public void writeInt(int value) {
-    this.hdos.writeInt(value);
+    hdos.writeInt(value);
   }
 
   public void writeLong(long value) {
-    this.hdos.writeLong(value);
+    hdos.writeLong(value);
   }
 
   public void writeFloat(float value) {
-    this.hdos.writeFloat(value);
+    hdos.writeFloat(value);
   }
 
   public void writeDouble(double value) {
-    this.hdos.writeDouble(value);
+    hdos.writeDouble(value);
   }
 
   public HeapDataOutputStream.LongUpdater reserveLong() {
-    return this.hdos.reserveLong();
+    return hdos.reserveLong();
   }
 
   public void write(byte b) {
-    this.hdos.write(b);
+    hdos.write(b);
   }
 
   public void sendTo(DataOutput out) throws IOException {
-    this.hdos.sendTo(out);
+    hdos.sendTo(out);
   }
 
   @Override
   public void write(ByteBuffer data) {
-    this.hdos.write(data);
+    hdos.write(data);
   }
 
   public void write(ByteSource data) {
-    this.hdos.write(data);
+    hdos.write(data);
   }
 
   public ByteBuffer toByteBuffer() {
-    return this.hdos.toByteBuffer();
+    return hdos.toByteBuffer();
   }
 
   public ByteBuffer toByteBuffer(int startPosition) {
-    return this.hdos.toByteBuffer(startPosition);
+    return hdos.toByteBuffer(startPosition);
   }
 
   public byte[] toByteArray() {
-    return this.hdos.toByteArray();
+    return hdos.toByteArray();
   }
 
   public void write(byte[] source, int offset, int len) {
-    this.hdos.write(source, offset, len);
+    hdos.write(source, offset, len);
   }
 }
