@@ -18,16 +18,15 @@ import java.io.IOException;
 import java.math.BigDecimal;
 import java.math.BigInteger;
 import java.util.Collection;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
 import com.fasterxml.jackson.core.JsonEncoding;
 import com.fasterxml.jackson.core.JsonFactory;
-import com.fasterxml.jackson.core.JsonGenerationException;
 import com.fasterxml.jackson.core.JsonGenerator;
 import com.fasterxml.jackson.core.JsonGenerator.Feature;
 
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.annotations.internal.MutableForTesting;
 import org.apache.geode.internal.HeapDataOutputStream;
 import org.apache.geode.internal.serialization.KnownVersion;
@@ -44,7 +43,7 @@ public class PdxToJSON {
   @MutableForTesting
   public static boolean PDXTOJJSON_UNQUOTEFIELDNAMES =
       Boolean.getBoolean("pdxToJson.unQuoteFieldNames");
-  private PdxInstance m_pdxInstance;
+  private final PdxInstance m_pdxInstance;
 
   public PdxToJSON(PdxInstance pdx) {
     m_pdxInstance = pdx;
@@ -94,8 +93,9 @@ public class PdxToJSON {
     return (pdxObj != null ? JSONFormatter.toJSON(pdxObj) : null);
   }
 
-  private void writeValue(JsonGenerator jg, Object value, String pf)
-      throws JsonGenerationException, IOException {
+  @VisibleForTesting
+  protected void writeValue(JsonGenerator jg, Object value, String pf)
+      throws IOException {
 
     if (value == null) {
       jg.writeNull();
@@ -135,28 +135,26 @@ public class PdxToJSON {
       jg.writeString(value.toString());
     } else if (value.getClass().equals(PdxInstanceEnumInfo.class)) {
       jg.writeString(value.toString());
+    } else if (value instanceof PdxInstance) {
+      getJSONString(jg, (PdxInstance) value);
+    } else if (value instanceof Collection) {
+      getJSONStringFromCollection(jg, (Collection<?>) value, pf);
+    } else if (value instanceof Map) {
+      getJSONStringFromMap(jg, (Map) value, pf);
     } else {
-      if (value instanceof PdxInstance) {
-        getJSONString(jg, (PdxInstance) value);
-      } else if (value instanceof Collection) {
-        getJSONStringFromCollection(jg, (Collection<?>) value, pf);
-      } else if (value instanceof Map) {
-        getJSONStringFromMap(jg, (Map) value, pf);
-      } else {
-        throw new IllegalStateException(
-            "PdxInstance returns unknwon pdxfield " + pf + " for type " + value);
-      }
+      throw new IllegalStateException(
+          "The pdx field " + pf + " has a value " + value + " whose type " + value.getClass()
+              + " can not be converted to JSON.");
     }
   }
 
   private void getJSONStringFromMap(JsonGenerator jg, Map map, String pf)
-      throws JsonGenerationException, IOException {
+      throws IOException {
 
     jg.writeStartObject();
 
-    Iterator iter = map.entrySet().iterator();
-    while (iter.hasNext()) {
-      Map.Entry entry = (Map.Entry) iter.next();
+    for (final Object o : map.entrySet()) {
+      Map.Entry entry = (Map.Entry) o;
 
       // Iterate over Map and write key-value
       jg.writeFieldName(entry.getKey().toString()); // write Key in a Map
@@ -166,7 +164,7 @@ public class PdxToJSON {
   }
 
   private String getJSONString(JsonGenerator jg, PdxInstance pdxInstance)
-      throws JsonGenerationException, IOException {
+      throws IOException {
     jg.writeStartObject();
 
     List<String> pdxFields = pdxInstance.getFieldNames();
@@ -180,10 +178,15 @@ public class PdxToJSON {
     return null;
   }
 
-  private void getJSONStringFromArray(JsonGenerator jg, Object value, String pf)
-      throws JsonGenerationException, IOException {
+  @VisibleForTesting
+  protected void getJSONStringFromArray(JsonGenerator jg, Object value, String pf)
+      throws IOException {
 
-    if (value.getClass().getName().equals("[Z")) {
+    if (!value.getClass().isArray()) {
+      throw new IllegalStateException(
+          "Expected an array for pdx field " + pf + ", but got an object of type "
+              + value.getClass());
+    } else if (value.getClass().getName().equals("[Z")) {
       JsonHelper.getJsonFromPrimitiveBoolArray(jg, (boolean[]) value, pf);
     } else if (value.getClass().getName().equals("[B")) {
       JsonHelper.getJsonFromPrimitiveByteArray(jg, (byte[]) value, pf);
@@ -226,12 +229,14 @@ public class PdxToJSON {
       jg.writeEndArray();
     } else {
       throw new IllegalStateException(
-          "PdxInstance returns unknown pdxfield " + pf + " for type " + value);
+          "The pdx field " + pf + " is an array whose component type "
+              + value.getClass().getComponentType()
+              + " can not be converted to JSON.");
     }
   }
 
   private void getJSONStringFromCollection(JsonGenerator jg, Collection<?> coll, String pf)
-      throws JsonGenerationException, IOException {
+      throws IOException {
     jg.writeStartArray();
 
     for (Object obj : coll) {
