@@ -45,10 +45,12 @@ public class ResourcePermission extends WildcardPermission {
   /**
    * @deprecated use ALL
    */
+  @Deprecated
   public static final String ALL_REGIONS = "*";
   /**
    * @deprecated use All
    */
+  @Deprecated
   public static final String ALL_KEYS = "*";
 
   public enum Resource {
@@ -90,10 +92,10 @@ public class ResourcePermission extends WildcardPermission {
 
   public ResourcePermission() {
     setParts(Arrays.asList(
-        Collections.singleton(this.resource),
-        Collections.singleton(this.operation),
-        Collections.singleton(this.target),
-        Collections.singleton(this.key)));
+        Collections.singleton(resource),
+        Collections.singleton(operation),
+        Collections.singleton(target),
+        Collections.singleton(key)));
   }
 
   public ResourcePermission(Resource resource, Operation operation) {
@@ -169,6 +171,8 @@ public class ResourcePermission extends WildcardPermission {
 
   /**
    * Returns the resource, could be either ALL, NULL, DATA or CLUSTER
+   *
+   * @return the resource as a {@link Resource}
    */
   public Resource getResource() {
     if (ALL.equals(resource)) {
@@ -179,6 +183,8 @@ public class ResourcePermission extends WildcardPermission {
 
   /**
    * Returns the operation, could be either ALL, NULL, MANAGE, WRITE or READ
+   *
+   * @return the operation as an {@link Operation}
    */
   public Operation getOperation() {
     if (ALL.equals(operation)) {
@@ -190,6 +196,8 @@ public class ResourcePermission extends WildcardPermission {
 
   /**
    * could be either "*", "NULL", "DATA", "CLUSTER"
+   *
+   * @return the resource as a String
    */
   public String getResourceString() {
     return resource;
@@ -197,6 +205,8 @@ public class ResourcePermission extends WildcardPermission {
 
   /**
    * Returns the operation, could be either "*", "NULL", "MANAGE", "WRITE" or "READ"
+   *
+   * @return the operation as a String
    */
   public String getOperationString() {
     return operation;
@@ -204,20 +214,27 @@ public class ResourcePermission extends WildcardPermission {
 
   /**
    * returns the regionName, or cluster target, could be "*", meaning all regions or all targets
+   *
+   * @return the regionName, or cluster target
    */
   public String getTarget() {
     return target;
   }
 
   /**
+   * @return the regionName, or cluster target
+   *
    * @deprecated use getTarget()
    */
+  @Deprecated
   public String getRegionName() {
     return getTarget();
   }
 
   /**
    * returns the key, could be "*" meaning all keys.
+   *
+   * @return the key
    */
   public String getKey() {
     return key;
