@@ -85,11 +85,11 @@ public class AbstractRegionMapTest {
     RegionEntry mockRegionEntry = mock(RegionEntry.class);
     VersionHolder mockVersionHolder = mock(VersionHolder.class);
 
-    when(mockAbstractRegionMap.removeTombstone(eq(mockRegionEntry), eq(mockVersionHolder),
-        anyBoolean(), anyBoolean())).thenReturn(true);
+    when(mockAbstractRegionMap.removeTombstone(eq(mockRegionEntry), eq(mockVersionHolder)))
+        .thenReturn(true);
 
     assertThat(
-        mockAbstractRegionMap.removeTombstone(mockRegionEntry, mockVersionHolder, true, true))
+        mockAbstractRegionMap.removeTombstone(mockRegionEntry, mockVersionHolder))
             .isTrue();
   }
 
@@ -707,7 +707,7 @@ public class AbstractRegionMapTest {
     Object newValue = "value";
     arm.txApplyPut(Operation.CREATE, KEY, newValue, false,
         new TXId(mock(InternalDistributedMember.class), 1), mock(TXRmtEvent.class),
-        mock(EventID.class), null, new ArrayList<EntryEventImpl>(), null, null, null, null, 1);
+        mock(EventID.class), null, new ArrayList<>(), null, null, null, null, 1);
     RegionEntry re = arm.getEntry(KEY);
     assertNotNull(re);
 
@@ -886,7 +886,7 @@ public class AbstractRegionMapTest {
   }
 
   @Test
-  public void initialImagePut_givenPutIfAbsentReturningRegionEntryAndSameTombstoneWillAttemptToRemoveREAndInvokeNothingElse()
+  public void initialImagePut_givenPutIfAbsentReturningRegionEntryAndSameTombstoneWillReprocessTheTombstone()
       throws RegionClearedException {
     ConcurrentMapWithReusableEntries map = mock(ConcurrentMapWithReusableEntries.class);
     RegionEntry entry = mock(RegionEntry.class);
@@ -911,8 +911,8 @@ public class AbstractRegionMapTest {
 
     arm.initialImagePut(KEY, 0, Token.TOMBSTONE, false, false, versionTag, null, false);
 
-    verify(map, times(1)).remove(eq(KEY), eq(createdEntry));
-    verify(entry, never()).initialImagePut(any(), anyLong(), any(), anyBoolean(), anyBoolean());
+    verify(map, times(0)).remove(eq(KEY), eq(createdEntry));
+    verify(entry, times(1)).initialImagePut(any(), anyLong(), any(), anyBoolean(), anyBoolean());
   }
 
   @Test
@@ -1165,7 +1165,7 @@ public class AbstractRegionMapTest {
     re.setValue(arm._getOwner(), token);
     arm.txApplyInvalidate(key, Token.INVALID, false,
         new TXId(mock(InternalDistributedMember.class), 1), mock(TXRmtEvent.class), false,
-        mock(EventID.class), null, new ArrayList<EntryEventImpl>(), null, null, null, null, 1);
+        mock(EventID.class), null, new ArrayList<>(), null, null, null, null, 1);
     assertEquals(re.getValueAsToken(), token);
   }
 
@@ -1226,8 +1226,8 @@ public class AbstractRegionMapTest {
 
     @Override
     public RegionEntry getEntry(Object key) {
-      if (this.regionEntryForGetEntry != null) {
-        return this.regionEntryForGetEntry;
+      if (regionEntryForGetEntry != null) {
+        return regionEntryForGetEntry;
       } else {
         return super.getEntry(key);
       }
@@ -1239,7 +1239,7 @@ public class AbstractRegionMapTest {
    * TestableVMLRURegionMap
    */
   private static class TestableVMLRURegionMap extends VMLRURegionMap {
-    private static EvictionAttributes evictionAttributes =
+    private static final EvictionAttributes evictionAttributes =
         EvictionAttributes.createLRUEntryAttributes();
 
     protected TestableVMLRURegionMap() {
@@ -1480,7 +1480,7 @@ public class AbstractRegionMapTest {
 
     arm.txApplyInvalidate(new Object(), Token.INVALID, false,
         txId, mock(TXRmtEvent.class), false,
-        mock(EventID.class), null, new ArrayList<EntryEventImpl>(), null, null, null, null, 1);
+        mock(EventID.class), null, new ArrayList<>(), null, null, null, null, 1);
 
     verify(arm._getOwner()).lockWhenRegionIsInitializing();
     assertThat(arm._getOwner().lockWhenRegionIsInitializing()).isFalse();
@@ -1494,7 +1494,7 @@ public class AbstractRegionMapTest {
 
     arm.txApplyInvalidate(new Object(), Token.INVALID, false,
         txId, mock(TXRmtEvent.class), false,
-        mock(EventID.class), null, new ArrayList<EntryEventImpl>(), null, null, null, null, 1);
+        mock(EventID.class), null, new ArrayList<>(), null, null, null, null, 1);
 
     verify(arm._getOwner()).lockWhenRegionIsInitializing();
     assertThat(arm._getOwner().lockWhenRegionIsInitializing()).isTrue();
