@@ -58,21 +58,21 @@ import org.apache.geode.internal.util.concurrent.ConcurrentMapWithReusableEntrie
 @SuppressWarnings("unchecked")
 public class AbstractRegionMapTxApplyDestroyTest {
   // parameters
-  private Object key = "key";
+  private final Object key = "key";
   @Mock
   private TXId txId;
   private TXRmtEvent txEvent;
   private boolean inTokenMode;
   private boolean inRI;
-  private Operation operation = Operation.DESTROY;
+  private final Operation operation = Operation.DESTROY;
   @Mock
   private EventID eventId;
-  private Object aCallbackArgument = "aCallbackArgument";
+  private final Object aCallbackArgument = "aCallbackArgument";
   private final List<EntryEventImpl> pendingCallbacks = new ArrayList<>();
-  private FilterRoutingInfo filterRoutingInfo = null; // Provide a meaningful value for this?
+  private final FilterRoutingInfo filterRoutingInfo = null; // Provide a meaningful value for this?
   @Mock
   private ClientProxyMembershipID bridgeContext;
-  private boolean isOriginRemote = false;
+  private final boolean isOriginRemote = false;
   @Mock
   private TXEntryState txEntryState;
   private VersionTag versionTag;
@@ -133,7 +133,6 @@ public class AbstractRegionMapTxApplyDestroyTest {
     assertThat(pendingCallbacks).hasSize(1);
     EntryEventImpl callbackEvent = pendingCallbacks.get(0);
 
-    // noinspection Duplicates
     assertSoftly(softly -> {
       softly.assertThat(callbackEvent.getRegion()).isSameAs(owner);
       softly.assertThat(callbackEvent.getOperation()).isSameAs(operation);
@@ -162,13 +161,12 @@ public class AbstractRegionMapTxApplyDestroyTest {
 
     doTxApplyDestroy();
 
-    verify(owner, times(1)).handleWANEvent(any());
-    verify(txEntryState, times(1)).setTailKey(tailKey);
+    verify(owner).txHandleWANEvent(any());
+    verify(txEntryState).setTailKey(tailKey);
 
     assertThat(pendingCallbacks).hasSize(1);
     EntryEventImpl callbackEvent = pendingCallbacks.get(0);
 
-    // noinspection Duplicates
     assertSoftly(softly -> {
       softly.assertThat(callbackEvent.getRegion()).isSameAs(partitionedRegion);
       softly.assertThat(callbackEvent.getOperation()).isSameAs(operation);
@@ -191,7 +189,7 @@ public class AbstractRegionMapTxApplyDestroyTest {
     givenNoRegionEntry();
     givenNotInTokenMode();
     givenNoConcurrencyChecks();
-    doThrow(RuntimeException.class).when(owner).handleWANEvent(any());
+    doThrow(RuntimeException.class).when(owner).txHandleWANEvent(any());
 
     assertThatThrownBy(this::doTxApplyDestroy).isInstanceOf(RuntimeException.class);
 
@@ -242,14 +240,14 @@ public class AbstractRegionMapTxApplyDestroyTest {
     givenLocalRegion();
     givenNoConcurrencyChecks();
     givenExistingRegionEntry();
-    this.inTokenMode = true;
-    this.inRI = false;
+    inTokenMode = true;
+    inRI = false;
 
     doTxApplyDestroy();
 
     assertThat(pendingCallbacks).isEmpty();
     verify(owner, times(1)).txApplyDestroyPart2(same(existingRegionEntry), eq(key),
-        eq(this.inTokenMode), eq(false), eq(false));
+        eq(inTokenMode), eq(false), eq(false));
   }
 
   @Test
@@ -258,8 +256,8 @@ public class AbstractRegionMapTxApplyDestroyTest {
     givenLocalRegion();
     givenConcurrencyChecks();
     givenExistingRegionEntry();
-    this.inTokenMode = true;
-    this.inRI = false;
+    inTokenMode = true;
+    inRI = false;
 
     doTxApplyDestroy();
 
@@ -604,14 +602,26 @@ public class AbstractRegionMapTxApplyDestroyTest {
   }
 
   @Test
-  public void txApplyDestroyCallsHandleWanEvent_givenExistingRegionEntryWithPartitionedRegion() {
+  public void txApplyDestroyCallsTxHandleWanEvent_givenExistingRegionEntryWithPartitionedRegion() {
     givenBucketRegion();
     givenExistingRegionEntry();
 
     doTxApplyDestroy();
 
-    verify(owner, times(1)).handleWANEvent(any());
-    verify(txEntryState, times(1)).setTailKey(tailKey);
+    verify(owner).txHandleWANEvent(any());
+    verify(txEntryState).setTailKey(tailKey);
+  }
+
+  @Test
+  public void txApplyDestroyDoesNotSetTailKey_givenTailKeyIsNegativeOne() {
+    givenBucketRegion();
+    givenExistingRegionEntry();
+    tailKey = -1;
+
+    doTxApplyDestroy();
+
+    verify(owner).txHandleWANEvent(any());
+    verify(txEntryState, never()).setTailKey(tailKey);
   }
 
   @Test
@@ -915,15 +925,15 @@ public class AbstractRegionMapTxApplyDestroyTest {
   }
 
   @Test
-  public void txApplyDestroyCallsHandleWanEvent_givenFactoryRegionEntryWithPartitionedRegion() {
+  public void txApplyDestroyCallsTxHandleWanEvent_givenFactoryRegionEntryWithPartitionedRegion() {
     givenBucketRegion();
     givenConcurrencyChecks();
     givenFactoryRegionEntry();
 
     doTxApplyDestroy();
 
-    verify(owner, times(1)).handleWANEvent(any());
-    verify(txEntryState, times(1)).setTailKey(tailKey);
+    verify(owner).txHandleWANEvent(any());
+    verify(txEntryState).setTailKey(tailKey);
   }
 
   @Test
@@ -1177,7 +1187,6 @@ public class AbstractRegionMapTxApplyDestroyTest {
     assertThat(pendingCallbacks).hasSize(1);
     EntryEventImpl callbackEvent = pendingCallbacks.get(0);
 
-    // noinspection Duplicates
     assertSoftly(softly -> {
       softly.assertThat(callbackEvent.getRegion()).isSameAs(owner);
       softly.assertThat(callbackEvent.getOperation()).isSameAs(operation);
@@ -1273,15 +1282,15 @@ public class AbstractRegionMapTxApplyDestroyTest {
   }
 
   @Test
-  public void txApplyDestroyCallsHandleWanEvent_givenOldRegionEntryWithPartitionedRegion() {
+  public void txApplyDestroyCallsTxHandleWanEvent_givenOldRegionEntryWithPartitionedRegion() {
     givenBucketRegion();
     givenConcurrencyChecks();
     givenOldRegionEntry();
 
     doTxApplyDestroy();
 
-    verify(owner, times(1)).handleWANEvent(any());
-    verify(txEntryState, times(1)).setTailKey(tailKey);
+    verify(owner).txHandleWANEvent(any());
+    verify(txEntryState).setTailKey(tailKey);
   }
 
   @Test
@@ -1334,7 +1343,6 @@ public class AbstractRegionMapTxApplyDestroyTest {
 
     EntryEventImpl callbackEvent = pendingCallbacks.get(0);
 
-    // noinspection Duplicates
     assertSoftly(softly -> {
       softly.assertThat(callbackEvent.getRegion()).isSameAs(partitionedRegion);
       softly.assertThat(callbackEvent.getOperation()).isSameAs(operation);
