@@ -19,7 +19,7 @@ import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyString;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.RETURNS_DEEP_STUBS;
 import static org.mockito.Mockito.doCallRealMethod;
 import static org.mockito.Mockito.inOrder;
@@ -30,16 +30,18 @@ import static org.mockito.Mockito.when;
 
 import java.util.Collections;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.mockito.InOrder;
 
 import org.apache.geode.cache.DataPolicy;
 import org.apache.geode.cache.wan.GatewaySender;
 import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.internal.cache.event.EventTracker;
 import org.apache.geode.internal.cache.versions.RegionVersionHolder;
 import org.apache.geode.internal.cache.versions.RegionVersionVector;
 import org.apache.geode.internal.cache.versions.VersionSource;
+import org.apache.geode.internal.cache.versions.VersionTag;
 import org.apache.geode.internal.cache.wan.AsyncEventQueueConfigurationException;
 import org.apache.geode.internal.cache.wan.GatewaySenderConfigurationException;
 
@@ -49,26 +51,31 @@ public class DistributedRegionTest {
   private RegionVersionHolder<VersionSource<Object>> holder;
   private VersionSource<Object> lostMemberVersionID;
   private InternalDistributedMember member;
+  private EntryEventImpl event;
+  private EventTracker eventTracker;
+  private DistributedRegion distributedRegion;
 
-  @Before
+  @BeforeEach
   @SuppressWarnings("unchecked")
   public void setup() {
     vector = mock(RegionVersionVector.class);
     holder = mock(RegionVersionHolder.class);
     lostMemberVersionID = mock(VersionSource.class);
     member = mock(InternalDistributedMember.class);
+    event = mock(EntryEventImpl.class);
+    eventTracker = mock(EventTracker.class);
+    distributedRegion = mock(DistributedRegion.class);
   }
 
   @Test
   public void shouldBeMockable() throws Exception {
-    DistributedRegion mockDistributedRegion = mock(DistributedRegion.class);
     EntryEventImpl mockEntryEventImpl = mock(EntryEventImpl.class);
     Object returnValue = new Object();
 
-    when(mockDistributedRegion.validatedDestroy(any(), eq(mockEntryEventImpl)))
+    when(distributedRegion.validatedDestroy(any(), eq(mockEntryEventImpl)))
         .thenReturn(returnValue);
 
-    assertThat(mockDistributedRegion.validatedDestroy(new Object(), mockEntryEventImpl))
+    assertThat(distributedRegion.validatedDestroy(new Object(), mockEntryEventImpl))
         .isSameAs(returnValue);
   }
 
@@ -90,7 +97,6 @@ public class DistributedRegionTest {
 
   @Test
   public void cleanUpAfterFailedInitialImageDoesNotCloseEntriesIfIsPersistentRegionAndRecoveredFromDisk() {
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     DiskRegion diskRegion = mock(DiskRegion.class);
 
     doCallRealMethod().when(distributedRegion).cleanUpAfterFailedGII(true);
@@ -105,7 +111,6 @@ public class DistributedRegionTest {
 
   @Test
   public void lockHeldWhenRegionIsNotInitialized() {
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     doCallRealMethod().when(distributedRegion).lockWhenRegionIsInitializing();
     when(distributedRegion.isInitialized()).thenReturn(false);
 
@@ -115,7 +120,6 @@ public class DistributedRegionTest {
 
   @Test
   public void lockNotHeldWhenRegionIsInitialized() {
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     doCallRealMethod().when(distributedRegion).lockWhenRegionIsInitializing();
     when(distributedRegion.isInitialized()).thenReturn(true);
 
@@ -125,7 +129,6 @@ public class DistributedRegionTest {
 
   @Test
   public void versionHolderInvokesSetRegionSynchronizeScheduledIfVectorContainsLostMemberID() {
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     when(distributedRegion.getVersionVector()).thenReturn(vector);
     when(vector.getHolderForMember(lostMemberVersionID)).thenReturn(holder);
     doCallRealMethod().when(distributedRegion).setRegionSynchronizeScheduled(lostMemberVersionID);
@@ -137,7 +140,6 @@ public class DistributedRegionTest {
 
   @Test
   public void versionHolderInvokesSetRegionSynchronizeScheduledOrDoneIfNotIfVectorContainsLostMemberID() {
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     when(distributedRegion.getVersionVector()).thenReturn(vector);
     when(vector.getHolderForMember(lostMemberVersionID)).thenReturn(holder);
     doCallRealMethod().when(distributedRegion)
@@ -152,7 +154,6 @@ public class DistributedRegionTest {
 
   @Test
   public void setRegionSynchronizedWithIfNotScheduledReturnsFalseIfVectorDoesNotContainLostMemberID() {
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     when(distributedRegion.getVersionVector()).thenReturn(vector);
     when(vector.getHolderForMember(lostMemberVersionID)).thenReturn(holder);
 
@@ -164,7 +165,6 @@ public class DistributedRegionTest {
 
   @Test
   public void regionSyncInvokedInPerformSynchronizeForLostMemberTaskAfterRegionInitialized() {
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     when(distributedRegion.getDataPolicy()).thenReturn(mock(DataPolicy.class));
     when(distributedRegion.isInitializedWithWait()).thenReturn(true);
     doCallRealMethod().when(distributedRegion).performSynchronizeForLostMemberTask(member,
@@ -179,7 +179,6 @@ public class DistributedRegionTest {
 
   @Test
   public void regionSyncNotInvokedInPerformSynchronizeForLostMemberTaskIfRegionNotInitialized() {
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     when(distributedRegion.getDataPolicy()).thenReturn(mock(DataPolicy.class));
     when(distributedRegion.isInitializedWithWait()).thenReturn(false);
     doCallRealMethod().when(distributedRegion).performSynchronizeForLostMemberTask(member,
@@ -195,7 +194,6 @@ public class DistributedRegionTest {
     InternalCache internalCache = mock(InternalCache.class);
     when(internalCache.getAllGatewaySenders())
         .thenReturn(Collections.singleton(mock(GatewaySender.class)));
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     when(distributedRegion.getCache()).thenReturn(internalCache);
     doCallRealMethod().when(distributedRegion).validateAsynchronousEventDispatcher(anyString());
 
@@ -210,7 +208,6 @@ public class DistributedRegionTest {
     when(serialSender.getId()).thenReturn(senderId);
     InternalCache internalCache = mock(InternalCache.class);
     when(internalCache.getAllGatewaySenders()).thenReturn(Collections.singleton(serialSender));
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     when(distributedRegion.getCache()).thenReturn(internalCache);
     doCallRealMethod().when(distributedRegion).validateAsynchronousEventDispatcher(anyString());
 
@@ -228,7 +225,6 @@ public class DistributedRegionTest {
     InternalCache internalCache = mock(InternalCache.class);
     when(internalCache.getAllGatewaySenders())
         .thenReturn(Collections.singleton(parallelAsyncEventQueue));
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     when(distributedRegion.getCache()).thenReturn(internalCache);
     when(distributedRegion.getFullPath()).thenReturn(regionPath);
     doCallRealMethod().when(distributedRegion).validateAsynchronousEventDispatcher(anyString());
@@ -250,7 +246,6 @@ public class DistributedRegionTest {
     InternalCache internalCache = mock(InternalCache.class);
     when(internalCache.getAllGatewaySenders())
         .thenReturn(Collections.singleton(parallelGatewaySender));
-    DistributedRegion distributedRegion = mock(DistributedRegion.class);
     when(distributedRegion.getCache()).thenReturn(internalCache);
     when(distributedRegion.getFullPath()).thenReturn(regionPath);
     doCallRealMethod().when(distributedRegion).validateAsynchronousEventDispatcher(anyString());
@@ -260,4 +255,123 @@ public class DistributedRegionTest {
         .hasMessage("Parallel Gateway Sender " + senderId
             + " can not be used with replicated region " + regionPath);
   }
+
+  @Test
+  public void hasSeenEventDoesNotFindAndSetVersionTagIfFoundInEventTrackerAndVersionTagIsSet() {
+    doCallRealMethod().when(distributedRegion).hasSeenEvent(event);
+    when(distributedRegion.getEventTracker()).thenReturn(eventTracker);
+    when(eventTracker.hasSeenEvent(event)).thenReturn(true);
+    when(event.getVersionTag()).thenReturn(mock(VersionTag.class));
+
+    assertThat(distributedRegion.hasSeenEvent(event)).isTrue();
+    verify(distributedRegion).markEventAsDuplicate(event);
+    verify(distributedRegion, never()).findAndSetVersionTag(event);
+  }
+
+  @Test
+  public void hasSeenEventDoesNotFindAndSetVersionTagIfFoundInEventTrackerAndConcurrencyChecksNotEnabled() {
+    doCallRealMethod().when(distributedRegion).hasSeenEvent(event);
+    when(distributedRegion.getEventTracker()).thenReturn(eventTracker);
+    when(eventTracker.hasSeenEvent(event)).thenReturn(true);
+    when(event.getRegion()).thenReturn(distributedRegion);
+    when(distributedRegion.getConcurrencyChecksEnabled()).thenReturn(false);
+
+    assertThat(distributedRegion.hasSeenEvent(event)).isTrue();
+    verify(distributedRegion).markEventAsDuplicate(event);
+    verify(distributedRegion, never()).findAndSetVersionTag(event);
+  }
+
+  @Test
+  public void hasSeenEventDoesNotFindAndSetVersionTagIfFoundInEventTrackerAndEventIdIsNotSet() {
+    doCallRealMethod().when(distributedRegion).hasSeenEvent(event);
+    when(distributedRegion.getEventTracker()).thenReturn(eventTracker);
+    when(eventTracker.hasSeenEvent(event)).thenReturn(true);
+    when(event.getRegion()).thenReturn(distributedRegion);
+    when(distributedRegion.getConcurrencyChecksEnabled()).thenReturn(false);
+    when(event.getEventId()).thenReturn(null);
+
+    assertThat(distributedRegion.hasSeenEvent(event)).isTrue();
+    verify(distributedRegion).markEventAsDuplicate(event);
+    verify(distributedRegion, never()).findAndSetVersionTag(event);
+  }
+
+  @Test
+  public void hasSeenEventWillFindAndSetVersionTagIfFoundInEventTrackerButValidTagNotSet() {
+    doCallRealMethod().when(distributedRegion).hasSeenEvent(event);
+    when(distributedRegion.getEventTracker()).thenReturn(eventTracker);
+    when(eventTracker.hasSeenEvent(event)).thenReturn(true);
+    when(event.getRegion()).thenReturn(distributedRegion);
+    when(distributedRegion.getConcurrencyChecksEnabled()).thenReturn(true);
+    when(event.getEventId()).thenReturn(mock(EventID.class));
+
+    assertThat(distributedRegion.hasSeenEvent(event)).isTrue();
+    verify(distributedRegion).markEventAsDuplicate(event);
+    verify(distributedRegion).findAndSetVersionTag(event);
+  }
+
+  @Test
+  public void hasSeenEventDoesNotFindAndSetVersionTagIfNotFoundEventInEventTrackerAndNotADuplicateEvent() {
+    doCallRealMethod().when(distributedRegion).hasSeenEvent(event);
+    when(distributedRegion.getEventTracker()).thenReturn(eventTracker);
+    when(eventTracker.hasSeenEvent(event)).thenReturn(false);
+    when(event.isPossibleDuplicate()).thenReturn(false);
+
+    assertThat(distributedRegion.hasSeenEvent(event)).isFalse();
+    verify(distributedRegion, never()).findAndSetVersionTag(event);
+  }
+
+  @Test
+  public void hasSeenEventDoesNotFindAndSetVersionTagIfNotFoundInEventTrackerAndConcurrencyChecksNotEnabled() {
+    doCallRealMethod().when(distributedRegion).hasSeenEvent(event);
+    when(distributedRegion.getEventTracker()).thenReturn(eventTracker);
+    when(eventTracker.hasSeenEvent(event)).thenReturn(false);
+    when(event.isPossibleDuplicate()).thenReturn(true);
+    when(event.getRegion()).thenReturn(distributedRegion);
+    when(distributedRegion.getConcurrencyChecksEnabled()).thenReturn(false);
+
+    assertThat(distributedRegion.hasSeenEvent(event)).isFalse();
+    verify(distributedRegion, never()).findAndSetVersionTag(event);
+  }
+
+  @Test
+  public void hasSeenEventDoesNotFindAndSetVersionTagIfNotFoundInEventTrackerAndVersionTagIsSet() {
+    doCallRealMethod().when(distributedRegion).hasSeenEvent(event);
+    when(distributedRegion.getEventTracker()).thenReturn(eventTracker);
+    when(eventTracker.hasSeenEvent(event)).thenReturn(false);
+    when(event.isPossibleDuplicate()).thenReturn(true);
+    when(event.getRegion()).thenReturn(distributedRegion);
+    when(distributedRegion.getConcurrencyChecksEnabled()).thenReturn(true);
+    when(event.getVersionTag()).thenReturn(mock(VersionTag.class));
+
+    assertThat(distributedRegion.hasSeenEvent(event)).isFalse();
+    verify(distributedRegion, never()).findAndSetVersionTag(event);
+  }
+
+  @Test
+  public void hasSeenEventDoesNotFindAndSetVersionTagIfNotFoundInEventTrackerAndNoEventId() {
+    doCallRealMethod().when(distributedRegion).hasSeenEvent(event);
+    when(distributedRegion.getEventTracker()).thenReturn(eventTracker);
+    when(eventTracker.hasSeenEvent(event)).thenReturn(false);
+    when(event.isPossibleDuplicate()).thenReturn(true);
+    when(event.getRegion()).thenReturn(distributedRegion);
+    when(distributedRegion.getConcurrencyChecksEnabled()).thenReturn(true);
+    when(event.getEventId()).thenReturn(null);
+
+    assertThat(distributedRegion.hasSeenEvent(event)).isFalse();
+    verify(distributedRegion, never()).findAndSetVersionTag(event);
+  }
+
+  @Test
+  public void hasSeenEventWillFindAndSetVersionTagIfNotFoundInEventTrackerAndIsPossibleDuplicateWithConcurrencyChecksEnabled() {
+    doCallRealMethod().when(distributedRegion).hasSeenEvent(event);
+    when(distributedRegion.getEventTracker()).thenReturn(eventTracker);
+    when(eventTracker.hasSeenEvent(event)).thenReturn(false);
+    when(event.isPossibleDuplicate()).thenReturn(true);
+    when(event.getRegion()).thenReturn(distributedRegion);
+    when(distributedRegion.getConcurrencyChecksEnabled()).thenReturn(true);
+    when(event.getEventId()).thenReturn(mock(EventID.class));
+
+    assertThat(distributedRegion.hasSeenEvent(event)).isFalse();
+    verify(distributedRegion).findAndSetVersionTag(event);
+  }
 }
