@@ -16,15 +16,19 @@ package org.apache.geode.internal.cache;
 
 import static java.util.Collections.emptySet;
 import static org.apache.geode.cache.asyncqueue.internal.AsyncEventQueueImpl.getSenderIdFromAsyncEventQueueId;
+import static org.apache.geode.internal.cache.PartitionedRegionHelper.PR_ROOT_REGION_NAME;
 import static org.apache.geode.internal.statistics.StatisticsClockFactory.disabledClock;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatCode;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.assertj.core.api.Assertions.catchThrowable;
 import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyBoolean;
 import static org.mockito.ArgumentMatchers.anyInt;
 import static org.mockito.ArgumentMatchers.anyLong;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.ArgumentMatchers.isNull;
+import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.mock;
@@ -39,10 +43,12 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
 
-import junitparams.JUnitParamsRunner;
 import junitparams.Parameters;
 import junitparams.naming.TestCaseName;
+import org.jetbrains.annotations.NotNull;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
@@ -53,25 +59,35 @@ import org.mockito.junit.MockitoRule;
 import org.apache.geode.CancelCriterion;
 import org.apache.geode.Statistics;
 import org.apache.geode.cache.AttributesFactory;
+import org.apache.geode.cache.CacheClosedException;
 import org.apache.geode.cache.CacheLoader;
 import org.apache.geode.cache.CacheWriter;
 import org.apache.geode.cache.Operation;
 import org.apache.geode.cache.PartitionAttributesFactory;
 import org.apache.geode.cache.Region;
 import org.apache.geode.cache.RegionDestroyedException;
+import org.apache.geode.cache.RegionShortcut;
 import org.apache.geode.cache.TransactionDataRebalancedException;
 import org.apache.geode.cache.TransactionException;
 import org.apache.geode.cache.asyncqueue.AsyncEventQueue;
+import org.apache.geode.cache.query.Index;
+import org.apache.geode.cache.query.MultiIndexCreationException;
+import org.apache.geode.cache.query.internal.index.IndexCreationData;
+import org.apache.geode.cache.query.internal.index.IndexManager;
 import org.apache.geode.cache.wan.GatewaySender;
 import org.apache.geode.distributed.DistributedLockService;
+import org.apache.geode.distributed.DistributedSystemDisconnectedException;
+import org.apache.geode.distributed.LockServiceDestroyedException;
 import org.apache.geode.distributed.internal.DSClock;
 import org.apache.geode.distributed.internal.DistributionManager;
 import org.apache.geode.distributed.internal.InternalDistributedSystem;
 import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
 import org.apache.geode.internal.cache.control.InternalResourceManager;
+import org.apache.geode.internal.cache.partitioned.RegionAdvisor;
 import org.apache.geode.internal.cache.partitioned.colocation.ColocationLoggerFactory;
+import org.apache.geode.test.junit.runners.GeodeParamsRunner;
 
-@RunWith(JUnitParamsRunner.class)
+@RunWith(GeodeParamsRunner.class)
 @SuppressWarnings({"deprecation", "unchecked", "unused"})
 public class PartitionedRegionTest {
 
@@ -83,6 +99,9 @@ public class PartitionedRegionTest {
 
   private PartitionedRegion partitionedRegion;
 
+  private final String indexName = "index";
+  private final Index index = mock(Index.class);
+
   @Rule
   public MockitoRule mockitoRule = MockitoJUnit.rule().strictness(STRICT_STUBS);
 
@@ -117,7 +136,8 @@ public class PartitionedRegionTest {
 
     partitionedRegion = new PartitionedRegion("regionName", attributesFactory.create(), null,
         cache, mock(InternalRegionArguments.class), disabledClock(),
-        ColocationLoggerFactory.create());
+        ColocationLoggerFactory.create(),
+        region -> mock(RegionAdvisor.class));
   }
 
   private Object[] cacheLoaderAndWriter() {
@@ -131,6 +151,23 @@ public class PartitionedRegionTest {
     };
   }
 
+  @Test
+  public void postDestroyRegionForCacheCloseWillCloseDataStoreStats() {
+    PartitionedRegionDataStore dataStore = mock(PartitionedRegionDataStore.class);
+    CachePerfStats dataStoreStats = mock(CachePerfStats.class);
+    when(dataStore.getCachePerfStats()).thenReturn(dataStoreStats);
+    partitionedRegion.setDataStore(dataStore);
+    partitionedRegion.setClosed();
+    when(cache.getInternalResourceManager(anyBoolean()))
+        .thenReturn(mock(InternalResourceManager.class));
+    RegionEventImpl event = mock(RegionEventImpl.class);
+    when(event.getOperation()).thenReturn(Operation.CACHE_CLOSE);
+
+    partitionedRegion.postDestroyRegion(false, event);
+
+    verify(dataStoreStats).close();
+  }
+
   @Test
   @Parameters(method = "cacheLoaderAndWriter")
   @TestCaseName("{method}(CacheLoader={0}, CacheWriter={1})")
@@ -443,6 +480,40 @@ public class PartitionedRegionTest {
         .doesNotThrowAnyException();
   }
 
+  @Test
+  public void registerPartitionedRegionShouldHandleLockServiceDestroyedException()
+      throws ClassNotFoundException {
+    AttributesFactory attributesFactory = new AttributesFactory();
+    attributesFactory.setPartitionAttributes(
+        new PartitionAttributesFactory().setTotalNumBuckets(1).setRedundantCopies(1)
+            .setLocalMaxMemory(0).create());
+
+    partitionedRegion = new PartitionedRegion("region", attributesFactory.create(), null, cache,
+        mock(InternalRegionArguments.class), disabledClock(), ColocationLoggerFactory.create());
+
+    PartitionedRegion spyPartitionedRegion = spy(partitionedRegion);
+
+    InternalDistributedMember imageTarget = mock(InternalDistributedMember.class);
+    InternalRegionFactory factory = mock(InternalRegionFactory.class);
+    DistributedRegion partitionedRegionRoot = mock(DistributedRegion.class);
+    CacheDistributionAdvisor cda = mock(CacheDistributionAdvisor.class);
+    PartitionedRegion.RegionLock regionLock = mock(PartitionedRegion.RegionLock.class);
+
+    when(cache.createInternalRegionFactory(RegionShortcut.REPLICATE)).thenReturn(factory);
+    when(factory.create(PR_ROOT_REGION_NAME)).thenReturn(partitionedRegionRoot);
+    doNothing().when(cda).addMembershipListener(any());
+    when(partitionedRegionRoot.getDistributionAdvisor()).thenReturn(cda);
+    doReturn(regionLock).when(spyPartitionedRegion).getRegionLock();
+    doThrow(new LockServiceDestroyedException("Lock Service is destroyed in test")).when(regionLock)
+        .lock();
+    doThrow(new DistributedSystemDisconnectedException("test")).when(spyPartitionedRegion)
+        .cleanupFailedInitialization();
+
+    assertThatThrownBy(() -> spyPartitionedRegion.initialize(null, imageTarget, null))
+        .isInstanceOf(PartitionedRegionException.class)
+        .hasCauseInstanceOf(DistributedSystemDisconnectedException.class);
+  }
+
   @Test
   public void getDataRegionForWriteThrowsTransactionExceptionIfNotDataStore() {
     PartitionedRegion spyPartitionedRegion = spy(partitionedRegion);
@@ -597,6 +668,139 @@ public class PartitionedRegionTest {
     assertThat(partitionedRegion.isRegionCreateNotified()).isTrue();
   }
 
+  @Test
+  public void populateEmptyIndexesThrowsIfBucketRegionDestroyedDueToCacheClose() {
+    PartitionedRegion spyPartitionedRegion = spy(partitionedRegion);
+    BucketRegion bucketRegion = mock(BucketRegion.class);
+    when(bucketRegion.isDestroyed()).thenReturn(true);
+
+    Set<Index> indexes = setupIndexes();
+    ConcurrentMap<Integer, BucketRegion> map = setupBuckets(bucketRegion);
+    setupDataStore(spyPartitionedRegion, map);
+    CacheClosedException cacheClosedException = new CacheClosedException();
+    setupCancelCriterion(cacheClosedException);
+
+    assertThatThrownBy(() -> spyPartitionedRegion.populateEmptyIndexes(indexes, new HashMap<>()))
+        .isEqualTo(cacheClosedException);
+  }
+
+  @NotNull
+  private Set<Index> setupIndexes() {
+    Set<Index> indexes = new HashSet<>();
+    Index index = mock(Index.class);
+    indexes.add(index);
+    return indexes;
+  }
+
+  @NotNull
+  private ConcurrentMap<Integer, BucketRegion> setupBuckets(BucketRegion bucketRegion) {
+    ConcurrentMap<Integer, BucketRegion> map = new ConcurrentHashMap<>();
+    map.put(1, bucketRegion);
+    return map;
+  }
+
+  private void setupDataStore(PartitionedRegion spyPartitionedRegion,
+      ConcurrentMap<Integer, BucketRegion> map) {
+    PartitionedRegionDataStore dataStore = mock(PartitionedRegionDataStore.class);
+    doReturn(dataStore).when(spyPartitionedRegion).getDataStore();
+    when(dataStore.getAllLocalBuckets()).thenReturn(map.entrySet());
+  }
+
+  private void setupCancelCriterion(CacheClosedException cacheClosedException) {
+    CancelCriterion cancelCriterion = mock(CancelCriterion.class);
+    when(cache.getCancelCriterion()).thenReturn(cancelCriterion);
+    doThrow(cacheClosedException).when(cancelCriterion).checkCancelInProgress();
+  }
+
+  @Test
+  public void populateEmptyIndexesReturnsFalseIfIndexManagerPopulateIndexesSuccessfully() {
+    PartitionedRegion spyPartitionedRegion = spy(partitionedRegion);
+    IndexManager indexManager = mock(IndexManager.class);
+    BucketRegion bucketRegion = mock(BucketRegion.class);
+    when(bucketRegion.getIndexManager()).thenReturn(indexManager);
+
+    Set<Index> indexes = setupIndexes();
+    ConcurrentMap<Integer, BucketRegion> map = setupBuckets(bucketRegion);
+    setupDataStore(spyPartitionedRegion, map);
+    doReturn(indexes).when(spyPartitionedRegion).getBucketIndexesForPRIndexes(bucketRegion,
+        indexes);
+
+    assertThat(spyPartitionedRegion.populateEmptyIndexes(indexes, new HashMap<>())).isFalse();
+  }
+
+  @Test
+  public void populateEmptyIndexesReturnsTrueIfIndexManagerPopulateIndexesThrows()
+      throws Exception {
+    PartitionedRegion spyPartitionedRegion = spy(partitionedRegion);
+    IndexManager indexManager = mock(IndexManager.class);
+    BucketRegion bucketRegion = mock(BucketRegion.class);
+    when(bucketRegion.getIndexManager()).thenReturn(indexManager);
+    MultiIndexCreationException exception = mock(MultiIndexCreationException.class);
+
+    Set<Index> indexes = setupIndexes();
+    ConcurrentMap<Integer, BucketRegion> map = setupBuckets(bucketRegion);
+    setupDataStore(spyPartitionedRegion, map);
+    doReturn(indexes).when(spyPartitionedRegion).getBucketIndexesForPRIndexes(bucketRegion,
+        indexes);
+    doThrow(exception).when(indexManager).populateIndexes(indexes);
+
+    assertThat(spyPartitionedRegion.populateEmptyIndexes(indexes, new HashMap<>())).isTrue();
+  }
+
+  @Test
+  public void createEmptyIndexesCanAddIndexToIndexSet() throws Exception {
+    PartitionedRegion spyPartitionedRegion = spy(partitionedRegion);
+    HashSet<IndexCreationData> indexDefinitions = setupIndexCreationData();
+    Set<Index> indexes = new HashSet<>();
+    HashMap<String, Exception> exceptionsMap = new HashMap<>();
+    doReturn(index).when(spyPartitionedRegion).createIndex(true, null, indexName, null, null, null,
+        false, false);
+
+    assertThat(
+        spyPartitionedRegion.createEmptyIndexes(indexDefinitions, true, indexes, exceptionsMap))
+            .isFalse();
+    assertThat(indexes).contains(index);
+    assertThat(exceptionsMap).hasSize(0);
+  }
+
+  @Test
+  public void createEmptyIndexesThrowsIfCreateIndexFailedWithCacheClosedException()
+      throws Exception {
+    PartitionedRegion spyPartitionedRegion = spy(partitionedRegion);
+    HashSet<IndexCreationData> indexDefinitions = setupIndexCreationData();
+    CacheClosedException exception = new CacheClosedException();
+    doThrow(exception).when(spyPartitionedRegion).createIndex(true, null, indexName, null, null,
+        null, false, false);
+
+    assertThatThrownBy(() -> spyPartitionedRegion.createEmptyIndexes(indexDefinitions, true,
+        new HashSet<>(), new HashMap<>())).isEqualTo(exception);
+  }
+
+  @Test
+  public void createEmptyIndexesAddsExceptionToMapIfCreateIndexFailed() throws Exception {
+    PartitionedRegion spyPartitionedRegion = spy(partitionedRegion);
+    HashSet<IndexCreationData> indexDefinitions = setupIndexCreationData();
+    Set<Index> indexes = new HashSet<>();
+    HashMap<String, Exception> exceptionsMap = new HashMap<>();
+    RuntimeException runtimeException = new RuntimeException();
+    doThrow(runtimeException).when(spyPartitionedRegion).createIndex(true, null, indexName, null,
+        null, null, false, false);
+
+    assertThat(
+        spyPartitionedRegion.createEmptyIndexes(indexDefinitions, true, indexes, exceptionsMap))
+            .isTrue();
+    assertThat(indexes).hasSize(0);
+    assertThat(exceptionsMap.get(indexName)).isEqualTo(runtimeException);
+  }
+
+  @NotNull
+  private HashSet<IndexCreationData> setupIndexCreationData() {
+    HashSet<IndexCreationData> indexDefinitions = new HashSet<>();
+    IndexCreationData indexCreationData = new IndexCreationData(indexName);
+    indexDefinitions.add(indexCreationData);
+    return indexDefinitions;
+  }
+
   private static <K> Set<K> asSet(K... values) {
     Set<K> set = new HashSet<>();
     Collections.addAll(set, values);
