@@ -109,7 +109,7 @@ public class RegionMapPutTest {
     givenExistingRegionEntry();
     givenAnOperationThatDoesNotGuaranteeOldValue();
     givenPutDoesNotNeedToDoCacheWrite();
-    this.requireOldValue = false;
+    requireOldValue = false;
 
     Object oldValue = new Object();
     when(existingRegionEntry.getValue()).thenReturn(oldValue);
@@ -137,7 +137,7 @@ public class RegionMapPutTest {
   public void doesNotSetEventOldValueIfRetriedPutIfAbsentOperation() {
     final byte[] bytes = new byte[] {1, 2, 3, 4, 5};
     givenExistingRegionEntry();
-    when(existingRegionEntry.getValue()).thenReturn(bytes);
+    when(existingRegionEntry.getValueRetain(internalRegion)).thenReturn(bytes);
     when(internalRegion.getConcurrencyChecksEnabled()).thenReturn(true);
     givenPutIfAbsentOperation(bytes); // duplicate operation
     doPut();
@@ -145,9 +145,35 @@ public class RegionMapPutTest {
     assertThat(instance.isOverwritePutIfAbsent()).isTrue();
   }
 
+  @Test
+  public void doesNotSetEventOldValueIfRetriedPutIfAbsentOperationOfNull() {
+    givenExistingRegionEntry();
+    when(existingRegionEntry.getValueRetain(internalRegion)).thenReturn(Token.INVALID);
+    when(internalRegion.getConcurrencyChecksEnabled()).thenReturn(true);
+    givenPutIfAbsentOperation(null); // duplicate operation
+    doPut();
+    verify(event).setOldValue(null, true);
+    assertThat(instance.isOverwritePutIfAbsent()).isTrue();
+  }
+
+  @Test
+  public void overWritePutIfAbsentIsTrueIfRetriedPutIfAbsentOperationHavingValidVersionTag() {
+    final byte[] bytes = new byte[] {1, 2, 3, 4, 5};
+    givenExistingRegionEntry();
+    when(existingRegionEntry.getValueRetain(internalRegion)).thenReturn(bytes);
+    when(internalRegion.getConcurrencyChecksEnabled()).thenReturn(true);
+    givenPutIfAbsentOperation(bytes); // duplicate operation
+    when(event.hasValidVersionTag()).thenReturn(true);
+
+    doPut();
+
+    verify(event).setOldValue(null, true);
+    assertThat(instance.isOverwritePutIfAbsent()).isTrue();
+  }
+
   private void givenPutIfAbsentOperation(byte[] bytes) {
     when(event.isPossibleDuplicate()).thenReturn(true);
-    when(event.basicGetNewValue()).thenReturn(bytes);
+    when(event.getRawNewValue()).thenReturn(bytes);
     when(event.getOperation()).thenReturn(Operation.PUT_IF_ABSENT);
     when(event.hasValidVersionTag()).thenReturn(false);
     ifNew = true;
@@ -201,7 +227,7 @@ public class RegionMapPutTest {
 
   @Test
   public void setsEventOldValueToExistingRegionEntryValue_ifIsRequiredOldValueAndOperationDoesNotGuaranteeOldValue() {
-    this.requireOldValue = true;
+    requireOldValue = true;
     givenExistingRegionEntry();
     givenAnOperationThatDoesNotGuaranteeOldValue();
 
@@ -333,12 +359,12 @@ public class RegionMapPutTest {
   public void cacheWriteBeforePutCalledWithRequireOldValue_givenRequireOldValueTrue() {
     givenPutNeedsToDoCacheWrite();
     when(internalRegion.isInitialized()).thenReturn(true);
-    this.requireOldValue = true;
+    requireOldValue = true;
 
     doPut();
 
     verify(internalRegion, times(1)).cacheWriteBeforePut(same(event), any(), any(),
-        eq(this.requireOldValue), eq(null));
+        eq(requireOldValue), eq(null));
   }
 
   @Test
@@ -810,7 +836,7 @@ public class RegionMapPutTest {
     when(event.getOperation()).thenReturn(Operation.CREATE);
     doThrow(ConcurrentCacheModificationException.class).when(event).putNewEntry(any(), any());
 
-    assertThatThrownBy(() -> doPut()).isInstanceOf(ConcurrentCacheModificationException.class);
+    assertThatThrownBy(this::doPut).isInstanceOf(ConcurrentCacheModificationException.class);
 
     verify(event, times(1)).getVersionTag();
   }
@@ -825,7 +851,7 @@ public class RegionMapPutTest {
     when(versionTag.isTimeStampUpdated()).thenReturn(true);
     when(event.getVersionTag()).thenReturn(versionTag);
 
-    assertThatThrownBy(() -> doPut()).isInstanceOf(ConcurrentCacheModificationException.class);
+    assertThatThrownBy(this::doPut).isInstanceOf(ConcurrentCacheModificationException.class);
 
     verify(internalRegion, times(1)).notifyTimestampsToGateways(same(event));
   }
@@ -837,7 +863,7 @@ public class RegionMapPutTest {
     when(focusedRegionMap.disableLruUpdateCallback()).thenReturn(true);
     doThrow(DiskAccessException.class).when(focusedRegionMap).lruUpdateCallback();
 
-    assertThatThrownBy(() -> doPut()).isInstanceOf(DiskAccessException.class);
+    assertThatThrownBy(this::doPut).isInstanceOf(DiskAccessException.class);
 
     verify(internalRegion, times(1)).handleDiskAccessException(any());
   }
