@@ -46,33 +46,33 @@ public class MessageJUnitTest {
   @Before
   public void setUp() throws Exception {
     Socket mockSocket = mock(Socket.class);
-    this.message = new Message(2, KnownVersion.CURRENT);
-    assertEquals(2, this.message.getNumberOfParts());
+    message = new Message(2, KnownVersion.CURRENT);
+    assertEquals(2, message.getNumberOfParts());
     MessageStats mockStats = mock(MessageStats.class);
     ByteBuffer msgBuffer = ByteBuffer.allocate(1000);
     ServerConnection mockServerConnection = mock(ServerConnection.class);
-    this.message.setComms(mockServerConnection, mockSocket, msgBuffer, mockStats);
+    message.setComms(mockServerConnection, mockSocket, msgBuffer, mockStats);
   }
 
   @Test
   public void clearDoesNotThrowNPE() throws Exception {
     // unsetComms clears the message's ByteBuffer, which was causing an NPE during shutdown
     // when clear() was invoked
-    this.message.unsetComms();
-    this.message.clear();
+    message.unsetComms();
+    message.clear();
   }
 
   @Test
   public void numberOfPartsIsAdjusted() {
-    int numParts = this.message.getNumberOfParts();
-    this.message.setNumberOfParts(2 * numParts + 1);
-    assertEquals(2 * numParts + 1, this.message.getNumberOfParts());
-    this.message.addBytesPart(new byte[1]);
-    this.message.addIntPart(2);
-    this.message.addLongPart(3);
-    this.message.addObjPart("4");
-    this.message.addStringPart("5");
-    assertEquals(5, this.message.getNextPartNumber());
+    int numParts = message.getNumberOfParts();
+    message.setNumberOfParts(2 * numParts + 1);
+    assertEquals(2 * numParts + 1, message.getNumberOfParts());
+    message.addBytesPart(new byte[1]);
+    message.addIntPart(2);
+    message.addLongPart(3);
+    message.addObjPart("4");
+    message.addStringPart("5");
+    assertEquals(5, message.getNextPartNumber());
   }
 
   @Test
@@ -82,9 +82,9 @@ public class MessageJUnitTest {
     Part[] parts = new Part[2];
     parts[0] = mockPart1;
     parts[1] = mockPart1;
-    this.message.setParts(parts);
+    message.setParts(parts);
     try {
-      this.message.send();
+      message.send();
       fail("expected an exception but none was thrown");
     } catch (MessageTooLargeException e) {
       assertTrue(e.getMessage().contains("exceeds maximum integer value"));
@@ -98,9 +98,9 @@ public class MessageJUnitTest {
     Part[] parts = new Part[2];
     parts[0] = mockPart1;
     parts[1] = mockPart1;
-    this.message.setParts(parts);
+    message.setParts(parts);
     try {
-      this.message.send();
+      message.send();
       fail("expected an exception but none was thrown");
     } catch (MessageTooLargeException e) {
       assertFalse(e.getMessage().contains("exceeds maximum integer value"));
@@ -117,8 +117,8 @@ public class MessageJUnitTest {
     Part[] parts = new Part[2];
     parts[0] = mockPart1;
     parts[1] = mockPart1;
-    this.message.setParts(parts);
-    this.message.clearParts();
+    message.setParts(parts);
+    message.clearParts();
     verify(mockPart1, times(2)).clear();
   }
 
@@ -128,7 +128,7 @@ public class MessageJUnitTest {
    * problems. This test ensures that the method Message.receiveWithHeaderReadTimeout correctly
    * times out when trying to read a message header.
    *
-   * @See ClientServerMiscDUnitTest#testClientReceivesPingIntervalSetting
+   * See ClientServerMiscDUnitTest#testClientReceivesPingIntervalSetting
    */
   @Test(expected = SocketTimeoutException.class)
   public void messageWillTimeoutDuringRecvOnInactiveSocket() throws Exception {
@@ -141,15 +141,15 @@ public class MessageJUnitTest {
         try {
           client = serverSocket.accept();
           Thread.sleep(12000);
-        } catch (InterruptedException e) {
+        } catch (InterruptedException ignored) {
 
-        } catch (IOException e) {
+        } catch (IOException ignored) {
 
         } finally {
           if (client != null && !client.isClosed()) {
             try {
               client.close();
-            } catch (IOException e) {
+            } catch (IOException ignored) {
             }
           }
         }
@@ -185,15 +185,15 @@ public class MessageJUnitTest {
         try {
           client = serverSocket.accept();
           Thread.sleep(12000);
-        } catch (InterruptedException e) {
+        } catch (InterruptedException ignored) {
 
-        } catch (IOException e) {
+        } catch (IOException ignored) {
 
         } finally {
           if (client != null && !client.isClosed()) {
             try {
               client.close();
-            } catch (IOException e) {
+            } catch (IOException ignored) {
             }
           }
         }
