@@ -15,7 +15,7 @@
 package org.apache.geode.internal.cache.tier.sockets.command;
 
 import static org.mockito.ArgumentMatchers.eq;
-import static org.mockito.Matchers.isA;
+import static org.mockito.ArgumentMatchers.isA;
 import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
@@ -82,90 +82,90 @@ public class DestroyRegionTest {
 
   @Before
   public void setUp() throws Exception {
-    this.destroyRegion = new DestroyRegion();
+    destroyRegion = new DestroyRegion();
     MockitoAnnotations.initMocks(this);
 
-    when(this.authzRequest.destroyRegionAuthorize(eq(REGION_NAME), eq(CALLBACK_ARG)))
+    when(authzRequest.destroyRegionAuthorize(eq(REGION_NAME), eq(CALLBACK_ARG)))
         .thenReturn(mock(RegionDestroyOperationContext.class));
 
-    when(this.cache.getRegion(isA(String.class))).thenReturn(this.region);
-    when(this.cache.getCancelCriterion()).thenReturn(mock(CancelCriterion.class));
+    when(cache.getRegion(isA(String.class))).thenReturn(region);
+    when(cache.getCancelCriterion()).thenReturn(mock(CancelCriterion.class));
 
-    when(this.callbackArgPart.getObject()).thenReturn(CALLBACK_ARG);
+    when(callbackArgPart.getObject()).thenReturn(CALLBACK_ARG);
 
-    when(this.eventPart.getSerializedForm()).thenReturn(EVENT);
+    when(eventPart.getSerializedForm()).thenReturn(EVENT);
 
-    when(this.message.getNumberOfParts()).thenReturn(3);
-    when(this.message.getPart(eq(0))).thenReturn(this.regionNamePart);
-    when(this.message.getPart(eq(1))).thenReturn(this.eventPart);
-    when(this.message.getPart(eq(2))).thenReturn(this.callbackArgPart);
+    when(message.getNumberOfParts()).thenReturn(3);
+    when(message.getPart(eq(0))).thenReturn(regionNamePart);
+    when(message.getPart(eq(1))).thenReturn(eventPart);
+    when(message.getPart(eq(2))).thenReturn(callbackArgPart);
 
-    when(this.regionNamePart.getCachedString()).thenReturn(REGION_NAME);
+    when(regionNamePart.getCachedString()).thenReturn(REGION_NAME);
 
-    when(this.serverConnection.getCache()).thenReturn(this.cache);
-    when(this.serverConnection.getCacheServerStats()).thenReturn(this.cacheServerStats);
-    when(this.serverConnection.getAuthzRequest()).thenReturn(this.authzRequest);
-    when(this.serverConnection.getCachedRegionHelper()).thenReturn(mock(CachedRegionHelper.class));
-    when(this.serverConnection.getErrorResponseMessage()).thenReturn(this.errorResponseMessage);
-    when(this.serverConnection.getReplyMessage()).thenReturn(this.responseMessage);
-    when(this.serverConnection.getClientVersion()).thenReturn(KnownVersion.CURRENT);
+    when(serverConnection.getCache()).thenReturn(cache);
+    when(serverConnection.getCacheServerStats()).thenReturn(cacheServerStats);
+    when(serverConnection.getAuthzRequest()).thenReturn(authzRequest);
+    when(serverConnection.getCachedRegionHelper()).thenReturn(mock(CachedRegionHelper.class));
+    when(serverConnection.getErrorResponseMessage()).thenReturn(errorResponseMessage);
+    when(serverConnection.getReplyMessage()).thenReturn(responseMessage);
+    when(serverConnection.getClientVersion()).thenReturn(KnownVersion.CURRENT);
   }
 
   @Test
   public void noSecurityShouldSucceed() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(false);
+    when(securityService.isClientSecurityRequired()).thenReturn(false);
 
-    this.destroyRegion.cmdExecute(this.message, this.serverConnection, this.securityService, 0);
+    destroyRegion.cmdExecute(message, serverConnection, securityService, 0);
 
-    verify(this.securityService).authorize(Resource.DATA, Operation.MANAGE);
-    verify(this.responseMessage).send(this.serverConnection);
+    verify(securityService).authorize(Resource.DATA, Operation.MANAGE);
+    verify(responseMessage).send(serverConnection);
   }
 
   @Test
   public void integratedSecurityShouldSucceedIfAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(true);
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(true);
 
-    this.destroyRegion.cmdExecute(this.message, this.serverConnection, this.securityService, 0);
+    destroyRegion.cmdExecute(message, serverConnection, securityService, 0);
 
-    verify(this.securityService).authorize(Resource.DATA, Operation.MANAGE);
-    verify(this.responseMessage).send(this.serverConnection);
+    verify(securityService).authorize(Resource.DATA, Operation.MANAGE);
+    verify(responseMessage).send(serverConnection);
   }
 
   @Test
   public void integratedSecurityShouldFailIfNotAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(true);
-    doThrow(new NotAuthorizedException("")).when(this.securityService).authorize(Resource.DATA,
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(true);
+    doThrow(new NotAuthorizedException("")).when(securityService).authorize(Resource.DATA,
         Operation.MANAGE);
 
-    this.destroyRegion.cmdExecute(this.message, this.serverConnection, this.securityService, 0);
+    destroyRegion.cmdExecute(message, serverConnection, securityService, 0);
 
-    verify(this.errorResponseMessage).send(this.serverConnection);
+    verify(errorResponseMessage).send(serverConnection);
   }
 
   @Test
   public void oldSecurityShouldSucceedIfAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(false);
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(false);
 
-    this.destroyRegion.cmdExecute(this.message, this.serverConnection, this.securityService, 0);
+    destroyRegion.cmdExecute(message, serverConnection, securityService, 0);
 
-    verify(this.authzRequest).destroyRegionAuthorize(eq(REGION_NAME), eq(CALLBACK_ARG));
-    verify(this.responseMessage).send(this.serverConnection);
+    verify(authzRequest).destroyRegionAuthorize(eq(REGION_NAME), eq(CALLBACK_ARG));
+    verify(responseMessage).send(serverConnection);
   }
 
   @Test
   public void oldSecurityShouldFailIfNotAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(false);
-    doThrow(new NotAuthorizedException("")).when(this.authzRequest)
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(false);
+    doThrow(new NotAuthorizedException("")).when(authzRequest)
         .destroyRegionAuthorize(eq(REGION_NAME), eq(CALLBACK_ARG));
 
-    this.destroyRegion.cmdExecute(this.message, this.serverConnection, this.securityService, 0);
+    destroyRegion.cmdExecute(message, serverConnection, securityService, 0);
 
-    verify(this.authzRequest).destroyRegionAuthorize(eq(REGION_NAME), eq(CALLBACK_ARG));
-    verify(this.errorResponseMessage).send(this.serverConnection);
+    verify(authzRequest).destroyRegionAuthorize(eq(REGION_NAME), eq(CALLBACK_ARG));
+    verify(errorResponseMessage).send(serverConnection);
   }
 
 }
