@@ -14,9 +14,9 @@
  */
 package org.apache.geode.internal.cache.tier.sockets.command;
 
+import static org.apache.geode.util.internal.UncheckedUtils.uncheckedCast;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.mockito.ArgumentMatchers.any;
-import static org.mockito.ArgumentMatchers.anyInt;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.ArgumentMatchers.isA;
 import static org.mockito.Mockito.doThrow;
@@ -37,6 +37,7 @@ import org.apache.geode.cache.operations.RegisterInterestOperationContext;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.LocalRegion;
 import org.apache.geode.internal.cache.tier.CachedRegionHelper;
+import org.apache.geode.internal.cache.tier.InterestType;
 import org.apache.geode.internal.cache.tier.sockets.AcceptorImpl;
 import org.apache.geode.internal.cache.tier.sockets.ChunkedMessage;
 import org.apache.geode.internal.cache.tier.sockets.Message;
@@ -87,110 +88,113 @@ public class RegisterInterest61Test {
 
   @Before
   public void setUp() throws Exception {
-    this.registerInterest61 = new RegisterInterest61();
-    MockitoAnnotations.initMocks(this);
+    registerInterest61 = new RegisterInterest61();
+    MockitoAnnotations.openMocks(this);
 
-    when(this.authzRequest.registerInterestAuthorize(eq(REGION_NAME), eq(KEY), anyInt(), any()))
-        .thenReturn(this.registerInterestOperationContext);
+    when(authzRequest.registerInterestAuthorize(eq(REGION_NAME), eq(KEY), any(InterestType.class),
+        any()))
+            .thenReturn(registerInterestOperationContext);
 
-    when(this.cache.getRegion(isA(String.class))).thenReturn(mock(LocalRegion.class));
-    when(this.cache.getCancelCriterion()).thenReturn(mock(CancelCriterion.class));
+    when(cache.getRegion(isA(String.class))).thenReturn(uncheckedCast(mock(LocalRegion.class)));
+    when(cache.getCancelCriterion()).thenReturn(mock(CancelCriterion.class));
 
-    when(this.durablePart.getObject()).thenReturn(DURABLE);
+    when(durablePart.getObject()).thenReturn(DURABLE);
 
-    when(this.interestTypePart.getInt()).thenReturn(0);
+    when(interestTypePart.getInt()).thenReturn(0);
 
-    when(this.keyPart.getStringOrObject()).thenReturn(KEY);
+    when(keyPart.getStringOrObject()).thenReturn(KEY);
 
-    when(this.message.getNumberOfParts()).thenReturn(6);
-    when(this.message.getPart(eq(0))).thenReturn(this.regionNamePart);
-    when(this.message.getPart(eq(1))).thenReturn(this.interestTypePart);
-    when(this.message.getPart(eq(2))).thenReturn(mock(Part.class));
-    when(this.message.getPart(eq(3))).thenReturn(this.durablePart);
-    when(this.message.getPart(eq(4))).thenReturn(this.keyPart);
-    when(this.message.getPart(eq(5))).thenReturn(this.notifyPart);
+    when(message.getNumberOfParts()).thenReturn(6);
+    when(message.getPart(eq(0))).thenReturn(regionNamePart);
+    when(message.getPart(eq(1))).thenReturn(interestTypePart);
+    when(message.getPart(eq(2))).thenReturn(mock(Part.class));
+    when(message.getPart(eq(3))).thenReturn(durablePart);
+    when(message.getPart(eq(4))).thenReturn(keyPart);
+    when(message.getPart(eq(5))).thenReturn(notifyPart);
 
-    when(this.notifyPart.getObject()).thenReturn(DURABLE);
+    when(notifyPart.getObject()).thenReturn(DURABLE);
 
-    when(this.regionNamePart.getCachedString()).thenReturn(REGION_NAME);
+    when(regionNamePart.getCachedString()).thenReturn(REGION_NAME);
 
-    when(this.registerInterestOperationContext.getKey()).thenReturn(KEY);
+    when(registerInterestOperationContext.getKey()).thenReturn(KEY);
 
-    when(this.serverConnection.getCache()).thenReturn(this.cache);
-    when(this.serverConnection.getAuthzRequest()).thenReturn(this.authzRequest);
-    when(this.serverConnection.getCachedRegionHelper()).thenReturn(mock(CachedRegionHelper.class));
-    when(this.serverConnection.getChunkedResponseMessage()).thenReturn(this.chunkedResponseMessage);
-    when(this.serverConnection.getClientVersion()).thenReturn(KnownVersion.GFE_80);
-    when(this.serverConnection.getAcceptor()).thenReturn(mock(AcceptorImpl.class));
+    when(serverConnection.getCache()).thenReturn(cache);
+    when(serverConnection.getAuthzRequest()).thenReturn(authzRequest);
+    when(serverConnection.getCachedRegionHelper()).thenReturn(mock(CachedRegionHelper.class));
+    when(serverConnection.getChunkedResponseMessage()).thenReturn(chunkedResponseMessage);
+    when(serverConnection.getClientVersion()).thenReturn(KnownVersion.GFE_81);
+    when(serverConnection.getAcceptor()).thenReturn(mock(AcceptorImpl.class));
   }
 
   @Test
   public void noSecurityShouldSucceed() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(false);
+    when(securityService.isClientSecurityRequired()).thenReturn(false);
 
-    this.registerInterest61.cmdExecute(this.message, this.serverConnection, this.securityService,
+    registerInterest61.cmdExecute(message, serverConnection, securityService,
         0);
 
-    verify(this.chunkedResponseMessage).sendChunk(this.serverConnection);
+    verify(chunkedResponseMessage).sendChunk(serverConnection);
   }
 
   @Test
   public void integratedSecurityShouldSucceedIfAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(true);
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(true);
 
-    this.registerInterest61.cmdExecute(this.message, this.serverConnection, this.securityService,
+    registerInterest61.cmdExecute(message, serverConnection, securityService,
         0);
 
-    verify(this.securityService).authorize(Resource.DATA, Operation.READ, REGION_NAME, KEY);
-    verify(this.chunkedResponseMessage).sendChunk(this.serverConnection);
+    verify(securityService).authorize(Resource.DATA, Operation.READ, REGION_NAME, KEY);
+    verify(chunkedResponseMessage).sendChunk(serverConnection);
   }
 
   @Test
   public void integratedSecurityShouldThrowIfNotAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(true);
-    doThrow(new NotAuthorizedException("")).when(this.securityService).authorize(Resource.DATA,
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(true);
+    doThrow(new NotAuthorizedException("")).when(securityService).authorize(Resource.DATA,
         Operation.READ, REGION_NAME, KEY);
 
-    this.registerInterest61.cmdExecute(this.message, this.serverConnection, this.securityService,
+    registerInterest61.cmdExecute(message, serverConnection, securityService,
         0);
 
-    verify(this.securityService).authorize(Resource.DATA, Operation.READ, REGION_NAME, KEY);
-    verify(this.chunkedResponseMessage).sendChunk(this.serverConnection);
+    verify(securityService).authorize(Resource.DATA, Operation.READ, REGION_NAME, KEY);
+    verify(chunkedResponseMessage).sendChunk(serverConnection);
   }
 
   @Test
   public void oldSecurityShouldSucceedIfAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(false);
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(false);
 
-    this.registerInterest61.cmdExecute(this.message, this.serverConnection, this.securityService,
+    registerInterest61.cmdExecute(message, serverConnection, securityService,
         0);
 
-    verify(this.authzRequest).registerInterestAuthorize(eq(REGION_NAME), eq(KEY), anyInt(), any());
-    verify(this.chunkedResponseMessage).sendChunk(this.serverConnection);
+    verify(authzRequest).registerInterestAuthorize(eq(REGION_NAME), eq(KEY),
+        any(InterestType.class), any());
+    verify(chunkedResponseMessage).sendChunk(serverConnection);
   }
 
   @Test
   public void oldSecurityShouldFailIfNotAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(false);
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(false);
 
-    doThrow(new NotAuthorizedException("")).when(this.authzRequest)
-        .registerInterestAuthorize(eq(REGION_NAME), eq(KEY), anyInt(), any());
+    doThrow(new NotAuthorizedException("")).when(authzRequest)
+        .registerInterestAuthorize(eq(REGION_NAME), eq(KEY), any(InterestType.class), any());
 
-    this.registerInterest61.cmdExecute(this.message, this.serverConnection, this.securityService,
+    registerInterest61.cmdExecute(message, serverConnection, securityService,
         0);
 
-    verify(this.authzRequest).registerInterestAuthorize(eq(REGION_NAME), eq(KEY), anyInt(), any());
+    verify(authzRequest).registerInterestAuthorize(eq(REGION_NAME), eq(KEY),
+        any(InterestType.class), any());
 
     ArgumentCaptor<NotAuthorizedException> argument =
         ArgumentCaptor.forClass(NotAuthorizedException.class);
-    verify(this.chunkedResponseMessage).addObjPart(argument.capture());
+    verify(chunkedResponseMessage).addObjPart(argument.capture());
 
     assertThat(argument.getValue()).isExactlyInstanceOf(NotAuthorizedException.class);
-    verify(this.chunkedResponseMessage).sendChunk(this.serverConnection);
+    verify(chunkedResponseMessage).sendChunk(serverConnection);
   }
 
 }
