@@ -14,6 +14,7 @@
  */
 package org.apache.geode.internal.cache.tier.sockets.command;
 
+import static org.apache.geode.util.internal.UncheckedUtils.uncheckedCast;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.eq;
@@ -93,113 +94,113 @@ public class RegisterInterestList66Test {
 
   @Before
   public void setUp() throws Exception {
-    this.registerInterestList66 = new RegisterInterestList66();
-    MockitoAnnotations.initMocks(this);
+    registerInterestList66 = new RegisterInterestList66();
+    MockitoAnnotations.openMocks(this);
 
-    when(this.authzRequest.registerInterestListAuthorize(eq(REGION_NAME), any(), any()))
-        .thenReturn(this.registerInterestOperationContext);
+    when(authzRequest.registerInterestListAuthorize(eq(REGION_NAME), any(), any()))
+        .thenReturn(registerInterestOperationContext);
 
-    when(this.cache.getRegion(isA(String.class))).thenReturn(mock(LocalRegion.class));
-    when(this.cache.getCancelCriterion()).thenReturn(mock(CancelCriterion.class));
+    when(cache.getRegion(isA(String.class))).thenReturn(uncheckedCast(mock(LocalRegion.class)));
+    when(cache.getCancelCriterion()).thenReturn(mock(CancelCriterion.class));
 
-    when(this.durablePart.getObject()).thenReturn(DURABLE);
+    when(durablePart.getObject()).thenReturn(DURABLE);
 
-    when(this.interestTypePart.getInt()).thenReturn(0);
+    when(interestTypePart.getInt()).thenReturn(0);
 
-    when(this.keyPart.getObject()).thenReturn(mock(ArrayList.class));
+    when(keyPart.getObject()).thenReturn(mock(ArrayList.class));
 
-    when(this.message.getNumberOfParts()).thenReturn(6);
-    when(this.message.getPart(eq(0))).thenReturn(this.regionNamePart);
-    when(this.message.getPart(eq(1))).thenReturn(this.interestTypePart);
-    when(this.message.getPart(eq(2))).thenReturn(this.durablePart);
-    when(this.message.getPart(eq(3))).thenReturn(this.keyPart);
-    when(this.message.getPart(eq(4))).thenReturn(this.notifyPart);
-    when(this.message.getPart(eq(5))).thenReturn(this.regionDataPolicyPart);
+    when(message.getNumberOfParts()).thenReturn(6);
+    when(message.getPart(eq(0))).thenReturn(regionNamePart);
+    when(message.getPart(eq(1))).thenReturn(interestTypePart);
+    when(message.getPart(eq(2))).thenReturn(durablePart);
+    when(message.getPart(eq(3))).thenReturn(keyPart);
+    when(message.getPart(eq(4))).thenReturn(notifyPart);
+    when(message.getPart(eq(5))).thenReturn(regionDataPolicyPart);
 
-    when(this.notifyPart.getObject()).thenReturn(DURABLE);
+    when(notifyPart.getObject()).thenReturn(DURABLE);
 
-    when(this.numberOfKeysPart.getInt()).thenReturn(1);
+    when(numberOfKeysPart.getInt()).thenReturn(1);
 
-    when(this.regionDataPolicyPart.getObject()).thenReturn(DATA_POLICY);
+    when(regionDataPolicyPart.getObject()).thenReturn(DATA_POLICY);
 
-    when(this.regionNamePart.getCachedString()).thenReturn(REGION_NAME);
+    when(regionNamePart.getCachedString()).thenReturn(REGION_NAME);
 
-    when(this.registerInterestOperationContext.getKey()).thenReturn(KEY);
+    when(registerInterestOperationContext.getKey()).thenReturn(KEY);
 
-    when(this.serverConnection.getCache()).thenReturn(this.cache);
-    when(this.serverConnection.getAuthzRequest()).thenReturn(this.authzRequest);
-    when(this.serverConnection.getCachedRegionHelper()).thenReturn(mock(CachedRegionHelper.class));
-    when(this.serverConnection.getChunkedResponseMessage()).thenReturn(this.chunkedResponseMessage);
-    when(this.serverConnection.getClientVersion()).thenReturn(KnownVersion.GFE_80);
-    when(this.serverConnection.getAcceptor()).thenReturn(mock(AcceptorImpl.class));
+    when(serverConnection.getCache()).thenReturn(cache);
+    when(serverConnection.getAuthzRequest()).thenReturn(authzRequest);
+    when(serverConnection.getCachedRegionHelper()).thenReturn(mock(CachedRegionHelper.class));
+    when(serverConnection.getChunkedResponseMessage()).thenReturn(chunkedResponseMessage);
+    when(serverConnection.getClientVersion()).thenReturn(KnownVersion.GFE_81);
+    when(serverConnection.getAcceptor()).thenReturn(mock(AcceptorImpl.class));
   }
 
   @Test
   public void noSecurityShouldSucceed() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(false);
+    when(securityService.isClientSecurityRequired()).thenReturn(false);
 
-    this.registerInterestList66.cmdExecute(this.message, this.serverConnection,
-        this.securityService, 0);
+    registerInterestList66.cmdExecute(message, serverConnection,
+        securityService, 0);
 
-    verify(this.chunkedResponseMessage).sendChunk(this.serverConnection);
+    verify(chunkedResponseMessage).sendChunk(serverConnection);
   }
 
   @Test
   public void integratedSecurityShouldSucceedIfAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(true);
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(true);
 
-    this.registerInterestList66.cmdExecute(this.message, this.serverConnection,
-        this.securityService, 0);
+    registerInterestList66.cmdExecute(message, serverConnection,
+        securityService, 0);
 
-    verify(this.securityService).authorize(Resource.DATA, Operation.READ, REGION_NAME);
-    verify(this.chunkedResponseMessage).sendChunk(this.serverConnection);
+    verify(securityService).authorize(Resource.DATA, Operation.READ, REGION_NAME);
+    verify(chunkedResponseMessage).sendChunk(serverConnection);
   }
 
   @Test
   public void integratedSecurityShouldThrowIfNotAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(true);
-    doThrow(new NotAuthorizedException("")).when(this.securityService).authorize(Resource.DATA,
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(true);
+    doThrow(new NotAuthorizedException("")).when(securityService).authorize(Resource.DATA,
         Operation.READ, REGION_NAME);
 
-    this.registerInterestList66.cmdExecute(this.message, this.serverConnection,
-        this.securityService, 0);
+    registerInterestList66.cmdExecute(message, serverConnection,
+        securityService, 0);
 
-    verify(this.securityService).authorize(Resource.DATA, Operation.READ, REGION_NAME);
-    verify(this.chunkedResponseMessage).sendChunk(this.serverConnection);
+    verify(securityService).authorize(Resource.DATA, Operation.READ, REGION_NAME);
+    verify(chunkedResponseMessage).sendChunk(serverConnection);
   }
 
   @Test
   public void oldSecurityShouldSucceedIfAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(false);
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(false);
 
-    this.registerInterestList66.cmdExecute(this.message, this.serverConnection,
-        this.securityService, 0);
+    registerInterestList66.cmdExecute(message, serverConnection,
+        securityService, 0);
 
-    verify(this.authzRequest).registerInterestListAuthorize(eq(REGION_NAME), any(), any());
-    verify(this.chunkedResponseMessage).sendChunk(this.serverConnection);
+    verify(authzRequest).registerInterestListAuthorize(eq(REGION_NAME), any(), any());
+    verify(chunkedResponseMessage).sendChunk(serverConnection);
   }
 
   @Test
   public void oldSecurityShouldFailIfNotAuthorized() throws Exception {
-    when(this.securityService.isClientSecurityRequired()).thenReturn(true);
-    when(this.securityService.isIntegratedSecurity()).thenReturn(false);
+    when(securityService.isClientSecurityRequired()).thenReturn(true);
+    when(securityService.isIntegratedSecurity()).thenReturn(false);
 
-    doThrow(new NotAuthorizedException("")).when(this.authzRequest)
+    doThrow(new NotAuthorizedException("")).when(authzRequest)
         .registerInterestListAuthorize(eq(REGION_NAME), any(), any());
 
-    this.registerInterestList66.cmdExecute(this.message, this.serverConnection,
-        this.securityService, 0);
+    registerInterestList66.cmdExecute(message, serverConnection,
+        securityService, 0);
 
-    verify(this.authzRequest).registerInterestListAuthorize(eq(REGION_NAME), any(), any());
+    verify(authzRequest).registerInterestListAuthorize(eq(REGION_NAME), any(), any());
 
     ArgumentCaptor<NotAuthorizedException> argument =
         ArgumentCaptor.forClass(NotAuthorizedException.class);
-    verify(this.chunkedResponseMessage).addObjPart(argument.capture());
+    verify(chunkedResponseMessage).addObjPart(argument.capture());
 
     assertThat(argument.getValue()).isExactlyInstanceOf(NotAuthorizedException.class);
-    verify(this.chunkedResponseMessage).sendChunk(this.serverConnection);
+    verify(chunkedResponseMessage).sendChunk(serverConnection);
   }
 }
