@@ -14,6 +14,7 @@
  */
 package org.apache.geode.internal.cache.versions;
 
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
@@ -53,6 +54,53 @@ public class RegionVersionHolderJUnitTest {
     return member;
   }
 
+  @Test
+  public void fillSpecialExceptionForRVHWithBitSet() {
+    fillSpecialExceptionForRVH(true);
+  }
+
+  @Test
+  public void fillSpecialExceptionForRVHWithoutBitSet() {
+    fillSpecialExceptionForRVH(false);
+  }
+
+  private void fillSpecialExceptionForRVH(boolean useBitSet) {
+    RegionVersionHolder<InternalDistributedMember> vh1;
+    RegionVersionHolder<InternalDistributedMember> vh2;
+    if (useBitSet) {
+      vh1 = new RegionVersionHolder<>(member);
+      vh2 = new RegionVersionHolder<>(member);
+    } else {
+      vh1 = new RegionVersionHolder<>(0);
+      vh2 = new RegionVersionHolder<>(0);
+    }
+    for (int i = 1; i <= 3; i++) {
+      vh1.recordVersion(i);
+    }
+    for (int i = 1; i <= 5; i++) {
+      vh2.recordVersion(i);
+    }
+
+    // create special exception 5(n=6,p=3)
+    vh2.initializeFrom(vh1);
+    List<RVVException> exceptionList = vh2.getExceptionForTest();
+    assertThat(exceptionList.size()).isEqualTo(1);
+    RVVException exception = exceptionList.get(0);
+    assertThat(exception.previousVersion).isEqualTo(3);
+    assertThat(exception.nextVersion).isEqualTo(6);
+
+    vh2.recordVersion(5);
+    exceptionList = vh2.getExceptionForTest();
+    assertThat(exceptionList.size()).isEqualTo(1);
+    exception = exceptionList.get(0);
+    assertThat(exception.previousVersion).isEqualTo(3);
+    assertThat(exception.nextVersion).isEqualTo(5);
+
+    vh2.recordVersion(4);
+    exceptionList = vh2.getExceptionForTest();
+    assertThat(exceptionList.size()).isEqualTo(0);
+  }
+
   @Test
   public void test48066_1() {
     RegionVersionHolder vh1 = new RegionVersionHolder(member);
