@@ -94,7 +94,8 @@ public class TCPConduitTest {
             TCPConduit -> connectionTable, socketCreator, doNothing(), false);
     InternalDistributedMember member = mock(InternalDistributedMember.class);
     doThrow(new IOException("Cannot form connection to alert listener"))
-        .when(connectionTable).get(eq(member), anyBoolean(), anyLong(), anyLong(), anyLong());
+        .when(connectionTable)
+        .get(eq(member), anyBoolean(), anyLong(), anyLong(), anyLong(), anyBoolean());
     when(membership.memberExists(eq(member)))
         .thenReturn(true);
     when(membership.isShunned(same(member)))
@@ -102,7 +103,7 @@ public class TCPConduitTest {
 
     AlertingAction.execute(() -> {
       Throwable thrown = catchThrowable(() -> {
-        tcpConduit.getConnection(member, false, false, 0L, 0L, 0L);
+        tcpConduit.getConnection(member, false, 0L, 0L, 0L);
       });
 
       assertThat(thrown)
@@ -123,13 +124,14 @@ public class TCPConduitTest {
     doThrow(new IOException("Cannot form connection to alert listener"))
         // getConnection will loop indefinitely until connectionTable returns connection
         .doReturn(connection)
-        .when(connectionTable).get(eq(member), anyBoolean(), anyLong(), anyLong(), anyLong());
+        .when(connectionTable)
+        .get(eq(member), anyBoolean(), anyLong(), anyLong(), anyLong(), anyBoolean());
     when(membership.memberExists(eq(member)))
         .thenReturn(true);
     when(membership.isShunned(same(member)))
         .thenReturn(false);
 
-    Connection value = tcpConduit.getConnection(member, false, false, 0L, 0L, 0L);
+    Connection value = tcpConduit.getConnection(member, false, 0L, 0L, 0L);
 
     assertThat(value)
         .isSameAs(connection);
@@ -143,12 +145,13 @@ public class TCPConduitTest {
             TCPConduit -> connectionTable, socketCreator, doNothing(), false);
     InternalDistributedMember member = mock(InternalDistributedMember.class);
     doThrow(new IOException("Cannot form connection to alert listener"))
-        .when(connectionTable).get(eq(member), anyBoolean(), anyLong(), anyLong(), anyLong());
+        .when(connectionTable)
+        .get(eq(member), anyBoolean(), anyLong(), anyLong(), anyLong(), anyBoolean());
     when(membership.memberExists(eq(member)))
         .thenReturn(false);
 
     Throwable thrown = catchThrowable(() -> {
-      tcpConduit.getConnection(member, false, false, 0L, 0L, 0L);
+      tcpConduit.getConnection(member, false, 0L, 0L, 0L);
     });
 
     assertThat(thrown)
@@ -164,14 +167,15 @@ public class TCPConduitTest {
             TCPConduit -> connectionTable, socketCreator, doNothing(), false);
     InternalDistributedMember member = mock(InternalDistributedMember.class);
     doThrow(new IOException("Cannot form connection to alert listener"))
-        .when(connectionTable).get(same(member), anyBoolean(), anyLong(), anyLong(), anyLong());
+        .when(connectionTable)
+        .get(same(member), anyBoolean(), anyLong(), anyLong(), anyLong(), anyBoolean());
     when(membership.memberExists(same(member)))
         .thenReturn(true);
     when(membership.isShunned(same(member)))
         .thenReturn(true);
 
     Throwable thrown = catchThrowable(() -> {
-      tcpConduit.getConnection(member, false, false, 0L, 0L, 0L);
+      tcpConduit.getConnection(member, false, 0L, 0L, 0L);
     });
 
     assertThat(thrown)
@@ -188,7 +192,8 @@ public class TCPConduitTest {
             TCPConduit -> connectionTable, socketCreator, doNothing(), false);
     InternalDistributedMember member = mock(InternalDistributedMember.class);
     doThrow(new IOException("Cannot form connection to alert listener"))
-        .when(connectionTable).get(same(member), anyBoolean(), anyLong(), anyLong(), anyLong());
+        .when(connectionTable)
+        .get(same(member), anyBoolean(), anyLong(), anyLong(), anyLong(), anyBoolean());
     when(membership.memberExists(same(member)))
         .thenReturn(true);
     when(membership.isShunned(same(member)))
@@ -197,7 +202,7 @@ public class TCPConduitTest {
         .thenReturn(true);
 
     Throwable thrown = catchThrowable(() -> {
-      tcpConduit.getConnection(member, false, false, 0L, 0L, 0L);
+      tcpConduit.getConnection(member, false, 0L, 0L, 0L);
     });
 
     assertThat(thrown)
@@ -214,7 +219,8 @@ public class TCPConduitTest {
             TCPConduit -> connectionTable, socketCreator, doNothing(), false);
     InternalDistributedMember member = mock(InternalDistributedMember.class);
     doThrow(new IOException("Cannot form connection to alert listener"))
-        .when(connectionTable).get(same(member), anyBoolean(), anyLong(), anyLong(), anyLong());
+        .when(connectionTable)
+        .get(same(member), anyBoolean(), anyLong(), anyLong(), anyLong(), anyBoolean());
     when(membership.memberExists(same(member)))
         .thenReturn(true);
     when(membership.isShunned(same(member)))
@@ -223,7 +229,7 @@ public class TCPConduitTest {
         .thenReturn(true);
 
     Throwable thrown = catchThrowable(() -> {
-      tcpConduit.getConnection(member, false, false, 0L, 0L, 0L);
+      tcpConduit.getConnection(member, false, 0L, 0L, 0L);
     });
 
     assertThat(thrown)
@@ -231,6 +237,73 @@ public class TCPConduitTest {
         .hasMessage("Abandoned because shutdown is in progress");
   }
 
+  @Test
+  public void getFirstScanForConnectionThrowsAlertingIOException_ifCaughtIOException_whileAlerting()
+      throws Exception {
+    TCPConduit tcpConduit =
+        new TCPConduit(membership, 0, localHost, false, directChannel, mock(BufferPool.class),
+            new Properties(),
+            TCPConduit -> connectionTable, socketCreator, doNothing(), false);
+    InternalDistributedMember member = mock(InternalDistributedMember.class);
+    doThrow(new IOException("Cannot form connection to alert listener"))
+        .when(connectionTable)
+        .get(eq(member), anyBoolean(), anyLong(), anyLong(), anyLong(), anyBoolean());
+
+    AlertingAction.execute(() -> {
+      Throwable thrown = catchThrowable(() -> {
+        tcpConduit.getFirstScanForConnection(member, false, 0L, 0L, 0L);
+      });
+
+      assertThat(thrown)
+          .isInstanceOf(AlertingIOException.class);
+    });
+  }
+
+  @Test
+  public void getFirstScanForConnectionRethrows_ifCaughtIOException_whileNotAlerting()
+      throws Exception {
+    TCPConduit tcpConduit =
+        new TCPConduit(membership, 0, localHost, false, directChannel, mock(BufferPool.class),
+            new Properties(),
+            TCPConduit -> connectionTable, socketCreator, doNothing(), false);
+    InternalDistributedMember member = mock(InternalDistributedMember.class);
+    Connection connection = mock(Connection.class);
+    doThrow(new IOException("Connection not created in first try"))
+        .doReturn(connection)
+        .when(connectionTable)
+        .get(eq(member), anyBoolean(), anyLong(), anyLong(), anyLong(), anyBoolean());
+
+    Throwable thrown = catchThrowable(() -> {
+      tcpConduit.getFirstScanForConnection(member, false, 0L, 0L, 0L);
+    });
+
+    assertThat(thrown)
+        .isInstanceOf(IOException.class);
+  }
+
+
+  @Test
+  public void getFirstScanForConnectionRethrows_ifCaughtIOException_whithoutMessage()
+      throws Exception {
+    TCPConduit tcpConduit =
+        new TCPConduit(membership, 0, localHost, false, directChannel, mock(BufferPool.class),
+            new Properties(),
+            TCPConduit -> connectionTable, socketCreator, doNothing(), false);
+    InternalDistributedMember member = mock(InternalDistributedMember.class);
+    Connection connection = mock(Connection.class);
+    doThrow(new IOException())
+        .doReturn(connection)
+        .when(connectionTable)
+        .get(eq(member), anyBoolean(), anyLong(), anyLong(), anyLong(), anyBoolean());
+
+    Throwable thrown = catchThrowable(() -> {
+      tcpConduit.getFirstScanForConnection(member, false, 0L, 0L, 0L);
+    });
+
+    assertThat(thrown)
+        .isInstanceOf(IOException.class);
+  }
+
   private Runnable doNothing() {
     return () -> {
       // nothing
