@@ -20,39 +20,31 @@ import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.doThrow;
-import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
-import static org.mockito.Mockito.when;
 
 import java.io.File;
 import java.io.IOException;
 import java.nio.file.Paths;
-import java.util.HashMap;
-import java.util.Map;
+import java.time.Instant;
 
 import org.apache.commons.lang3.NotImplementedException;
 import org.junit.Before;
 import org.junit.Test;
 
-import org.apache.geode.internal.DeployedJar;
 import org.apache.geode.management.api.RealizationResult;
 import org.apache.geode.management.configuration.Deployment;
 import org.apache.geode.management.runtime.DeploymentInfo;
+import org.apache.geode.services.result.impl.Failure;
+import org.apache.geode.services.result.impl.Success;
 
 public class DeploymentRealizerTest {
   private DeploymentRealizer realizer;
-  private Map<String, DeployedJar> deployed;
   private Deployment deployment;
-  private DeployedJar deployedJar;
-
 
   @Before
   public void before() throws Exception {
     realizer = spy(new DeploymentRealizer());
-    deployed = new HashMap<>();
-    doReturn(deployed).when(realizer).getDeployedJars();
-    deployment = new Deployment();
-    deployedJar = mock(DeployedJar.class);
+    deployment = new Deployment("a.jar", "test", Instant.now().toString());
   }
 
   @Test
@@ -65,18 +57,13 @@ public class DeploymentRealizerTest {
   @Test
   public void getWithJarFound() {
     deployment.setFileName("a.jar");
-    when(deployedJar.getFile()).thenReturn(new File("/test/a.jar"));
-    deployed.put("a", deployedJar);
+    deployment.setFile(new File("/test/a.jar"));
+    doReturn(Success.of(deployment)).when(realizer).getDeployed(any());
     DeploymentInfo deploymentInfo = realizer.get(deployment, null);
     assertThat(Paths.get(deploymentInfo.getJarLocation()).toUri())
         .isEqualTo(Paths.get("/test/a.jar").toUri());
   }
 
-  @Test
-  public void getDateString() {
-    assertThat(realizer.getDateString(1576029093330L)).isEqualTo("2019-12-11T01:51:33.330Z");
-  }
-
   @Test
   public void existsReturnsFalse() {
     assertThat(realizer.exists(any(), any())).isFalse();
@@ -98,7 +85,7 @@ public class DeploymentRealizerTest {
 
   @Test
   public void createWithAlreadyExistingJar() throws Exception {
-    doReturn(null).when(realizer).deploy(any(File.class));
+    doReturn(Success.of(null)).when(realizer).deploy(any(Deployment.class));
     deployment.setFile(new File("/test/test.jar"));
 
     RealizationResult realizationResult = realizer.create(deployment, null);
@@ -110,13 +97,16 @@ public class DeploymentRealizerTest {
   @Test
   public void createWithNewJar() throws Exception {
     String canonicalPath = "/home/sweet/home/test/test.jar";
-    doReturn(canonicalPath).when(deployedJar).getFileCanonicalPath();
-    doReturn(deployedJar).when(realizer).deploy(any(File.class));
+    Deployment expectedDeployment = new Deployment("test.jar", "by", "time");
+    File file = new File(canonicalPath);
+    expectedDeployment.setFile(file);
+    deployment = new Deployment(canonicalPath, "test", Instant.now().toString());
     deployment.setFile(new File("/test/test.jar"));
+    doReturn(Success.of(expectedDeployment)).when(realizer).deploy(any(Deployment.class));
 
     RealizationResult realizationResult = realizer.create(deployment, null);
 
-    assertThat(realizationResult.getMessage()).contains(canonicalPath);
+    assertThat(realizationResult.getMessage()).contains(file.getCanonicalPath());
     assertThat(realizationResult.isSuccess()).isTrue();
   }
 
@@ -124,7 +114,7 @@ public class DeploymentRealizerTest {
   public void createWithFailedDeploy() throws IOException, ClassNotFoundException {
     String eMessage = "test runtime exception";
     RuntimeException runtimeException = new RuntimeException(eMessage);
-    doThrow(runtimeException).when(realizer).deploy(any(File.class));
+    doThrow(runtimeException).when(realizer).deploy(any(Deployment.class));
     deployment.setFile(new File("/test/test.jar"));
 
     assertThatThrownBy(() -> realizer.create(deployment, null))
@@ -135,21 +125,19 @@ public class DeploymentRealizerTest {
   @Test
   public void createWithFailedGetForCanonicalPath() throws Exception {
     String eMessage = "error getting canonical path";
-    IOException ioException = new IOException(eMessage);
-    doThrow(ioException).when(deployedJar).getFileCanonicalPath();
-    doReturn(deployedJar).when(realizer).deploy(any(File.class));
+    doReturn(Failure.of(eMessage)).when(realizer).deploy(any(Deployment.class));
     deployment.setFile(new File("/test/test.jar"));
 
-    assertThatThrownBy(() -> realizer.create(deployment, null))
-        .isInstanceOf(IOException.class)
-        .hasMessageContaining(eMessage);
+    RealizationResult realizationResult = realizer.create(deployment, null);
+    assertThat(realizationResult.isSuccess()).isFalse();
+    assertThat(realizationResult.getMessage()).contains(eMessage);
   }
 
   @Test
   public void alreadyDeployed() throws Exception {
-    doReturn(null).when(realizer).deploy(any());
+    doReturn(Success.of(null)).when(realizer).deploy(any());
     RealizationResult realizationResult = realizer.create(deployment, null);
     assertThat(realizationResult.isSuccess()).isTrue();
-    assertThat(realizationResult.getMessage()).isEqualTo("Already deployed");
+    assertThat(realizationResult.getMessage()).contains("Already deployed");
   }
 }
