@@ -22,7 +22,7 @@ import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.verify;
-import static org.powermock.api.mockito.PowerMockito.when;
+import static org.mockito.Mockito.when;
 
 import org.junit.Before;
 import org.junit.Test;
@@ -76,7 +76,7 @@ public class RegionConfigRealizerTest {
   }
 
   @Test
-  public void getRegionFactory() throws Exception {
+  public void getRegionFactory() {
     config.setType(RegionType.REPLICATE);
     config.setDiskStoreName("diskstore");
     config.setKeyConstraint("java.lang.String");
@@ -91,7 +91,7 @@ public class RegionConfigRealizerTest {
 
 
   @Test
-  public void createPartitionRegion() throws Exception {
+  public void createPartitionRegion() {
     config.setType(RegionType.PARTITION);
     config.setRedundantCopies(2);
 
@@ -104,7 +104,7 @@ public class RegionConfigRealizerTest {
   }
 
   @Test
-  public void getRegionFactoryWhenValueNotSet() throws Exception {
+  public void getRegionFactoryWhenValueNotSet() {
     config.setType(RegionType.REPLICATE);
     config.setDiskStoreName(null);
     config.setKeyConstraint(null);
