@@ -57,7 +57,7 @@ public class RebalanceOperationPerformerTest {
   public void executeRebalanceOnDSWithNoRegionsReturnsSuccessAndNoRegionMessage() {
     ManagementService managementService = mock(ManagementService.class);
     DistributedSystemMXBean distributedSystemMXBean = mock(DistributedSystemMXBean.class);
-    when(distributedSystemMXBean.listRegions()).thenReturn(new String[] {});
+    when(distributedSystemMXBean.listAllRegionPaths()).thenReturn(new String[] {});
     when(managementService.getDistributedSystemMXBean()).thenReturn(distributedSystemMXBean);
     InternalDistributedSystem internalDistributedSystem = mock(InternalDistributedSystem.class);
     InternalCache cache = mock(InternalCache.class);
@@ -84,7 +84,7 @@ public class RebalanceOperationPerformerTest {
     when(managementService.getDistributedRegionMXBean(SEPARATOR + "region1"))
         .thenReturn(regionMXBean);
     DistributedSystemMXBean distributedSystemMXBean = mock(DistributedSystemMXBean.class);
-    when(distributedSystemMXBean.listRegions()).thenReturn(new String[] {"region1"});
+    when(distributedSystemMXBean.listAllRegionPaths()).thenReturn(new String[] {"region1"});
     when(managementService.getDistributedSystemMXBean()).thenReturn(distributedSystemMXBean);
     InternalDistributedSystem internalDistributedSystem = mock(InternalDistributedSystem.class);
     InternalCache cache = mock(InternalCache.class);
@@ -116,7 +116,7 @@ public class RebalanceOperationPerformerTest {
     when(managementService.getDistributedRegionMXBean(SEPARATOR + "region1"))
         .thenReturn(regionMXBean);
     DistributedSystemMXBean distributedSystemMXBean = mock(DistributedSystemMXBean.class);
-    when(distributedSystemMXBean.listRegions()).thenReturn(new String[] {"region1"});
+    when(distributedSystemMXBean.listAllRegionPaths()).thenReturn(new String[] {"region1"});
     when(managementService.getDistributedSystemMXBean()).thenReturn(distributedSystemMXBean);
     InternalDistributedSystem internalDistributedSystem = mock(InternalDistributedSystem.class);
     InternalCache cache = mock(InternalCache.class);
@@ -148,7 +148,7 @@ public class RebalanceOperationPerformerTest {
     assertThat(result.getRebalanceRegionResults()).isNotNull();
     assertThat(result.getRebalanceRegionResults()).hasSize(1);
     RebalanceRegionResult regionResult = result.getRebalanceRegionResults().get(0);
-    assertThat(regionResult.getRegionName()).isEqualTo("region1");
+    assertThat(regionResult.getRegionName()).isEqualTo(SEPARATOR + "region1");
     assertThat(regionResult.getBucketCreateBytes()).isEqualTo(0);
     assertThat(regionResult.getBucketCreateTimeInMilliseconds()).isEqualTo(1);
     assertThat(regionResult.getBucketCreatesCompleted()).isEqualTo(2);
