@@ -55,7 +55,7 @@ import org.apache.geode.test.junit.categories.ClientSubscriptionTest;
 public class CqStatsDUnitTest extends JUnit4CacheTestCase {
 
   // TODO: delete this use of CqQueryDUnitTest
-  private CqQueryDUnitTest cqDUnitTest = new CqQueryDUnitTest();
+  private final CqQueryDUnitTest cqDUnitTest = new CqQueryDUnitTest();
 
   @Override
   public final void postSetUp() throws Exception {
@@ -253,7 +253,7 @@ public class CqStatsDUnitTest extends JUnit4CacheTestCase {
 
     /* Init Server and Client */
     cqDUnitTest.createServer(server);
-    final int port = server.invoke(() -> CqQueryDUnitTest.getCacheServerPort());
+    final int port = server.invoke(CqQueryDUnitTest::getCacheServerPort);
     final String host0 = NetworkUtils.getServerHostName(server.getHost());
     cqDUnitTest.createClient(client, port, host0);
 
@@ -334,14 +334,14 @@ public class CqStatsDUnitTest extends JUnit4CacheTestCase {
 
     /* Init Server and Client */
     cqDUnitTest.createServer(server);
-    final int port = server.invoke(() -> CqQueryDUnitTest.getCacheServerPort());
+    final int port = server.invoke(CqQueryDUnitTest::getCacheServerPort);
     final String host0 = NetworkUtils.getServerHostName(server.getHost());
     cqDUnitTest.createClient(client1, port, host0);
     cqDUnitTest.createClient(client2, port, host0);
 
     /* Create CQs. */
-    String cqName = new String("testCQServiceStatistics_0");
-    String cqName10 = new String("testCQServiceStatistics_10");
+    String cqName = "testCQServiceStatistics_0";
+    String cqName10 = "testCQServiceStatistics_10";
     cqDUnitTest.createCQ(client1, cqName, cqDUnitTest.cqs[0]);
     cqDUnitTest.createCQ(client2, cqName10, cqDUnitTest.cqs[2]);
     Wait.pause(PAUSE);
