@@ -125,12 +125,12 @@ public class RemoteCQTransactionDUnitTest extends JUnit4CacheTestCase {
     if (interestPolicy != null) {
       af.setSubscriptionAttributes(new SubscriptionAttributes(interestPolicy));
     }
-    af.setPartitionAttributes(new PartitionAttributesFactory<CustId, Customer>()
+    af.setPartitionAttributes(new PartitionAttributesFactory<>()
         .setTotalNumBuckets(4).setLocalMaxMemory(accessor ? 0 : 1)
         .setPartitionResolver(new CustomerIDPartitionResolver("resolver1"))
         .setRedundantCopies(redundantCopies).create());
     getCache().createRegion(CUSTOMER, af.create());
-    af.setPartitionAttributes(new PartitionAttributesFactory<OrderId, Order>().setTotalNumBuckets(4)
+    af.setPartitionAttributes(new PartitionAttributesFactory<>().setTotalNumBuckets(4)
         .setLocalMaxMemory(accessor ? 0 : 1)
         .setPartitionResolver(new CustomerIDPartitionResolver("resolver2"))
         .setRedundantCopies(redundantCopies).setColocatedWith(CUSTOMER).create());
@@ -570,7 +570,7 @@ public class RemoteCQTransactionDUnitTest extends JUnit4CacheTestCase {
     }
 
     public boolean isListenerInvoked() {
-      return this.listenerInvoked;
+      return listenerInvoked;
     }
 
     @Override
@@ -647,7 +647,7 @@ public class RemoteCQTransactionDUnitTest extends JUnit4CacheTestCase {
   }
 
   protected Set<Customer> getCustomerSet(int size) {
-    Set<Customer> expectedSet = new HashSet<Customer>();
+    Set<Customer> expectedSet = new HashSet<>();
     for (int i = 0; i < size; i++) {
       expectedSet.add(new Customer("customer" + i, "address" + i));
     }
@@ -655,7 +655,7 @@ public class RemoteCQTransactionDUnitTest extends JUnit4CacheTestCase {
   }
 
   Set<CustId> getCustIdSet(int size) {
-    Set<CustId> expectedSet = new HashSet<CustId>();
+    Set<CustId> expectedSet = new HashSet<>();
     for (int i = 0; i < size; i++) {
       expectedSet.add(new CustId(i));
     }
