@@ -16,14 +16,17 @@ package org.apache.geode.internal.cache.tier.sockets;
 
 
 import static org.apache.geode.cache.Region.SEPARATOR;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.ControlCqListener;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.createCacheClient;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.createCacheClientFromXml;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.createCacheServer;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.createCacheServerFromXml;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.getCache;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.getClientCache;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.getPool;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
-import static org.apache.geode.test.dunit.NetworkUtils.getServerHostName;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.fail;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
 
 import java.util.List;
 import java.util.Map;
@@ -50,15 +53,11 @@ import org.apache.geode.cache30.CacheSerializableRunnable;
 import org.apache.geode.distributed.internal.DistributionConfig;
 import org.apache.geode.distributed.internal.ServerLocation;
 import org.apache.geode.distributed.internal.ServerLocationAndMemberId;
-import org.apache.geode.internal.cache.ClientServerObserverAdapter;
-import org.apache.geode.internal.cache.ClientServerObserverHolder;
-import org.apache.geode.test.awaitility.GeodeAwaitility;
 import org.apache.geode.test.dunit.AsyncInvocation;
 import org.apache.geode.test.dunit.IgnoredException;
 import org.apache.geode.test.dunit.NetworkUtils;
 import org.apache.geode.test.dunit.SerializableRunnableIF;
 import org.apache.geode.test.dunit.VM;
-import org.apache.geode.test.dunit.WaitCriterion;
 import org.apache.geode.test.junit.categories.ClientSubscriptionTest;
 
 @Category({ClientSubscriptionTest.class})
@@ -74,8 +73,7 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     String lessThan5Query = "select * from " + SEPARATOR + regionName + " p where p.ID < 5";
 
     // Start a server
-    server1Port = this.server1VM
-        .invoke(() -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+    server1Port = server1VM.invoke(() -> createCacheServer(regionName, true));
 
     // Start a durable client that is kept alive on the server when it stops
     // normally
@@ -93,15 +91,15 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
         server1VM);
 
     // Stop the durable client
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
     // Start normal publisher client
     startClient(publisherClientVM, server1Port, regionName);
 
     // Publish some entries
-    publishEntries(regionName, 10);
+    publishEntries(publisherClientVM, regionName, 10);
 
-    this.server1VM.invoke(new CacheSerializableRunnable("Close cq for durable client") {
+    server1VM.invoke("Close cq for durable client", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
 
@@ -139,13 +137,13 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
         /* numEventsToWaitFor */ 5/* secondsToWait */);
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the publisher client
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   /**
@@ -168,18 +166,17 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     String lessThan5Query = "select * from " + SEPARATOR + regionName + " p where p.ID < 5";
 
     // Start a server 1
-    server1Port = this.server1VM
-        .invoke(() -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+    server1Port = server1VM
+        .invoke(() -> createCacheServer(regionName, true));
 
     // Start server 2
-    server2Port = this.server2VM.invoke(CacheServerTestUtil.class,
-        "createCacheServer", new Object[] {regionName, Boolean.TRUE});
+    server2Port = server2VM.invoke(() -> createCacheServer(regionName, true));
 
     // Start a durable client that is kept alive on the server when it stops normally
     durableClientId = getName() + "_client";
-    CacheServerTestUtil.createCacheClient(
-        getClientPool(NetworkUtils.getServerHostName(), server1Port, server2Port, true, 0),
-        regionName, getClientDistributedSystemProperties(durableClientId), Boolean.TRUE);
+    createCacheClient(
+        getClientPool(VM.getHostName(), server1Port, server2Port, true, 0),
+        regionName, getClientDistributedSystemProperties(durableClientId), true);
 
     // register non durable cq
     createCq("GreaterThan5", greaterThan5Query, false).execute();
@@ -189,7 +186,7 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     createCq("LessThan5", lessThan5Query, true).execute();
 
     // send client ready
-    CacheServerTestUtil.getClientCache().readyForEvents();
+    getClientCache().readyForEvents();
 
     int oldPrimaryPort = getPrimaryServerPort();
     // Close the server that is hosting subscription queue
@@ -203,7 +200,7 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     // Wait until failover to the another server is successfully performed
     waitForFailoverToPerform(oldPrimaryPort);
     primary = getPrimaryServerVM();
-    waitForDurableClientPresence(durableClientId, primary, 1);
+    waitForDurableClientPresence(durableClientId, primary);
     int primaryPort = getPrimaryServerPort();
 
     // Stop the durable client
@@ -213,13 +210,13 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     startClient(publisherClientVM, primaryPort, regionName);
 
     // Publish some entries
-    publishEntries(regionName, 10);
+    publishEntries(publisherClientVM, regionName, 10);
 
     // Restart the durable client
-    CacheServerTestUtil.createCacheClient(
-        getClientPool(NetworkUtils.getServerHostName(), primaryPort, true),
-        regionName, getClientDistributedSystemProperties(durableClientId), Boolean.TRUE);
-    assertThat(CacheServerTestUtil.getClientCache()).isNotNull();
+    createCacheClient(
+        getClientPool(VM.getHostName(), primaryPort, true),
+        regionName, getClientDistributedSystemProperties(durableClientId), true);
+    assertThat(getClientCache()).isNotNull();
 
     // Re-register non durable cq
     createCq("GreaterThan5", greaterThan5Query, false).execute();
@@ -229,7 +226,7 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     createCq("LessThan5", lessThan5Query, true).execute();
 
     // send client ready
-    CacheServerTestUtil.getClientCache().readyForEvents();
+    getClientCache().readyForEvents();
 
     // verify cq events for all 3 cqs
     checkCqListenerEvents("GreaterThan5", 0 /* numEventsExpected */,
@@ -243,7 +240,7 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     // Stop the durable client
     CacheServerTestUtil.closeCache(false);
     // Stop the publisher client
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
     // Stop the remaining server
     primary.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
@@ -260,8 +257,8 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     String lessThan5Query = "select * from " + SEPARATOR + regionName + " p where p.ID < 5";
 
     // Start server 1
-    server1Port = this.server1VM.invoke(
-        () -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+    server1Port = server1VM.invoke(
+        () -> createCacheServer(regionName, true));
 
     final String durableClientId = getName() + "_client";
 
@@ -279,13 +276,13 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
         server1VM);
 
     // Stop the durable client
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
     // Start normal publisher client
     startClient(publisherClientVM, server1Port, regionName);
 
     // Publish some entries
-    publishEntries(regionName, 10);
+    publishEntries(publisherClientVM, regionName, 10);
 
     closeCQsforDurableClient(durableClientId);
 
@@ -311,16 +308,16 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
         /* numEventsToWaitFor */ 5/* secondsToWait */);
     checkCqListenerEvents(durableClientVM, "All", 0 /* numEventsExpected */,
         /* numEventsToWaitFor */ 5/* secondsToWait */);
-    checkListenerEvents(10, 1, -1, this.durableClientVM);
+    checkListenerEvents(10, 1, -1, durableClientVM);
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the publisher client
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   /**
@@ -335,8 +332,8 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     String lessThan5Query = "select * from " + SEPARATOR + regionName + " p where p.ID < 5";
 
     // Start server 1
-    server1Port = this.server1VM.invoke(
-        () -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+    server1Port = server1VM.invoke(
+        () -> createCacheServer(regionName, true));
 
     durableClientId = getName() + "_client";
 
@@ -353,13 +350,13 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
         server1VM);
 
     // Stop the durable client
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
     // Start normal publisher client
     startClient(publisherClientVM, server1Port, regionName);
 
     // Publish some entries
-    publishEntries(regionName, 10);
+    publishEntries(publisherClientVM, regionName, 10);
 
     closeCQsforDurableClient(durableClientId);
 
@@ -392,10 +389,10 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
 
     // the flush entry message may remain in the queue due
     // verify the queue stats are as close/correct as possible
-    this.checkHAQueueSize(server1VM, durableClientId, 0, 1);
+    checkHAQueueSize(server1VM, durableClientId, 0, 1);
 
     // continue to publish and make sure we get the events
-    publishEntries(regionName, 10);
+    publishEntries(publisherClientVM, regionName, 10);
     checkCqListenerEvents(durableClientVM, "GreaterThan5", 4 /* numEventsExpected */,
         /* numEventsToWaitFor */ 10/* secondsToWait */);
     checkCqListenerEvents(durableClientVM, "LessThan5", 5 /* numEventsExpected */,
@@ -411,20 +408,20 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
 
     // the flush entry message may remain in the queue due
     // verify the queue stats are as close/correct as possible
-    this.checkHAQueueSize(server1VM, durableClientId, 0, 1);
+    checkHAQueueSize(server1VM, durableClientId, 0, 1);
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the publisher client
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   private void closeCQsforDurableClient(String durableClientId) {
-    this.server1VM.invoke(new CacheSerializableRunnable("Close cq for durable client") {
+    server1VM.invoke("Close cq for durable client", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
 
@@ -452,8 +449,8 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     String lessThan5Query = "select * from " + SEPARATOR + regionName + " p where p.ID < 5";
 
     // Start server 1
-    server1Port = this.server1VM.invoke(
-        () -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+    server1Port = server1VM.invoke(
+        () -> createCacheServer(regionName, true));
 
     final String durableClientId = getName() + "_client";
     final String durableClientId2 = getName() + "_client2";
@@ -470,7 +467,7 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
         server1VM);
 
     // Stop the durable client
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
     startDurableClient(durableClientVM, durableClientId2, server1Port, regionName);
     // register durable cqs
@@ -481,7 +478,7 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     sendClientReady(durableClientVM);
 
     // Verify 2nd durable client on server
-    this.server1VM.invoke(new CacheSerializableRunnable("Verify 2nd durable client") {
+    server1VM.invoke("Verify 2nd durable client", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
         // Find the proxy
@@ -489,15 +486,15 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
       }
     });
 
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
     // Start normal publisher client
     startClient(publisherClientVM, server1Port, regionName);
 
     // Publish some entries
-    publishEntries(regionName, 10);
+    publishEntries(publisherClientVM, regionName, 10);
 
-    this.server1VM.invoke(new CacheSerializableRunnable("Close cq for durable client 1") {
+    server1VM.invoke("Close cq for durable client 1", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
 
@@ -534,7 +531,7 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     checkCqListenerEvents(durableClientVM, "All", 0 /* numEventsExpected */,
         /* numEventsToWaitFor */ 5/* secondsToWait */);
 
-    this.disconnectDurableClient(false);
+    disconnectDurableClient(false);
 
     // Restart the 2nd durable client
     startDurableClient(durableClientVM, durableClientId2, server1Port, regionName);
@@ -560,13 +557,13 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
         /* numEventsToWaitFor */ 15/* secondsToWait */);
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the publisher client
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   /**
@@ -586,11 +583,11 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
       String lessThan5Query = "select * from " + SEPARATOR + regionName + " p where p.ID < 5";
 
       // Start server 1
-      server1Port = this.server1VM.invoke(
-          () -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+      server1Port = server1VM.invoke(
+          () -> createCacheServer(regionName, true));
 
       final String durableClientId = getName() + "_client";
-      this.durableClientVM.invoke(CacheServerTestUtil::disableShufflingOfEndpoints);
+      durableClientVM.invoke(CacheServerTestUtil::disableShufflingOfEndpoints);
 
       startDurableClient(durableClientVM, durableClientId, server1Port, regionName);
 
@@ -605,15 +602,15 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
           server1VM);
 
       // Stop the durable client
-      this.disconnectDurableClient(true);
+      disconnectDurableClient(true);
 
       // Start normal publisher client
       startClient(publisherClientVM, server1Port, regionName);
 
       // Publish some entries
-      publishEntries(regionName, 10);
+      publishEntries(publisherClientVM, regionName, 10);
 
-      this.server1VM.invoke(new CacheSerializableRunnable("Set test hook") {
+      server1VM.invoke("Set test hook", new CacheSerializableRunnable() {
         @Override
         public void run2() throws CacheException {
           // Set the Test Hook!
@@ -622,7 +619,7 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
         }
       });
 
-      this.server1VM.invokeAsync(new CacheSerializableRunnable("Close cq for durable client") {
+      server1VM.invokeAsync("Close cq for durable client", new CacheSerializableRunnable() {
         @Override
         public void run2() throws CacheException {
 
@@ -639,15 +636,16 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
       // Restart the durable client
       startDurableClient(durableClientVM, durableClientId, server1Port, regionName);
 
-      this.server1VM.invoke(new CacheSerializableRunnable("verify was rejected at least once") {
+      server1VM.invoke("verify was rejected at least once", new CacheSerializableRunnable() {
         @Override
         public void run2() throws CacheException {
           await()
               .until(() -> CacheClientProxy.testHook != null
                   && (((RejectClientReconnectTestHook) CacheClientProxy.testHook)
                       .wasClientRejected()));
-          assertTrue(
-              ((RejectClientReconnectTestHook) CacheClientProxy.testHook).wasClientRejected());
+          assertThat(
+              ((RejectClientReconnectTestHook) CacheClientProxy.testHook).wasClientRejected())
+                  .isTrue();
         }
       });
 
@@ -676,15 +674,15 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
           /* numEventsToWaitFor */ 5/* secondsToWait */);
 
       // Stop the durable client
-      this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+      durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
       // Stop the publisher client
-      this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+      publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
       // Stop the server
-      this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+      server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
     } finally {
-      this.server1VM.invoke(new CacheSerializableRunnable("unset test hook") {
+      server1VM.invoke("unset test hook", new CacheSerializableRunnable() {
         @Override
         public void run2() throws CacheException {
           CacheClientProxy.testHook = null;
@@ -705,8 +703,8 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
       String lessThan5Query = "select * from " + SEPARATOR + regionName + " p where p.ID < 5";
 
       // Start server 1
-      server1Port = this.server1VM.invoke(
-          () -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+      server1Port = server1VM.invoke(
+          () -> createCacheServer(regionName, true));
 
       durableClientId = getName() + "_client";
 
@@ -723,16 +721,16 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
           server1VM);
 
       // Stop the durable client
-      this.disconnectDurableClient(true);
+      disconnectDurableClient(true);
 
       // Start normal publisher client
       startClient(publisherClientVM, server1Port, regionName);
 
       // Publish some entries
-      publishEntries(regionName, 10);
+      publishEntries(publisherClientVM, regionName, 10);
 
-      AsyncInvocation async =
-          this.server1VM.invokeAsync(new CacheSerializableRunnable("Close cq for durable client") {
+      AsyncInvocation<Void> async =
+          server1VM.invokeAsync("Close cq for durable client", new CacheSerializableRunnable() {
             @Override
             public void run2() throws CacheException {
 
@@ -775,9 +773,7 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
       // send client ready
       sendClientReady(durableClientVM);
 
-      async.join();
-      assertFalse(async.getException() != null ? async.getException().toString() : "No error",
-          async.exceptionOccurred());
+      async.await();
 
       // verify cq listener events
       checkCqListenerEvents(durableClientVM, "GreaterThan5", 4 /* numEventsExpected */,
@@ -788,15 +784,15 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
           /* numEventsToWaitFor */ 15/* secondsToWait */);
 
       // Stop the durable client
-      this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+      durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
       // Stop the publisher client
-      this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+      publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
       // Stop the server
-      this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+      server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
     } finally {
-      this.server1VM.invoke(new CacheSerializableRunnable("unset test hook") {
+      server1VM.invoke("unset test hook", new CacheSerializableRunnable() {
         @Override
         public void run2() throws CacheException {
           CacheClientProxy.testHook = null;
@@ -815,8 +811,8 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     String lessThan5Query = "select * from " + SEPARATOR + regionName + " p where p.ID < 5";
 
     // Start a server
-    server1Port = this.server1VM
-        .invoke(() -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+    server1Port = server1VM
+        .invoke(() -> createCacheServer(regionName, true));
 
     // Start a durable client that is kept alive on the server when it stops
     // normally
@@ -836,10 +832,10 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     startClient(publisherClientVM, server1Port, regionName);
 
     // Publish some entries
-    publishEntries(regionName, 10);
+    publishEntries(publisherClientVM, regionName, 10);
 
     // Attempt to close a cq even though the client is running
-    this.server1VM.invoke(new CacheSerializableRunnable("Close cq for durable client") {
+    server1VM.invoke("Close cq for durable client", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
 
@@ -876,13 +872,13 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
         /* numEventsToWaitFor */ 15/* secondsToWait */);
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the publisher client
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   @Test
@@ -890,25 +886,25 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
 
 
     // Start server 1
-    server1Port = this.server1VM.invoke(CacheServerTestUtil.class,
-        "createCacheServer", new Object[] {regionName, Boolean.TRUE});
+    server1Port = server1VM.invoke(CacheServerTestUtil.class,
+        "createCacheServer", new Object[] {regionName, true});
 
     // Start server 2
-    final int server2Port = this.server2VM.invoke(CacheServerTestUtil.class,
-        "createCacheServer", new Object[] {regionName, Boolean.TRUE});
+    final int server2Port = server2VM.invoke(CacheServerTestUtil.class,
+        "createCacheServer", new Object[] {regionName, true});
 
     // Start a durable client
     durableClientId = getName() + "_client";
-    this.durableClientVM.invoke(() -> {
-      CacheServerTestUtil
-          .createCacheClient(getClientPool(getServerHostName(), server1Port, server2Port,
-              true, 0),
-              regionName, getClientDistributedSystemProperties(durableClientId, 60), Boolean.TRUE);
+    durableClientVM.invoke(() -> {
+      createCacheClient(getClientPool(NetworkUtils.getServerHostName(),
+          server1Port, server2Port,
+          true, 0),
+          regionName, getClientDistributedSystemProperties(durableClientId, 60), true);
 
     });
 
     // Send clientReady message
-    sendClientReady(this.durableClientVM);
+    sendClientReady(durableClientVM);
 
     // Register durable CQ
     String cqName = getName() + "_cq";
@@ -916,32 +912,32 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
 
     // Execute getAllDurableCqsFromServer on the client
     List<String> durableCqNames =
-        this.durableClientVM.invoke(DurableClientCQDUnitTest::getAllDurableCqsFromServer);
+        durableClientVM.invoke(DurableClientCQDUnitTest::getAllDurableCqsFromServer);
 
-    this.durableClientVM.invoke(() -> verifyDurableCqs(durableCqNames, cqName));
+    durableClientVM.invoke(() -> verifyDurableCqs(durableCqNames, cqName));
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the servers
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
-    this.server2VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server2VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   private static List<String> getAllDurableCqsFromServer() throws CqException {
-    QueryService queryService = CacheServerTestUtil.getPool().getQueryService();
+    QueryService queryService = getPool().getQueryService();
     return queryService.getAllDurableCqsFromServer();
   }
 
   private static void verifyDurableCqs(final List<String> durableCqNames,
       final String registeredCqName) {
     // Verify the number of durable CQ names is one, and it matches the registered name
-    assertEquals(1, durableCqNames.size());
+    assertThat(durableCqNames).hasSize(1);
     String returnedCqName = durableCqNames.get(0);
-    assertEquals(registeredCqName, returnedCqName);
+    assertThat(registeredCqName).isEqualTo(returnedCqName);
 
     // Get client's primary server
-    PoolImpl pool = CacheServerTestUtil.getPool();
+    PoolImpl pool = getPool();
     ServerLocation primaryServerLocation = pool.getPrimary();
 
     // Verify the primary server was used and no other server was used
@@ -950,7 +946,7 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
     for (Map.Entry<ServerLocationAndMemberId, ConnectionStats> entry : statistics.entrySet()) {
       int expectedGetDurableCqInvocations =
           entry.getKey().getServerLocation().equals(primaryServerLocation) ? 1 : 0;
-      assertEquals(expectedGetDurableCqInvocations, entry.getValue().getGetDurableCqs());
+      assertThat(entry.getValue().getGetDurableCqs()).isEqualTo(expectedGetDurableCqInvocations);
     }
   }
 
@@ -960,126 +956,95 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
    */
   @Test
   public void testReadyForEventsNotCalledImplicitlyWithCacheXML() throws InterruptedException {
-    try {
-      setPeriodicACKObserver(durableClientVM);
-      final String cqName = "cqTest";
-      // Start a server
-      server1Port =
-          this.server1VM.invoke(() -> CacheServerTestUtil.createCacheServerFromXml(
-              DurableClientTestBase.class.getResource("durablecq-server-cache.xml")));
 
-      // Start a durable client that is not kept alive on the server when it
-      // stops normally
-      final String durableClientId = getName() + "_client";
+    final String cqName = "cqTest";
+    // Start a server
+    server1Port =
+        server1VM.invoke(() -> createCacheServerFromXml(
+            DurableClientTestBase.class.getResource("durablecq-server-cache.xml")));
 
-      // create client cache from xml
-      this.durableClientVM.invoke(() -> CacheServerTestUtil.createCacheClientFromXml(
-          DurableClientTestBase.class.getResource("durablecq-client-cache.xml"), "client",
-          durableClientId, VERY_LONG_DURABLE_TIMEOUT_SECONDS, Boolean.FALSE));
+    // Start a durable client that is not kept alive on the server when it
+    // stops normally
+    final String durableClientId = getName() + "_client";
 
-      // verify that readyForEvents has not yet been called on all the client's pools
-      this.durableClientVM.invoke(new CacheSerializableRunnable("check readyForEvents not called") {
-        @Override
-        public void run2() throws CacheException {
-          for (Pool p : PoolManager.getAll().values()) {
-            assertFalse(((PoolImpl) p).getReadyForEventsCalled());
-          }
+    // create client cache from xml
+    durableClientVM.invoke(() -> createCacheClientFromXml(
+        DurableClientTestBase.class.getResource("durablecq-client-cache.xml"), "client",
+        durableClientId, VERY_LONG_DURABLE_TIMEOUT_SECONDS, false));
+
+    // verify that readyForEvents has not yet been called on all the client's pools
+    durableClientVM.invoke("check readyForEvents not called", new CacheSerializableRunnable() {
+      @Override
+      public void run2() throws CacheException {
+        for (Pool p : PoolManager.getAll().values()) {
+          assertThat(((PoolImpl) p).getReadyForEventsCalled()).isFalse();
         }
-      });
+      }
+    });
 
-      // Send clientReady message
-      sendClientReady(durableClientVM);
-      registerDurableCq(cqName);
+    // Send clientReady message
+    sendClientReady(durableClientVM);
+    registerDurableCq(cqName);
 
-      // Verify durable client on server1
-      verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId, server1VM);
+    // Verify durable client on server1
+    verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId, server1VM);
 
-      // Start normal publisher client
-      this.publisherClientVM.invoke(() -> CacheServerTestUtil.createCacheClient(
-          getClientPool(getServerHostName(), server1Port, false),
-          regionName));
+    // Start normal publisher client
+    publisherClientVM.invoke(() -> createCacheClient(
+        getClientPool(publisherClientVM.getHost().getHostName(), server1Port,
+            false),
+        regionName));
 
-      // Publish some entries
-      final int numberOfEntries = 10;
-      publishEntries(0, numberOfEntries);
+    // Publish some entries
+    final int numberOfEntries = 10;
+    publishEntries(publisherClientVM, 0, numberOfEntries);
 
-      // Verify the durable client received the updates
-      checkCqListenerEvents(this.durableClientVM, cqName, numberOfEntries,
-          VERY_LONG_DURABLE_TIMEOUT_SECONDS);
+    // Verify the durable client received the updates
+    checkCqListenerEvents(durableClientVM, cqName, numberOfEntries,
+        VERY_LONG_DURABLE_TIMEOUT_SECONDS);
 
-      Thread.sleep(10000);
+    Thread.sleep(10000);
 
-      // Stop the durable client
-      this.durableClientVM.invoke(() -> CacheServerTestUtil.closeCache(Boolean.TRUE));
+    // Stop the durable client
+    durableClientVM.invoke(() -> CacheServerTestUtil.closeCache(true));
 
-      // Verify the durable client still exists on the server
-      verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId,
-          server1VM);
+    // Verify the durable client still exists on the server
+    verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId,
+        server1VM);
 
-      // Publish some more entries
-      publishEntries(10, numberOfEntries);
+    // Publish some more entries
+    publishEntries(publisherClientVM, 10, numberOfEntries);
 
-      this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
-      // Re-start the durable client
-      this.durableClientVM.invoke(() -> CacheServerTestUtil.createCacheClientFromXml(
-          DurableClientTestBase.class.getResource("durablecq-client-cache.xml"), "client",
-          durableClientId, VERY_LONG_DURABLE_TIMEOUT_SECONDS, Boolean.FALSE));
+    // Re-start the durable client
+    durableClientVM.invoke(() -> createCacheClientFromXml(
+        DurableClientTestBase.class.getResource("durablecq-client-cache.xml"), "client",
+        durableClientId, VERY_LONG_DURABLE_TIMEOUT_SECONDS, false));
 
-      // Durable client registers durable cq on server
-      registerDurableCq(cqName);
+    // Durable client registers durable cq on server
+    registerDurableCq(cqName);
 
-      // Send clientReady message
-      sendClientReady(this.durableClientVM);
+    // Send clientReady message
+    sendClientReady(durableClientVM);
 
-      // Verify durable client on server
-      verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId, server1VM);
+    // Verify durable client on server
+    verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId, server1VM);
 
-      // Verify the durable client received the updates held for it on the server
-      checkCqListenerEvents(this.durableClientVM, cqName, 10, VERY_LONG_DURABLE_TIMEOUT_SECONDS);
+    // Verify the durable client received the updates held for it on the server
+    checkCqListenerEvents(durableClientVM, cqName, 10, VERY_LONG_DURABLE_TIMEOUT_SECONDS);
 
-      // Stop the durable client
-      this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    // Stop the durable client
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+
+    // Stop the server
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
-      // Stop the server
-      this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
-    } finally {
-      unsetPeriodicACKObserver(durableClientVM);
-    }
   }
 
-  private void setPeriodicACKObserver(VM vm) {
-    CacheSerializableRunnable cacheSerializableRunnable =
-        new CacheSerializableRunnable("Set ClientServerObserver") {
-          @Override
-          public void run2() throws CacheException {
-            PoolImpl.BEFORE_SENDING_CLIENT_ACK_CALLBACK_FLAG = true;
-            ClientServerObserverHolder.setInstance(new ClientServerObserverAdapter() {
-              @Override
-              public void beforeSendingClientAck() {
-                // logger.info("beforeSendingClientAck invoked");
-
-              }
-            });
-
-          }
-        };
-    vm.invoke(cacheSerializableRunnable);
-  }
-
-  private void unsetPeriodicACKObserver(VM vm) {
-    CacheSerializableRunnable cacheSerializableRunnable =
-        new CacheSerializableRunnable("Unset ClientServerObserver") {
-          @Override
-          public void run2() throws CacheException {
-            PoolImpl.BEFORE_SENDING_CLIENT_ACK_CALLBACK_FLAG = false;
-          }
-        };
-    vm.invoke(cacheSerializableRunnable);
-  }
 
   public VM getPrimaryServerVM() {
-    if (this.server1Port == getPrimaryServerPort()) {
+    if (server1Port == getPrimaryServerPort()) {
       return server1VM;
     } else {
       return server2VM;
@@ -1087,49 +1052,37 @@ public class DurableClientCQDUnitTest extends DurableClientTestBase {
   }
 
   public int getPrimaryServerPort() {
-    PoolImpl pool = CacheServerTestUtil.getPool();
+    PoolImpl pool = getPool();
     ServerLocation primaryServerLocation = pool.getPrimary();
     return primaryServerLocation.getPort();
   }
 
   public void waitForFailoverToPerform(int oldPrimaryPort) {
-    final PoolImpl pool = CacheServerTestUtil.getPool();
-    WaitCriterion ev = new WaitCriterion() {
-      @Override
-      public boolean done() {
-        return pool.getPrimary() != null && pool.getPrimary().getPort() != oldPrimaryPort;
-      }
-
-      @Override
-      public String description() {
-        return null;
-      }
-    };
-
-    GeodeAwaitility.await().untilAsserted(ev);
-    assertNotNull(pool.getPrimary());
+    final PoolImpl pool = getPool();
+    await().until(() -> pool.getPrimary() != null && pool.getPrimary().getPort() != oldPrimaryPort);
+    assertThat(pool.getPrimary()).isNotNull();
   }
 
   void registerDurableCq(final String cqName) {
     // Durable client registers durable cq on server
-    this.durableClientVM.invoke(new CacheSerializableRunnable("Register Cq") {
+    durableClientVM.invoke("Register Cq", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
         // Get the region
-        Region<Object, Object> region = CacheServerTestUtil.getCache().getRegion(regionName);
-        assertNotNull(region);
+        Region<Object, Object> region = getCache().getRegion(regionName);
+        assertThat(region).isNotNull();
 
         // Create CQ Attributes.
         CqAttributesFactory cqAf = new CqAttributesFactory();
 
         // Initialize and set CqListener.
-        CqListener[] cqListeners = {new CacheServerTestUtil.ControlCqListener()};
+        CqListener[] cqListeners = {new ControlCqListener()};
         cqAf.initCqListeners(cqListeners);
         CqAttributes cqa = cqAf.create();
 
         // Create cq's
         // Get the query service for the Pool
-        QueryService queryService = CacheServerTestUtil.getPool().getQueryService();
+        QueryService queryService = getPool().getQueryService();
 
         try {
           CqQuery query =
