@@ -21,12 +21,18 @@ import static org.apache.geode.distributed.ConfigurationProperties.DURABLE_CLIEN
 import static org.apache.geode.distributed.ConfigurationProperties.DURABLE_CLIENT_TIMEOUT;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.ControlCqListener;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.ControlListener;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.createCacheClient;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.createCacheServer;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.getCache;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.getClientCache;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.getPool;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.fail;
 import static org.hamcrest.Matchers.notNullValue;
 import static org.hamcrest.Matchers.nullValue;
-import static org.junit.Assert.assertNotNull;
 
 import java.time.Duration;
 import java.util.Iterator;
@@ -34,8 +40,6 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.concurrent.CountDownLatch;
 
-import org.apache.logging.log4j.Logger;
-
 import org.apache.geode.cache.CacheException;
 import org.apache.geode.cache.InterestResultPolicy;
 import org.apache.geode.cache.Region;
@@ -59,18 +63,15 @@ import org.apache.geode.internal.cache.CacheServerImpl;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.PoolFactoryImpl;
 import org.apache.geode.internal.cache.ha.HARegionQueue;
-import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.test.awaitility.GeodeAwaitility;
 import org.apache.geode.test.dunit.IgnoredException;
 import org.apache.geode.test.dunit.NetworkUtils;
 import org.apache.geode.test.dunit.SerializableRunnableIF;
 import org.apache.geode.test.dunit.VM;
-import org.apache.geode.test.dunit.WaitCriterion;
 import org.apache.geode.test.dunit.internal.JUnit4DistributedTestCase;
 
 public class DurableClientTestBase extends JUnit4DistributedTestCase {
 
-  protected static final Logger logger = LogService.getLogger();
   private static final Duration VERY_LONG_DURABLE_CLIENT_TIMEOUT = Duration.ofMinutes(10);
   static final int VERY_LONG_DURABLE_TIMEOUT_SECONDS =
       (int) VERY_LONG_DURABLE_CLIENT_TIMEOUT.getSeconds();
@@ -86,12 +87,12 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   String durableClientId;
 
   @Override
-  public final void postSetUp() throws Exception {
-    this.server1VM = VM.getVM(0);
-    this.server2VM = VM.getVM(1);
-    this.durableClientVM = VM.getVM(2);
-    this.publisherClientVM = VM.getVM(3);
-    this.regionName = getName() + "_region";
+  public final void postSetUp() {
+    server1VM = VM.getVM(0);
+    server2VM = VM.getVM(1);
+    durableClientVM = VM.getVM(2);
+    publisherClientVM = VM.getVM(3);
+    regionName = getName() + "_region";
     // Clients see this when the servers disconnect
     IgnoredException.addIgnoredException("Could not find any server");
     System.out.println("\n\n[setup] START TEST " + getClass().getSimpleName() + "."
@@ -105,10 +106,10 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   public final void preTearDown() {
     preTearDownDurableClientTestBase();
 
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
-    this.server2VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server2VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   protected void preTearDownDurableClientTestBase() {}
@@ -116,11 +117,23 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
 
   void startupDurableClientAndServer(final int durableClientTimeout) {
 
-    server1Port = this.server1VM
-        .invoke(() -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+    server1Port = server1VM
+        .invoke(() -> createCacheServer(regionName, Boolean.TRUE));
 
     durableClientId = getName() + "_client";
-    startupDurableClient(durableClientTimeout, Boolean.TRUE);
+    durableClientVM.invoke(() -> createCacheClient(
+        getClientPool(NetworkUtils.getServerHostName(), server1Port, true), regionName,
+        getClientDistributedSystemProperties(durableClientId, durableClientTimeout),
+        Boolean.TRUE));
+
+    durableClientVM.invoke(() -> {
+      await().atMost(HEAVY_TEST_LOAD_DELAY_SUPPORT_MULTIPLIER, MINUTES)
+          .pollInterval(100, MILLISECONDS)
+          .until(CacheServerTestUtil::getCache, notNullValue());
+    });
+
+    // Send clientReady message
+    sendClientReady(durableClientVM);
     verifyDurableClientPresent(durableClientTimeout, durableClientId, server1VM);
 
   }
@@ -128,24 +141,26 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   // This exists so child classes can override the behavior and mock out network failures
   public void restartDurableClient(int durableClientTimeout, Pool clientPool,
       Boolean addControlListener) {
-    startupDurableClient(durableClientTimeout, clientPool, addControlListener);
+    durableClientVM.invoke(() -> createCacheClient(clientPool, regionName,
+        getClientDistributedSystemProperties(durableClientId, durableClientTimeout),
+        addControlListener));
+
+    durableClientVM.invoke(() -> {
+      await().atMost(HEAVY_TEST_LOAD_DELAY_SUPPORT_MULTIPLIER, MINUTES)
+          .pollInterval(100, MILLISECONDS)
+          .until(CacheServerTestUtil::getCache, notNullValue());
+    });
   }
 
   // This exists so child classes can override the behavior and mock out network failures
   public void restartDurableClient(int durableClientTimeout, Boolean addControlListener) {
-    startupDurableClient(durableClientTimeout, addControlListener);
-  }
-
-
-  void startupDurableClient(int durableClientTimeout, Pool clientPool,
-      Boolean addControlListener) {
-    this.durableClientVM.invoke(() -> CacheServerTestUtil.createCacheClient(
-        clientPool,
-        regionName, getClientDistributedSystemProperties(durableClientId, durableClientTimeout),
+    durableClientVM.invoke(() -> createCacheClient(
+        getClientPool(NetworkUtils.getServerHostName(), server1Port, true), regionName,
+        getClientDistributedSystemProperties(durableClientId, durableClientTimeout),
         addControlListener));
 
-    this.durableClientVM.invoke(() -> {
-      await().atMost(1 * HEAVY_TEST_LOAD_DELAY_SUPPORT_MULTIPLIER, MINUTES)
+    durableClientVM.invoke(() -> {
+      await().atMost(HEAVY_TEST_LOAD_DELAY_SUPPORT_MULTIPLIER, MINUTES)
           .pollInterval(100, MILLISECONDS)
           .until(CacheServerTestUtil::getCache, notNullValue());
     });
@@ -154,49 +169,24 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
     sendClientReady(durableClientVM);
   }
 
-  private void startupDurableClient(int durableClientTimeout, Boolean addControlListener) {
-    startupDurableClient(durableClientTimeout,
-        getClientPool(NetworkUtils.getServerHostName(), server1Port, true), addControlListener);
-  }
-
-  void verifySimpleDurableClient() {
-    verifyDurableClientNotPresent(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT,
-        durableClientId, durableClientVM);
-  }
-
   void verifyDurableClientPresent(int durableClientTimeout, String durableClientId,
       final VM serverVM) {
     verifyDurableClientPresence(durableClientTimeout, durableClientId, serverVM, 1);
   }
 
-  void verifyDurableClientNotPresent(int durableClientTimeout, String durableClientId,
+  void verifyDurableClientNotPresent(String durableClientId,
       final VM serverVM) {
-    verifyDurableClientPresence(durableClientTimeout, durableClientId, serverVM, 0);
+    verifyDurableClientPresence(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT, durableClientId,
+        serverVM, 0);
   }
 
-  void waitForDurableClientPresence(String durableClientId, VM serverVM, final int count) {
+  void waitForDurableClientPresence(String durableClientId, VM serverVM) {
     serverVM.invoke(() -> {
-      if (count > 0) {
-
-        WaitCriterion ev = new WaitCriterion() {
-          @Override
-          public boolean done() {
-            checkNumberOfClientProxies(count);
-            CacheClientProxy proxy = getClientProxy();
-
-            if (proxy != null && durableClientId.equals(proxy.getDurableId())) {
-              return true;
-            }
-            return false;
-          }
-
-          @Override
-          public String description() {
-            return null;
-          }
-        };
-        GeodeAwaitility.await().untilAsserted(ev);
-      }
+      GeodeAwaitility.await().until(() -> {
+        checkNumberOfClientProxies(1);
+        CacheClientProxy proxy = getClientProxy();
+        return proxy != null && durableClientId.equals(proxy.getDurableId());
+      });
     });
   }
 
@@ -207,9 +197,7 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
 
       if (count > 0) {
         CacheClientProxy proxy = getClientProxy();
-
         assertThat(proxy).isNotNull();
-        // checkProxyIsAlive(proxy);
 
         // Verify that it is durable and its properties are correct
         assertThat(proxy.isDurable()).isTrue();
@@ -219,38 +207,24 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
     });
   }
 
+  void waitUntilHARegionQueueSizeIsZero(VM serverVM) {
+    serverVM.invoke(() -> await().atMost(60, SECONDS)
+        .until(() -> getClientProxy().getHARegionQueue().size() == 0));
+  }
+
   public void closeDurableClient() {
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   public void disconnectDurableClient(boolean keepAlive) {
-    printClientProxyState("Before");
-    this.durableClientVM.invoke("close durable client cache",
+    durableClientVM.invoke("close durable client cache",
         () -> CacheServerTestUtil.closeCache(keepAlive));
-    await()
-        .until(CacheServerTestUtil::getCache, nullValue());
-    printClientProxyState("after");
-  }
-
-  private void printClientProxyState(String st) {
-    CacheSerializableRunnable s =
-        new CacheSerializableRunnable("Logging CCCP and ServerConnection state") {
-          @Override
-          public void run2() throws CacheException {
-            // TODO Auto-generated method stub
-            CacheServerTestUtil.getCache().getLogger()
-                .info(st + " CCP states: " + getAllClientProxyState());
-            CacheServerTestUtil.getCache().getLogger().info(st + " CHM states: "
-                + printMap(
-                    ClientHealthMonitor.getInstance().getConnectedClients(null)));
-          }
-        };
-    server1VM.invoke(s);
+    await().until(CacheServerTestUtil::getCache, nullValue());
   }
 
   private static String printMap(Map<String, Object[]> m) {
     Iterator<Map.Entry<String, Object[]>> itr = m.entrySet().iterator();
-    StringBuffer sb = new StringBuffer();
+    StringBuilder sb = new StringBuilder();
     sb.append("size = ").append(m.size()).append(" ");
     while (itr.hasNext()) {
       sb.append("{");
@@ -263,7 +237,7 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
     return sb.toString();
   }
 
-  private static void printMapValue(Object value, StringBuffer sb) {
+  private static void printMapValue(Object value, StringBuilder sb) {
     if (value.getClass().isArray()) {
 
       sb.append("{");
@@ -300,11 +274,11 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
     }
 
     registerInterest(client, regionName, false, InterestResultPolicy.NONE);
-    server.invoke(new CacheSerializableRunnable("flush entries") {
+    server.invoke("flush entries", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
-        Region<String, String> region = CacheServerTestUtil.getCache().getRegion(regionName);
-        assertNotNull(region);
+        Region<String, String> region = getCache().getRegion(regionName);
+        assertThat(region).isNotNull();
         region.put("LAST", "ENTRY");
       }
     });
@@ -315,7 +289,7 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   // The client will then be able to continue, and get rejected
   // Then we proceed to drain and release all locks
   // The client will then reconnect
-  public class RejectClientReconnectTestHook implements CacheClientProxy.TestHook {
+  public static class RejectClientReconnectTestHook implements CacheClientProxy.TestHook {
     final CountDownLatch reconnectLatch = new CountDownLatch(1);
     final CountDownLatch continueDrain = new CountDownLatch(1);
     volatile boolean clientWasRejected = false;
@@ -361,7 +335,8 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
    * wait to continue server will be unblocked, and rejected client will the be unlocked after
    * server is rejected and continue
    */
-  public class CqExceptionDueToActivatingClientTestHook implements CacheClientProxy.TestHook {
+  public static class CqExceptionDueToActivatingClientTestHook
+      implements CacheClientProxy.TestHook {
     final CountDownLatch unblockDrain = new CountDownLatch(1);
     final CountDownLatch unblockClient = new CountDownLatch(1);
     final CountDownLatch finish = new CountDownLatch(1);
@@ -402,9 +377,9 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
 
   CqQuery createCq(String cqName, String cqQuery, boolean durable)
       throws CqException, CqExistsException {
-    QueryService qs = CacheServerTestUtil.getCache().getQueryService();
+    QueryService qs = getCache().getQueryService();
     CqAttributesFactory cqf = new CqAttributesFactory();
-    CqListener[] cqListeners = {new CacheServerTestUtil.ControlCqListener()};
+    CqListener[] cqListeners = {new ControlCqListener()};
     cqf.initCqListeners(cqListeners);
     CqAttributes cqa = cqf.create();
     return qs.newCq(cqName, cqQuery, cqa, durable);
@@ -467,15 +442,7 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   }
 
   static void checkNumberOfClientProxies(final int expected) {
-    await()
-        .until(() -> {
-          return expected == getNumberOfClientProxies();
-        });
-  }
-
-  static void checkProxyIsAlive(final CacheClientProxy proxy) {
-    await()
-        .until(proxy::isAlive);
+    await().atMost(30, SECONDS).until(() -> expected == getNumberOfClientProxies());
   }
 
   private static int getNumberOfClientProxies() {
@@ -484,7 +451,7 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
 
   static CacheServerImpl getBridgeServer() {
     CacheServerImpl bridgeServer =
-        (CacheServerImpl) CacheServerTestUtil.getCache().getCacheServers().iterator().next();
+        (CacheServerImpl) getCache().getCacheServers().iterator().next();
     assertThat(bridgeServer).isNotNull();
     return bridgeServer;
   }
@@ -523,21 +490,21 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
 
   void sendClientReady(VM vm) {
     // Send clientReady message
-    vm.invoke(new CacheSerializableRunnable("Send clientReady") {
+    vm.invoke("Send clientReady", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
-        CacheServerTestUtil.getClientCache().readyForEvents();
+        getClientCache().readyForEvents();
       }
     });
   }
 
   protected void registerInterest(VM vm, final String regionName, final boolean durable,
       final InterestResultPolicy interestResultPolicy) {
-    vm.invoke(new CacheSerializableRunnable("Register interest on region : " + regionName) {
+    vm.invoke("Register interest on region : " + regionName, new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
 
-        Region<Object, Object> region = CacheServerTestUtil.getCache().getRegion(regionName);
+        Region<Object, Object> region = getCache().getRegion(regionName);
         assertThat(region).isNotNull();
 
         // Register interest in all keys
@@ -555,7 +522,7 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   }
 
   void createCq(VM vm, final String cqName, final String cqQuery, final boolean durable) {
-    vm.invoke(new CacheSerializableRunnable("Register cq " + cqName) {
+    vm.invoke("Register cq " + cqName, new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
 
@@ -570,14 +537,13 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   }
 
   // Publishes strings
-  void publishEntries(int startingValue, final int count) {
-    this.publisherClientVM.invoke(new CacheSerializableRunnable("Publish entries") {
+  void publishEntries(VM publisherClientVM, int startingValue, final int count) {
+    publisherClientVM.invoke("Publish entries", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
-        Region<String, String> region = CacheServerTestUtil.getCache().getRegion(
+        Region<String, String> region = getCache().getRegion(
             regionName);
         assertThat(region).isNotNull();
-
         // Publish some entries
         for (int i = startingValue; i < startingValue + count; i++) {
           String keyAndValue = String.valueOf(i);
@@ -590,12 +556,12 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   }
 
   // Publishes portfolios
-  void publishEntries(final String regionName, final int numEntries) {
-    publisherClientVM.invoke(new CacheSerializableRunnable("publish " + numEntries + " entries") {
+  void publishEntries(VM publisherClientVM, final String regionName, final int numEntries) {
+    publisherClientVM.invoke("publish " + numEntries + " entries", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
         // Get the region
-        Region<Object, Object> region = CacheServerTestUtil.getCache().getRegion(regionName);
+        Region<Object, Object> region = getCache().getRegion(regionName);
         assertThat(region).isNotNull();
 
         // Publish some entries
@@ -615,25 +581,27 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
 
   void checkCqStatOnServer(VM server, final String durableClientId, final String cqName,
       final int expectedNumber) {
-    server.invoke(new CacheSerializableRunnable(
-        "Check ha queued cq stats for durable client " + durableClientId + " cq: " + cqName) {
-      @Override
-      public void run2() throws CacheException {
+    server.invoke(
+        "Check ha queued cq stats for durable client " + durableClientId + " cq: " + cqName,
+        new CacheSerializableRunnable() {
+          @Override
+          public void run2() throws CacheException {
 
-        final CacheClientNotifier ccnInstance = CacheClientNotifier.getInstance();
-        final CacheClientProxy clientProxy = ccnInstance.getClientProxy(durableClientId);
-        ClientProxyMembershipID proxyId = clientProxy.getProxyID();
-        CqService cqService = ((InternalCache) CacheServerTestUtil.getCache()).getCqService();
-        cqService.start();
-        final CqQueryImpl cqQuery = (CqQueryImpl) cqService.getClientCqFromServer(proxyId, cqName);
+            final CacheClientNotifier ccnInstance = CacheClientNotifier.getInstance();
+            final CacheClientProxy clientProxy = ccnInstance.getClientProxy(durableClientId);
+            ClientProxyMembershipID proxyId = clientProxy.getProxyID();
+            CqService cqService = ((InternalCache) getCache()).getCqService();
+            cqService.start();
+            final CqQueryImpl cqQuery =
+                (CqQueryImpl) cqService.getClientCqFromServer(proxyId, cqName);
 
-        // Wait until we get the expected number of events or until 10 seconds are up
-        await()
-            .until(() -> cqQuery.getVsdStats().getNumHAQueuedEvents() == expectedNumber);
+            // Wait until we get the expected number of events or until 10 seconds are up
+            await()
+                .until(() -> cqQuery.getVsdStats().getNumHAQueuedEvents() == expectedNumber);
 
-        assertThat(expectedNumber).isEqualTo(cqQuery.getVsdStats().getNumHAQueuedEvents());
-      }
-    });
+            assertThat(expectedNumber).isEqualTo(cqQuery.getVsdStats().getNumHAQueuedEvents());
+          }
+        });
   }
 
   /*
@@ -642,44 +610,40 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
    */
   void checkHAQueueSize(VM server, final String durableClientId, final int expectedNumber,
       final int remaining) {
-    server.invoke(new CacheSerializableRunnable(
-        "Check ha queued size for durable client " + durableClientId) {
-      @Override
-      public void run2() throws CacheException {
+    server.invoke("Check ha queued size for durable client " + durableClientId,
+        new CacheSerializableRunnable() {
+          @Override
+          public void run2() throws CacheException {
 
-        final CacheClientNotifier ccnInstance = CacheClientNotifier.getInstance();
-        final CacheClientProxy clientProxy = ccnInstance.getClientProxy(durableClientId);
+            final CacheClientNotifier ccnInstance = CacheClientNotifier.getInstance();
+            final CacheClientProxy clientProxy = ccnInstance.getClientProxy(durableClientId);
 
-        // Wait until we get the expected number of events or until 10 seconds are up
-        await()
-            .until(() -> clientProxy.getQueueSizeStat() == expectedNumber
-                || clientProxy.getQueueSizeStat() == remaining);
-
-        assertThat(clientProxy.getQueueSizeStat() == expectedNumber
-            || clientProxy.getQueueSizeStat() == remaining).isTrue();
-      }
-    });
+            // Wait until we get the expected number of events or until 10 seconds are up
+            await().untilAsserted(
+                () -> assertThat(clientProxy.getQueueSizeStat()).isIn(expectedNumber, remaining));
+          }
+        });
   }
 
   void checkNumDurableCqs(VM server, final String durableClientId,
       final int expectedNumber) {
-    server.invoke(new CacheSerializableRunnable(
-        "check number of durable cqs on server for durable client: " + durableClientId) {
-      @Override
-      public void run2() throws CacheException {
-        try {
-          final CacheClientNotifier ccnInstance = CacheClientNotifier.getInstance();
-          final CacheClientProxy clientProxy = ccnInstance.getClientProxy(durableClientId);
-          ClientProxyMembershipID proxyId = clientProxy.getProxyID();
-          CqService cqService = ((InternalCache) CacheServerTestUtil.getCache()).getCqService();
-          cqService.start();
-          java.util.List<String> cqNames = cqService.getAllDurableClientCqs(proxyId);
-          assertThat(expectedNumber).isEqualTo(cqNames.size());
-        } catch (Exception e) {
-          throw new CacheException(e) {};
-        }
-      }
-    });
+    server.invoke("check number of durable cqs on server for durable client: " + durableClientId,
+        new CacheSerializableRunnable() {
+          @Override
+          public void run2() throws CacheException {
+            try {
+              final CacheClientNotifier ccnInstance = CacheClientNotifier.getInstance();
+              final CacheClientProxy clientProxy = ccnInstance.getClientProxy(durableClientId);
+              ClientProxyMembershipID proxyId = clientProxy.getProxyID();
+              CqService cqService = ((InternalCache) getCache()).getCqService();
+              cqService.start();
+              java.util.List<String> cqNames = cqService.getAllDurableClientCqs(proxyId);
+              assertThat(expectedNumber).isEqualTo(cqNames.size());
+            } catch (Exception e) {
+              throw new CacheException(e) {};
+            }
+          }
+        });
   }
 
   /*
@@ -690,19 +654,16 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
    */
   void checkCqListenerEvents(VM vm, final String cqName, final int numEvents,
       final int secondsToWait) {
-    vm.invoke(() -> {
-      checkCqListenerEvents(cqName, numEvents, secondsToWait);
-    });
+    vm.invoke(() -> checkCqListenerEvents(cqName, numEvents, secondsToWait));
   }
 
-  void checkCqListenerEvents(final String cqName, final int numEvents,
-      final int secondsToWait) {
-    QueryService qs = CacheServerTestUtil.getCache().getQueryService();
+  void checkCqListenerEvents(final String cqName, final int numEvents, final int secondsToWait) {
+    QueryService qs = getCache().getQueryService();
     CqQuery cq = qs.getCq(cqName);
     // Get the listener and wait for the appropriate number of events
-    CacheServerTestUtil.ControlCqListener listener =
-        (CacheServerTestUtil.ControlCqListener) cq.getCqAttributes().getCqListener();
-    listener.waitWhileNotEnoughEvents(secondsToWait * 1000, numEvents);
+    ControlCqListener listener =
+        (ControlCqListener) cq.getCqAttributes().getCqListener();
+    listener.waitWhileNotEnoughEvents(SECONDS.toMillis(secondsToWait), numEvents);
     assertThat(numEvents).isEqualTo(listener.events.size());
   }
 
@@ -710,21 +671,20 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
       final VM vm) {
     vm.invoke(() -> {
       // Get the region
-      Region<Object, Object> region = CacheServerTestUtil.getCache().getRegion(regionName);
+      Region<Object, Object> region = getCache().getRegion(regionName);
       assertThat(region).isNotNull();
 
       // Get the listener and wait for the appropriate number of events
-      CacheServerTestUtil.ControlListener controlListener =
-          (CacheServerTestUtil.ControlListener) region.getAttributes().getCacheListeners()[0];
-
-      controlListener.waitWhileNotEnoughEvents(sleepMinutes * 60 * 1000, numberOfEntries,
+      ControlListener controlListener =
+          (ControlListener) region.getAttributes().getCacheListeners()[0];
+      controlListener.waitWhileNotEnoughEvents(MINUTES.toMillis(sleepMinutes), numberOfEntries,
           controlListener.getEvents(eventType));
     });
   }
 
   void startDurableClient(VM vm, String durableClientId, int serverPort1,
       String regionName, int durableTimeoutInSeconds) {
-    vm.invoke(() -> CacheServerTestUtil.createCacheClient(
+    vm.invoke(() -> createCacheClient(
         getClientPool(NetworkUtils.getServerHostName(), serverPort1, true),
         regionName, getClientDistributedSystemProperties(durableClientId, durableTimeoutInSeconds),
         Boolean.TRUE));
@@ -733,38 +693,35 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   void startDurableClient(VM vm, String durableClientId, int serverPort1,
       String regionName) {
     vm.invoke(() -> {
-      CacheServerTestUtil.createCacheClient(
+      createCacheClient(
           getClientPool(NetworkUtils.getServerHostName(), serverPort1, true),
           regionName, getClientDistributedSystemProperties(durableClientId), Boolean.TRUE);
-      assertThat(CacheServerTestUtil.getClientCache()).isNotNull();
+      assertThat(getClientCache()).isNotNull();
     });
   }
 
   void startDurableClient(VM vm, String durableClientId, int serverPort1, int serverPort2,
       String regionName) {
-    vm.invoke(() -> CacheServerTestUtil.createCacheClient(
+    vm.invoke(() -> createCacheClient(
         getClientPool(NetworkUtils.getServerHostName(), serverPort1, serverPort2, true),
         regionName, getClientDistributedSystemProperties(durableClientId), Boolean.TRUE));
   }
 
   void startClient(VM vm, int serverPort1, String regionName) {
     vm.invoke(() -> {
-      CacheServerTestUtil.createCacheClient(
+      createCacheClient(
           getClientPool(NetworkUtils.getServerHostName(), serverPort1, false),
           regionName);
-      assertThat(CacheServerTestUtil.getClientCache()).isNotNull();
+      assertThat(getClientCache()).isNotNull();
     });
   }
 
   void checkPrimaryUpdater(VM vm) {
-    vm.invoke(new CacheSerializableRunnable("Verify durable client") {
+    vm.invoke("Verify durable client", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
-
-        await()
-            .until(() -> CacheServerTestUtil.getPool().isPrimaryUpdaterAlive());
-
-        assertThat(CacheServerTestUtil.getPool().isPrimaryUpdaterAlive()).isTrue();
+        await().until(() -> getPool().isPrimaryUpdaterAlive());
+        assertThat(getPool().isPrimaryUpdaterAlive()).isTrue();
       }
     });
   }
@@ -772,6 +729,4 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   protected void closeCache(VM vm) {
     vm.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
-
-
 }
