@@ -16,12 +16,18 @@ package org.apache.geode.internal.cache.tier.sockets;
 
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
 import static java.util.concurrent.TimeUnit.MINUTES;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.createCacheClient;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.createCacheServer;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.createCacheServerReturnPorts;
 import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.getCache;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.getClientCache;
+import static org.apache.geode.internal.cache.tier.sockets.CacheServerTestUtil.unsetJavaSystemProperties;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.hamcrest.Matchers.notNullValue;
 
 import java.util.Properties;
+import java.util.concurrent.TimeUnit;
 
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
@@ -59,9 +65,9 @@ public class DurableClientTestCase extends DurableClientTestBase {
     startupDurableClientAndServer(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
-    this.closeDurableClient();
+    closeDurableClient();
 
   }
 
@@ -71,26 +77,26 @@ public class DurableClientTestCase extends DurableClientTestBase {
    * not
    */
   @Test
-  public void testSpecialDurableProperty() throws InterruptedException {
+  public void testSpecialDurableProperty() {
     final Properties jp = new Properties();
     jp.setProperty(GeodeGlossary.GEMFIRE_PREFIX + "SPECIAL_DURABLE", "true");
 
     try {
 
-      server1Port = this.server1VM
-          .invoke(() -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+      server1Port = server1VM
+          .invoke(() -> createCacheServer(regionName, true));
 
       durableClientId = getName() + "_client";
       final String dId = durableClientId + "_gem_" + "CacheServerTestUtil";
 
-      this.durableClientVM.invoke(() -> CacheServerTestUtil.createCacheClient(
-          getClientPool(NetworkUtils.getServerHostName(), server1Port, Boolean.TRUE),
+      durableClientVM.invoke(() -> createCacheClient(
+          getClientPool(NetworkUtils.getServerHostName(), server1Port, true),
           regionName, getClientDistributedSystemProperties(durableClientId,
               DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT),
-          Boolean.TRUE, jp));
+          true, jp));
 
-      this.durableClientVM.invoke(() -> {
-        await().atMost(1 * HEAVY_TEST_LOAD_DELAY_SUPPORT_MULTIPLIER, MINUTES)
+      durableClientVM.invoke(() -> {
+        await().atMost(HEAVY_TEST_LOAD_DELAY_SUPPORT_MULTIPLIER, MINUTES)
             .pollInterval(100, MILLISECONDS)
             .until(CacheServerTestUtil::getCache, notNullValue());
       });
@@ -99,7 +105,7 @@ public class DurableClientTestCase extends DurableClientTestBase {
       sendClientReady(durableClientVM);
 
       // Verify durable client on server
-      this.server1VM.invoke(() -> {
+      server1VM.invoke(() -> {
         // Find the proxy
         checkNumberOfClientProxies(1);
         CacheClientProxy proxy = getClientProxy();
@@ -119,19 +125,19 @@ public class DurableClientTestCase extends DurableClientTestBase {
       });
 
       // Stop the durable client
-      this.disconnectDurableClient(false);
+      disconnectDurableClient(false);
 
       // Verify the durable client is present on the server for closeCache=false case.
-      this.verifyDurableClientNotPresent(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT,
+      verifyDurableClientNotPresent(
           durableClientId, server1VM);
 
       // Stop the server
-      this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+      server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
-      this.closeDurableClient();
+      closeDurableClient();
     } finally {
 
-      this.durableClientVM.invoke(() -> CacheServerTestUtil.unsetJavaSystemProperties(jp));
+      durableClientVM.invoke(() -> unsetJavaSystemProperties(jp));
     }
 
   }
@@ -146,21 +152,21 @@ public class DurableClientTestCase extends DurableClientTestBase {
     startupDurableClientAndServer(VERY_LONG_DURABLE_TIMEOUT_SECONDS);
 
     // Stop the durable client
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
     verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId, server1VM);
 
     // Re-start the durable client
-    this.restartDurableClient(VERY_LONG_DURABLE_TIMEOUT_SECONDS, Boolean.TRUE);
+    restartDurableClient(VERY_LONG_DURABLE_TIMEOUT_SECONDS, true);
 
     // Verify durable client on server
     verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId, server1VM);
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   /**
@@ -172,28 +178,27 @@ public class DurableClientTestCase extends DurableClientTestBase {
     startupDurableClientAndServer(VERY_LONG_DURABLE_TIMEOUT_SECONDS);
 
     // Stop the durable client
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
     // Verify the durable client still exists on the server, and the socket is closed
-    this.server1VM.invoke(() -> {
+    server1VM.invoke(() -> {
       // Find the proxy
       CacheClientProxy proxy = getClientProxy();
       assertThat(proxy).isNotNull();
       assertThat(proxy._socket).isNotNull();
 
-      await()
-          .untilAsserted(() -> assertThat(proxy._socket.isClosed()).isTrue());
+      await().untilAsserted(() -> assertThat(proxy._socket.isClosed()).isTrue());
     });
 
     // Re-start the durable client (this is necessary so the
     // netDown test will set the appropriate system properties.
-    this.restartDurableClient(VERY_LONG_DURABLE_TIMEOUT_SECONDS, Boolean.TRUE);
+    restartDurableClient(VERY_LONG_DURABLE_TIMEOUT_SECONDS, true);
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   /**
@@ -207,10 +212,10 @@ public class DurableClientTestCase extends DurableClientTestBase {
     startupDurableClientAndServer(durableClientTimeout);
 
     // Stop the durable client
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
     // Verify it no longer exists on the server
-    this.server1VM.invoke(new CacheSerializableRunnable("Verify durable client") {
+    server1VM.invoke("Verify durable client", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
         // Find the proxy
@@ -220,13 +225,13 @@ public class DurableClientTestCase extends DurableClientTestBase {
       }
     });
 
-    this.restartDurableClient(durableClientTimeout, Boolean.TRUE);
+    restartDurableClient(durableClientTimeout, true);
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   /**
@@ -236,56 +241,56 @@ public class DurableClientTestCase extends DurableClientTestBase {
   public void testDurableClientPrimaryUpdate() {
     startupDurableClientAndServer(VERY_LONG_DURABLE_TIMEOUT_SECONDS);
 
-    registerInterest(this.durableClientVM, regionName, true, InterestResultPolicy.NONE);
+    registerInterest(durableClientVM, regionName, true, InterestResultPolicy.NONE);
 
     // Start normal publisher client
-    this.publisherClientVM.invoke(() -> CacheServerTestUtil.createCacheClient(
+    publisherClientVM.invoke(() -> createCacheClient(
         getClientPool(NetworkUtils.getServerHostName(), server1Port,
             false),
         regionName));
 
     // Publish some entries
-    publishEntries(0, 1);
+    publishEntries(publisherClientVM, 0, 1);
 
     // Wait until queue count is 0 on server1VM
-    waitUntilQueueContainsRequiredNumberOfEvents(this.server1VM, 0);
+    waitUntilQueueContainsRequiredNumberOfEvents(server1VM, 0);
 
     // Verify the durable client received the updates
-    this.checkListenerEvents(1, 1, -1, this.durableClientVM);
+    checkListenerEvents(1, 1, -1, durableClientVM);
 
     // Stop the durable client
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
     // Make sure the proxy is actually paused, not dispatching
-    this.server1VM.invoke(DurableClientTestBase::waitForCacheClientProxyPaused);
+    server1VM.invoke(DurableClientTestBase::waitForCacheClientProxyPaused);
 
     // Publish some more entries
-    publishEntries(1, 1);
+    publishEntries(publisherClientVM, 1, 1);
 
     // Verify the durable client's queue contains the entries
-    waitUntilQueueContainsRequiredNumberOfEvents(this.server1VM, 1);
+    waitUntilQueueContainsRequiredNumberOfEvents(server1VM, 1);
 
     // Verify that disconnected client does not receive any events.
-    this.verifyListenerUpdatesDisconnected(1);
+    verifyListenerUpdatesDisconnected(1);
 
     // Re-start the durable client
-    this.restartDurableClient(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT, Boolean.TRUE);
+    restartDurableClient(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT, true);
 
     // Verify durable client on server
     verifyDurableClientPresent(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT, durableClientId,
         server1VM);
 
     // Verify the durable client received the updates held for it on the server
-    this.checkListenerEvents(1, 1, -1, this.durableClientVM);
+    checkListenerEvents(1, 1, -1, durableClientVM);
 
     // Stop the publisher client
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the durable client VM
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
 
@@ -296,19 +301,19 @@ public class DurableClientTestCase extends DurableClientTestBase {
   public void testStartStopStartDurableClientUpdate() {
     startupDurableClientAndServer(VERY_LONG_DURABLE_TIMEOUT_SECONDS);
     // Have the durable client register interest in all keys
-    registerInterest(this.durableClientVM, regionName, true, InterestResultPolicy.NONE);
+    registerInterest(durableClientVM, regionName, true, InterestResultPolicy.NONE);
 
     // Start normal publisher client
-    this.publisherClientVM.invoke(() -> CacheServerTestUtil.createCacheClient(
+    publisherClientVM.invoke(() -> createCacheClient(
         getClientPool(NetworkUtils.getServerHostName(), server1Port,
             false),
         regionName));
 
     // Publish some entries
-    publishEntries(0, 1);
+    publishEntries(publisherClientVM, 0, 1);
 
     // Verify the durable client received the updates
-    this.checkListenerEvents(1, 1, -1, this.durableClientVM);
+    checkListenerEvents(1, 1, -1, durableClientVM);
 
     server1VM.invoke("wait for client acknowledgement", () -> {
       CacheClientProxy proxy = getClientProxy();
@@ -318,16 +323,16 @@ public class DurableClientTestCase extends DurableClientTestBase {
     });
 
     // Stop the durable client
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
     // Verify the durable client still exists on the server
-    this.server1VM.invoke(DurableClientTestBase::waitForCacheClientProxyPaused);
+    server1VM.invoke(DurableClientTestBase::waitForCacheClientProxyPaused);
 
     // Publish some entries
-    publishEntries(1, 1);
+    publishEntries(publisherClientVM, 1, 1);
 
     // Verify the durable client's queue contains the entries
-    this.server1VM.invoke(new CacheSerializableRunnable("Verify durable client") {
+    server1VM.invoke("Verify durable client", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
         CacheClientProxy proxy = getClientProxy();
@@ -338,26 +343,26 @@ public class DurableClientTestCase extends DurableClientTestBase {
     });
 
     // Verify that disconnected client does not receive any events.
-    this.verifyListenerUpdatesDisconnected(1);
+    verifyListenerUpdatesDisconnected(1);
 
     // Re-start the durable client
-    this.restartDurableClient(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT, Boolean.TRUE);
+    restartDurableClient(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT, true);
 
     // Verify durable client on server
     verifyDurableClientPresent(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT, durableClientId,
         server1VM);
 
     // Verify the durable client received the updates held for it on the server
-    this.checkListenerEvents(1, 1, -1, this.durableClientVM);
+    checkListenerEvents(1, 1, -1, durableClientVM);
 
     // Stop the publisher client
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the durable client VM
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
   /**
@@ -367,68 +372,69 @@ public class DurableClientTestCase extends DurableClientTestBase {
   public void testDurableClientConnectServerStopStart() {
     // Start a server
     // Start server 1
-    Integer[] ports = this.server1VM.invoke(
-        () -> CacheServerTestUtil.createCacheServerReturnPorts(regionName, Boolean.TRUE));
+    Integer[] ports = server1VM.invoke(
+        () -> createCacheServerReturnPorts(regionName, true));
     final int serverPort = ports[0];
 
     // Start a durable client that is not kept alive on the server when it
     // stops normally
     final String durableClientId = getName() + "_client";
-    this.durableClientVM.invoke(() -> CacheServerTestUtil.createCacheClient(
+    durableClientVM.invoke(() -> createCacheClient(
         getClientPool(NetworkUtils.getServerHostName(), serverPort, true),
-        regionName, getClientDistributedSystemProperties(durableClientId), Boolean.TRUE));
+        regionName, getClientDistributedSystemProperties(durableClientId), true));
+
+    registerInterest(durableClientVM, regionName, true, InterestResultPolicy.NONE);
 
     // Send clientReady message
-    this.durableClientVM.invoke(new CacheSerializableRunnable("Send clientReady") {
+    durableClientVM.invoke("Send clientReady", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
-        CacheServerTestUtil.getClientCache().readyForEvents();
+        getClientCache().readyForEvents();
       }
     });
 
-    registerInterest(this.durableClientVM, regionName, true, InterestResultPolicy.NONE);
-
     // Verify durable client on server
     verifyDurableClientPresent(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT, durableClientId,
         server1VM);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Re-start the server
-    this.server1VM.invoke(() -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE,
-        serverPort));
+    server1VM.invoke(() -> createCacheServer(regionName, true, serverPort));
 
     // Verify durable client on server
     verifyDurableClientPresent(DistributionConfig.DEFAULT_DURABLE_CLIENT_TIMEOUT, durableClientId,
         server1VM);
 
     // Start a publisher
-    this.publisherClientVM.invoke(() -> CacheServerTestUtil.createCacheClient(
-        getClientPool(NetworkUtils.getServerHostName(), serverPort,
-            false),
-        regionName));
+    publisherClientVM.invoke(() -> createCacheClient(getClientPool(NetworkUtils.getServerHostName(),
+        serverPort, false), regionName));
 
     // Publish some entries
-    publishEntries(0, 10);
+    publishEntries(publisherClientVM, 0, 10);
 
     // Verify the durable client received the updates
-    checkListenerEvents(10, 1, -1, this.durableClientVM);
+    checkListenerEvents(10, 1, -1, durableClientVM);
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the publisher client
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the server
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
 
   @Test
   public void testDurableNonHAFailover() {
     durableFailover(0);
+  }
+
+  @Test
+  public void testDurableNonHAFailoverAfterReconnect() {
     durableFailoverAfterReconnect(0);
   }
 
@@ -437,6 +443,12 @@ public class DurableClientTestCase extends DurableClientTestBase {
     // Clients see this when the servers disconnect
     IgnoredException.addIgnoredException("Could not find any server");
     durableFailover(1);
+  }
+
+  @Test
+  public void testDurableHAFailoverAfterReconnect() {
+    // Clients see this when the servers disconnect
+    IgnoredException.addIgnoredException("Could not find any server");
     durableFailoverAfterReconnect(1);
   }
 
@@ -446,17 +458,13 @@ public class DurableClientTestCase extends DurableClientTestBase {
    * Redundancy level is set to 1 for this test case.
    */
   private void durableFailover(int redundancyLevel) {
-
     // Start server 1
-    server1Port = this.server1VM.invoke(
-        () -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+    server1Port = server1VM.invoke(() -> createCacheServer(regionName, true));
 
-    // Start server 2 using the same mcast port as server 1
-    final int server2Port = this.server2VM
-        .invoke(() -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE));
+    final int server2Port = server2VM.invoke(() -> createCacheServer(regionName, true));
 
     // Stop server 2
-    this.server2VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server2VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Start a durable client
     durableClientId = getName() + "_client";
@@ -470,93 +478,110 @@ public class DurableClientTestCase extends DurableClientTestBase {
           server2Port, true, 0);
     }
 
-    this.durableClientVM.invoke(CacheServerTestUtil::disableShufflingOfEndpoints);
-    this.durableClientVM.invoke(() -> CacheServerTestUtil.createCacheClient(clientPool, regionName,
+    durableClientVM.invoke(CacheServerTestUtil::disableShufflingOfEndpoints);
+    durableClientVM.invoke(() -> createCacheClient(clientPool, regionName,
         getClientDistributedSystemProperties(durableClientId, VERY_LONG_DURABLE_TIMEOUT_SECONDS),
-        Boolean.TRUE));
+        true));
+
+    registerInterest(durableClientVM, regionName, true, InterestResultPolicy.NONE);
 
     // Send clientReady message
-    this.durableClientVM.invoke(new CacheSerializableRunnable("Send clientReady") {
+    durableClientVM.invoke("Send clientReady", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
-        CacheServerTestUtil.getClientCache().readyForEvents();
+        getCache().readyForEvents();
       }
     });
 
-    registerInterest(this.durableClientVM, regionName, true, InterestResultPolicy.NONE);
+    // Verify the durable client is connected to server1
+    verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId, server1VM);
 
-    // Re-start server2
-    this.server2VM.invoke(() -> CacheServerTestUtil.createCacheServer(regionName, Boolean.TRUE,
-        server2Port));
+    // Re-start server2 and wait for it to be up.
+    server2VM.invoke(() -> createCacheServer(regionName, true, server2Port));
 
+    if (redundancyLevel == 1) {
+      // Verify the durable client is connected to server2
+      verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId, server2VM);
+    }
     // Start normal publisher client
-    this.publisherClientVM.invoke(() -> CacheServerTestUtil.createCacheClient(
-        getClientPool(NetworkUtils.getServerHostName(), server1Port,
-            server2Port, false),
-        regionName));
+    publisherClientVM.invoke(() -> createCacheClient(getClientPool(
+        NetworkUtils.getServerHostName(), server1Port, server2Port,
+        false), regionName));
 
     // Publish some entries
-    publishEntries(0, 1);
+    publishEntries(publisherClientVM, 0, 1);
 
     // Verify the durable client received the updates
-    this.checkListenerEvents(1, 1, -1, this.durableClientVM);
+    checkListenerEvents(1, 1, -1, durableClientVM);
+
+    // Wait to until the HARegionQueue has emptied before disconnecting the Durable client
+    // to avoid having left over messages that processed, in particular, the key 0 message
+    waitUntilHARegionQueueSizeIsZero(server1VM);
 
     // Stop the durable client, which discards the known entry
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
-    // Publish updates during client downtime
-    publishEntries(1, 1);
+    // Put key 1 during client downtime
+    publishEntries(publisherClientVM, 1, 1);
 
     // Re-start the durable client that is kept alive on the server
-    this.restartDurableClient(VERY_LONG_DURABLE_TIMEOUT_SECONDS, clientPool, Boolean.TRUE);
+    restartDurableClient(VERY_LONG_DURABLE_TIMEOUT_SECONDS, clientPool, true);
 
-    registerInterest(this.durableClientVM, regionName, true, InterestResultPolicy.NONE);
+    // Re-register interest
+    registerInterest(durableClientVM, regionName, true, InterestResultPolicy.NONE);
 
-    publishEntries(2, 1);
+    // Send clientReady message
+    sendClientReady(durableClientVM);
 
-    // Verify the durable client received the updates before failover
-    this.checkListenerEvents(2, 1, -1, this.durableClientVM);
+    // put key 2
+    publishEntries(publisherClientVM, 2, 1);
 
-    this.durableClientVM.invoke("Get", () -> {
-      await().untilAsserted(() -> {
-        Region<Object, Object> region = getCache().getRegion(regionName);
-        assertThat(region).isNotNull();
+    // Verify the durable client received the 2 total updates
+    checkListenerEvents(2, 1, -1, durableClientVM);
 
-        assertThat(region.getEntry("0")).isNull();
-        assertThat(region.getEntry("2")).isNotNull();
-      });
-    });
+    // Verify that the 0 entry is not present, but that 2 is.
+    durableClientVM.invoke("Get", () -> await().atMost(10, TimeUnit.SECONDS).untilAsserted(() -> {
+      Region<Object, Object> region = getCache().getRegion(regionName);
+      assertThat(region).isNotNull();
+
+      assertThat(region.getEntry("0")).isNull();
+      assertThat(region.getEntry("2")).isNotNull();
+    }));
 
     // Stop server 1
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Verify durable client failed over if redundancyLevel=0
     if (redundancyLevel == 0) {
-      this.server2VM.invoke(() -> verifyClientHasConnected());
+      server2VM.invoke(this::verifyClientHasConnected);
     }
 
-    publishEntries(3, 1);
+    // put key 3
+    publishEntries(publisherClientVM, 3, 1);
 
     // Verify the durable client received the updates after failover
-    this.checkListenerEvents(3, 1, -1, this.durableClientVM);
+    checkListenerEvents(3, 1, -1, durableClientVM);
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the publisher client
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop server 2
-    this.server2VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server2VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
+  /**
+   * wait unit we have the required number of events in the queue
+   */
   private void waitUntilQueueContainsRequiredNumberOfEvents(final VM vm,
       final int requiredEntryCount) {
-    vm.invoke(new CacheSerializableRunnable("Verify durable client") {
+    vm.invoke("Verify durable client", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
 
-        await().until(() -> {
+        await().atMost(30, TimeUnit.SECONDS).until(() -> {
           CacheClientProxy proxy = getClientProxy();
           if (proxy == null) {
             return false;
@@ -571,11 +596,10 @@ public class DurableClientTestCase extends DurableClientTestBase {
 
   private void durableFailoverAfterReconnect(int redundancyLevel) {
     // Start server 1
-    server1Port = this.server1VM
-        .invoke(() -> CacheServerTestUtil.createCacheServer(regionName, true));
+    server1Port = server1VM.invoke(() -> createCacheServer(regionName, true));
 
-    int server2Port = this.server2VM
-        .invoke(() -> CacheServerTestUtil.createCacheServer(regionName, true));
+    // start server 2
+    final int server2Port = server2VM.invoke(() -> createCacheServer(regionName, true));
 
     // Start a durable client
     durableClientId = getName() + "_client";
@@ -589,88 +613,106 @@ public class DurableClientTestCase extends DurableClientTestBase {
           server2Port, true, 0);
     }
 
-    this.durableClientVM.invoke(CacheServerTestUtil::disableShufflingOfEndpoints);
-    this.durableClientVM.invoke(() -> CacheServerTestUtil.createCacheClient(clientPool, regionName,
+    durableClientVM.invoke(CacheServerTestUtil::disableShufflingOfEndpoints);
+    // Create the durable client cache (type = cache)
+    durableClientVM.invoke(() -> createCacheClient(clientPool, regionName,
         getClientDistributedSystemProperties(durableClientId, VERY_LONG_DURABLE_TIMEOUT_SECONDS),
-        Boolean.TRUE));
+        true));
+
+    // Register interest in all entries in the region
+    registerInterest(durableClientVM, regionName, true, InterestResultPolicy.NONE);
 
     // Send clientReady message
-    this.durableClientVM.invoke(new CacheSerializableRunnable("Send clientReady") {
+    durableClientVM.invoke("Send clientReady", new CacheSerializableRunnable() {
       @Override
       public void run2() throws CacheException {
-        CacheServerTestUtil.getCache().readyForEvents();
+        getCache().readyForEvents();
       }
     });
 
-    registerInterest(this.durableClientVM, regionName, true, InterestResultPolicy.NONE);
-
+    // Verify the durable client is connected to the servers.
+    verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId, server1VM);
+    if (redundancyLevel == 1) {
+      verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId, server2VM);
+    }
     // Start normal publisher client
-    this.publisherClientVM.invoke(() -> CacheServerTestUtil.createCacheClient(
+    publisherClientVM.invoke(() -> createCacheClient(
         getClientPool(NetworkUtils.getServerHostName(), server1Port,
             server2Port, false),
         regionName));
 
-    // Publish some entries
-    publishEntries(0, 1);
+    // put key 0
+    publishEntries(publisherClientVM, 0, 1);
 
-    // Verify the durable client received the updates
-    this.checkListenerEvents(1, 1, -1, this.durableClientVM);
+    // Verify the durable client received key 0
+    checkListenerEvents(1, 1, -1, durableClientVM);
 
-    verifyDurableClientPresent(VERY_LONG_DURABLE_TIMEOUT_SECONDS, durableClientId, server1VM);
+    // Wait to until the HARegionQueue has emptied before disconnecting the Durable client
+    // to avoid having left over messages that processed, in particular, the key 0 message
+    waitUntilHARegionQueueSizeIsZero(server1VM);
+    if (redundancyLevel == 1) {
+      waitUntilHARegionQueueSizeIsZero(server2VM);
+    }
 
     // Stop the durable client
-    this.disconnectDurableClient(true);
+    disconnectDurableClient(true);
 
-    // Stop server 1 - publisher will put 10 entries during shutdown/primary identification
-    this.server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    // Stop server 1 - publisher will put 1 entries during shutdown/primary identification
+    server1VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
-    // Publish updates during client downtime
-    publishEntries(1, 1);
+    // Put key 1 during client downtime
+    publishEntries(publisherClientVM, 1, 1);
 
     // Re-start the durable client that is kept alive on the server
-    this.restartDurableClient(VERY_LONG_DURABLE_TIMEOUT_SECONDS, clientPool, Boolean.TRUE);
+    restartDurableClient(VERY_LONG_DURABLE_TIMEOUT_SECONDS, clientPool, true);
 
-    registerInterest(this.durableClientVM, regionName, true, InterestResultPolicy.NONE);
+    // Re-register interest in all entries in the region
+    registerInterest(durableClientVM, regionName, true, InterestResultPolicy.NONE);
 
-    publishEntries(2, 2);
+    // Send clientReady message
+    sendClientReady(durableClientVM);
+
+    // Put keys 2 and 3
+    publishEntries(publisherClientVM, 2, 2);
 
     // Verify the durable client received the updates before failover
     if (redundancyLevel == 1) {
-      this.checkListenerEvents(4, 1, -1, this.durableClientVM);
+      checkListenerEvents(3, 1, -1, durableClientVM);
     } else {
-      this.checkListenerEvents(2, 1, -1, this.durableClientVM);
+      checkListenerEvents(1, 1, -1, durableClientVM);
     }
 
-    this.durableClientVM.invoke("Get", () -> {
-      await().untilAsserted(() -> {
-        Region<Object, Object> region = getCache().getRegion(regionName);
-        assertThat(region).isNotNull();
-        // Register interest in all keys
-        assertThat(region.getEntry("0")).isNull();
-      });
-    });
+    // Verify that key 0 is not present
+    durableClientVM.invoke("Get", () -> await().atMost(30, TimeUnit.SECONDS).untilAsserted(() -> {
+      Region<Object, Object> region = getCache().getRegion(regionName);
+      assertThat(region).isNotNull();
 
-    publishEntries(4, 1);
+      assertThat(region.getEntry("0")).isNull();
+    }));
+
+    // put key 4
+    publishEntries(publisherClientVM, 4, 1);
 
     // Verify the durable client received the updates after failover
     if (redundancyLevel == 1) {
-      this.checkListenerEvents(5, 1, -1, this.durableClientVM);
+      checkListenerEvents(4, 1, -1, durableClientVM);
     } else {
-      this.checkListenerEvents(3, 1, -1, this.durableClientVM);
+      checkListenerEvents(2, 1, -1, durableClientVM);
     }
 
     // Stop the durable client
-    this.durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    durableClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop the publisher client
-    this.publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    publisherClientVM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
 
     // Stop server 2
-    this.server2VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
+    server2VM.invoke((SerializableRunnableIF) CacheServerTestUtil::closeCache);
   }
 
+
   private void verifyClientHasConnected() {
-    CacheServer cacheServer = CacheServerTestUtil.getCache().getCacheServers().get(0);
+    CacheServer cacheServer = getCache().getCacheServers().get(0);
     CacheClientNotifier ccn =
         ((InternalCacheServer) cacheServer).getAcceptor().getCacheClientNotifier();
     await().until(() -> ccn.getClientProxies().size() == 1);
