@@ -15,11 +15,14 @@
 package org.apache.geode.security;
 
 import static org.apache.geode.cache.Region.SEPARATOR;
+import static org.apache.geode.distributed.ConfigurationProperties.SECURITY_CLIENT_AUTH_INIT;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.util.Properties;
+import java.util.concurrent.Future;
 
+import org.junit.After;
 import org.junit.BeforeClass;
 import org.junit.ClassRule;
 import org.junit.Rule;
@@ -29,6 +32,7 @@ import org.apache.geode.cache.Region;
 import org.apache.geode.cache.RegionService;
 import org.apache.geode.cache.RegionShortcut;
 import org.apache.geode.cache.client.ClientCache;
+import org.apache.geode.cache.client.ClientRegionShortcut;
 import org.apache.geode.cache.client.Pool;
 import org.apache.geode.cache.execute.FunctionService;
 import org.apache.geode.cache.query.CqAttributesFactory;
@@ -37,9 +41,12 @@ import org.apache.geode.cache.query.Query;
 import org.apache.geode.examples.SimpleSecurityManager;
 import org.apache.geode.pdx.JSONFormatter;
 import org.apache.geode.pdx.PdxInstance;
+import org.apache.geode.security.templates.CountableUserPasswordAuthInit;
+import org.apache.geode.security.templates.UserPasswordAuthInit;
 import org.apache.geode.test.dunit.rules.ClusterStartupRule;
 import org.apache.geode.test.dunit.rules.MemberVM;
 import org.apache.geode.test.junit.rules.ClientCacheRule;
+import org.apache.geode.test.junit.rules.ExecutorServiceRule;
 
 public class MultiUserAPIDUnitTest {
   @ClassRule
@@ -50,6 +57,9 @@ public class MultiUserAPIDUnitTest {
   @Rule
   public ClientCacheRule client = new ClientCacheRule();
 
+  @Rule
+  public ExecutorServiceRule executor = new ExecutorServiceRule();
+
   @BeforeClass
   public static void setUp() throws Exception {
     MemberVM locator =
@@ -98,18 +108,18 @@ public class MultiUserAPIDUnitTest {
         .isInstanceOf(UnsupportedOperationException.class);
     assertThatThrownBy(() -> region.destroy("key"))
         .isInstanceOf(UnsupportedOperationException.class);
-    assertThatThrownBy(() -> region.destroyRegion())
+    assertThatThrownBy(region::destroyRegion)
         .isInstanceOf(UnsupportedOperationException.class);
     assertThatThrownBy(() -> region.registerInterest("key"))
         .isInstanceOf(UnsupportedOperationException.class);
-    assertThatThrownBy(() -> region.clear()).isInstanceOf(UnsupportedOperationException.class);
+    assertThatThrownBy(region::clear).isInstanceOf(UnsupportedOperationException.class);
 
 
     assertThatThrownBy(() -> regionView.createSubregion("subRegion", null))
         .isInstanceOf(UnsupportedOperationException.class);
-    assertThatThrownBy(() -> regionView.forceRolling())
+    assertThatThrownBy(regionView::forceRolling)
         .isInstanceOf(UnsupportedOperationException.class);
-    assertThatThrownBy(() -> regionView.getAttributesMutator())
+    assertThatThrownBy(regionView::getAttributesMutator)
         .isInstanceOf(UnsupportedOperationException.class);
     assertThatThrownBy(() -> regionView.loadSnapshot(null))
         .isInstanceOf(UnsupportedOperationException.class);
@@ -142,9 +152,9 @@ public class MultiUserAPIDUnitTest {
     CqQuery cqQuery =
         pool.getQueryService().newCq("SELECT * FROM " + SEPARATOR + "region",
             new CqAttributesFactory().create());
-    assertThatThrownBy(() -> cqQuery.execute())
+    assertThatThrownBy(cqQuery::execute)
         .hasCauseInstanceOf(UnsupportedOperationException.class);
-    assertThatThrownBy(() -> cqQuery.executeWithInitialResults())
+    assertThatThrownBy(cqQuery::executeWithInitialResults)
         .hasCauseInstanceOf(UnsupportedOperationException.class);
 
     assertThatThrownBy(() -> regionService.getQueryService().getIndexes())
@@ -209,7 +219,10 @@ public class MultiUserAPIDUnitTest {
 
   @Test
   public void jsonFormatterOnTheClientWithSingleUser() throws Exception {
-    client.withCredential("data", "data").withMultiUser(false)
+    client.withProperty(SECURITY_CLIENT_AUTH_INIT, CountableUserPasswordAuthInit.class.getName())
+        .withProperty(UserPasswordAuthInit.USER_NAME, "data")
+        .withProperty(UserPasswordAuthInit.PASSWORD, "data")
+        .withMultiUser(false)
         .withServerConnection(server.getPort()).createCache();
     Region region = client.createProxyRegion("region");
 
@@ -217,6 +230,37 @@ public class MultiUserAPIDUnitTest {
     String json = "{\"key\" : \"value\"}";
     PdxInstance value = JSONFormatter.fromJSON(json);
     region.put("key", value);
+
+    // make sure the client only needs to authenticate once
+    assertThat(CountableUserPasswordAuthInit.count.get()).isEqualTo(1);
+  }
+
+  @Test
+  public void multiUser_OneUserShouldOnlyAuthenticateOnceByDifferentThread() throws Exception {
+    ClientCache cache = client.withServerConnection(server.getPort())
+        .withProperty(SECURITY_CLIENT_AUTH_INIT, CountableUserPasswordAuthInit.class.getName())
+        .withMultiUser(true)
+        .createCache();
+    Properties properties = new Properties();
+    properties.setProperty(UserPasswordAuthInit.USER_NAME, "data");
+    properties.setProperty(UserPasswordAuthInit.PASSWORD, "data");
+    RegionService regionService = cache.createAuthenticatedView(properties);
+
+    cache.createClientRegionFactory(ClientRegionShortcut.PROXY).create("region");
+    Region region = regionService.getRegion(SEPARATOR + "region");
+
+    Future<Object> put1 = executor.submit(() -> region.put("key", "value"));
+    Future<Object> put2 = executor.submit(() -> region.put("key", "value"));
+
+    put1.get();
+    put2.get();
+    assertThat(CountableUserPasswordAuthInit.count.get()).isEqualTo(1);
+  }
+
+
+  @After
+  public void after() throws Exception {
+    CountableUserPasswordAuthInit.reset();
   }
 
   @Test
@@ -237,4 +281,24 @@ public class MultiUserAPIDUnitTest {
     PdxInstance value = regionService.getJsonFormatter().toPdxInstance(json);
     regionView.put("key", value);
   }
+
+  @Test
+  public void multiUserWithCQ_Should_Authentiate() throws Exception {
+    ClientCache cache = client.withServerConnection(server.getPort())
+        .withPoolSubscription(true)
+        .withProperty(SECURITY_CLIENT_AUTH_INIT, CountableUserPasswordAuthInit.class.getName())
+        .withMultiUser(true)
+        .createCache();
+    Properties properties = new Properties();
+    properties.setProperty(UserPasswordAuthInit.USER_NAME, "data");
+    properties.setProperty(UserPasswordAuthInit.PASSWORD, "wrongPassword");
+    RegionService regionService = cache.createAuthenticatedView(properties);
+
+    cache.createClientRegionFactory(ClientRegionShortcut.PROXY).create("region");
+    CqQuery cqQuery =
+        regionService.getQueryService()
+            .newCq("select * from /region", new CqAttributesFactory().create());
+    assertThatThrownBy(cqQuery::execute)
+        .hasCauseInstanceOf(AuthenticationFailedException.class);
+  }
 }
