@@ -15,6 +15,7 @@
 package org.apache.geode.internal.cache.tier.sockets;
 
 import static org.apache.geode.cache.Region.SEPARATOR;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertEquals;
@@ -59,25 +60,25 @@ import org.apache.geode.test.junit.categories.BackwardCompatibilityTest;
 import org.apache.geode.test.junit.categories.ClientServerTest;
 import org.apache.geode.test.junit.runners.CategoryWithParameterizedRunnerFactory;
 import org.apache.geode.test.version.VersionManager;
+import org.apache.geode.test.version.VmConfiguration;
+import org.apache.geode.test.version.VmConfigurations;
 
 @Category({ClientServerTest.class, BackwardCompatibilityTest.class})
 @RunWith(Parameterized.class)
 @Parameterized.UseParametersRunnerFactory(CategoryWithParameterizedRunnerFactory.class)
 public class ClientServerMiscBCDUnitTest extends ClientServerMiscDUnitTestBase {
   @Parameterized.Parameters
-  public static Collection<String> data() {
-    List<String> result = VersionManager.getInstance().getVersionsWithoutCurrent();
-    if (result.size() < 1) {
-      throw new RuntimeException("No older versions of Geode were found to test against");
-    } else {
-      System.out.println("running against these versions: " + result);
-    }
-    return result;
+  public static Collection<VmConfiguration> data() {
+    List<VmConfiguration> upgradeConfigurations = VmConfigurations.upgrades();
+    assertThat(upgradeConfigurations)
+        .as("configurations to upgrade from")
+        .isNotEmpty();
+    System.out.println("upgrading from configurations: " + upgradeConfigurations);
+    return upgradeConfigurations;
   }
 
-  public ClientServerMiscBCDUnitTest(String version) {
-    super();
-    testVersion = version;
+  public ClientServerMiscBCDUnitTest(VmConfiguration clientVmConfiguration) {
+    super(clientVmConfiguration);
   }
 
   @Override
@@ -99,7 +100,7 @@ public class ClientServerMiscBCDUnitTest extends ClientServerMiscDUnitTestBase {
   @Test
   public void testClientProtocolVersion() {
     int serverPort = initServerCache(true);
-    VM client1 = Host.getHost(0).getVM(testVersion, 1);
+    VM client1 = Host.getHost(0).getVM(clientVmConfiguration, 1);
     String hostname = NetworkUtils.getServerHostName();
     short ordinal = client1.invoke("create client1 cache", () -> {
       createClientCache(hostname, serverPort);
@@ -133,8 +134,8 @@ public class ClientServerMiscBCDUnitTest extends ClientServerMiscDUnitTestBase {
   public void testSubscriptionWithCurrentServerAndOldClients() throws Exception {
     // start server first
     int serverPort = initServerCache(true);
-    VM client1 = Host.getHost(0).getVM(testVersion, 1);
-    VM client2 = Host.getHost(0).getVM(testVersion, 3);
+    VM client1 = Host.getHost(0).getVM(clientVmConfiguration, 1);
+    VM client2 = Host.getHost(0).getVM(clientVmConfiguration, 3);
     String hostname = NetworkUtils.getServerHostName(Host.getHost(0));
     client1.invoke("create client1 cache", () -> {
       createClientCache(hostname, serverPort);
@@ -145,7 +146,7 @@ public class ClientServerMiscBCDUnitTest extends ClientServerMiscDUnitTestBase {
       Pool ignore = createClientCache(hostname, serverPort);
     });
 
-    client2.invoke("putting data in client2", () -> putForClient());
+    client2.invoke("putting data in client2", ClientServerMiscDUnitTestBase::putForClient);
 
     // client1 will receive client2's updates asynchronously
     client1.invoke(() -> {
@@ -164,33 +165,34 @@ public class ClientServerMiscBCDUnitTest extends ClientServerMiscDUnitTestBase {
 
   @Test
   public void testSubscriptionWithMixedServersAndNewPeerFeed() throws Exception {
-    doTestSubscriptionWithMixedServersAndPeerFeed(VersionManager.CURRENT_VERSION, true);
+    doTestSubscriptionWithMixedServersAndPeerFeed(VmConfiguration.current(), true);
   }
 
   @Test
   public void testSubscriptionWithMixedServersAndOldPeerFeed() throws Exception {
-    doTestSubscriptionWithMixedServersAndPeerFeed(testVersion, true);
+    doTestSubscriptionWithMixedServersAndPeerFeed(clientVmConfiguration, true);
   }
 
   @Test
   public void testSubscriptionWithMixedServersAndOldClientFeed() throws Exception {
-    doTestSubscriptionWithMixedServersAndPeerFeed(testVersion, false);
+    doTestSubscriptionWithMixedServersAndPeerFeed(clientVmConfiguration, false);
   }
 
-  private void doTestSubscriptionWithMixedServersAndPeerFeed(String version,
+  private void doTestSubscriptionWithMixedServersAndPeerFeed(VmConfiguration feederVmConfiguration,
       boolean usePeerForFeed) {
-    server1 = Host.getHost(0).getVM(testVersion, 2);
+    server1 = Host.getHost(0).getVM(clientVmConfiguration, 2);
     server2 = Host.getHost(0).getVM(VersionManager.CURRENT_VERSION, 3);
     VM server3 = Host.getHost(0).getVM(VersionManager.CURRENT_VERSION, 4);
-    VM interestClient = Host.getHost(0).getVM(testVersion, 0);
-    VM feeder = Host.getHost(0).getVM(version, 1);
+    VM interestClient = Host.getHost(0).getVM(clientVmConfiguration, 0);
+    VM feeder = Host.getHost(0).getVM(feederVmConfiguration, 1);
 
     // start servers first
     int server1Port = initServerCache(true);
 
     int server2Port = initServerCache2();
 
-    int server3Port = server3.invoke(() -> createServerCache(true, getMaxThreads(), false));
+    int server3Port = getRandomAvailableTCPPort();
+    server3.invoke(() -> createServerCache(true, getMaxThreads(), false, server3Port));
 
     System.out.println("old server is vm 2 and new server is vm 3");
     System.out
@@ -208,7 +210,7 @@ public class ClientServerMiscBCDUnitTest extends ClientServerMiscDUnitTestBase {
         Pool ignore = createClientCache(hostname, server1Port);
       });
     }
-    feeder.invoke("putting data in feeder", () -> putForClient());
+    feeder.invoke("putting data in feeder", ClientServerMiscDUnitTestBase::putForClient);
 
     // interestClient will receive feeder's updates asynchronously
     interestClient.invoke("verification 1", () -> {
@@ -268,23 +270,23 @@ public class ClientServerMiscBCDUnitTest extends ClientServerMiscDUnitTestBase {
 
   @Test
   public void giiEventQueueFromOldToCurrentMemberShouldSucceed() {
-    giiEventQueueShouldSucceedWithMixedVersions(testVersion, VersionManager.CURRENT_VERSION);
+    giiEventQueueShouldSucceedWithMixedVersions(clientVmConfiguration, VmConfiguration.current());
   }
 
   @Test
   public void giiEventQueueFromCurrentToOldMemberShouldSucceed() {
     final IgnoredException expectedEx =
         IgnoredException.addIgnoredException(ConnectException.class.getName());
-    giiEventQueueShouldSucceedWithMixedVersions(VersionManager.CURRENT_VERSION, testVersion);
+    giiEventQueueShouldSucceedWithMixedVersions(VmConfiguration.current(), clientVmConfiguration);
     expectedEx.remove();
   }
 
-  public void giiEventQueueShouldSucceedWithMixedVersions(String server1Version,
-      String server2Version) {
-    VM interestClient = Host.getHost(0).getVM(testVersion, 0);
+  public void giiEventQueueShouldSucceedWithMixedVersions(VmConfiguration server1VmConfiguration,
+      VmConfiguration server2VmConfiguration) {
+    VM interestClient = Host.getHost(0).getVM(clientVmConfiguration, 0);
     VM feeder = Host.getHost(0).getVM(VersionManager.CURRENT_VERSION, 1);
-    server1 = Host.getHost(0).getVM(server1Version, 2);
-    server2 = Host.getHost(0).getVM(server2Version, 3);
+    server1 = Host.getHost(0).getVM(server1VmConfiguration, 2);
+    server2 = Host.getHost(0).getVM(server2VmConfiguration, 3);
 
     // start servers first
     int server1Port = initServerCache(true, server1, true);
@@ -301,7 +303,7 @@ public class ClientServerMiscBCDUnitTest extends ClientServerMiscDUnitTestBase {
       registerCQ();
     });
 
-    feeder.invoke("putting data in feeder", () -> putForClient());
+    feeder.invoke("putting data in feeder", ClientServerMiscDUnitTestBase::putForClient);
 
     // Start server 2
     server2.invoke(() -> {
@@ -358,7 +360,7 @@ public class ClientServerMiscBCDUnitTest extends ClientServerMiscDUnitTestBase {
     int serverPort = initServerCache(true);
 
     // Start old version client and do puts
-    VM client = Host.getHost(0).getVM(testVersion, 1);
+    VM client = Host.getHost(0).getVM(clientVmConfiguration, 1);
     String hostname = NetworkUtils.getServerHostName(Host.getHost(0));
     client.invoke("create client cache", () -> {
       createClientCache(hostname, serverPort);
@@ -367,11 +369,11 @@ public class ClientServerMiscBCDUnitTest extends ClientServerMiscDUnitTestBase {
 
     // Get client member id byte array on client
     byte[] clientMembershipIdBytesOnClient =
-        client.invoke(() -> getClientMembershipIdBytesOnClient());
+        client.invoke(this::getClientMembershipIdBytesOnClient);
 
     // Get client member id byte array on server
     byte[] clientMembershipIdBytesOnServer =
-        server1.invoke(() -> getClientMembershipIdBytesOnServer());
+        server1.invoke(this::getClientMembershipIdBytesOnServer);
 
     // Verify member id bytes on client and server are equal
     String complaint = "size on client=" + clientMembershipIdBytesOnClient.length
