@@ -16,9 +16,9 @@
  */
 package org.apache.geode.test.dunit.rules.tests;
 
+import static java.util.Arrays.asList;
 import static org.apache.geode.test.dunit.VM.getController;
 import static org.apache.geode.test.dunit.VM.getVM;
-import static org.apache.geode.test.dunit.VM.toArray;
 import static org.apache.geode.test.junit.runners.TestRunner.runTestWithValidation;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.mockito.Mockito.mock;
@@ -27,7 +27,11 @@ import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 
 import java.io.Closeable;
+import java.io.IOException;
 import java.io.Serializable;
+import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicReference;
 
 import org.junit.Before;
 import org.junit.Rule;
@@ -37,7 +41,7 @@ import org.apache.geode.test.dunit.VM;
 import org.apache.geode.test.dunit.rules.DistributedReference;
 import org.apache.geode.test.dunit.rules.DistributedRule;
 
-@SuppressWarnings({"serial", "unused"})
+@SuppressWarnings({"serial", "CodeBlock2Expr"})
 public class DistributedReferenceTest {
 
   @Rule
@@ -52,14 +56,14 @@ public class DistributedReferenceTest {
   public void closesAutoCloseableInLocalVm() throws Exception {
     runTestWithValidation(SetAutoCloseableInLocalVm.class);
 
-    verify(SetAutoCloseableInLocalVm.autoCloseable).close();
+    verify(SetAutoCloseableInLocalVm.autoCloseable.get()).close();
   }
 
   @Test
   public void doesNotAutoCloseIfAutoCloseIsFalse() throws Exception {
     runTestWithValidation(DisableAutoCloseInLocalVm.class);
 
-    verify(DisableAutoCloseInLocalVm.autoCloseable, times(0)).close();
+    verify(DisableAutoCloseInLocalVm.autoCloseable.get(), times(0)).close();
   }
 
   @Test
@@ -71,7 +75,7 @@ public class DistributedReferenceTest {
   public void closesAutoCloseableInRemoteVm() {
     runTestWithValidation(SetAutoCloseableInRemoteVm.class);
 
-    getVM(0).invoke(() -> verify(SetAutoCloseableInRemoteVm.autoCloseable).close());
+    getVM(0).invoke(() -> verify(SetAutoCloseableInRemoteVm.autoCloseable.get()).close());
   }
 
   @Test
@@ -83,9 +87,9 @@ public class DistributedReferenceTest {
   public void closesAutoCloseableInEachVm() {
     runTestWithValidation(SetAutoCloseableInEachVm.class);
 
-    for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+    for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
       vm.invoke(() -> {
-        verify(SetAutoCloseableInEachVm.autoCloseable).close();
+        verify(SetAutoCloseableInEachVm.autoCloseable.get()).close();
       });
     }
   }
@@ -96,10 +100,10 @@ public class DistributedReferenceTest {
   }
 
   @Test
-  public void closesCloseableInLocalVm() throws Exception {
+  public void closesCloseableInLocalVm() throws IOException {
     runTestWithValidation(SetCloseableInLocalVm.class);
 
-    verify(SetCloseableInLocalVm.closeable).close();
+    verify(SetCloseableInLocalVm.closeable.get()).close();
   }
 
   @Test
@@ -111,7 +115,7 @@ public class DistributedReferenceTest {
   public void closesCloseableInRemoteVm() {
     runTestWithValidation(SetCloseableInRemoteVm.class);
 
-    getVM(0).invoke(() -> verify(SetCloseableInRemoteVm.closeable).close());
+    getVM(0).invoke(() -> verify(SetCloseableInRemoteVm.closeable.get()).close());
   }
 
   @Test
@@ -123,9 +127,9 @@ public class DistributedReferenceTest {
   public void closesCloseableInEachVm() {
     runTestWithValidation(SetCloseableInEachVm.class);
 
-    for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+    for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
       vm.invoke(() -> {
-        verify(SetCloseableInEachVm.closeable).close();
+        verify(SetCloseableInEachVm.closeable.get()).close();
       });
     }
   }
@@ -139,7 +143,7 @@ public class DistributedReferenceTest {
   public void closesWithCloseInLocalVm() {
     runTestWithValidation(SetWithCloseInLocalVm.class);
 
-    verify(SetWithCloseInLocalVm.withClose).close();
+    verify(SetWithCloseInLocalVm.withClose.get()).close();
   }
 
   @Test
@@ -151,7 +155,7 @@ public class DistributedReferenceTest {
   public void closesWithCloseInRemoteVm() {
     runTestWithValidation(SetWithCloseInRemoteVm.class);
 
-    getVM(0).invoke(() -> verify(SetWithCloseInRemoteVm.withClose).close());
+    getVM(0).invoke(() -> verify(SetWithCloseInRemoteVm.withClose.get()).close());
   }
 
   @Test
@@ -163,9 +167,9 @@ public class DistributedReferenceTest {
   public void closesWithCloseInEachVm() {
     runTestWithValidation(SetWithCloseInEachVm.class);
 
-    for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+    for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
       vm.invoke(() -> {
-        verify(SetWithCloseInEachVm.withClose).close();
+        verify(SetWithCloseInEachVm.withClose.get()).close();
       });
     }
   }
@@ -179,7 +183,7 @@ public class DistributedReferenceTest {
   public void disconnectsWithDisconnectInLocalVm() {
     runTestWithValidation(SetWithDisconnectInLocalVm.class);
 
-    verify(SetWithDisconnectInLocalVm.withDisconnect).disconnect();
+    verify(SetWithDisconnectInLocalVm.withDisconnect.get()).disconnect();
   }
 
   @Test
@@ -191,7 +195,7 @@ public class DistributedReferenceTest {
   public void disconnectsWithDisconnectInRemoteVm() {
     runTestWithValidation(SetWithDisconnectInRemoteVm.class);
 
-    getVM(0).invoke(() -> verify(SetWithDisconnectInRemoteVm.withDisconnect).disconnect());
+    getVM(0).invoke(() -> verify(SetWithDisconnectInRemoteVm.withDisconnect.get()).disconnect());
   }
 
   @Test
@@ -203,55 +207,118 @@ public class DistributedReferenceTest {
   public void disconnectsWithDisconnectInEachVm() {
     runTestWithValidation(SetWithDisconnectInEachVm.class);
 
-    for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+    for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
       vm.invoke(() -> {
-        verify(SetWithDisconnectInEachVm.withDisconnect).disconnect();
+        verify(SetWithDisconnectInEachVm.withDisconnect.get()).disconnect();
       });
     }
   }
 
+  @Test
+  public void accessesAtomicBooleanInEachVm() {
+    runTestWithValidation(SetAtomicBooleanInLocalVm.class);
+  }
+
+  @Test
+  public void setsAtomicBooleanToFalseInEachVm() {
+    runTestWithValidation(SetAtomicBooleanInLocalVm.class);
+
+    for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      vm.invoke(() -> {
+        assertThat(SetAtomicBooleanInLocalVm.atomicBoolean.get()).isFalse();
+      });
+    }
+  }
+
+  @Test
+  public void accessesCountDownLatchInEachVm() {
+    runTestWithValidation(SetCountDownLatchInLocalVm.class);
+  }
+
+  @Test
+  public void opensCountDownLatchInEachVm() {
+    runTestWithValidation(SetCountDownLatchInLocalVm.class);
+
+    for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      vm.invoke(() -> {
+        assertThat(SetCountDownLatchInLocalVm.latch.get().getCount()).isZero();
+      });
+    }
+  }
+
+  @Test
+  public void accessesTwoReferencesInEachVm() {
+    runTestWithValidation(SetTwoCloseablesInEachVm.class);
+  }
+
+  @Test
+  public void closesTwoReferencesInEachVm() {
+    runTestWithValidation(SetTwoCloseablesInEachVm.class);
+
+    getController().invoke(() -> {
+      verify(SetTwoCloseablesInEachVm.withClose1.get()).close();
+      verify(SetTwoCloseablesInEachVm.withClose2.get()).close();
+    });
+  }
+
+  @Test
+  public void accessesManyReferencesInEachVm() {
+    runTestWithValidation(SetManyReferencesInEachVm.class);
+  }
+
+  @Test
+  public void closesManyReferencesInEachVm() {
+    runTestWithValidation(SetManyReferencesInEachVm.class);
+
+    getController().invoke(() -> {
+      verify(SetManyReferencesInEachVm.withClose.get()).close();
+      verify(SetManyReferencesInEachVm.withDisconnect.get()).disconnect();
+      verify(SetManyReferencesInEachVm.withStop.get()).stop();
+    });
+  }
+
   public static class SetAutoCloseableInLocalVm implements Serializable {
 
-    private static AutoCloseable autoCloseable;
+    private static final AtomicReference<AutoCloseable> autoCloseable = new AtomicReference<>();
 
     @Rule
     public DistributedReference<AutoCloseable> reference = new DistributedReference<>();
 
     @Before
     public void setUp() {
-      autoCloseable = mock(AutoCloseable.class);
-      reference.set(autoCloseable);
+      autoCloseable.set(mock(AutoCloseable.class));
+      reference.set(autoCloseable.get());
     }
 
     @Test
     public void hasReferenceInLocalVm() {
-      assertThat(reference.get()).isSameAs(autoCloseable);
+      assertThat(reference.get()).isSameAs(autoCloseable.get());
     }
   }
 
   public static class DisableAutoCloseInLocalVm implements Serializable {
 
-    private static AutoCloseable autoCloseable;
+    private static final AtomicReference<AutoCloseable> autoCloseable = new AtomicReference<>();
 
     @Rule
-    public DistributedReference<AutoCloseable> reference =
-        new DistributedReference<AutoCloseable>().autoClose(false);
+    public DistributedReference<AutoCloseable> reference = new DistributedReference<AutoCloseable>()
+        .autoClose(false);
 
     @Before
     public void setUp() {
-      autoCloseable = mock(AutoCloseable.class);
-      reference.set(autoCloseable);
+      autoCloseable.set(mock(AutoCloseable.class));
+      reference.set(autoCloseable.get());
     }
 
     @Test
     public void hasReferenceInLocalVm() {
-      assertThat(reference.get()).isSameAs(autoCloseable);
+      assertThat(reference.get()).isSameAs(autoCloseable.get());
     }
   }
 
   public static class SetAutoCloseableInRemoteVm implements Serializable {
 
-    private static AutoCloseable autoCloseable;
+    private static final AtomicReference<AutoCloseable> autoCloseable = new AtomicReference<>();
 
     @Rule
     public DistributedReference<AutoCloseable> reference = new DistributedReference<>();
@@ -260,41 +327,41 @@ public class DistributedReferenceTest {
     public void setUp() {
       VM vm = getVM(0);
       vm.invoke(() -> {
-        autoCloseable = mock(AutoCloseable.class, "AutoCloseable in VM-" + vm.getId());
-        reference.set(autoCloseable);
+        autoCloseable.set(mock(AutoCloseable.class, "AutoCloseable in VM-" + vm.getId()));
+        reference.set(autoCloseable.get());
       });
     }
 
     @Test
     public void hasAutoCloseableInRemoteVm() {
       getVM(0).invoke(() -> {
-        assertThat(reference.get()).isSameAs(autoCloseable);
+        assertThat(reference.get()).isSameAs(autoCloseable.get());
       });
     }
   }
 
   public static class SetAutoCloseableInEachVm implements Serializable {
 
-    private static AutoCloseable autoCloseable;
+    private static final AtomicReference<AutoCloseable> autoCloseable = new AtomicReference<>();
 
     @Rule
     public DistributedReference<AutoCloseable> reference = new DistributedReference<>();
 
     @Before
     public void setUp() {
-      for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
         vm.invoke(() -> {
-          autoCloseable = mock(AutoCloseable.class, "AutoCloseable in VM-" + vm.getId());
-          reference.set(autoCloseable);
+          autoCloseable.set(mock(AutoCloseable.class, "AutoCloseable in VM-" + vm.getId()));
+          reference.set(autoCloseable.get());
         });
       }
     }
 
     @Test
     public void hasAutoCloseableInEachVm() {
-      for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
         vm.invoke(() -> {
-          assertThat(reference.get()).isSameAs(autoCloseable);
+          assertThat(reference.get()).isSameAs(autoCloseable.get());
           assertThat(reference.get().toString()).isEqualTo("AutoCloseable in VM-" + vm.getId());
         });
       }
@@ -303,26 +370,26 @@ public class DistributedReferenceTest {
 
   public static class SetCloseableInLocalVm implements Serializable {
 
-    private static Closeable closeable;
+    private static final AtomicReference<Closeable> closeable = new AtomicReference<>();
 
     @Rule
     public DistributedReference<Closeable> reference = new DistributedReference<>();
 
     @Before
     public void setUp() {
-      closeable = mock(Closeable.class);
-      reference.set(closeable);
+      closeable.set(mock(Closeable.class));
+      reference.set(closeable.get());
     }
 
     @Test
     public void hasCloseableInLocalVm() {
-      assertThat(reference.get()).isSameAs(closeable);
+      assertThat(reference.get()).isSameAs(closeable.get());
     }
   }
 
   public static class SetCloseableInRemoteVm implements Serializable {
 
-    private static Closeable closeable;
+    private static final AtomicReference<Closeable> closeable = new AtomicReference<>();
 
     @Rule
     public DistributedReference<Closeable> reference = new DistributedReference<>();
@@ -331,41 +398,41 @@ public class DistributedReferenceTest {
     public void setUp() {
       VM vm = getVM(0);
       vm.invoke(() -> {
-        closeable = mock(Closeable.class, "Closeable in VM-" + vm.getId());
-        reference.set(closeable);
+        closeable.set(mock(Closeable.class, "Closeable in VM-" + vm.getId()));
+        reference.set(closeable.get());
       });
     }
 
     @Test
     public void hasCloseableInRemoteVm() {
       getVM(0).invoke(() -> {
-        assertThat(reference.get()).isSameAs(closeable);
+        assertThat(reference.get()).isSameAs(closeable.get());
       });
     }
   }
 
   public static class SetCloseableInEachVm implements Serializable {
 
-    private static Closeable closeable;
+    private static final AtomicReference<Closeable> closeable = new AtomicReference<>();
 
     @Rule
     public DistributedReference<Closeable> reference = new DistributedReference<>();
 
     @Before
     public void setUp() {
-      for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
         vm.invoke(() -> {
-          closeable = mock(Closeable.class, "Closeable in VM-" + vm.getId());
-          reference.set(closeable);
+          closeable.set(mock(Closeable.class, "Closeable in VM-" + vm.getId()));
+          reference.set(closeable.get());
         });
       }
     }
 
     @Test
     public void hasCloseableInEachVm() {
-      for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
         vm.invoke(() -> {
-          assertThat(reference.get()).isSameAs(closeable);
+          assertThat(reference.get()).isSameAs(closeable.get());
           assertThat(reference.get().toString()).isEqualTo("Closeable in VM-" + vm.getId());
         });
       }
@@ -374,26 +441,26 @@ public class DistributedReferenceTest {
 
   public static class SetWithCloseInLocalVm implements Serializable {
 
-    private static WithClose withClose;
+    private static final AtomicReference<WithClose> withClose = new AtomicReference<>();
 
     @Rule
     public DistributedReference<WithClose> reference = new DistributedReference<>();
 
     @Before
     public void setUp() {
-      withClose = spy(new WithClose());
-      reference.set(withClose);
+      withClose.set(spy(new WithClose()));
+      reference.set(withClose.get());
     }
 
     @Test
     public void hasWithCloseInLocalVm() {
-      assertThat(reference.get()).isSameAs(withClose);
+      assertThat(reference.get()).isSameAs(withClose.get());
     }
   }
 
   public static class SetWithCloseInRemoteVm implements Serializable {
 
-    private static WithClose withClose;
+    private static final AtomicReference<WithClose> withClose = new AtomicReference<>();
 
     @Rule
     public DistributedReference<WithClose> reference = new DistributedReference<>();
@@ -402,41 +469,41 @@ public class DistributedReferenceTest {
     public void setUp() {
       VM vm = getVM(0);
       vm.invoke(() -> {
-        withClose = spy(new WithClose("WithClose in VM-" + vm.getId()));
-        reference.set(withClose);
+        withClose.set(spy(new WithClose("WithClose in VM-" + vm.getId())));
+        reference.set(withClose.get());
       });
     }
 
     @Test
     public void hasWithCloseInRemoteVm() {
       getVM(0).invoke(() -> {
-        assertThat(reference.get()).isSameAs(withClose);
+        assertThat(reference.get()).isSameAs(withClose.get());
       });
     }
   }
 
   public static class SetWithCloseInEachVm implements Serializable {
 
-    private static WithClose withClose;
+    private static final AtomicReference<WithClose> withClose = new AtomicReference<>();
 
     @Rule
     public DistributedReference<WithClose> reference = new DistributedReference<>();
 
     @Before
     public void setUp() {
-      for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
         vm.invoke(() -> {
-          withClose = spy(new WithClose("WithClose in VM-" + vm.getId()));
-          reference.set(withClose);
+          withClose.set(spy(new WithClose("WithClose in VM-" + vm.getId())));
+          reference.set(withClose.get());
         });
       }
     }
 
     @Test
     public void hasCloseableInEachVm() {
-      for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
         vm.invoke(() -> {
-          assertThat(reference.get()).isSameAs(withClose);
+          assertThat(reference.get()).isSameAs(withClose.get());
           assertThat(reference.get().toString()).isEqualTo("WithClose in VM-" + vm.getId());
         });
       }
@@ -445,26 +512,26 @@ public class DistributedReferenceTest {
 
   public static class SetWithDisconnectInLocalVm implements Serializable {
 
-    private static WithDisconnect withDisconnect;
+    private static final AtomicReference<WithDisconnect> withDisconnect = new AtomicReference<>();
 
     @Rule
     public DistributedReference<WithDisconnect> reference = new DistributedReference<>();
 
     @Before
     public void setUp() {
-      withDisconnect = spy(new WithDisconnect());
-      reference.set(withDisconnect);
+      withDisconnect.set(spy(new WithDisconnect()));
+      reference.set(withDisconnect.get());
     }
 
     @Test
     public void hasWithDisconnectInLocalVm() {
-      assertThat(reference.get()).isSameAs(withDisconnect);
+      assertThat(reference.get()).isSameAs(withDisconnect.get());
     }
   }
 
   public static class SetWithDisconnectInRemoteVm implements Serializable {
 
-    private static WithDisconnect withDisconnect;
+    private static final AtomicReference<WithDisconnect> withDisconnect = new AtomicReference<>();
 
     @Rule
     public DistributedReference<WithDisconnect> reference = new DistributedReference<>();
@@ -473,41 +540,41 @@ public class DistributedReferenceTest {
     public void setUp() {
       VM vm = getVM(0);
       vm.invoke(() -> {
-        withDisconnect = spy(new WithDisconnect("WithDisconnect in VM-" + vm.getId()));
-        reference.set(withDisconnect);
+        withDisconnect.set(spy(new WithDisconnect("WithDisconnect in VM-" + vm.getId())));
+        reference.set(withDisconnect.get());
       });
     }
 
     @Test
     public void hasWithDisconnectInRemoteVm() {
       getVM(0).invoke(() -> {
-        assertThat(reference.get()).isSameAs(withDisconnect);
+        assertThat(reference.get()).isSameAs(withDisconnect.get());
       });
     }
   }
 
   public static class SetWithDisconnectInEachVm implements Serializable {
 
-    private static WithDisconnect withDisconnect;
+    private static final AtomicReference<WithDisconnect> withDisconnect = new AtomicReference<>();
 
     @Rule
     public DistributedReference<WithDisconnect> reference = new DistributedReference<>();
 
     @Before
     public void setUp() {
-      for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
         vm.invoke(() -> {
-          withDisconnect = spy(new WithDisconnect("WithDisconnect in VM-" + vm.getId()));
-          reference.set(withDisconnect);
+          withDisconnect.set(spy(new WithDisconnect("WithDisconnect in VM-" + vm.getId())));
+          reference.set(withDisconnect.get());
         });
       }
     }
 
     @Test
     public void hasWithDisconnectInEachVm() {
-      for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
         vm.invoke(() -> {
-          assertThat(reference.get()).isSameAs(withDisconnect);
+          assertThat(reference.get()).isSameAs(withDisconnect.get());
           assertThat(reference.get().toString()).isEqualTo("WithDisconnect in VM-" + vm.getId());
         });
       }
@@ -516,26 +583,26 @@ public class DistributedReferenceTest {
 
   public static class SetWithStopInLocalVm implements Serializable {
 
-    private static WithStop withStop;
+    private static final AtomicReference<WithStop> withStop = new AtomicReference<>();
 
     @Rule
     public DistributedReference<WithStop> reference = new DistributedReference<>();
 
     @Before
     public void setUp() {
-      withStop = spy(new WithStop());
-      reference.set(withStop);
+      withStop.set(spy(new WithStop()));
+      reference.set(withStop.get());
     }
 
     @Test
     public void hasWithStopInLocalVm() {
-      assertThat(reference.get()).isSameAs(withStop);
+      assertThat(reference.get()).isSameAs(withStop.get());
     }
   }
 
   public static class SetWithStopInRemoteVm implements Serializable {
 
-    private static WithStop withStop;
+    private static final AtomicReference<WithStop> withStop = new AtomicReference<>();
 
     @Rule
     public DistributedReference<WithStop> reference = new DistributedReference<>();
@@ -544,39 +611,39 @@ public class DistributedReferenceTest {
     public void setUp() {
       VM vm = getVM(0);
       vm.invoke(() -> {
-        withStop = spy(new WithStop("WithStop in VM-" + vm.getId()));
-        reference.set(withStop);
+        withStop.set(spy(new WithStop("WithStop in VM-" + vm.getId())));
+        reference.set(withStop.get());
       });
     }
 
     @Test
     public void hasWithStopInRemoteVm() {
       getVM(0).invoke(() -> {
-        assertThat(reference.get()).isSameAs(withStop);
+        assertThat(reference.get()).isSameAs(withStop.get());
       });
     }
   }
 
   public static class SetWithStopInEachVm implements Serializable {
 
-    private static WithStop withStop;
+    private static final AtomicReference<WithStop> withStop = new AtomicReference<>();
 
     @Rule
     public DistributedReference<WithStop> reference = new DistributedReference<>();
 
     @Before
     public void setUp() {
-      for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
         vm.invoke(() -> {
-          withStop = spy(new WithStop("WithStop in VM-" + vm.getId()));
-          reference.set(withStop);
+          withStop.set(spy(new WithStop("WithStop in VM-" + vm.getId())));
+          reference.set(withStop.get());
         });
       }
     }
 
     @Test
     public void hasWithStopInEachVm() {
-      for (VM vm : toArray(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
         vm.invoke(() -> {
           assertThat(reference.get()).isSameAs(withStop);
           assertThat(reference.get().toString()).isEqualTo("WithStop in VM-" + vm.getId());
@@ -585,6 +652,146 @@ public class DistributedReferenceTest {
     }
   }
 
+  public static class SetAtomicBooleanInLocalVm implements Serializable {
+
+    private static final AtomicReference<AtomicBoolean> atomicBoolean = new AtomicReference<>();
+
+    @Rule
+    public DistributedReference<AtomicBoolean> reference = new DistributedReference<>();
+
+    @Before
+    public void setUp() {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+        vm.invoke(() -> {
+          atomicBoolean.set(new AtomicBoolean(true));
+          reference.set(atomicBoolean.get());
+        });
+      }
+    }
+
+    @Test
+    public void hasAtomicBooleanInEachVm() {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+        vm.invoke(() -> {
+          assertThat(reference.get())
+              .isSameAs(atomicBoolean.get())
+              .isTrue();
+        });
+      }
+    }
+  }
+
+  public static class SetCountDownLatchInLocalVm implements Serializable {
+
+    private static final AtomicReference<CountDownLatch> latch = new AtomicReference<>();
+
+    @Rule
+    public DistributedReference<CountDownLatch> reference = new DistributedReference<>();
+
+    @Before
+    public void setUp() {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+        vm.invoke(() -> {
+          latch.set(new CountDownLatch(2));
+          reference.set(latch.get());
+        });
+      }
+    }
+
+    @Test
+    public void hasReferenceInLocalVm() {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+        vm.invoke(() -> {
+          assertThat(reference.get()).isSameAs(latch.get());
+          assertThat(latch.get().getCount()).isEqualTo(2);
+        });
+      }
+    }
+  }
+
+  public static class SetTwoCloseablesInEachVm implements Serializable {
+
+    private static final AtomicReference<WithClose> withClose1 = new AtomicReference<>();
+    private static final AtomicReference<WithClose> withClose2 = new AtomicReference<>();
+
+    @Rule
+    public DistributedReference<WithClose> reference1 = new DistributedReference<>();
+    @Rule
+    public DistributedReference<WithClose> reference2 = new DistributedReference<>();
+
+    @Before
+    public void setUp() {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+        vm.invoke(() -> {
+          withClose1.set(spy(new WithClose("WithClose1 in VM-" + vm.getId())));
+          reference1.set(withClose1.get());
+
+          withClose2.set(spy(new WithClose("WithClose2 in VM-" + vm.getId())));
+          reference2.set(withClose2.get());
+        });
+      }
+    }
+
+    @Test
+    public void hasTwoWithCloseInEachVm() {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+        vm.invoke(() -> {
+          assertThat(reference1.get()).isSameAs(withClose1.get());
+          assertThat(reference2.get()).isSameAs(withClose2.get());
+
+          assertThat(reference1.get().toString()).isEqualTo("WithClose1 in VM-" + vm.getId());
+          assertThat(reference2.get().toString()).isEqualTo("WithClose2 in VM-" + vm.getId());
+        });
+      }
+    }
+  }
+
+  public static class SetManyReferencesInEachVm implements Serializable {
+
+    private static final AtomicReference<WithClose> withClose = new AtomicReference<>();
+    private static final AtomicReference<WithDisconnect> withDisconnect = new AtomicReference<>();
+    private static final AtomicReference<WithStop> withStop = new AtomicReference<>();
+
+    @Rule
+    public DistributedReference<WithClose> refWithClose = new DistributedReference<>();
+    @Rule
+    public DistributedReference<WithDisconnect> refWithDisconnect = new DistributedReference<>();
+    @Rule
+    public DistributedReference<WithStop> refWithStop = new DistributedReference<>();
+
+    @Before
+    public void setUp() {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+        vm.invoke(() -> {
+          withClose.set(spy(new WithClose("WithClose in VM-" + vm.getId())));
+          withDisconnect.set(spy(new WithDisconnect("WithDisconnect in VM-" + vm.getId())));
+          withStop.set(spy(new WithStop("WithStop in VM-" + vm.getId())));
+
+          refWithClose.set(withClose.get());
+          refWithDisconnect.set(withDisconnect.get());
+          refWithStop.set(withStop.get());
+        });
+      }
+    }
+
+    @Test
+    public void hasManyReferencesInEachVm() {
+      for (VM vm : asList(getVM(0), getVM(1), getVM(2), getVM(3), getController())) {
+        vm.invoke(() -> {
+          assertThat(refWithClose.get()).isSameAs(withClose.get());
+          assertThat(refWithDisconnect.get()).isSameAs(withDisconnect.get());
+          assertThat(refWithStop.get()).isSameAs(withStop.get());
+
+          assertThat(refWithClose.get().toString()).isEqualTo("WithClose in VM-" + vm.getId());
+          assertThat(refWithDisconnect.get().toString())
+              .isEqualTo("WithDisconnect in VM-" + vm.getId());
+          assertThat(refWithStop.get().toString()).isEqualTo("WithStop in VM-" + vm.getId());
+        });
+      }
+    }
+  }
+
+  @SuppressWarnings("WeakerAccess")
   public static class WithClose {
 
     private final String value;
@@ -607,6 +814,7 @@ public class DistributedReferenceTest {
     }
   }
 
+  @SuppressWarnings("WeakerAccess")
   public static class WithDisconnect {
 
     private final String value;
@@ -629,6 +837,7 @@ public class DistributedReferenceTest {
     }
   }
 
+  @SuppressWarnings({"unused", "WeakerAccess"})
   public static class WithStop {
 
     private final String value;
