@@ -77,7 +77,7 @@ public abstract class OrderByTestImplementation {
 
   @Test
   public void testOrderByWithIndexResultDefaultProjection() throws Exception {
-    String queries[] = {
+    String[] queries = {
         // Test case No. IUMR021
         "SELECT  distinct * FROM " + SEPARATOR + "portfolio1 pf1 where ID > 10 order by ID desc ",
         "SELECT  distinct * FROM " + SEPARATOR + "portfolio1 pf1 where ID > 10 order by ID asc ",
@@ -109,7 +109,7 @@ public abstract class OrderByTestImplementation {
             + "portfolio1 pf1 where ID != 10 order by ID desc limit 10",
 
     };
-    Object r[][] = new Object[queries.length][2];
+    Object[][] r = new Object[queries.length][2];
     QueryService qs;
     qs = CacheUtils.getQueryService();
     Position.resetCounter();
@@ -136,7 +136,7 @@ public abstract class OrderByTestImplementation {
     }
     // Create Indexes
 
-    this.createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
+    createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
 
     // Execute Queries with Indexes
     for (int i = 0; i < queries.length; i++) {
@@ -255,7 +255,7 @@ public abstract class OrderByTestImplementation {
 
   @Test
   public void testOrderByWithIndexResultWithProjection() throws Exception {
-    String queries[] = {
+    String[] queries = {
         // Test case No. IUMR021
         "SELECT  distinct ID, description, createTime FROM " + SEPARATOR
             + "portfolio1 pf1 where ID > 10 order by ID desc ",
@@ -291,7 +291,7 @@ public abstract class OrderByTestImplementation {
             + "portfolio1 pf1 where ID != 10 order by ID desc limit 10",
 
     };
-    Object r[][] = new Object[queries.length][2];
+    Object[][] r = new Object[queries.length][2];
     QueryService qs;
     qs = CacheUtils.getQueryService();
     Position.resetCounter();
@@ -318,7 +318,7 @@ public abstract class OrderByTestImplementation {
     }
     // Create Indexes
 
-    this.createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
+    createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
 
     // Execute Queries with Indexes
     for (int i = 0; i < queries.length; i++) {
@@ -372,7 +372,7 @@ public abstract class OrderByTestImplementation {
 
   @Test
   public void testMultiColOrderByWithIndexResultDefaultProjection() throws Exception {
-    String queries[] = {
+    String[] queries = {
         // Test case No. IUMR021
         "SELECT  distinct * FROM " + SEPARATOR
             + "portfolio1 pf1 where ID > 10 order by ID desc, pkid asc ",
@@ -408,7 +408,7 @@ public abstract class OrderByTestImplementation {
             + "portfolio1 pf1 where ID != 10 order by ID desc, pkid desc limit 10",
 
     };
-    Object r[][] = new Object[queries.length][2];
+    Object[][] r = new Object[queries.length][2];
     QueryService qs;
     qs = CacheUtils.getQueryService();
     Position.resetCounter();
@@ -435,7 +435,7 @@ public abstract class OrderByTestImplementation {
     }
     // Create Indexes
 
-    this.createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
+    createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
 
     // Execute Queries with Indexes
     for (int i = 0; i < queries.length; i++) {
@@ -487,8 +487,8 @@ public abstract class OrderByTestImplementation {
 
   @Test
   public void testMultiColOrderByWithIndexResultWithProjection() throws Exception {
-    String queries[] = getQueriesForMultiColOrderByWithIndexResultWithProjection();
-    Object r[][] = new Object[queries.length][2];
+    String[] queries = getQueriesForMultiColOrderByWithIndexResultWithProjection();
+    Object[][] r = new Object[queries.length][2];
     QueryService qs;
     qs = CacheUtils.getQueryService();
     Position.resetCounter();
@@ -515,7 +515,7 @@ public abstract class OrderByTestImplementation {
     }
     // Create Indexes
 
-    this.createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
+    createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
 
     // Execute Queries with Indexes
     for (int i = 0; i < queries.length; i++) {
@@ -565,7 +565,7 @@ public abstract class OrderByTestImplementation {
 
   @Test
   public void testMultiColOrderByWithMultiIndexResultDefaultProjection() throws Exception {
-    String queries[] = {
+    String[] queries = {
         // Test case No. IUMR021
         "SELECT  distinct * FROM " + SEPARATOR
             + "portfolio1 pf1 where pkid = '12' and ID > 10 order by ID desc, pkid asc ",
@@ -601,7 +601,7 @@ public abstract class OrderByTestImplementation {
             + "portfolio1 pf1 where pkid > '1' and ID != 10 order by ID desc, pkid desc limit 10",
 
     };
-    Object r[][] = new Object[queries.length][2];
+    Object[][] r = new Object[queries.length][2];
     QueryService qs;
     qs = CacheUtils.getQueryService();
     Position.resetCounter();
@@ -628,8 +628,8 @@ public abstract class OrderByTestImplementation {
     }
     // Create Indexes
 
-    this.createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
-    this.createIndex("PKIDIndexPf1", IndexType.FUNCTIONAL, "pkid", SEPARATOR + "portfolio1");
+    createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
+    createIndex("PKIDIndexPf1", IndexType.FUNCTIONAL, "pkid", SEPARATOR + "portfolio1");
     // Execute Queries with Indexes
     for (int i = 0; i < queries.length; i++) {
       Query q = null;
@@ -654,9 +654,8 @@ public abstract class OrderByTestImplementation {
           fail("Index is NOT uesd");
         }
 
-        Iterator itr = observer.indexesUsed.iterator();
-        while (itr.hasNext()) {
-          String indexUsed = itr.next().toString();
+        for (final Object o : observer.indexesUsed) {
+          String indexUsed = o.toString();
           if (!(indexUsed).equals("IDIndexPf1")) {
             fail("<IDIndexPf1> was expected but found " + indexUsed);
           }
@@ -683,8 +682,8 @@ public abstract class OrderByTestImplementation {
 
   @Test
   public void testMultiColOrderByWithMultiIndexResultProjection() throws Exception {
-    String queries[] = getQueriesForMultiColOrderByWithMultiIndexResultProjection();
-    Object r[][] = new Object[queries.length][2];
+    String[] queries = getQueriesForMultiColOrderByWithMultiIndexResultProjection();
+    Object[][] r = new Object[queries.length][2];
     QueryService qs;
     qs = CacheUtils.getQueryService();
     Position.resetCounter();
@@ -711,8 +710,8 @@ public abstract class OrderByTestImplementation {
     }
     // Create Indexes
 
-    this.createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
-    this.createIndex("PKIDIndexPf1", IndexType.FUNCTIONAL, "pkid", SEPARATOR + "portfolio1");
+    createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
+    createIndex("PKIDIndexPf1", IndexType.FUNCTIONAL, "pkid", SEPARATOR + "portfolio1");
     // Execute Queries with Indexes
     for (int i = 0; i < queries.length; i++) {
       Query q = null;
@@ -735,9 +734,8 @@ public abstract class OrderByTestImplementation {
         }
         assertTrue(!limitQuery || rcw.size() <= limit);
 
-        Iterator itr = observer.indexesUsed.iterator();
-        while (itr.hasNext()) {
-          String indexUsed = itr.next().toString();
+        for (final Object o : observer.indexesUsed) {
+          String indexUsed = o.toString();
           if (!(indexUsed).equals("IDIndexPf1")) {
             fail("<IDIndexPf1> was expected but found " + indexUsed);
           }
@@ -763,9 +761,9 @@ public abstract class OrderByTestImplementation {
 
   @Test
   public void testLimitNotAppliedIfOrderByNotUsingIndex() throws Exception {
-    String queries[] = getQueriesForLimitNotAppliedIfOrderByNotUsingIndex();
+    String[] queries = getQueriesForLimitNotAppliedIfOrderByNotUsingIndex();
 
-    Object r[][] = new Object[queries.length][2];
+    Object[][] r = new Object[queries.length][2];
     QueryService qs;
     qs = CacheUtils.getQueryService();
     Position.resetCounter();
@@ -792,7 +790,7 @@ public abstract class OrderByTestImplementation {
     }
     // Create Indexes
 
-    this.createIndex("PKIDIndexPf1", IndexType.FUNCTIONAL, "pkid", SEPARATOR + "portfolio1");
+    createIndex("PKIDIndexPf1", IndexType.FUNCTIONAL, "pkid", SEPARATOR + "portfolio1");
     // Execute Queries with Indexes
     for (int i = 0; i < queries.length; i++) {
       Query q = null;
@@ -816,9 +814,8 @@ public abstract class OrderByTestImplementation {
         }
         assertTrue(!limitQuery || !observer.limitAppliedAtIndex);
 
-        Iterator itr = observer.indexesUsed.iterator();
-        while (itr.hasNext()) {
-          String indexUsed = itr.next().toString();
+        for (final Object o : observer.indexesUsed) {
+          String indexUsed = o.toString();
           if (!(indexUsed).equals("PKIDIndexPf1")) {
             fail("<PKIDIndexPf1> was expected but found " + indexUsed);
           }
@@ -848,7 +845,7 @@ public abstract class OrderByTestImplementation {
   public void testOrderByWithNullValuesUseIndex() throws Exception {
     // IN ORDER BY NULL values are treated as smallest. E.g For an ascending order by field
     // its null values are reported first and then the values in ascending order.
-    String queries[] =
+    String[] queries =
         {"SELECT  distinct * FROM " + SEPARATOR + "portfolio1 pf1 where ID > 0 order by pkid", // 0
             // null
             // values
@@ -887,14 +884,14 @@ public abstract class OrderByTestImplementation {
                 + "portfolio1 pf1 where ID > 0 order by pkid", // 9
         };
 
-    Object r[][] = new Object[queries.length][2];
+    Object[][] r = new Object[queries.length][2];
     QueryService qs;
     qs = CacheUtils.getQueryService();
 
     // Create Regions
     final int size = 9;
     final int numNullValues = 3;
-    Region r1 = this.createRegion("portfolio1", Portfolio.class);
+    Region r1 = createRegion("portfolio1", Portfolio.class);
     for (int i = 1; i <= size; i++) {
       Portfolio pf = new Portfolio(i);
       // Add numNullValues null values.
@@ -906,8 +903,8 @@ public abstract class OrderByTestImplementation {
     }
 
     // Create Indexes
-    this.createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
-    this.createIndex("PKIDIndexPf1", IndexType.FUNCTIONAL, "pkid", SEPARATOR + "portfolio1");
+    createIndex("IDIndexPf1", IndexType.FUNCTIONAL, "ID", SEPARATOR + "portfolio1");
+    createIndex("PKIDIndexPf1", IndexType.FUNCTIONAL, "pkid", SEPARATOR + "portfolio1");
 
     Query q = null;
     SelectResults results = null;
@@ -1048,7 +1045,7 @@ public abstract class OrderByTestImplementation {
       list = results.asList();
       for (int i = 1; i <= size; i++) {
         Struct strct = (Struct) list.get(i - 1);
-        int id = ((Integer) strct.getFieldValues()[0]).intValue();
+        int id = (Integer) strct.getFieldValues()[0];
         // ID should be one of 1, 2, 3 because of distinct
         if (i <= numNullValues) {
           if (!(id == 1 || id == 2 || id == 3)) {
@@ -1069,7 +1066,7 @@ public abstract class OrderByTestImplementation {
       list = results.asList();
       for (int i = 1; i <= list.size(); i++) {
         Struct strct = (Struct) list.get(i - 1);
-        int id = ((Integer) strct.getFieldValues()[0]).intValue();
+        int id = (Integer) strct.getFieldValues()[0];
         if (id != (numNullValues + i)) {
           fail(" Value of ID is not as expected, " + id);
         }
@@ -1083,7 +1080,7 @@ public abstract class OrderByTestImplementation {
       list = results.asList();
       for (int i = 1; i <= size; i++) {
         Struct vals = (Struct) list.get((i - 1));
-        int id = ((Integer) vals.get("ID")).intValue();
+        int id = (Integer) vals.get("ID");
         String pkid = (String) vals.get("pkid");
 
         // ID should be one of 1, 2, 3 because of distinct
@@ -1112,7 +1109,7 @@ public abstract class OrderByTestImplementation {
 
       for (int i = 1; i <= list.size(); i++) {
         Struct vals = (Struct) list.get((i - 1));
-        int id = ((Integer) vals.get("ID")).intValue();
+        int id = (Integer) vals.get("ID");
         String pkid = (String) vals.get("pkid");
 
         if (i <= numNullValues) {
@@ -1138,7 +1135,7 @@ public abstract class OrderByTestImplementation {
 
   @Test
   public void testOrderByForUndefined() throws Exception {
-    String queries[] =
+    String[] queries =
         {"SELECT DISTINCT position1.secId FROM " + SEPARATOR + "test ORDER BY position1.secId", // 0
             "SELECT DISTINCT position1.secId FROM " + SEPARATOR
                 + "test ORDER BY position1.secId desc", // 1
@@ -1151,7 +1148,7 @@ public abstract class OrderByTestImplementation {
             "SELECT DISTINCT position1.secId, ID FROM " + SEPARATOR
                 + "test ORDER BY position1.secId desc, ID",// 5
         };
-    Region r1 = this.createRegion("test", Portfolio.class);
+    Region r1 = createRegion("test", Portfolio.class);
     for (int i = 0; i < 10; i++) {
       Portfolio pf = new Portfolio(i);
       if (i % 2 == 0) {
@@ -1195,8 +1192,8 @@ public abstract class OrderByTestImplementation {
     }
 
 
-    this.createIndex("secIndex", "position1.secId", r1.getFullPath());
-    this.createIndex("IDIndex", "ID", r1.getFullPath());
+    createIndex("secIndex", "position1.secId", r1.getFullPath());
+    createIndex("IDIndex", "ID", r1.getFullPath());
 
     for (int i = 0; i < queries.length; i++) {
       try {
@@ -1257,7 +1254,7 @@ public abstract class OrderByTestImplementation {
 
     @Override
     public void limitAppliedAtIndexLevel(Index index, int limit, Collection indexResult) {
-      this.limitAppliedAtIndex = true;
+      limitAppliedAtIndex = true;
     }
 
   }
