@@ -22,8 +22,8 @@ import static org.apache.geode.distributed.ConfigurationProperties.LOG_FILE;
 import static org.apache.geode.distributed.ConfigurationProperties.LOG_LEVEL;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
-import static org.apache.geode.test.dunit.Assert.assertNotNull;
-import static org.apache.geode.test.dunit.Assert.fail;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.fail;
 
 import java.io.File;
 import java.net.InetSocketAddress;
@@ -53,7 +53,6 @@ import org.apache.geode.cache.server.CacheServer;
 import org.apache.geode.cache.util.CacheListenerAdapter;
 import org.apache.geode.cache.util.CqListenerAdapter;
 import org.apache.geode.distributed.DistributedSystem;
-import org.apache.geode.internal.cache.GemFireCacheImpl;
 import org.apache.geode.internal.cache.PoolFactoryImpl;
 import org.apache.geode.internal.cache.PoolFactoryImpl.PoolAttributes;
 import org.apache.geode.test.dunit.DistributedTestUtils;
@@ -69,6 +68,7 @@ import org.apache.geode.util.internal.GeodeGlossary;
  * @deprecated Please use {@link DistributedRule} and Geode User APIs or {@link ClusterStartupRule}
  *             instead.
  */
+@Deprecated
 public class CacheServerTestUtil extends JUnit4DistributedTestCase {
 
   private static Cache cache = null;
@@ -94,8 +94,7 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
     createClientCache(poolAttr, regionName, getClientProperties());
   }
 
-  public static void createClientCache(Pool poolAttr, String regionName, Properties dsProperties)
-      throws Exception {
+  public static void createClientCache(Pool poolAttr, String regionName, Properties dsProperties) {
     ClientCacheFactory ccf = new ClientCacheFactory(dsProperties);
     if (poolAttr != null) {
       ccf.setPoolFreeConnectionTimeout(poolAttr.getFreeConnectionTimeout())
@@ -128,25 +127,13 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
     new CacheServerTestUtil().createClientCache(dsProperties, ccf);
     ClientCache cc = (ClientCache) cache;
     cc.createClientRegionFactory(ClientRegionShortcut.CACHING_PROXY).create(regionName);
-    pool = (PoolImpl) ((GemFireCacheImpl) cc).getDefaultPool();
+    pool = (PoolImpl) cc.getDefaultPool();
   }
 
-  public static void createPool(PoolAttributes poolAttr) throws Exception {
-    Properties props = new Properties();
-    props.setProperty(MCAST_PORT, "0");
-    props.setProperty(LOCATORS, "");
-
-    DistributedSystem ds = new CacheServerTestUtil().getSystem(props);;
-
+  public static void createPool(PoolAttributes poolAttr) {
     PoolFactoryImpl pf = (PoolFactoryImpl) PoolManager.createFactory();
     pf.init(poolAttr);
-    PoolImpl p = (PoolImpl) pf.create("CacheServerTestUtil");
-    AttributesFactory factory = new AttributesFactory();
-    factory.setScope(Scope.LOCAL);
-    factory.setPoolName(p.getName());
-
-    RegionAttributes attrs = factory.create();
-    pool = p;
+    pool = (PoolImpl) pf.create("CacheServerTestUtil");
   }
 
   public static void createCacheClient(Pool poolAttr, String regionName, Properties dsProperties,
@@ -155,12 +142,12 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
   }
 
   public static void createCacheClient(Pool poolAttr, String regionName, Properties dsProperties,
-      Boolean addControlListener, Properties javaSystemProperties) throws Exception {
+      Boolean addControlListener, Properties javaSystemProperties) {
     new CacheServerTestUtil().createCache(dsProperties);
     IgnoredException.addIgnoredException("java.net.ConnectException||java.net.SocketException");
 
     if (javaSystemProperties != null && javaSystemProperties.size() > 0) {
-      Enumeration e = javaSystemProperties.propertyNames();
+      Enumeration<?> e = javaSystemProperties.propertyNames();
 
       while (e.hasMoreElements()) {
         String key = (String) e.nextElement();
@@ -171,20 +158,20 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
     PoolFactoryImpl pf = (PoolFactoryImpl) PoolManager.createFactory();
     pf.init(poolAttr);
     PoolImpl p = (PoolImpl) pf.create("CacheServerTestUtil");
-    AttributesFactory factory = new AttributesFactory();
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
     factory.setScope(Scope.LOCAL);
     factory.setPoolName(p.getName());
-    if (addControlListener.booleanValue()) {
+    if (addControlListener) {
       factory.addCacheListener(new ControlListener());
     }
-    RegionAttributes attrs = factory.create();
+    RegionAttributes<Object, Object> attrs = factory.create();
     cache.createRegion(regionName, attrs);
     pool = p;
   }
 
   public static void unsetJavaSystemProperties(Properties javaSystemProperties) {
     if (javaSystemProperties != null && javaSystemProperties.size() > 0) {
-      Enumeration e = javaSystemProperties.propertyNames();
+      Enumeration<?> e = javaSystemProperties.propertyNames();
 
       while (e.hasMoreElements()) {
         String key = (String) e.nextElement();
@@ -193,16 +180,15 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
     }
   }
 
-  public static void createCacheClient(Pool poolAttr, String regionName1, String regionName2)
-      throws Exception {
+  public static void createCacheClient(Pool poolAttr, String regionName1, String regionName2) {
     new CacheServerTestUtil().createCache(getClientProperties());
     PoolFactoryImpl pf = (PoolFactoryImpl) PoolManager.createFactory();
     pf.init(poolAttr);
     PoolImpl p = (PoolImpl) pf.create("CacheServerTestUtil");
-    AttributesFactory factory = new AttributesFactory();
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
     factory.setScope(Scope.LOCAL);
     factory.setPoolName(p.getName());
-    RegionAttributes attrs = factory.create();
+    RegionAttributes<Object, Object> attrs = factory.create();
     cache.createRegion(regionName1, attrs);
     cache.createRegion(regionName2, attrs);
     pool = p;
@@ -263,7 +249,7 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
       throw new ExceptionInInitializerError(e);
     }
     cache = ccf.create();
-    return new Integer(cache.getCacheServers().get(0).getPort());
+    return cache.getCacheServers().get(0).getPort();
   }
 
   public static Integer createCacheServerFromXml(URL url) {
@@ -277,28 +263,28 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
       throw new ExceptionInInitializerError(e);
     }
     cache = ccf.create();
-    return new Integer(cache.getCacheServers().get(0).getPort());
+    return cache.getCacheServers().get(0).getPort();
   }
 
   /**
    * Create client regions
    */
   public static void createCacheClients(Pool poolAttr, String regionName1, String regionName2,
-      Properties dsProperties) throws Exception {
+      Properties dsProperties) {
     new CacheServerTestUtil().createCache(dsProperties);
 
     // Initialize region1
     PoolFactoryImpl pf = (PoolFactoryImpl) PoolManager.createFactory();
     pf.init(poolAttr);
     Pool p = pf.create("CacheServerTestUtil1");
-    AttributesFactory factory1 = new AttributesFactory();
+    AttributesFactory<Object, Object> factory1 = new AttributesFactory<>();
     factory1.setScope(Scope.LOCAL);
     factory1.setPoolName(p.getName());
     cache.createRegion(regionName1, factory1.create());
 
     // Initialize region2
     p = pf.create("CacheServerTestUtil2");
-    AttributesFactory factory2 = new AttributesFactory();
+    AttributesFactory<Object, Object> factory2 = new AttributesFactory<>();
     factory2.setScope(Scope.LOCAL);
     factory2.setPoolName(p.getName());
     cache.createRegion(regionName2, factory2.create());
@@ -338,26 +324,26 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
     props.setProperty(MCAST_PORT, "0");
     props.setProperty(LOCATORS, "localhost[" + DistributedTestUtils.getDUnitLocatorPort() + "]");
     new CacheServerTestUtil().createCache(props);
-    AttributesFactory factory = new AttributesFactory();
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
     factory.setScope(Scope.DISTRIBUTED_ACK);
     factory.setEnableBridgeConflation(true);
     factory.setDataPolicy(DataPolicy.REPLICATE);
-    RegionAttributes attrs = factory.create();
+    RegionAttributes<Object, Object> attrs = factory.create();
     cache.createRegion(regionName, attrs);
     CacheServer server = cache.addCacheServer();
-    server.setPort(serverPort.intValue());
-    server.setNotifyBySubscription(notifyBySubscription.booleanValue());
+    server.setPort(serverPort);
+    server.setNotifyBySubscription(notifyBySubscription);
     server.start();
   }
 
   public static Integer createCacheServer(String regionName1, String regionName2,
       Boolean notifyBySubscription) throws Exception {
     new CacheServerTestUtil().createCache(new Properties());
-    AttributesFactory factory = new AttributesFactory();
+    AttributesFactory<Object, Object> factory = new AttributesFactory<>();
     factory.setScope(Scope.DISTRIBUTED_ACK);
     factory.setEnableBridgeConflation(true);
     factory.setDataPolicy(DataPolicy.REPLICATE);
-    RegionAttributes attrs = factory.create();
+    RegionAttributes<Object, Object> attrs = factory.create();
     if (!regionName1.equals("")) {
       cache.createRegion(regionName1, attrs);
     }
@@ -367,28 +353,28 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
     CacheServer server1 = cache.addCacheServer();
     int port = getRandomAvailableTCPPort();
     server1.setPort(port);
-    server1.setNotifyBySubscription(notifyBySubscription.booleanValue());
+    server1.setNotifyBySubscription(notifyBySubscription);
     server1.start();
-    return new Integer(server1.getPort());
+    return server1.getPort();
   }
 
-  private void createCache(Properties props) throws Exception {
+  private void createCache(Properties props) {
     DistributedSystem ds = getSystem(props);
-    assertNotNull(ds);
+    assertThat(ds).isNotNull();
     ds.disconnect();
     ds = getSystem(props);
     cache = CacheFactory.create(ds);
-    assertNotNull(cache);
+    assertThat(cache).isNotNull();
   }
 
-  private void createClientCache(Properties props, ClientCacheFactory ccf) throws Exception {
+  private void createClientCache(Properties props, ClientCacheFactory ccf) {
     DistributedSystem ds = getSystem(props);
-    assertNotNull(ds);
+    assertThat(ds).isNotNull();
     ds.disconnect();
     ClientCache cc = ccf.create();
     setSystem(props, cc.getDistributedSystem());
     cache = (Cache) cc;
-    assertNotNull(cache);
+    assertThat(cache).isNotNull();
     expected = IgnoredException
         .addIgnoredException("java.net.ConnectionException||java.net.SocketException");
   }
@@ -474,15 +460,15 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
     public final int type;
 
     public EventWrapper(EntryEvent ee, int type) {
-      this.event = ee;
-      this.key = ee.getKey();
-      this.val = ee.getNewValue();
-      this.arg = ee.getCallbackArgument();
+      event = ee;
+      key = ee.getKey();
+      val = ee.getNewValue();
+      arg = ee.getCallbackArgument();
       this.type = type;
     }
 
     public boolean isCreate() {
-      return this.type == TYPE_CREATE;
+      return type == TYPE_CREATE;
     }
 
     public String toString() {
@@ -491,10 +477,10 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
   }
 
   public static class ControlListener extends CacheListenerAdapter implements Declarable {
-    public final LinkedList<EventWrapper> events = new LinkedList();
-    public final LinkedList<EntryEvent> createEvents = new LinkedList();
-    public final LinkedList<EntryEvent> updateEvents = new LinkedList();
-    public final LinkedList<EntryEvent> destroyEvents = new LinkedList();
+    public final LinkedList<EventWrapper> events = new LinkedList<>();
+    public final LinkedList<EntryEvent> createEvents = new LinkedList<>();
+    public final LinkedList<EntryEvent> updateEvents = new LinkedList<>();
+    public final LinkedList<EntryEvent> destroyEvents = new LinkedList<>();
     public final Object CONTROL_LOCK = new Object();
 
     // added to test creation of cache from xml
@@ -509,16 +495,21 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
       return waitWhileNotEnoughEvents(sleepMs, eventCount, getEvents(eventType));
     }
 
+
+    /**
+     * This method is not implemented to test event count matches the eventsToCheck.size() which is
+     * confusing. It will wait and return if it got something in the eventsToCheck or not.
+     */
     public boolean waitWhileNotEnoughEvents(long sleepMs, int eventCount, List eventsToCheck) {
       long maxMillis = System.currentTimeMillis() + sleepMs;
-      synchronized (this.CONTROL_LOCK) {
+      synchronized (CONTROL_LOCK) {
         try {
           while (eventsToCheck.size() < eventCount) {
             long waitMillis = maxMillis - System.currentTimeMillis();
             if (waitMillis < 10) {
               break;
             }
-            this.CONTROL_LOCK.wait(waitMillis);
+            CONTROL_LOCK.wait(waitMillis);
           } // while
         } catch (InterruptedException abort) {
           fail("interrupted");
@@ -528,55 +519,55 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
     }
 
     public List getEvents(int eventType) {
-      List eventsToCheck = null;
+      List eventsToCheck;
       switch (eventType) {
         case TYPE_CREATE:
-          eventsToCheck = this.createEvents;
+          eventsToCheck = createEvents;
           break;
         case TYPE_UPDATE:
-          eventsToCheck = this.updateEvents;
+          eventsToCheck = updateEvents;
           break;
         case TYPE_DESTROY:
-          eventsToCheck = this.destroyEvents;
+          eventsToCheck = destroyEvents;
           break;
         default:
-          eventsToCheck = this.events;
+          eventsToCheck = events;
       }
       return eventsToCheck;
     }
 
     @Override
     public void afterCreate(EntryEvent e) {
-      synchronized (this.CONTROL_LOCK) {
-        this.events.add(new EventWrapper(e, TYPE_CREATE));
-        this.createEvents.add(e);
-        this.CONTROL_LOCK.notifyAll();
+      synchronized (CONTROL_LOCK) {
+        events.add(new EventWrapper(e, TYPE_CREATE));
+        createEvents.add(e);
+        CONTROL_LOCK.notifyAll();
       }
     }
 
     @Override
     public void afterUpdate(EntryEvent e) {
-      synchronized (this.CONTROL_LOCK) {
-        this.events.add(new EventWrapper(e, TYPE_UPDATE));
-        this.updateEvents.add(e);
-        this.CONTROL_LOCK.notifyAll();
+      synchronized (CONTROL_LOCK) {
+        events.add(new EventWrapper(e, TYPE_UPDATE));
+        updateEvents.add(e);
+        CONTROL_LOCK.notifyAll();
       }
     }
 
     @Override
     public void afterInvalidate(EntryEvent e) {
-      synchronized (this.CONTROL_LOCK) {
-        this.events.add(new EventWrapper(e, TYPE_INVALIDATE));
-        this.CONTROL_LOCK.notifyAll();
+      synchronized (CONTROL_LOCK) {
+        events.add(new EventWrapper(e, TYPE_INVALIDATE));
+        CONTROL_LOCK.notifyAll();
       }
     }
 
     @Override
     public void afterDestroy(EntryEvent e) {
-      synchronized (this.CONTROL_LOCK) {
-        this.events.add(new EventWrapper(e, TYPE_DESTROY));
-        this.destroyEvents.add(e);
-        this.CONTROL_LOCK.notifyAll();
+      synchronized (CONTROL_LOCK) {
+        events.add(new EventWrapper(e, TYPE_DESTROY));
+        destroyEvents.add(e);
+        CONTROL_LOCK.notifyAll();
       }
     }
   }
@@ -587,27 +578,27 @@ public class CacheServerTestUtil extends JUnit4DistributedTestCase {
 
     public boolean waitWhileNotEnoughEvents(long sleepMs, int eventCount) {
       long maxMillis = System.currentTimeMillis() + sleepMs;
-      synchronized (this.CONTROL_LOCK) {
+      synchronized (CONTROL_LOCK) {
         try {
-          while (this.events.size() < eventCount) {
+          while (events.size() < eventCount) {
             long waitMillis = maxMillis - System.currentTimeMillis();
             if (waitMillis < 10) {
               break;
             }
-            this.CONTROL_LOCK.wait(waitMillis);
+            CONTROL_LOCK.wait(waitMillis);
           } // while
         } catch (InterruptedException abort) {
           fail("interrupted");
         }
-        return !this.events.isEmpty();
+        return !events.isEmpty();
       } // synchronized
     }
 
     @Override
     public void onEvent(CqEvent aCqEvent) {
-      synchronized (this.CONTROL_LOCK) {
-        this.events.add(aCqEvent);
-        this.CONTROL_LOCK.notifyAll();
+      synchronized (CONTROL_LOCK) {
+        events.add(aCqEvent);
+        CONTROL_LOCK.notifyAll();
       }
     }
   }
