@@ -92,6 +92,7 @@ import org.apache.geode.test.dunit.cache.internal.JUnit4CacheTestCase;
 import org.apache.geode.test.dunit.internal.DUnitLauncher;
 import org.apache.geode.test.junit.categories.ClientServerTest;
 import org.apache.geode.test.version.VersionManager;
+import org.apache.geode.test.version.VmConfiguration;
 import org.apache.geode.util.internal.GeodeGlossary;
 
 /**
@@ -138,11 +139,15 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
   private final int putRange_2End = 10;
 
 
-  String testVersion; // version for client caches for backward-compatibility
-                      // testing
+  // configuration for client caches for backward-compatibility testing
+  final VmConfiguration clientVmConfiguration;
 
   public ClientServerMiscDUnitTestBase() {
-    testVersion = VersionManager.CURRENT_VERSION;
+    this(VmConfiguration.current());
+  }
+
+  public ClientServerMiscDUnitTestBase(VmConfiguration clientVmConfiguration) {
+    this.clientVmConfiguration = clientVmConfiguration;
   }
 
   @Override
@@ -169,7 +174,8 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
   }
 
   int initServerCache(boolean notifyBySub, VM vm, boolean isHA) {
-    return vm.invoke(() -> createServerCache(notifyBySub, getMaxThreads(), isHA));
+    int port = getRandomAvailableTCPPort();
+    return vm.invoke(() -> createServerCache(notifyBySub, getMaxThreads(), isHA, port));
   }
 
   @Test
@@ -177,15 +183,15 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
     int port1 = initServerCache(true); // vm0
     int port2 = initServerCache2(); // vm1
     String serverName = NetworkUtils.getServerHostName();
-    host.getVM(testVersion, 0).invoke(() -> createClientCacheV(serverName, port1));
-    host.getVM(testVersion, 1).invoke(() -> createClientCacheV(serverName, port2));
+    host.getVM(clientVmConfiguration, 0).invoke(() -> createClientCacheV(serverName, port1));
+    host.getVM(clientVmConfiguration, 1).invoke(() -> createClientCacheV(serverName, port2));
     LogService.getLogger()
         .info("Testing concurrent map operations from a client with a distributed region");
-    concurrentMapTest(host.getVM(testVersion, 0), SEPARATOR + REGION_NAME1);
+    concurrentMapTest(host.getVM(clientVmConfiguration, 0), SEPARATOR + REGION_NAME1);
     // TODO add verification in vm1
     LogService.getLogger()
         .info("Testing concurrent map operations from a client with a partitioned region");
-    concurrentMapTest(host.getVM(testVersion, 0), SEPARATOR + PR_REGION_NAME);
+    concurrentMapTest(host.getVM(clientVmConfiguration, 0), SEPARATOR + PR_REGION_NAME);
     // TODO add verification in vm1
   }
 
@@ -196,7 +202,7 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
    */
   @Test
   public void testClientReceivesPingIntervalSetting() {
-    VM clientVM = Host.getHost(0).getVM(testVersion, 0);
+    VM clientVM = Host.getHost(0).getVM(clientVmConfiguration, 0);
 
     final int port = initServerCache(true);
     final String host = NetworkUtils.getServerHostName();
@@ -241,15 +247,15 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
     int port1 = initServerCache(true); // vm0
     int port2 = initServerCache2(); // vm1
     String serverName = NetworkUtils.getServerHostName();
-    host.getVM(testVersion, 0).invoke(() -> createEmptyClientCache(serverName, port1));
-    host.getVM(testVersion, 1).invoke(() -> createClientCacheV(serverName, port2));
+    host.getVM(clientVmConfiguration, 0).invoke(() -> createEmptyClientCache(serverName, port1));
+    host.getVM(clientVmConfiguration, 1).invoke(() -> createClientCacheV(serverName, port2));
     LogService.getLogger()
         .info("Testing concurrent map operations from a client with a distributed region");
-    concurrentMapTest(host.getVM(testVersion, 0), SEPARATOR + REGION_NAME1);
+    concurrentMapTest(host.getVM(clientVmConfiguration, 0), SEPARATOR + REGION_NAME1);
     // TODO add verification in vm1
     LogService.getLogger()
         .info("Testing concurrent map operations from a client with a partitioned region");
-    concurrentMapTest(host.getVM(testVersion, 0), SEPARATOR + PR_REGION_NAME);
+    concurrentMapTest(host.getVM(clientVmConfiguration, 0), SEPARATOR + PR_REGION_NAME);
     // TODO add verification in vm1
   }
 
@@ -461,7 +467,7 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
     // start server first
     PORT1 = initServerCache(true);
     int serverPort = PORT1;
-    VM client1 = Host.getHost(0).getVM(testVersion, 1);
+    VM client1 = Host.getHost(0).getVM(clientVmConfiguration, 1);
     String hostname = NetworkUtils.getServerHostName();
     client1.invoke("create client1 cache", () -> {
       createClientCache(hostname, serverPort);
@@ -469,9 +475,9 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
       registerInterest();
     });
 
-    server1.invoke("putting entries in server1", () -> put());
+    server1.invoke("putting entries in server1", ClientServerMiscDUnitTestBase::put);
 
-    client1.invoke(() -> verifyUpdates());
+    client1.invoke(ClientServerMiscDUnitTestBase::verifyUpdates);
   }
 
   /**
@@ -491,8 +497,8 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
     registerInterestInBothTheRegions();
     closeRegion1();
     Wait.pause(6000);
-    server1.invoke(() -> ClientServerMiscDUnitTestBase.verifyInterestListOnServer());
-    server1.invoke(() -> ClientServerMiscDUnitTestBase.put());
+    server1.invoke(ClientServerMiscDUnitTestBase::verifyInterestListOnServer);
+    server1.invoke(ClientServerMiscDUnitTestBase::put);
     // pause(5000);
     verifyUpdatesOnRegion2();
   }
@@ -515,7 +521,7 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
     assertFalse(pool.isDestroyed());
     pool.destroy();
     assertTrue(pool.isDestroyed());
-    server1.invoke(() -> ClientServerMiscDUnitTestBase.verifyNoCacheClientProxyOnServer());
+    server1.invoke(ClientServerMiscDUnitTestBase::verifyNoCacheClientProxyOnServer);
 
   }
 
@@ -547,7 +553,7 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
     pool.destroy();
     assertTrue(pool.isDestroyed());
     // pause(5000);
-    server1.invoke(() -> ClientServerMiscDUnitTestBase.verifyNoCacheClientProxyOnServer());
+    server1.invoke(ClientServerMiscDUnitTestBase::verifyNoCacheClientProxyOnServer);
 
     assertThatThrownBy(() -> getCache().createRegion(REGION_NAME2, attrs))
         .isExactlyInstanceOf(IllegalStateException.class);
@@ -565,7 +571,7 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
     createClientCache(NetworkUtils.getServerHostName(), PORT1);
     registerInterestForInvalidatesInBothTheRegions();
     populateCache();
-    server1.invoke(() -> ClientServerMiscDUnitTestBase.put());
+    server1.invoke(ClientServerMiscDUnitTestBase::put);
     // pause(5000);
     verifyInvalidatesOnBothRegions();
 
@@ -606,11 +612,8 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
     PORT1 = initServerCache(false);
     createClientCache(NetworkUtils.getServerHostName(), PORT1);
     Region region = static_cache.getRegion(REGION_NAME1);
-    Op operation = new Op() {
-      @Override
-      public Object attempt(Connection cnx) throws Exception {
-        throw new MessageTooLargeException("message is too big");
-      }
+    Op operation = cnx -> {
+      throw new MessageTooLargeException("message is too big");
     };
     try {
       ((LocalRegion) region).getServerProxy().getPool().execute(operation);
@@ -657,7 +660,7 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
     assertNotNull(conn);
 
     populateCache();
-    server1.invoke(() -> ClientServerMiscDUnitTestBase.put());
+    server1.invoke(ClientServerMiscDUnitTestBase::put);
 
     await().until(() -> {
       Object val = region1.getEntry(k1).getValue();
@@ -720,7 +723,7 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
     // region1.registerInterest(CacheClientProxy.ALL_KEYS);
     region2.registerInterest("ALL_KEYS");
     Wait.pause(6000);
-    server1.invoke(() -> ClientServerMiscDUnitTestBase.verifyInterestListOnServer());
+    server1.invoke(ClientServerMiscDUnitTestBase::verifyInterestListOnServer);
 
   }
 
@@ -945,8 +948,8 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
   }
 
 
-  public static Integer createServerCache(Boolean notifyBySubscription, Integer maxThreads,
-      boolean isHA) throws Exception {
+  protected static Integer createServerCache(Boolean notifyBySubscription, Integer maxThreads,
+      boolean isHA, int port) throws Exception {
     Cache cache = new ClientServerMiscDUnitTestBase().createCacheV(new Properties());
     unsetSlowDispatcherFlag();
     AttributesFactory factory = new AttributesFactory();
@@ -971,7 +974,6 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
     assertNotNull(pr);
 
     CacheServer server = cache.addCacheServer();
-    int port = getRandomAvailableTCPPort();
     r1.getCache().getDistributedSystem().getLogWriter().info("Starting server on port " + port);
     server.setPort(port);
     server.setMaxThreads(maxThreads);
@@ -1353,7 +1355,7 @@ public class ClientServerMiscDUnitTestBase extends JUnit4CacheTestCase {
 
     putIntoRegion(prName, size, isCachingProxy);
     if (isHA) {
-      server1.invoke(() -> closeMyCache());
+      server1.invoke(this::closeMyCache);
     }
     verifySizeOnServer(prName, size);
 
