@@ -44,7 +44,6 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
@@ -72,11 +71,11 @@ import org.apache.geode.cache.query.SelectResults;
 import org.apache.geode.cache.query.Struct;
 import org.apache.geode.distributed.ConfigurationProperties;
 import org.apache.geode.distributed.internal.DistributionConfig;
-import org.apache.geode.internal.AvailablePort.Keeper;
 import org.apache.geode.internal.AvailablePortHelper;
 import org.apache.geode.internal.cache.LocalRegion;
 import org.apache.geode.internal.cache.entries.AbstractRegionEntry;
 import org.apache.geode.internal.cache.tier.sockets.ServerConnection;
+import org.apache.geode.internal.membership.utils.AvailablePort.Keeper;
 import org.apache.geode.security.generator.AuthzCredentialGenerator;
 import org.apache.geode.security.generator.AuthzCredentialGenerator.ClassCode;
 import org.apache.geode.security.generator.CredentialGenerator;
@@ -91,6 +90,7 @@ import org.apache.geode.test.dunit.internal.JUnit4DistributedTestCase;
 import org.apache.geode.test.dunit.rules.ClusterStartupRule;
 import org.apache.geode.test.dunit.rules.DistributedRule;
 import org.apache.geode.test.version.VersionManager;
+import org.apache.geode.test.version.VmConfiguration;
 
 /**
  * Base class for tests for authorization from client to server. It contains utility functions for
@@ -101,6 +101,7 @@ import org.apache.geode.test.version.VersionManager;
  * @deprecated Please use {@link DistributedRule} and Geode User APIs or {@link ClusterStartupRule}
  *             instead.
  */
+@Deprecated
 public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestCase {
 
   private static final int PAUSE = 5 * 1000;
@@ -110,7 +111,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
   protected static VM client1 = null;
   protected static VM client2 = null;
 
-  public String clientVersion = VersionManager.CURRENT_VERSION;
+  public final VmConfiguration clientVmConfiguration;
 
   protected static final String regionName = REGION_NAME; // TODO: remove
   protected static final String SUBREGION_NAME = "AuthSubregion";
@@ -125,6 +126,14 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
       {AuthenticationFailedException.class.getName(), NotAuthorizedException.class.getName(),
           RegionDestroyedException.class.getName()};
 
+  public ClientAuthorizationTestCase() {
+    this(VmConfiguration.current());
+  }
+
+  protected ClientAuthorizationTestCase(VmConfiguration clientVmConfiguration) {
+    this.clientVmConfiguration = clientVmConfiguration;
+  }
+
   @Override
   public final void preSetUp() throws Exception {}
 
@@ -141,13 +150,8 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
     server2 = host.getVM(VersionManager.CURRENT_VERSION, 1);
     server1.invoke(() -> ServerConnection.allowInternalMessagesWithoutCredentials = false);
     server2.invoke(() -> ServerConnection.allowInternalMessagesWithoutCredentials = false);
-    if (VersionManager.isCurrentVersion(clientVersion)) {
-      client1 = host.getVM(VersionManager.CURRENT_VERSION, 2);
-      client2 = host.getVM(VersionManager.CURRENT_VERSION, 3);
-    } else {
-      client1 = host.getVM(clientVersion, 2);
-      client2 = host.getVM(clientVersion, 3);
-    }
+    client1 = host.getVM(clientVmConfiguration, 2);
+    client2 = host.getVM(clientVmConfiguration, 3);
     setUpIgnoredExceptions();
   }
 
@@ -341,11 +345,11 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
     boolean exceptionOccurred = false;
     boolean breakLoop = false;
 
-    for (int indexIndex = 0; indexIndex < numOps; ++indexIndex) {
+    for (final int i : indices) {
       if (breakLoop) {
         break;
       }
-      int index = indices[indexIndex];
+      int index = i;
 
       try {
         final Object key = keys[index];
@@ -381,8 +385,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
 
             Map entries = region.getAll(keyList);
 
-            for (int keyNumIndex = 0; keyNumIndex < numOps; ++keyNumIndex) {
-              int keyNum = indices[keyNumIndex];
+            for (int keyNum : indices) {
               searchKey = keys[keyNum];
               if ((flags & OpFlags.CHECK_FAIL) > 0) {
                 assertFalse(entries.containsKey(searchKey));
@@ -403,8 +406,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
               @Override
               public Boolean call() throws Exception {
                 Object value = getLocalValue(region, key);
-                return (flags & OpFlags.CHECK_FAIL) > 0 ? !expectedVal.equals(value)
-                    : expectedVal.equals(value);
+                return ((flags & OpFlags.CHECK_FAIL) > 0) != expectedVal.equals(value);
               }
 
               public Callable<Boolean> init(Region region) {
@@ -452,8 +454,8 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
 
         } else if (op.isPutAll()) {
           HashMap map = new HashMap();
-          for (int i = 0; i < indices.length; i++) {
-            map.put(keys[indices[i]], vals[indices[i]]);
+          for (final int j : indices) {
+            map.put(keys[j], vals[j]);
           }
           region.putAll(map);
           breakLoop = true;
@@ -516,8 +518,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
             breakLoop = true;
             // Register interest list in this case
             List keyList = new ArrayList(numOps);
-            for (int keyNumIndex = 0; keyNumIndex < numOps; ++keyNumIndex) {
-              int keyNum = indices[keyNumIndex];
+            for (int keyNum : indices) {
               keyList.add(keys[keyNum]);
             }
             region.registerInterest(keyList, policy);
@@ -539,8 +540,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
             breakLoop = true;
             // Register interest list in this case
             List keyList = new ArrayList(numOps);
-            for (int keyNumIndex = 0; keyNumIndex < numOps; ++keyNumIndex) {
-              int keyNum = indices[keyNumIndex];
+            for (int keyNum : indices) {
               keyList.add(keys[keyNum]);
             }
             region.unregisterInterest(keyList);
@@ -570,8 +570,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
           if ((flags & OpFlags.CHECK_FAIL) == 0) {
             assertEquals(numOps, keySet.size());
           }
-          for (int keyNumIndex = 0; keyNumIndex < numOps; ++keyNumIndex) {
-            int keyNum = indices[keyNumIndex];
+          for (int keyNum : indices) {
             if ((flags & OpFlags.CHECK_FAIL) > 0) {
               assertFalse(keySet.contains(keys[keyNum]));
             } else {
@@ -588,8 +587,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
           if ((flags & OpFlags.CHECK_FAIL) == 0) {
             assertEquals(numOps, queryResultSet.size());
           }
-          for (int keyNumIndex = 0; keyNumIndex < numOps; ++keyNumIndex) {
-            int keyNum = indices[keyNumIndex];
+          for (int keyNum : indices) {
             if ((flags & OpFlags.CHECK_FAIL) > 0) {
               assertFalse(queryResultSet.contains(vals[keyNum]));
             } else {
@@ -655,8 +653,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
               assertEquals(numOps, cqResultSet.size());
             }
 
-            for (int keyNumIndex = 0; keyNumIndex < numOps; ++keyNumIndex) {
-              int keyNum = indices[keyNumIndex];
+            for (int keyNum : indices) {
               if ((flags & OpFlags.CHECK_FAIL) > 0) {
                 assertFalse(cqResultValues.contains(vals[keyNum]));
               } else {
@@ -737,7 +734,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
               + "] with flags " + OpFlags.description(flags) + ": " + ex.getCause());
           continue;
         } else if (expectedResult == OTHER_EXCEPTION) {
-          System.out.println("doOp: Got expected exception when doing operation: " + ex.toString());
+          System.out.println("doOp: Got expected exception when doing operation: " + ex);
           continue;
         } else {
           fail("doOp: Got unexpected exception when doing operation. Policy = " + policy
@@ -755,9 +752,8 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
       final int port2, final String authInit, final Properties extraAuthProps,
       final Properties extraAuthzProps, final TestCredentialGenerator credentialGenerator,
       final Random random) throws InterruptedException {
-    for (Iterator<OperationWithAction> opIter = opBlock.iterator(); opIter.hasNext();) {
+    for (OperationWithAction currentOp : opBlock) {
       // Start client with valid credentials as specified in OperationWithAction
-      OperationWithAction currentOp = opIter.next();
       OperationCode opCode = currentOp.getOperationCode();
       int opFlags = currentOp.getFlags();
       int clientNum = currentOp.getClientNum();
@@ -846,11 +842,11 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
 
       // Perform the operation from selected client
       if (useThisVM) {
-        doOp(opCode, currentOp.getIndices(), new Integer(opFlags), new Integer(expectedResult));
+        doOp(opCode, currentOp.getIndices(), opFlags, expectedResult);
       } else {
         int[] indices = currentOp.getIndices();
         clientVM.invoke("ClientAuthorizationTestCase.doOp", () -> ClientAuthorizationTestCase
-            .doOp(opCode, indices, new Integer(opFlags), new Integer(expectedResult)));
+            .doOp(opCode, indices, opFlags, expectedResult));
       }
     }
   }
@@ -865,10 +861,9 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
 
   protected List<AuthzCredentialGenerator> getDummyGeneratorCombos() {
     List<AuthzCredentialGenerator> generators = new ArrayList<>();
-    Iterator authzCodeIter = AuthzCredentialGenerator.ClassCode.getAll().iterator();
 
-    while (authzCodeIter.hasNext()) {
-      ClassCode authzClassCode = (ClassCode) authzCodeIter.next();
+    for (final Object o : ClassCode.getAll()) {
+      ClassCode authzClassCode = (ClassCode) o;
       AuthzCredentialGenerator authzGen = AuthzCredentialGenerator.create(authzClassCode);
 
       if (authzGen != null) {
@@ -964,7 +959,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
    */
   private static class AuthzCqListener implements CqListener {
 
-    private List<CqEvent> eventList;
+    private final List<CqEvent> eventList;
     private int numCreates;
     private int numUpdates;
     private int numDestroys;
@@ -972,69 +967,67 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
     private int numErrors;
 
     public AuthzCqListener() {
-      this.eventList = new ArrayList<>();
+      eventList = new ArrayList<>();
       reset();
     }
 
     public void reset() {
-      this.eventList.clear();
-      this.numCreates = 0;
-      this.numUpdates = 0;
-      this.numErrors = 0;
+      eventList.clear();
+      numCreates = 0;
+      numUpdates = 0;
+      numErrors = 0;
     }
 
     @Override
     public void onEvent(final CqEvent aCqEvent) {
       Operation op = aCqEvent.getBaseOperation();
       if (op.isCreate()) {
-        ++this.numCreates;
+        ++numCreates;
       } else if (op.isUpdate()) {
-        ++this.numUpdates;
+        ++numUpdates;
       } else if (op.isDestroy()) {
-        ++this.numDestroys;
+        ++numDestroys;
       } else {
-        ++this.numOtherOps;
+        ++numOtherOps;
       }
       eventList.add(aCqEvent);
     }
 
     @Override
     public void onError(final CqEvent aCqEvent) {
-      ++this.numErrors;
+      ++numErrors;
     }
 
     @Override
     public void close() {
-      this.eventList.clear();
+      eventList.clear();
     }
 
     public int getNumCreates() {
-      return this.numCreates;
+      return numCreates;
     }
 
     public int getNumUpdates() {
-      return this.numUpdates;
+      return numUpdates;
     }
 
     public int getNumDestroys() {
-      return this.numDestroys;
+      return numDestroys;
     }
 
     public int getNumOtherOps() {
-      return this.numOtherOps;
+      return numOtherOps;
     }
 
     public int getNumErrors() {
-      return this.numErrors;
+      return numErrors;
     }
 
     public void checkPuts(final String[] vals, final int[] indices) {
-      for (int indexIndex = 0; indexIndex < indices.length; ++indexIndex) {
-        int index = indices[indexIndex];
+      for (int index : indices) {
         boolean foundKey = false;
 
-        for (Iterator<CqEvent> eventIter = this.eventList.iterator(); eventIter.hasNext();) {
-          CqEvent event = (CqEvent) eventIter.next();
+        for (CqEvent event : eventList) {
           if (KEYS[index].equals(event.getKey())) {
             assertEquals(vals[index], event.getNewValue());
             foundKey = true;
@@ -1148,7 +1141,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
     public static final int USE_GET_ENTRY_IN_TX = 0x10000;
 
     public static String description(int f) {
-      StringBuffer sb = new StringBuffer();
+      StringBuilder sb = new StringBuilder();
       sb.append("[");
       if ((f & CHECK_FAIL) != 0) {
         sb.append("CHECK_FAIL,");
@@ -1214,23 +1207,23 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
     /**
      * The operation to be performed.
      */
-    private OperationCode opCode;
+    private final OperationCode opCode;
 
     /**
      * The operation for which authorized or unauthorized credentials have to be generated. This is
      * the same as {@link #opCode} when not specified.
      */
-    private OperationCode authzOpCode;
+    private final OperationCode authzOpCode;
 
     /**
      * The client number on which the operation has to be performed.
      */
-    private int clientNum;
+    private final int clientNum;
 
     /**
      * Bitwise or'd {@link OpFlags} integer to change/specify the behaviour of the operations.
      */
-    private int flags;
+    private final int flags;
 
     /**
      * Indices of the KEYS array to be used for operations.
@@ -1253,92 +1246,92 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
     public static final OperationWithAction OPBLOCK_NO_FAILOVER = new OperationWithAction(null, 5);
 
     private void setIndices(int numOps) {
-      this.indices = new int[numOps];
+      indices = new int[numOps];
       for (int index = 0; index < numOps; ++index) {
-        this.indices[index] = index;
+        indices[index] = index;
       }
     }
 
     public OperationWithAction(final OperationCode opCode) {
       this.opCode = opCode;
-      this.authzOpCode = opCode;
-      this.clientNum = 1;
-      this.flags = OpFlags.NONE;
+      authzOpCode = opCode;
+      clientNum = 1;
+      flags = OpFlags.NONE;
       setIndices(4);
-      this.opNum = 0;
+      opNum = 0;
     }
 
     public OperationWithAction(final OperationCode opCode, final int clientNum) {
       this.opCode = opCode;
-      this.authzOpCode = opCode;
+      authzOpCode = opCode;
       this.clientNum = clientNum;
-      this.flags = OpFlags.NONE;
+      flags = OpFlags.NONE;
       setIndices(4);
-      this.opNum = 0;
+      opNum = 0;
     }
 
     public OperationWithAction(final OperationCode opCode, final int clientNum, final int flags,
         final int numOps) {
       this.opCode = opCode;
-      this.authzOpCode = opCode;
+      authzOpCode = opCode;
       this.clientNum = clientNum;
       this.flags = flags;
       setIndices(numOps);
-      this.opNum = 0;
+      opNum = 0;
     }
 
     public OperationWithAction(final OperationCode opCode, final OperationCode deniedOpCode,
         final int clientNum, final int flags, final int numOps) {
       this.opCode = opCode;
-      this.authzOpCode = deniedOpCode;
+      authzOpCode = deniedOpCode;
       this.clientNum = clientNum;
       this.flags = flags;
       setIndices(numOps);
-      this.opNum = 0;
+      opNum = 0;
     }
 
     public OperationWithAction(final OperationCode opCode, final int clientNum, final int flags,
         final int[] indices) {
       this.opCode = opCode;
-      this.authzOpCode = opCode;
+      authzOpCode = opCode;
       this.clientNum = clientNum;
       this.flags = flags;
       this.indices = indices;
-      this.opNum = 0;
+      opNum = 0;
     }
 
     public OperationWithAction(final OperationCode opCode, final OperationCode deniedOpCode,
         final int clientNum, final int flags, final int[] indices) {
       this.opCode = opCode;
-      this.authzOpCode = deniedOpCode;
+      authzOpCode = deniedOpCode;
       this.clientNum = clientNum;
       this.flags = flags;
       this.indices = indices;
-      this.opNum = 0;
+      opNum = 0;
     }
 
     public OperationCode getOperationCode() {
-      return this.opCode;
+      return opCode;
     }
 
     public OperationCode getAuthzOperationCode() {
-      return this.authzOpCode;
+      return authzOpCode;
     }
 
     public int getClientNum() {
-      return this.clientNum;
+      return clientNum;
     }
 
     public int getFlags() {
-      return this.flags;
+      return flags;
     }
 
     public int[] getIndices() {
-      return this.indices;
+      return indices;
     }
 
     public int getOpNum() {
-      return this.opNum;
+      return opNum;
     }
 
     public void setOpNum(int opNum) {
@@ -1347,9 +1340,9 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
 
     @Override
     public String toString() {
-      return "opCode:" + this.opCode + ",authOpCode:" + this.authzOpCode + ",clientNum:"
-          + this.clientNum + ",flags:" + this.flags + ",numOps:" + this.indices.length + ",indices:"
-          + indicesToString(this.indices);
+      return "opCode:" + opCode + ",authOpCode:" + authzOpCode + ",clientNum:"
+          + clientNum + ",flags:" + flags + ",numOps:" + indices.length + ",indices:"
+          + indicesToString(indices);
     }
   }
 
@@ -1361,24 +1354,26 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
    */
   protected interface TestCredentialGenerator {
 
-    /**
+    /*
      * Get allowed credentials for the given set of operations in the given regions and indices of
-     * KEYS in the <code>KEYS</code> array
+     * KEYS in the KEYS array
      */
-    public Properties getAllowedCredentials(OperationCode[] opCodes, String[] regionNames,
+    Properties getAllowedCredentials(OperationCode[] opCodes, String[] regionNames,
         int[] keyIndices, int num);
 
-    /**
+    /*
      * Get disallowed credentials for the given set of operations in the given regions and indices
-     * of KEYS in the <code>KEYS</code> array
+     * of KEYS in the KEYS array
      */
-    public Properties getDisallowedCredentials(OperationCode[] opCodes, String[] regionNames,
+    Properties getDisallowedCredentials(OperationCode[] opCodes, String[] regionNames,
         int[] keyIndices, int num);
 
     /**
      * Get the {@link CredentialGenerator} if any.
+     *
+     * @return the {@link CredentialGenerator} if any
      */
-    public CredentialGenerator getCredentialGenerator();
+    CredentialGenerator getCredentialGenerator();
   }
 
   /**
@@ -1389,7 +1384,7 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
    */
   protected static class TestAuthzCredentialGenerator implements TestCredentialGenerator {
 
-    private AuthzCredentialGenerator authzGen;
+    private final AuthzCredentialGenerator authzGen;
 
     public TestAuthzCredentialGenerator(final AuthzCredentialGenerator authzGen) {
       this.authzGen = authzGen;
@@ -1398,13 +1393,13 @@ public abstract class ClientAuthorizationTestCase extends JUnit4DistributedTestC
     @Override
     public Properties getAllowedCredentials(final OperationCode[] opCodes,
         final String[] regionNames, final int[] keyIndices, final int num) {
-      return this.authzGen.getAllowedCredentials(opCodes, regionNames, num);
+      return authzGen.getAllowedCredentials(opCodes, regionNames, num);
     }
 
     @Override
     public Properties getDisallowedCredentials(final OperationCode[] opCodes,
         final String[] regionNames, final int[] keyIndices, final int num) {
-      return this.authzGen.getDisallowedCredentials(opCodes, regionNames, num);
+      return authzGen.getDisallowedCredentials(opCodes, regionNames, num);
     }
 
     @Override
