@@ -54,11 +54,11 @@ import org.apache.geode.security.NotAuthorizedException;
  * An implementation of the {@link AccessControl} interface that allows authorization using the
  * permissions as specified in the given XML file.
  *
- * The format of the XML file is specified in <a href="authz5_5.dtd"/>. It implements a role-based
- * authorization at the operation level for each region. Each principal name may be associated with
- * a set of roles. The name of the principal is obtained using the {@link Principal#getName()}
- * method and no other information of the principal is utilized. Each role can be provided
- * permissions to execute operations for each region.
+ * The format of the XML file is specified in <a href="authz5_5.dtd">authz5_5.dtd</a>. It implements
+ * a role-based authorization at the operation level for each region. Each principal name may be
+ * associated with a set of roles. The name of the principal is obtained using the
+ * {@link Principal#getName()} method and no other information of the principal is utilized. Each
+ * role can be provided permissions to execute operations for each region.
  *
  * The top-level element in the XML is "acl" tag that contains the "role" and "permission" tags. The
  * "role" tag contains the list of users that have been given that role. The name of the role is
@@ -152,7 +152,7 @@ public class XmlAuthorization implements AccessControl {
     XmlAuthorization.xmlLoadFailure = null;
   }
 
-  /**
+  /*
    * Change the region name to a standard format having single '/' as separator and starting with a
    * '/' as in standard POSIX paths
    */
@@ -206,9 +206,9 @@ public class XmlAuthorization implements AccessControl {
   }
 
   private XmlAuthorization() {
-    this.allowedOps = new HashMap<String, Map<OperationCode, FunctionSecurityPrmsHolder>>();
-    this.systemLogWriter = null;
-    this.securityLogWriter = null;
+    allowedOps = new HashMap<>();
+    systemLogWriter = null;
+    securityLogWriter = null;
   }
 
   /**
@@ -236,8 +236,8 @@ public class XmlAuthorization implements AccessControl {
       XmlAuthorization.init(cache);
     }
 
-    this.systemLogWriter = cache.getLogger();
-    this.securityLogWriter = cache.getSecurityLogger();
+    systemLogWriter = cache.getLogger();
+    securityLogWriter = cache.getSecurityLogger();
 
     String name;
     if (principal != null) {
@@ -256,10 +256,10 @@ public class XmlAuthorization implements AccessControl {
               .entrySet()) {
             String regionName = regionEntry.getKey();
             Map<OperationCode, FunctionSecurityPrmsHolder> regionOperations =
-                this.allowedOps.get(regionName);
+                allowedOps.get(regionName);
             if (regionOperations == null) {
-              regionOperations = new HashMap<OperationCode, FunctionSecurityPrmsHolder>();
-              this.allowedOps.put(regionName, regionOperations);
+              regionOperations = new HashMap<>();
+              allowedOps.put(regionName, regionOperations);
             }
             regionOperations.putAll(regionEntry.getValue());
           }
@@ -287,9 +287,9 @@ public class XmlAuthorization implements AccessControl {
 
     // Check GET permissions for updates from server to client
     if (context.isClientUpdate()) {
-      operationMap = this.allowedOps.get(regionName);
+      operationMap = allowedOps.get(regionName);
       if (operationMap == null && regionName.length() > 0) {
-        operationMap = this.allowedOps.get(EMPTY_VALUE);
+        operationMap = allowedOps.get(EMPTY_VALUE);
       }
       if (operationMap != null) {
         return operationMap.containsKey(OperationCode.GET);
@@ -300,7 +300,7 @@ public class XmlAuthorization implements AccessControl {
     OperationCode opCode = context.getOperationCode();
     if (opCode.isQuery() || opCode.isExecuteCQ() || opCode.isCloseCQ() || opCode.isStopCQ()) {
       // First check if cache-level permission has been provided
-      operationMap = this.allowedOps.get(EMPTY_VALUE);
+      operationMap = allowedOps.get(EMPTY_VALUE);
       boolean globalPermission = (operationMap != null && operationMap.containsKey(opCode));
       Set<String> regionNames = ((QueryOperationContext) context).getRegionNames();
       if (regionNames == null || regionNames.size() == 0) {
@@ -309,7 +309,7 @@ public class XmlAuthorization implements AccessControl {
 
       for (String r : regionNames) {
         regionName = normalizeRegionName(r);
-        operationMap = this.allowedOps.get(regionName);
+        operationMap = allowedOps.get(regionName);
         if (operationMap == null) {
           if (!globalPermission) {
             return false;
@@ -322,9 +322,9 @@ public class XmlAuthorization implements AccessControl {
     }
 
     final String normalizedRegionName = normalizeRegionName(regionName);
-    operationMap = this.allowedOps.get(normalizedRegionName);
+    operationMap = allowedOps.get(normalizedRegionName);
     if (operationMap == null && normalizedRegionName.length() > 0) {
-      operationMap = this.allowedOps.get(EMPTY_VALUE);
+      operationMap = allowedOps.get(EMPTY_VALUE);
     }
     if (operationMap != null) {
       if (context.getOperationCode() != OperationCode.EXECUTE_FUNCTION) {
@@ -343,7 +343,7 @@ public class XmlAuthorization implements AccessControl {
             // OnRegion execution
             if (functionContext.getRegionName() != null) {
               if (functionParameter.isOptimizeForWrite() != null && functionParameter
-                  .isOptimizeForWrite().booleanValue() != functionContext.isOptimizeForWrite()) {
+                  .isOptimizeForWrite() != functionContext.isOptimizeForWrite()) {
                 return false;
               }
               if (functionParameter.getFunctionIds() != null && !functionParameter.getFunctionIds()
@@ -351,18 +351,14 @@ public class XmlAuthorization implements AccessControl {
                 return false;
               }
               if (functionParameter.getKeySet() != null && functionContext.getKeySet() != null) {
-                if (functionContext.getKeySet().containsAll(functionParameter.getKeySet())) {
-                  return false;
-                }
+                return !functionContext.getKeySet().containsAll(functionParameter.getKeySet());
               }
               return true;
 
             } else {// On Server execution
-              if (functionParameter.getFunctionIds() != null && !functionParameter.getFunctionIds()
-                  .contains(functionContext.getFunctionId())) {
-                return false;
-              }
-              return true;
+              return functionParameter.getFunctionIds() == null
+                  || functionParameter.getFunctionIds()
+                      .contains(functionContext.getFunctionId());
             }
 
           } else {
@@ -375,19 +371,14 @@ public class XmlAuthorization implements AccessControl {
                   && functionParameter.getKeySet() != null) {
                 ArrayList<String> resultList = (ArrayList) functionContext.getResult();
                 Set<String> nonAllowedKeys = functionParameter.getKeySet();
-                if (resultList.containsAll(nonAllowedKeys)) {
-                  return false;
-                }
+                return !resultList.containsAll(nonAllowedKeys);
               }
               return true;
 
             } else {
               ArrayList<String> resultList = (ArrayList) functionContext.getResult();
               final String inSecureItem = "Insecure item";
-              if (resultList.contains(inSecureItem)) {
-                return false;
-              }
-              return true;
+              return !resultList.contains(inSecureItem);
             }
           }
         }
@@ -401,7 +392,7 @@ public class XmlAuthorization implements AccessControl {
    */
   @Override
   public void close() {
-    this.allowedOps.clear();
+    allowedOps.clear();
   }
 
   /** Get the attribute value for a given attribute name of a node. */
@@ -461,9 +452,9 @@ public class XmlAuthorization implements AccessControl {
 
       final Document xmlDocument = builder.parse(xmlDocumentUri);
 
-      XmlAuthorization.userRoles = new HashMap<String, HashSet<String>>();
+      XmlAuthorization.userRoles = new HashMap<>();
       XmlAuthorization.rolePermissions =
-          new HashMap<String, Map<String, Map<OperationCode, FunctionSecurityPrmsHolder>>>();
+          new HashMap<>();
 
       final NodeList roleUserNodes = xmlDocument.getElementsByTagName(TAG_ROLE);
 
@@ -479,7 +470,7 @@ public class XmlAuthorization implements AccessControl {
             final String userName = getNodeValue(userNode);
             HashSet<String> userRoleSet = XmlAuthorization.userRoles.get(userName);
             if (userRoleSet == null) {
-              userRoleSet = new HashSet<String>();
+              userRoleSet = new HashSet<>();
               XmlAuthorization.userRoles.put(userName, userRoleSet);
             }
             userRoleSet.add(roleName);
@@ -502,13 +493,13 @@ public class XmlAuthorization implements AccessControl {
 
         if (regionOperationMap == null) {
           regionOperationMap =
-              new HashMap<String, Map<OperationCode, FunctionSecurityPrmsHolder>>();
+              new HashMap<>();
           XmlAuthorization.rolePermissions.put(roleName, regionOperationMap);
         }
 
         final NodeList operationNodes = rolePermissionNode.getChildNodes();
         final HashMap<OperationCode, FunctionSecurityPrmsHolder> operationMap =
-            new HashMap<OperationCode, FunctionSecurityPrmsHolder>();
+            new HashMap<>();
 
         for (int opIndex = 0; opIndex < operationNodes.getLength(); opIndex++) {
           final Node operationNode = operationNodes.item(opIndex);
@@ -544,9 +535,9 @@ public class XmlAuthorization implements AccessControl {
                 functionIds = null;
               } else {
                 final String[] functionArray = functionAttr.split(",");
-                functionIds = new HashSet<String>();
-                for (int strIndex = 0; strIndex < functionArray.length; ++strIndex) {
-                  functionIds.add((functionArray[strIndex]));
+                functionIds = new HashSet<>();
+                for (final String s : functionArray) {
+                  functionIds.add(s);
                 }
               }
 
@@ -554,9 +545,9 @@ public class XmlAuthorization implements AccessControl {
                 keySet = null;
               } else {
                 final String[] keySetArray = keysAttr.split(",");
-                keySet = new HashSet<String>();
-                for (int strIndex = 0; strIndex < keySetArray.length; ++strIndex) {
-                  keySet.add((keySetArray[strIndex]));
+                keySet = new HashSet<>();
+                for (final String s : keySetArray) {
+                  keySet.add(s);
                 }
               }
 
@@ -576,8 +567,8 @@ public class XmlAuthorization implements AccessControl {
           regionOperationMap.put(EMPTY_VALUE, operationMap);
         } else {
           final String[] regionNamesSplit = regionNames.split(",");
-          for (int strIndex = 0; strIndex < regionNamesSplit.length; ++strIndex) {
-            regionOperationMap.put(normalizeRegionName(regionNamesSplit[strIndex]), operationMap);
+          for (final String s : regionNamesSplit) {
+            regionOperationMap.put(normalizeRegionName(s), operationMap);
           }
         }
       }
