@@ -23,12 +23,13 @@ import org.apache.geode.test.awaitility.GeodeAwaitility;
  *
  * @deprecated Use {@link GeodeAwaitility} instead.
  */
+@Deprecated
 public interface StoppableWaitCriterion extends WaitCriterion {
 
-  /**
+  /*
    * If this method returns true then quit waiting even if we are not done. This allows a wait to
    * fail early.
    */
-  public boolean stopWaiting();
+  boolean stopWaiting();
 
 }
