@@ -64,6 +64,7 @@ import org.apache.geode.test.dunit.rules.DistributedRule;
  * @deprecated Please use {@link DistributedRule} and Geode User APIs or {@link ClusterStartupRule}
  *             instead.
  */
+@Deprecated
 public abstract class JUnit4CacheTestCase extends JUnit4DistributedTestCase
     implements CacheTestFixture {
 
@@ -345,15 +346,15 @@ public abstract class JUnit4CacheTestCase extends JUnit4DistributedTestCase
 
   @Override
   public void preTearDownCacheTestCase() throws Exception {
-    if (this.cacheTestFixture != this) {
-      this.cacheTestFixture.preTearDownCacheTestCase();
+    if (cacheTestFixture != this) {
+      cacheTestFixture.preTearDownCacheTestCase();
     }
   }
 
   @Override
   public void postTearDownCacheTestCase() throws Exception {
-    if (this.cacheTestFixture != this) {
-      this.cacheTestFixture.postTearDownCacheTestCase();
+    if (cacheTestFixture != this) {
+      cacheTestFixture.postTearDownCacheTestCase();
     }
   }
 
@@ -579,12 +580,12 @@ public abstract class JUnit4CacheTestCase extends JUnit4DistributedTestCase
 
     @Override
     public void close() {
-      this.closed = true;
+      closed = true;
     }
 
     @Override
     public boolean isClosed() {
-      return this.closed;
+      return closed;
     }
   }
 }
