@@ -21,6 +21,7 @@ import java.rmi.RemoteException;
 import org.apache.geode.test.dunit.Host;
 import org.apache.geode.test.dunit.VM;
 import org.apache.geode.test.version.VersionManager;
+import org.apache.geode.test.version.VmConfiguration;
 
 class DUnitHost extends Host {
   private static final long serialVersionUID = -8034165624503666383L;
@@ -32,8 +33,7 @@ class DUnitHost extends Host {
   DUnitHost(String hostName, ProcessManager processManager, VMEventNotifier vmEventNotifier)
       throws RemoteException {
     super(hostName, vmEventNotifier);
-    this.debuggingVM = new VM(this, VersionManager.CURRENT_VERSION, -1, new RemoteDUnitVM(0), null,
-        null);
+    debuggingVM = new VM(this, VmConfiguration.current(), -1, new RemoteDUnitVM(0), null, null);
     this.processManager = processManager;
     this.vmEventNotifier = vmEventNotifier;
   }
@@ -43,7 +43,7 @@ class DUnitHost extends Host {
     for (int i = 0; i < numVMs; i++) {
       RemoteDUnitVMIF remote = processManager.getStub(i);
       ProcessHolder processHolder = processManager.getProcessHolder(i);
-      addVM(i, VersionManager.CURRENT_VERSION, remote, processHolder, processManager);
+      addVM(i, VmConfiguration.current(), remote, processHolder, processManager);
     }
 
     if (launchLocator) {
@@ -74,46 +74,51 @@ class DUnitHost extends Host {
   }
 
   @Override
-  public VM getVM(String version, int n) {
-    if (n == DUnitLauncher.DEBUGGING_VM_NUM) {
+  public VM getVM(String geodeVersion, int whichVM) {
+    return getVM(VmConfiguration.forGeodeVersion(geodeVersion), whichVM);
+  }
+
+  @Override
+  public VM getVM(VmConfiguration configuration, int whichVM) {
+    if (whichVM == DUnitLauncher.DEBUGGING_VM_NUM) {
       // for ease of debugging, pass -1 to get the local VM
       return debuggingVM;
     }
 
-    if (n < getVMCount()) {
-      VM current = super.getVM(n);
-      if (!current.getVersion().equals(version)) {
-        current.bounce(version);
+    if (whichVM < getVMCount()) {
+      VM current = super.getVM(whichVM);
+      if (!current.getConfiguration().equals(configuration)) {
+        current.bounce(configuration, false);
       }
       return current;
     }
 
     int oldVMCount = getVMCount();
-    if (n >= oldVMCount) {
+    if (whichVM >= oldVMCount) {
       // If we don't have a VM with that number, dynamically create it.
       try {
         // first fill in any gaps, to keep the superclass, Host, happy
-        for (int i = oldVMCount; i < n; i++) {
+        for (int i = oldVMCount; i < whichVM; i++) {
           processManager.launchVM(i);
         }
         processManager.waitForVMs(DUnitLauncher.STARTUP_TIMEOUT);
 
-        for (int i = oldVMCount; i < n; i++) {
-          addVM(i, VersionManager.CURRENT_VERSION, processManager.getStub(i),
+        for (int i = oldVMCount; i < whichVM; i++) {
+          addVM(i, VmConfiguration.current(), processManager.getStub(i),
               processManager.getProcessHolder(i), processManager);
         }
 
         // now create the one we really want
-        processManager.launchVM(version, n, false, 0);
+        processManager.launchVM(configuration, whichVM, false, 0);
         processManager.waitForVMs(DUnitLauncher.STARTUP_TIMEOUT);
-        addVM(n, version, processManager.getStub(n), processManager.getProcessHolder(n),
-            processManager);
+        addVM(whichVM, configuration, processManager.getStub(whichVM),
+            processManager.getProcessHolder(whichVM), processManager);
 
       } catch (IOException | InterruptedException | NotBoundException e) {
-        throw new RuntimeException("Could not dynamically launch vm + " + n, e);
+        throw new RuntimeException("Could not dynamically launch vm + " + whichVM, e);
       }
     }
 
-    return super.getVM(n);
+    return super.getVM(whichVM);
   }
 }
