@@ -23,7 +23,7 @@ import static org.apache.geode.test.dunit.DistributedTestUtils.getAllDistributed
 import static org.apache.geode.test.dunit.DistributedTestUtils.unregisterInstantiatorsInThisVM;
 import static org.apache.geode.test.dunit.Invoke.invokeInEveryVM;
 import static org.apache.geode.test.dunit.Invoke.invokeInLocator;
-import static org.junit.Assert.assertNotNull;
+import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.File;
 import java.io.Serializable;
@@ -38,6 +38,7 @@ import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.Rule;
 
+import org.apache.geode.CancelException;
 import org.apache.geode.cache.Cache;
 import org.apache.geode.cache.Region;
 import org.apache.geode.distributed.DistributedSystem;
@@ -60,8 +61,9 @@ import org.apache.geode.test.version.VersionManager;
  * @deprecated Please use {@link DistributedRule} and Geode User APIs or {@link ClusterStartupRule}
  *             instead.
  */
+@Deprecated
 public abstract class JUnit4DistributedTestCase implements DistributedTestFixture, Serializable {
-  private static final Logger logger = LogService.getLogger();
+  protected static final Logger logger = LogService.getLogger();
 
   /** This VM's connection to the distributed system */
   protected static InternalDistributedSystem system;
@@ -121,14 +123,14 @@ public abstract class JUnit4DistributedTestCase implements DistributedTestFixtur
 
   @Override
   public final String getName() {
-    if (this.distributedTestFixture != this) {
-      return this.distributedTestFixture.getName();
+    if (distributedTestFixture != this) {
+      return distributedTestFixture.getName();
     }
-    return this.testNameForDistributedTestCase.getMethodName();
+    return testNameForDistributedTestCase.getMethodName();
   }
 
   public final Class<? extends DistributedTestFixture> getTestClass() {
-    return this.distributedTestFixture.getClass();
+    return distributedTestFixture.getClass();
   }
 
   /**
@@ -299,8 +301,8 @@ public abstract class JUnit4DistributedTestCase implements DistributedTestFixtur
    */
   @Override
   public Properties getDistributedSystemProperties() {
-    if (this.distributedTestFixture != this) {
-      return this.distributedTestFixture.getDistributedSystemProperties();
+    if (distributedTestFixture != this) {
+      return distributedTestFixture.getDistributedSystemProperties();
     }
     return defaultGetDistributedSystemProperties();
   }
@@ -347,7 +349,7 @@ public abstract class JUnit4DistributedTestCase implements DistributedTestFixtur
    * name of the method.
    */
   public final String getUniqueName() {
-    assertNotNull(getName());
+    assertThat(getName()).isNotNull();
     return getTestClass().getSimpleName() + "_" + getName();
   }
 
@@ -374,18 +376,17 @@ public abstract class JUnit4DistributedTestCase implements DistributedTestFixtur
    * Do not override this method.
    */
   private void doSetUpDistributedTestCase() {
-    final String className = getTestClass().getCanonicalName();
     final String methodName = getName();
 
     TestHistoryLogger.logTestHistory(getTestClass().getSimpleName(), methodName);
 
-    setUpVM(methodName, getDefaultDiskStoreName(0, -1, className, methodName));
+    setUpVM(methodName, getDefaultDiskStoreName(0, -1, methodName));
 
     for (int hostIndex = 0; hostIndex < Host.getHostCount(); hostIndex++) {
       Host host = Host.getHost(hostIndex);
       for (int vmIndex = 0; vmIndex < host.getVMCount(); vmIndex++) {
         final String vmDefaultDiskStoreName =
-            getDefaultDiskStoreName(hostIndex, vmIndex, className, methodName);
+            getDefaultDiskStoreName(hostIndex, vmIndex, methodName);
         host.getVM(vmIndex).invoke("setupVM", () -> setUpVM(methodName, vmDefaultDiskStoreName));
       }
     }
@@ -401,8 +402,8 @@ public abstract class JUnit4DistributedTestCase implements DistributedTestFixtur
    */
   @Override
   public void preSetUp() throws Exception {
-    if (this.distributedTestFixture != this) {
-      this.distributedTestFixture.preSetUp();
+    if (distributedTestFixture != this) {
+      distributedTestFixture.preSetUp();
     }
   }
 
@@ -414,20 +415,19 @@ public abstract class JUnit4DistributedTestCase implements DistributedTestFixtur
    */
   @Override
   public void postSetUp() throws Exception {
-    if (this.distributedTestFixture != this) {
-      this.distributedTestFixture.postSetUp();
+    if (distributedTestFixture != this) {
+      distributedTestFixture.postSetUp();
     }
   }
 
   private static String getDefaultDiskStoreName(final int hostIndex, final int vmIndex,
-      final String className, final String methodName) {
-    return "DiskStore-" + hostIndex + "-" + vmIndex + "-"
-        + className + "." + methodName; // used to be getDeclaringClass()
+      final String methodName) {
+    return "DiskStore-" + hostIndex + "-" + vmIndex + "-" + methodName;
   }
 
   private static void setUpVM(final String methodName, final String defaultDiskStoreName) {
-    assertNotNull("methodName must not be null", methodName);
-    assertNotNull("defaultDiskStoreName must not be null", defaultDiskStoreName);
+    assertThat(methodName).as("methodName must not be null").isNotNull();
+    assertThat(defaultDiskStoreName).as("defaultDiskStoreName must not be null").isNotNull();
     setTestMethodName(methodName);
     GemFireCacheImpl.setDefaultDiskStoreName(defaultDiskStoreName);
     setUpCreationStackGenerator();
@@ -458,7 +458,7 @@ public abstract class JUnit4DistributedTestCase implements DistributedTestFixtur
             sb.append("\n");
           }
           return new Throwable(
-              "Creating distributed system with the following configuration:\n" + sb.toString());
+              "Creating distributed system with the following configuration:\n" + sb);
         });
   }
 
@@ -508,8 +508,8 @@ public abstract class JUnit4DistributedTestCase implements DistributedTestFixtur
    */
   @Override
   public void preTearDown() throws Exception {
-    if (this.distributedTestFixture != this) {
-      this.distributedTestFixture.preTearDown();
+    if (distributedTestFixture != this) {
+      distributedTestFixture.preTearDown();
     }
   }
 
@@ -521,22 +521,22 @@ public abstract class JUnit4DistributedTestCase implements DistributedTestFixtur
    */
   @Override
   public void postTearDown() throws Exception {
-    if (this.distributedTestFixture != this) {
-      this.distributedTestFixture.postTearDown();
+    if (distributedTestFixture != this) {
+      distributedTestFixture.postTearDown();
     }
   }
 
   @Override
   public void preTearDownAssertions() throws Exception {
-    if (this.distributedTestFixture != this) {
-      this.distributedTestFixture.preTearDownAssertions();
+    if (distributedTestFixture != this) {
+      distributedTestFixture.preTearDownAssertions();
     }
   }
 
   @Override
   public void postTearDownAssertions() throws Exception {
-    if (this.distributedTestFixture != this) {
-      this.distributedTestFixture.postTearDownAssertions();
+    if (distributedTestFixture != this) {
+      distributedTestFixture.postTearDownAssertions();
     }
   }
 
@@ -569,17 +569,21 @@ public abstract class JUnit4DistributedTestCase implements DistributedTestFixtur
   protected static void destroyRegions(final Cache cache) {
     if (cache != null && !cache.isClosed()) {
       // try to destroy the root regions first so that we clean up any persistent files.
-      for (Region<?, ?> root : cache.rootRegions()) {
-        String regionFullPath = root == null ? null : root.getFullPath();
-        // for colocated regions you can't locally destroy a partitioned region.
-        if (root.isDestroyed() || root instanceof HARegion || root instanceof PartitionedRegion) {
-          continue;
-        }
-        try {
-          root.localDestroyRegion("teardown");
-        } catch (Throwable t) {
-          logger.error("Failure during tearDown destroyRegions for " + regionFullPath, t);
+      try {
+        for (Region<?, ?> root : cache.rootRegions()) {
+          String regionFullPath = root == null ? null : root.getFullPath();
+          // for colocated regions you can't locally destroy a partitioned region.
+          if (root.isDestroyed() || root instanceof HARegion || root instanceof PartitionedRegion) {
+            continue;
+          }
+          try {
+            root.localDestroyRegion("teardown");
+          } catch (Throwable t) {
+            logger.error("Failure during tearDown destroyRegions for " + regionFullPath, t);
+          }
         }
+      } catch (CancelException ce) {
+        logger.info("Cache is closing, no need to destroy regions");
       }
     }
   }
