@@ -14,7 +14,9 @@
  */
 package org.apache.geode.test.junit.rules;
 
+import static java.util.stream.Collectors.joining;
 import static org.apache.geode.test.dunit.IgnoredException.addIgnoredException;
+import static org.apache.geode.test.process.JavaModuleHelper.getJvmModuleOptions;
 import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.File;
@@ -73,13 +75,13 @@ import org.apache.geode.test.junit.assertions.CommandResultAssert;
  */
 public class GfshCommandRule extends DescribedExternalResource {
 
-  private Supplier<Integer> portSupplier;
+  private final Supplier<Integer> portSupplier;
   private PortType portType = PortType.jmxManager;
   private HeadlessGfsh gfsh = null;
   private int gfshTimeout = 2;
   private boolean connected = false;
   private IgnoredException ignoredException;
-  private TemporaryFolder temporaryFolder = new TemporaryFolder();
+  private final TemporaryFolder temporaryFolder = new TemporaryFolder();
   private File workingDir;
   private CommandResult commandResult;
 
@@ -102,7 +104,7 @@ public class GfshCommandRule extends DescribedExternalResource {
     } catch (IOException e) {
       workingDir = temporaryFolder.getRoot();
     }
-    this.gfsh = new HeadlessGfsh(getClass().getName(), gfshTimeout, workingDir.getAbsolutePath());
+    gfsh = new HeadlessGfsh(getClass().getName(), gfshTimeout, workingDir.getAbsolutePath());
     ignoredException =
         addIgnoredException("java.rmi.NoSuchObjectException: no such object in table");
 
@@ -150,17 +152,17 @@ public class GfshCommandRule extends DescribedExternalResource {
 
   public void connectAndVerify(Member locator, String... options) throws Exception {
     connect(locator.getPort(), PortType.locator, options);
-    assertThat(this.connected).isTrue();
+    assertThat(connected).isTrue();
   }
 
   public void connectAndVerify(int port, PortType type, Properties properties) throws Exception {
     connect(port, type, properties);
-    assertThat(this.connected).isTrue();
+    assertThat(connected).isTrue();
   }
 
   public void connectAndVerify(int port, PortType type, String... options) throws Exception {
     connect(port, type, options);
-    assertThat(this.connected).isTrue();
+    assertThat(connected).isTrue();
   }
 
   public void secureConnect(int port, PortType type, String username, String password)
@@ -173,13 +175,13 @@ public class GfshCommandRule extends DescribedExternalResource {
       throws Exception {
     connect(port, type, CliStrings.CONNECT__USERNAME, username, CliStrings.CONNECT__PASSWORD,
         password);
-    assertThat(this.connected).isTrue();
+    assertThat(connected).isTrue();
   }
 
   public void secureConnectWithTokenAndVerify(int port, PortType portType, String token)
       throws Exception {
     connect(port, portType, CliStrings.CONNECT__TOKEN, token);
-    assertThat(this.connected).isTrue();
+    assertThat(connected).isTrue();
   }
 
   public void connect(int port, PortType type, Properties properties) throws Exception {
@@ -198,7 +200,7 @@ public class GfshCommandRule extends DescribedExternalResource {
         absolutePath = temporaryFolder.getRoot().getAbsolutePath();
       }
 
-      this.gfsh = new HeadlessGfsh(getClass().getName(), 30, absolutePath);
+      gfsh = new HeadlessGfsh(getClass().getName(), 30, absolutePath);
     }
     final CommandStringBuilder connectCommand = new CommandStringBuilder(CliStrings.CONNECT);
     String endpoint;
@@ -233,7 +235,7 @@ public class GfshCommandRule extends DescribedExternalResource {
       if (!gfsh.outputString.contains("no such object in table")) {
         break;
       }
-      Thread.currentThread().sleep(2000);
+      Thread.sleep(2000);
     }
     connected = (result.getStatus() == Result.Status.OK);
   }
@@ -260,15 +262,24 @@ public class GfshCommandRule extends DescribedExternalResource {
   }
 
   /**
-   *
+   * @param command the String command to execute
    * @return Command result object
    *
    * @deprecated use executeAndAssertThat(command). if you really need to get the result object
    *             to do assertion, you can use hasTable().getActual() or hasData().getActual
    *             after that method call.
    */
+  @Deprecated
   public CommandResult executeCommand(String command) {
-    gfsh.executeCommand(command);
+    String moduleArgs = "";
+    if (command.matches("^start +server.*") || command.matches("^start +locator.*")) {
+      moduleArgs = getJvmModuleOptions().stream()
+          .map(s -> "--J=" + s)
+          .collect(joining(" ", " ", ""));
+    }
+
+    gfsh.executeCommand(command + moduleArgs);
+
     CommandResult result;
     try {
       result = gfsh.getResult();
@@ -307,7 +318,7 @@ public class GfshCommandRule extends DescribedExternalResource {
   }
 
   public GfshCommandRule withTimeout(int timeoutInSeconds) {
-    this.gfshTimeout = timeoutInSeconds;
+    gfshTimeout = timeoutInSeconds;
     return this;
   }
 
