@@ -39,6 +39,7 @@ import java.util.Collection;
 import java.util.List;
 import java.util.Objects;
 import java.util.Properties;
+import java.util.Set;
 import java.util.concurrent.TimeUnit;
 import java.util.function.Consumer;
 import java.util.function.Function;
@@ -73,7 +74,7 @@ import org.apache.geode.management.DistributedSystemMXBean;
 import org.apache.geode.management.ManagementService;
 import org.apache.geode.management.internal.MBeanJMXAdapter;
 import org.apache.geode.management.internal.SystemManagementService;
-import org.apache.geode.management.internal.cli.CliUtil;
+import org.apache.geode.management.internal.cli.CliUtils;
 import org.apache.geode.pdx.internal.TypeRegistry;
 import org.apache.geode.security.SecurityManager;
 import org.apache.geode.security.templates.UserPasswordAuthInit;
@@ -89,9 +90,12 @@ import org.apache.geode.test.junit.rules.serializable.SerializableExternalResour
  * created in the test will be cleaned up after the test.
  */
 public abstract class MemberStarterRule<T> extends SerializableExternalResource implements Member {
-  protected int memberPort = 0;
-  protected int jmxPort = -1;
-  protected int httpPort = -1;
+  private final int availableJmxPort;
+  private final int availableHttpPort;
+
+  protected int memberPort;
+  protected int jmxPort = -1; // -1 means not start on servere, 0 means use default, >0 means preset
+  protected int httpPort = -1; // -1 means do not start, 0 means use default, >0 means pre-assigned
 
   protected String name;
   protected boolean logFile = false;
@@ -99,7 +103,6 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
   protected Properties systemProperties = new Properties();
 
   protected boolean autoStart = false;
-  private final transient UniquePortSupplier portSupplier;
 
   private List<File> firstLevelChildrenFile = new ArrayList<>();
   private boolean cleanWorkingDir = true;
@@ -110,14 +113,16 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
 
   private static int WAIT_UNTIL_TIMEOUT = 30;
 
-  private AccessibleRestoreSystemProperties restore = new AccessibleRestoreSystemProperties();
+  private final AccessibleRestoreSystemProperties restore = new AccessibleRestoreSystemProperties();
 
   public MemberStarterRule() {
     this(new UniquePortSupplier());
   }
 
   public MemberStarterRule(UniquePortSupplier portSupplier) {
-    this.portSupplier = portSupplier;
+    availableJmxPort = portSupplier.getAvailablePort();
+    availableHttpPort = portSupplier.getAvailablePort();
+    memberPort = portSupplier.getAvailablePort();
 
     // initial values
     properties.setProperty(MCAST_PORT, "0");
@@ -176,12 +181,12 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
     return (T) this;
   }
 
-  /**
+  /*
    * All the logs are written in the logfile instead on the console. this is usually used with
    * withWorkingDir so that logs are accessible and will be cleaned up afterwards.
    */
   public T withLogFile() {
-    this.logFile = true;
+    logFile = true;
     return (T) this;
   }
 
@@ -204,7 +209,7 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
 
   public T withProperties(Properties props) {
     if (props != null) {
-      this.properties.putAll(props);
+      properties.putAll(props);
     }
     return (T) this;
   }
@@ -251,7 +256,7 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
   }
 
   public T withAutoStart() {
-    this.autoStart = true;
+    autoStart = true;
     return (T) this;
   }
 
@@ -274,18 +279,17 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
     return (T) this;
   }
 
-  /**
+  /*
    * be able to start JMX manager and admin rest on default ports
    */
   public T withJMXManager(boolean useProductDefaultPorts) {
     if (!useProductDefaultPorts) {
       // do no override these properties if already exists
-      properties.putIfAbsent(JMX_MANAGER_PORT,
-          portSupplier.getAvailablePort() + "");
-      this.jmxPort = Integer.parseInt(properties.getProperty(JMX_MANAGER_PORT));
+      properties.putIfAbsent(JMX_MANAGER_PORT, availableJmxPort + "");
+      jmxPort = Integer.parseInt(properties.getProperty(JMX_MANAGER_PORT));
     } else {
       // the real port numbers will be set after we started the server/locator.
-      this.jmxPort = 0;
+      jmxPort = 0;
     }
     properties.putIfAbsent(JMX_MANAGER, "true");
     properties.putIfAbsent(JMX_MANAGER_START, "true");
@@ -295,9 +299,8 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
   public T withHttpService(boolean useDefaultPort) {
     properties.setProperty(HTTP_SERVICE_BIND_ADDRESS, "localhost");
     if (!useDefaultPort) {
-      properties.put(HTTP_SERVICE_PORT,
-          portSupplier.getAvailablePort() + "");
-      this.httpPort = Integer.parseInt(properties.getProperty(HTTP_SERVICE_PORT));
+      properties.put(HTTP_SERVICE_PORT, availableHttpPort + "");
+      httpPort = Integer.parseInt(properties.getProperty(HTTP_SERVICE_PORT));
     } else {
       // indicate start http service but with default port
       // (different from Gemfire properties, 0 means do not start http service)
@@ -310,7 +313,7 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
     this.cleanWorkingDir = cleanWorkingDir;
   }
 
-  /**
+  /*
    * start the jmx manager and admin rest on a random ports
    */
   public T withJMXManager() {
@@ -402,14 +405,19 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
     await().until(() -> bean.getClientIds().length == clientCount);
   }
 
-  /**
+  /*
    * Invoked in serverVM
    */
 
   /**
    * convenience method to create a region with customized regionFactory
    *
+   * @param <K> the type of keys in the region
+   * @param <V> the ype of values in the region
+   * @param type the {@link RegionShortcut} to use to create the region
+   * @param name the name of the region to create
    * @param regionFactoryConsumer a lamda that allows you to customize the regionFactory
+   * @return the newly created region
    */
   public <K, V> Region<K, V> createRegion(RegionShortcut type, String name,
       Consumer<RegionFactory<K, V>> regionFactoryConsumer) {
@@ -427,9 +435,11 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
    * convenience method to create a partition region with customized regionFactory and a customized
    * PartitionAttributeFactory
    *
+   * @param name the name of the region to create
    * @param regionFactoryConsumer a lamda that allows you to customize the regionFactory
    * @param attributesFactoryConsumer a lamda that allows you to customize the
    *        partitionAttributeFactory
+   * @return a Partitioned Region
    */
   public Region createPartitionRegion(String name, Consumer<RegionFactory> regionFactoryConsumer,
       Consumer<PartitionAttributesFactory> attributesFactoryConsumer) {
@@ -489,7 +499,7 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
         .collect(Collectors.toList());
 
     waitUntilEqual(diskStoreSupplier,
-        x -> x.size(),
+        List::size,
         exactServerCount,
         predicateDescription,
         WAIT_UNTIL_TIMEOUT, TimeUnit.SECONDS);
@@ -501,8 +511,8 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
     String examinerDescription = String.format(
         "Expecting exactly %d servers to have an AEQ with id '%s'.", exactServerCount, queueId);
     waitUntilEqual(
-        () -> CliUtil.getMembersWithAsyncEventQueue(getCache(), queueId),
-        membersWithAEQ -> membersWithAEQ.size(),
+        () -> CliUtils.getMembersWithAsyncEventQueue(getCache(), queueId),
+        Set::size,
         exactServerCount,
         examinerDescription,
         WAIT_UNTIL_TIMEOUT, TimeUnit.SECONDS);
@@ -512,6 +522,8 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
    * This method wraps an {@link GeodeAwaitility#await()} call for more meaningful error
    * reporting.
    *
+   * @param <K> the type of results supplied by {@code supplier}
+   * @param <J> the type of results returned by {@code examiner}
    * @param supplier Method to retrieve the result to be tested, e.g.,
    *        get a list of visible region mbeans
    * @param examiner Method to evaluate the result provided by {@code provider}, e.g.,
@@ -542,7 +554,7 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
       // There is a very slight race condition here, where the above could conceivably time out,
       // and become satisfied before the next supplier.get()
       throw new ConditionTimeoutException(
-          "The observed result '" + String.valueOf(supplier.get())
+          "The observed result '" + supplier.get()
               + "' does not satisfy the provided assertionConsumer. \n" + e.getMessage());
     }
   }
@@ -550,6 +562,26 @@ public abstract class MemberStarterRule<T> extends SerializableExternalResource
   /**
    * Convenience alias for {@link #waitUntilSatisfied},
    * requiring equality rather than a generic assertion.
+   *
+   * @param <K> the type of results supplied by {@code provider}
+   * @param <J> the type of results returned by {@code examiner}
+   * @param provider Method to retrieve the result to be tested, e.g.,
+   *        get a list of visible region mbeans
+   * @param examiner Method to evaluate the result provided by {@code provider}, e.g.,
+   *        get the length of the provided list.
+   *        Use {@link java.util.function.Function#identity()} if {@code assertionConsumer}
+   *        directly tests the value provided by {@code supplier}.
+   * @param expectation assertThat styled condition on the output of {@code examiner} against
+   *        which
+   *        the {@code await().untilAsserted(...)} will be called. E.g.,
+   *        {@code beanCount -> assertThat(beanCount, is(5))}
+   * @param expectationDesription A description of the {@code assertionConsumer} method,
+   *        for additional failure information should this call time out.
+   *        E.g., "Visible region mbean count should be 5"
+   * @param timeout With {@code unit}, the maximum time to wait before raising an exception.
+   * @param unit With {@code timeout}, the maximum time to wait before raising an exception.
+   * @throws org.awaitility.core.ConditionTimeoutException The timeout has been reached
+   * @throws Exception Any exception produced by {@code provider.call()}
    */
   public <K, J> void waitUntilEqual(Supplier<K> provider,
       Function<K, J> examiner,
