@@ -26,10 +26,11 @@ import org.apache.geode.cache.Cache;
 import org.apache.geode.distributed.ConfigurationProperties;
 import org.apache.geode.distributed.ServerLauncher;
 import org.apache.geode.test.junit.rules.serializable.SerializableExternalResource;
+import org.apache.geode.test.junit.rules.serializable.SerializableTemporaryFolder;
 
 public class ServerLauncherStartupRule extends SerializableExternalResource {
   private ServerLauncher launcher;
-  private final TemporaryFolder temp = new TemporaryFolder();
+  private final TemporaryFolder temp = new SerializableTemporaryFolder();
   private final Properties properties = new Properties();
   private boolean autoStart;
   private UnaryOperator<ServerLauncher.Builder> builderOperator;
@@ -45,7 +46,7 @@ public class ServerLauncherStartupRule extends SerializableExternalResource {
   }
 
   public ServerLauncherStartupRule withProperty(String key, String value) {
-    this.properties.put(key, value);
+    properties.put(key, value);
     return this;
   }
 
