@@ -66,6 +66,7 @@ public class ServerStarterRule extends MemberStarterRule<ServerStarterRule> impl
   private PdxSerializer pdxSerializer = null;
   private boolean pdxReadSerialized = false;
   private boolean pdxReadSerializedUserSet = false;
+  private int maxThreads = -1;
   // By default we start one server per jvm
   private int serverCount = 1;
 
@@ -123,6 +124,11 @@ public class ServerStarterRule extends MemberStarterRule<ServerStarterRule> impl
     servers.clear();
   }
 
+  public ServerStarterRule withMaxThreads(int maxThreads) {
+    this.maxThreads = maxThreads;
+    return this;
+  }
+
   public ServerStarterRule withPDXPersistent() {
     pdxPersistent = true;
     pdxPersistentUserSet = true;
@@ -219,6 +225,9 @@ public class ServerStarterRule extends MemberStarterRule<ServerStarterRule> impl
       } else {
         server.setPort(0);
       }
+      if (maxThreads >= 0) {
+        server.setMaxThreads(maxThreads);
+      }
       try {
         server.start();
       } catch (IOException e) {
