@@ -17,6 +17,7 @@ package org.apache.geode.management.internal.cli.commands;
 import static java.lang.management.ManagementFactory.getPlatformMBeanServer;
 import static java.util.Arrays.asList;
 import static javax.management.ObjectName.getInstance;
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.lang.Identifiable.find;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.assertj.core.api.Assertions.assertThat;
@@ -444,9 +445,11 @@ public class CreateRegionCommandPersistsConfigurationDUnitTest {
       await().untilAsserted(() -> {
         assertThat(getPlatformMBeanServer().queryNames(getInstance("GemFire:*"), null))
             .contains(getInstance(
-                "GemFire:service=Region,name=/createRegionWithColocation,type=Distributed"))
+                "GemFire:service=Region,name=" + SEPARATOR
+                    + "createRegionWithColocation,type=Distributed"))
             .contains(getInstance(
-                "GemFire:service=Region,name=/createRegionWithColocation,type=Member,member=server-1"));
+                "GemFire:service=Region,name=" + SEPARATOR
+                    + "createRegionWithColocation,type=Member,member=server-1"));
       });
     });
 
@@ -471,14 +474,14 @@ public class CreateRegionCommandPersistsConfigurationDUnitTest {
       RegionConfig colocatedConfig = find(regions, colocatedRegionName);
       assertThat(
           colocatedConfig.getRegionAttributes().getPartitionAttributes().getColocatedWith())
-              .isEqualTo("/" + regionName);
+              .isEqualTo(SEPARATOR + regionName);
 
       RegionConfig colocatedConfigFromTemplate = find(regions,
           colocatedRegionFromTemplateName);
       assertThat(
           colocatedConfigFromTemplate.getRegionAttributes().getPartitionAttributes()
               .getColocatedWith())
-                  .isEqualTo("/" + regionName);
+                  .isEqualTo(SEPARATOR + regionName);
     });
   }
 
