@@ -28,8 +28,8 @@ import org.junit.experimental.categories.Category;
 import org.apache.geode.cache.execute.Execution;
 import org.apache.geode.cache.execute.FunctionService;
 import org.apache.geode.distributed.DistributedSystem;
-import org.apache.geode.internal.ClassPathLoader;
 import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.classloader.ClassPathLoader;
 import org.apache.geode.test.compiler.JarBuilder;
 import org.apache.geode.test.dunit.rules.ClusterStartupRule;
 import org.apache.geode.test.dunit.rules.MemberVM;
@@ -94,7 +94,7 @@ public class DeployCommandFunctionRegistrationDUnitTest {
 
   private File loadTestResource(String fileName) {
     String filePath =
-        createTempFileFromResource(this.getClass(), fileName).getAbsolutePath();
+        createTempFileFromResource(getClass(), fileName).getAbsolutePath();
     assertThat(filePath).isNotNull();
 
     return new File(filePath);
