@@ -18,7 +18,7 @@ import java.util.Optional;
 
 import org.junit.experimental.categories.Category;
 
-import org.apache.geode.management.internal.GfshSanctionedSerializablesService;
+import org.apache.geode.gfsh.internal.management.GfshSanctionedSerializablesService;
 import org.apache.geode.test.junit.categories.SerializationTest;
 
 @Category(SerializationTest.class)
