@@ -17,11 +17,19 @@ package org.apache.geode.management.internal.cli;
 import static java.lang.System.lineSeparator;
 import static org.assertj.core.api.Assertions.assertThat;
 
+import java.lang.reflect.Method;
+import java.lang.reflect.Parameter;
+import java.util.stream.Collectors;
+
+import org.junit.AfterClass;
+import org.junit.BeforeClass;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 import org.springframework.shell.core.Completion;
+import org.springframework.shell.core.annotation.CliOption;
 
+import org.apache.geode.management.internal.cli.commands.StartServerCommand;
 import org.apache.geode.management.internal.i18n.CliStrings;
 import org.apache.geode.test.junit.categories.GfshTest;
 import org.apache.geode.test.junit.rules.GfshParserRule;
@@ -30,6 +38,28 @@ import org.apache.geode.test.junit.rules.GfshParserRule.CommandCandidate;
 @Category(GfshTest.class)
 public class GfshParserAutoCompletionIntegrationTest {
 
+  private static int startServerCommandCliOptions = 0;
+
+  @BeforeClass
+  public static void calculateStartServerCommandParameters() {
+    Object o = new StartServerCommand();
+    for (Method method : o.getClass().getDeclaredMethods()) {
+      if (method.getName().equals("startServer")) {
+        for (Parameter param : method.getParameters()) {
+          CliOption annotation = param.getAnnotation(CliOption.class);
+          startServerCommandCliOptions += annotation.key().length;
+        }
+        break;
+      }
+    }
+    assertThat(startServerCommandCliOptions).isNotZero();
+  }
+
+  @AfterClass
+  public static void cleanup() {
+    startServerCommandCliOptions = 0;
+  }
+
   @Rule
   public GfshParserRule gfshParserRule = new GfshParserRule();
 
@@ -53,16 +83,18 @@ public class GfshParserAutoCompletionIntegrationTest {
   public void testCompletionDeploy() {
     String buffer = "deploy";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
-    assertThat(candidate.getCandidates()).hasSize(5);
-    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + " --dir");
+    assertThat(candidate.getCandidates()
+        .stream().map(completion -> completion.getValue().trim()).collect(Collectors.toList()))
+            .containsExactlyInAnyOrder("--dir", "--jar", "--jars", "--group", "--groups");
   }
 
   @Test
   public void testCompletionDeployWithSpace() {
     String buffer = "deploy ";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
-    assertThat(candidate.getCandidates()).hasSize(5);
-    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "--dir");
+    assertThat(candidate.getCandidates()
+        .stream().map(completion -> completion.getValue().trim()).collect(Collectors.toList()))
+            .containsExactlyInAnyOrder("--dir", "--jar", "--jars", "--group", "--groups");
   }
 
   @Test
@@ -148,7 +180,7 @@ public class GfshParserAutoCompletionIntegrationTest {
     String buffer = "start server --name=name1 --";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
     assertThat(candidate.getCursor()).isEqualTo(buffer.length() - 2);
-    assertThat(candidate.getCandidates()).hasSize(53);
+    assertThat(candidate.getCandidates()).hasSize(startServerCommandCliOptions - 1);
     assertThat(candidate.getCandidates()).contains(new Completion("--properties-file"));
     assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "J");
   }
@@ -158,7 +190,7 @@ public class GfshParserAutoCompletionIntegrationTest {
     String buffer = "start server --name=name1 ";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
     assertThat(candidate.getCursor()).isEqualTo(buffer.length() - 1);
-    assertThat(candidate.getCandidates()).hasSize(53);
+    assertThat(candidate.getCandidates()).hasSize(startServerCommandCliOptions - 1);
     assertThat(candidate.getCandidates()).contains(new Completion(" --properties-file"));
     assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "--J");
   }
@@ -168,7 +200,7 @@ public class GfshParserAutoCompletionIntegrationTest {
     String buffer = "start server --name=name1";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
     assertThat(candidate.getCursor()).isEqualTo(buffer.length());
-    assertThat(candidate.getCandidates()).hasSize(53);
+    assertThat(candidate.getCandidates()).hasSize(startServerCommandCliOptions - 1);
     assertThat(candidate.getCandidates()).contains(new Completion(" --properties-file"));
     assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + " --J");
   }
@@ -193,7 +225,7 @@ public class GfshParserAutoCompletionIntegrationTest {
   public void testCompleteWithDash() {
     String buffer = "start server --name=name1 --J=-Dfoo.bar --";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
-    assertThat(candidate.getCandidates()).hasSize(52);
+    assertThat(candidate.getCandidates()).hasSize(startServerCommandCliOptions - 2);
   }
 
   @Test
@@ -211,7 +243,7 @@ public class GfshParserAutoCompletionIntegrationTest {
     String buffer = "start server --name=name1 --J=-Dtest=test1 --J=-Dfoo=bar";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
     assertThat(candidate.getCursor()).isEqualTo(buffer.length());
-    assertThat(candidate.getCandidates()).hasSize(52);
+    assertThat(candidate.getCandidates()).hasSize(startServerCommandCliOptions - 2);
     assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + " --assign-buckets");
   }
 
@@ -220,7 +252,7 @@ public class GfshParserAutoCompletionIntegrationTest {
     String buffer = "start server --J=-Dtest=test1 --J=-Dfoo=bar --name=name1";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
     assertThat(candidate.getCursor()).isEqualTo(buffer.length());
-    assertThat(candidate.getCandidates()).hasSize(52);
+    assertThat(candidate.getCandidates()).hasSize(startServerCommandCliOptions - 2);
     assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + " --assign-buckets");
   }
 
@@ -229,7 +261,7 @@ public class GfshParserAutoCompletionIntegrationTest {
     String buffer = "start server --name=name1 --locators=localhost --J=-Dfoo=bar";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
     assertThat(candidate.getCursor()).isEqualTo(buffer.length());
-    assertThat(candidate.getCandidates()).hasSize(51);
+    assertThat(candidate.getCandidates()).hasSize(startServerCommandCliOptions - 3);
     assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + " --assign-buckets");
   }
 
@@ -238,7 +270,7 @@ public class GfshParserAutoCompletionIntegrationTest {
     String buffer = "start server --name=name1 --locators=localhost  --J=-Dfoo=bar --";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
     assertThat(candidate.getCursor()).isEqualTo(buffer.length() - 2);
-    assertThat(candidate.getCandidates()).hasSize(51);
+    assertThat(candidate.getCandidates()).hasSize(startServerCommandCliOptions - 3);
     assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "assign-buckets");
   }
 
@@ -270,7 +302,7 @@ public class GfshParserAutoCompletionIntegrationTest {
   public void testCompleteWithRegionTypeWithSpace() {
     String buffer = "create region --name=test --type=REPLICATE ";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
-    assertThat(candidate.getCandidates()).hasSize(45);
+    assertThat(candidate.getCandidates()).hasSize(47);
     assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "--async-event-queue-id");
   }
 
@@ -381,7 +413,7 @@ public class GfshParserAutoCompletionIntegrationTest {
     String hintArgument = "data";
     String hintsProvided = gfshParserRule.getCommandManager().obtainHint(hintArgument);
     String[] hintsProvidedArray = hintsProvided.split(lineSeparator());
-    assertThat(hintsProvidedArray.length).isEqualTo(17);
+    assertThat(hintsProvidedArray).hasSize(17);
     assertThat(hintsProvidedArray[0])
         .isEqualTo("User data as stored in regions of the Geode distributed system.");
   }
@@ -391,7 +423,7 @@ public class GfshParserAutoCompletionIntegrationTest {
     String hintArgument = "";
     String hintsProvided = gfshParserRule.getCommandManager().obtainHint(hintArgument);
     String[] hintsProvidedArray = hintsProvided.split(lineSeparator());
-    assertThat(hintsProvidedArray.length).isEqualTo(21);
+    assertThat(hintsProvidedArray).hasSize(21);
     assertThat(hintsProvidedArray[0]).isEqualTo(
         "Hints are available for the following topics. Use \"hint <topic-name>\" for a specific hint.");
   }
@@ -401,7 +433,7 @@ public class GfshParserAutoCompletionIntegrationTest {
     String hintArgument = "fortytwo";
     String hintsProvided = gfshParserRule.getCommandManager().obtainHint(hintArgument);
     String[] hintsProvidedArray = hintsProvided.split(lineSeparator());
-    assertThat(hintsProvidedArray.length).isEqualTo(1);
+    assertThat(hintsProvidedArray).hasSize(1);
     assertThat(hintsProvidedArray[0]).isEqualTo(
         "Unknown topic: " + hintArgument + ". Use hint to view the list of available topics.");
   }
@@ -429,4 +461,142 @@ public class GfshParserAutoCompletionIntegrationTest {
         .hasSize(org.apache.geode.cache.query.IndexType.values().length);
     assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "hash");
   }
+
+  @Test
+  public void testCompletionOffersMandatoryOptionsInAlphabeticalOrderForCreateGatewaySenderWithSpace() {
+    String buffer = "create gateway-sender ";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(2);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "--id");
+    assertThat(candidate.getCandidates().get(1).getValue())
+        .isEqualTo(buffer + "--remote-distributed-system-id");
+  }
+
+  @Test
+  public void testCompletionOffersTheFirstMandatoryOptionInAlphabeticalOrderForCreateGatewaySenderWithDash() {
+    String buffer = "create gateway-sender --";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(1);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "id");
+  }
+
+  @Test
+  public void testCompletionOffersMandatoryOptionsInAlphabeticalOrderForChangeLogLevelWithSpace() {
+    String buffer = "change loglevel ";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(1);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "--loglevel");
+  }
+
+  @Test
+  public void testCompletionOffersTheFirstMandatoryOptionInAlphabeticalOrderForChangeLogLevelWithDash() {
+    String buffer = "change loglevel --";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(1);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "loglevel");
+  }
+
+  @Test
+  public void testCompletionOffersMandatoryOptionsInAlphabeticalOrderForCreateDiskStoreWithSpace() {
+    String buffer = "create disk-store ";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(2);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "--dir");
+    assertThat(candidate.getCandidate(1)).isEqualTo(buffer + "--name");
+  }
+
+  @Test
+  public void testCompletionOffersTheFirstMandatoryOptionInAlphabeticalOrderForCreateDiskStoreWithDash() {
+    String buffer = "create disk-store --";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(1);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "dir");
+  }
+
+  @Test
+  public void testCompletionOffersMandatoryOptionsInAlphabeticalOrderForCreateJndiBindingWithSpace() {
+    String buffer = "create jndi-binding ";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(3);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "--connection-url");
+    assertThat(candidate.getCandidate(1)).isEqualTo(buffer + "--name");
+    assertThat(candidate.getCandidate(2)).isEqualTo(buffer + "--url");
+  }
+
+  @Test
+  public void testCompletionOffersTheFirstMandatoryOptionInAlphabeticalOrderForCreateJndiBindingWithDash() {
+    String buffer = "create jndi-binding --";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(2);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "connection-url");
+    assertThat(candidate.getCandidate(1)).isEqualTo(buffer + "url");
+  }
+
+  @Test
+  public void testCompletionOffersMandatoryOptionsInAlphabeticalOrderForDestroyGwSenderWithSpace() {
+    String buffer = "destroy gateway-sender ";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(1);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "--id");
+  }
+
+  @Test
+  public void testCompletionOffersTheFirstMandatoryOptionInAlphabeticalOrderForDestroyGwSenderWithDash() {
+    String buffer = "destroy gateway-sender --";
+
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(1);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "id");
+  }
+
+  @Test
+  public void testCompletionOffersMandatoryOptionsInAlphabeticalOrderForExportDataWithSpace() {
+    String buffer = "export data ";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(2);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "--member");
+    assertThat(candidate.getCandidate(1)).isEqualTo(buffer + "--region");
+  }
+
+  @Test
+  public void testCompletionOffersTheFirstMandatoryOptionInAlphabeticalOrderForExportDataWithDash() {
+    String buffer = "export data --";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(1);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "member");
+  }
+
+  @Test
+  public void testCompletionOffersMandatoryOptionsInAlphabeticalOrderForImportDataWithSpace() {
+    String buffer = "import data ";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(2);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "--member");
+    assertThat(candidate.getCandidate(1)).isEqualTo(buffer + "--region");
+  }
+
+  @Test
+  public void testCompletionOffersTheFirstMandatoryOptionInAlphabeticalOrderForImportDataWithDash() {
+    String buffer = "import data --";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(1);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "member");
+  }
+
+  @Test
+  public void testCompletionOffersMandatoryOptionsInAlphabeticalOrderForRemoveWithSpace() {
+    String buffer = "remove ";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(1);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "--region");
+  }
+
+  @Test
+  public void testCompletionOffersTheFirstMandatoryOptionInAlphabeticalOrderForRemoveWithDash() {
+    String buffer = "remove --";
+    CommandCandidate candidate = gfshParserRule.complete(buffer);
+    assertThat(candidate.getCandidates()).hasSize(1);
+    assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "region");
+  }
+
 }
