@@ -15,6 +15,7 @@
 
 package org.apache.geode.management.internal.cli.commands;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.assertj.core.api.Assertions.assertThat;
 
 import org.junit.BeforeClass;
@@ -45,41 +46,46 @@ public class AlterRegionCommandIntegrationTest {
 
   @Test
   public void validateGroup() {
-    gfsh.executeAndAssertThat("alter region --name=/REPLICATED --group=unknown").statusIsError()
+    gfsh.executeAndAssertThat("alter region --name=" + SEPARATOR + "REPLICATED --group=unknown")
+        .statusIsError()
         .containsOutput("No Members Found");
   }
 
   @Test
   public void invalidCacheListener() {
-    gfsh.executeAndAssertThat("alter region --name=/REPLICATED --cache-listener=abc-def")
+    gfsh.executeAndAssertThat(
+        "alter region --name=" + SEPARATOR + "REPLICATED --cache-listener=abc-def")
         .statusIsError().containsOutput(
             "java.lang.IllegalArgumentException: Failed to convert 'abc-def' to type ClassName[] for option 'cache-listener'");
   }
 
   @Test
   public void invalidCacheLoader() {
-    gfsh.executeAndAssertThat("alter region --name=/REPLICATED --cache-loader=abc-def")
+    gfsh.executeAndAssertThat(
+        "alter region --name=" + SEPARATOR + "REPLICATED --cache-loader=abc-def")
         .statusIsError().containsOutput(
             "java.lang.IllegalArgumentException: Failed to convert 'abc-def' to type ClassName for option 'cache-loader'");
   }
 
   @Test
   public void invalidCacheWriter() {
-    gfsh.executeAndAssertThat("alter region --name=/REPLICATED --cache-writer=abc-def")
+    gfsh.executeAndAssertThat(
+        "alter region --name=" + SEPARATOR + "REPLICATED --cache-writer=abc-def")
         .statusIsError().containsOutput(
             "java.lang.IllegalArgumentException: Failed to convert 'abc-def' to type ClassName for option 'cache-writer'");
   }
 
   @Test
   public void invalidEvictionMax() {
-    gfsh.executeAndAssertThat("alter region --name=/REPLICATED --eviction-max=-1").statusIsError()
+    gfsh.executeAndAssertThat("alter region --name=" + SEPARATOR + "REPLICATED --eviction-max=-1")
+        .statusIsError()
         .containsOutput("Specify 0 or a positive integer value for eviction-max");
   }
 
 
   @Test
   public void alterRegionWithGatewaySender() {
-    Region<?, ?> region = server.getCache().getRegion("/REPLICATED");
+    Region<?, ?> region = server.getCache().getRegion(SEPARATOR + "REPLICATED");
     region.getAttributesMutator().addGatewaySenderId("1");
     gfsh.executeAndAssertThat("alter region --name=REPLICATED --gateway-sender-id='1,2'")
         .statusIsSuccess();
@@ -92,7 +98,7 @@ public class AlterRegionCommandIntegrationTest {
 
   @Test
   public void alterRegionWithAsyncEventQueue() {
-    Region<?, ?> region = server.getCache().getRegion("/REPLICATED");
+    Region<?, ?> region = server.getCache().getRegion(SEPARATOR + "REPLICATED");
     region.getAttributesMutator().addAsyncEventQueueId("1");
     gfsh.executeAndAssertThat("alter region --name=REPLICATED --async-event-queue-id='1,2'")
         .statusIsSuccess();
