@@ -24,6 +24,7 @@ import java.util.Formatter;
 import java.util.HashMap;
 import java.util.Map;
 
+import org.joda.time.DateTime;
 import org.junit.BeforeClass;
 import org.junit.ClassRule;
 import org.junit.Test;
@@ -47,7 +48,7 @@ import org.apache.geode.test.junit.rules.ServerStarterRule;
 
 public class GetCommandIntegrationTest {
 
-  private static final Map<String, User> userDataStore = new HashMap<String, User>(5);
+  private static final Map<String, User> userDataStore = new HashMap<>(5);
 
   static {
     userDataStore.put("jackhandy", new User("jackhandy"));
@@ -57,10 +58,10 @@ public class GetCommandIntegrationTest {
     userDataStore.put("supertool", new User("supertool"));
   }
 
-  private static ServerStarterRule server =
+  private static final ServerStarterRule server =
       new ServerStarterRule().withJMXManager().withAutoStart();
 
-  private static GfshCommandRule gfsh =
+  private static final GfshCommandRule gfsh =
       new GfshCommandRule(server::getJmxPort, GfshCommandRule.PortType.jmxManager);
 
   @ClassRule
@@ -100,7 +101,11 @@ public class GetCommandIntegrationTest {
 
   @Test
   public void get() throws Exception {
-    gfsh.executeAndAssertThat("get --region=Users --key=jonbloom").statusIsSuccess();
+    gfsh.executeAndAssertThat("get --region=Users --key=jonbloom")
+        .statusIsSuccess()
+        .hasDataSection(DataCommandResult.DATA_INFO_SECTION)
+        .hasContent()
+        .hasEntrySatisfying("Value", v -> v.contains("\"startTime\":1653595626520"));
   }
 
   @Test
@@ -205,16 +210,28 @@ public class GetCommandIntegrationTest {
 
   private static class User implements Serializable {
     private final String username;
+    private final DateTime startTime;
 
     public User(final String username) {
       assert username != null : "The username cannot be null!";
       this.username = username;
+      this.startTime = new DateTime();
+    }
+
+    public User(final String username, DateTime startTime) {
+      assert username != null : "The username cannot be null!";
+      this.username = username;
+      this.startTime = startTime;
     }
 
     public String getUsername() {
       return username;
     }
 
+    public DateTime getStartTime() {
+      return startTime;
+    }
+
     public String getHashcode() {
       StringBuilder sb = new StringBuilder(username.getBytes().length * 2);
 
@@ -238,7 +255,7 @@ public class GetCommandIntegrationTest {
 
       User that = (User) obj;
 
-      return this.getUsername().equals(that.getUsername());
+      return getUsername().equals(that.getUsername());
     }
   }
 
@@ -255,7 +272,7 @@ public class GetCommandIntegrationTest {
   private static class UserPdxDataStoreCacheLoader
       implements CacheLoader<String, PdxInstance>, Serializable {
 
-    private InternalCache cache;
+    private final InternalCache cache;
 
     UserPdxDataStoreCacheLoader(InternalCache cache) {
       this.cache = cache;
