@@ -12,23 +12,24 @@
  * or implied. See the License for the specific language governing permissions and limitations under
  * the License.
  */
-
 package org.apache.geode.management.internal.cli.result.model;
 
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.io.File;
-import java.io.IOException;
 import java.nio.file.Files;
 
+import com.fasterxml.jackson.databind.ObjectMapper;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 
+import org.apache.geode.management.cli.Result;
 import org.apache.geode.management.internal.cli.result.CommandResult;
 import org.apache.geode.test.junit.assertions.ResultModelAssert;
+import org.apache.geode.util.internal.GeodeJsonMapper;
 
 public class ResultModelIntegrationTest {
 
@@ -45,35 +46,48 @@ public class ResultModelIntegrationTest {
   }
 
   @Test
-  public void emptyFileSizeDoesNothing() throws IOException {
+  public void emptyFileSizeDoesNothing() throws Exception {
     ResultModel emptyFileResult = new ResultModel();
     result.saveFileTo(temporaryFolder.newFolder());
+
     assertThat(emptyFileResult.getInfoSections()).hasSize(0);
   }
 
   @Test
   public void savesToNullThrowException() {
-    assertThatThrownBy(() -> result.saveFileTo(null)).isInstanceOf(NullPointerException.class);
+    assertThatThrownBy(() -> result.saveFileTo(null))
+        .isInstanceOf(NullPointerException.class);
   }
 
   @Test
-  public void notADirectory() throws IOException {
+  public void notADirectory() throws Exception {
     result.saveFileTo(temporaryFolder.newFile());
-    assertThis(result).hasInfoResultModel("fileSave").hasOutput().contains("is not a directory");
+
+    assertThis(result)
+        .hasInfoResultModel("fileSave")
+        .hasOutput()
+        .contains("is not a directory");
   }
 
   @Test
-  public void dirNotExistBefore() throws IOException {
+  public void dirNotExistBefore() throws Exception {
     File dir = temporaryFolder.newFolder("test");
     Files.delete(dir.toPath());
 
     result.saveFileTo(dir);
-    assertThat(dir).exists();
+    assertThat(dir)
+        .exists();
+
     File file1 = new File(dir, "test1.txt");
     File file2 = new File(dir, "test2.txt");
-    assertThat(dir.listFiles()).contains(file1, file2);
 
-    assertThis(result).hasInfoResultModel("fileSave").hasLines().hasSize(2)
+    assertThat(dir.listFiles())
+        .contains(file1, file2);
+
+    assertThis(result)
+        .hasInfoResultModel("fileSave")
+        .hasLines()
+        .hasSize(2)
         .containsExactlyInAnyOrder(
             "File saved to " + file1.getAbsolutePath(),
             "File saved to " + file2.getAbsolutePath());
@@ -81,13 +95,30 @@ public class ResultModelIntegrationTest {
 
   @Test
   @SuppressWarnings("deprecation")
-  public void modelCommandResultShouldNotDealWithFiles() throws IOException {
+  public void modelCommandResultShouldNotDealWithFiles() throws Exception {
     result.saveFileTo(temporaryFolder.newFolder("test"));
-    CommandResult commandResult = new CommandResult(result);
-    assertThat(commandResult.hasIncomingFiles()).isFalse();
+    Result commandResult = new CommandResult(result);
+
+    assertThat(commandResult.hasIncomingFiles())
+        .isFalse();
   }
 
-  public static ResultModelAssert assertThis(ResultModel model) {
+  @Test
+  public void serializeFileToDownload() throws Exception {
+    File file = temporaryFolder.newFile("test.log");
+    ResultModel result = new ResultModel();
+    result.addFile(file, FileResultModel.FILE_TYPE_FILE);
+    ObjectMapper mapper = GeodeJsonMapper.getMapper();
+    String json = mapper.writeValueAsString(result);
+    ResultModel resultModel = mapper.readValue(json, ResultModel.class);
+
+    File value = resultModel.getFileToDownload().toFile();
+
+    assertThat(value)
+        .isEqualTo(file);
+  }
+
+  private static ResultModelAssert assertThis(ResultModel model) {
     return new ResultModelAssert(model);
   }
 }
