@@ -86,7 +86,8 @@ public class ConnectCommand extends OfflineGfshCommand {
           unspecifiedDefaultValue = "false",
           help = CliStrings.CONNECT__USE_HTTP__HELP) boolean useHttp,
       @CliOption(key = {CliStrings.CONNECT__URL}, help = CliStrings.CONNECT__URL__HELP) String url,
-      @CliOption(key = {CliStrings.CONNECT__USERNAME}, specifiedDefaultValue = "",
+      @CliOption(key = {CliStrings.CONNECT__USERNAME, CliStrings.CONNECT__USERNAME_LONGFORM},
+          specifiedDefaultValue = "",
           help = CliStrings.CONNECT__USERNAME__HELP) String userName,
       @CliOption(key = {CliStrings.CONNECT__PASSWORD}, specifiedDefaultValue = "",
           help = CliStrings.CONNECT__PASSWORD__HELP) String password,
