@@ -40,6 +40,7 @@ import org.apache.geode.cache.configuration.CacheElement;
 import org.apache.geode.cache.configuration.ClassNameType;
 import org.apache.geode.cache.configuration.DeclarableType;
 import org.apache.geode.cache.configuration.EnumActionDestroyOverflow;
+import org.apache.geode.cache.configuration.RegionAttributesScope;
 import org.apache.geode.cache.configuration.RegionAttributesType;
 import org.apache.geode.cache.configuration.RegionConfig;
 import org.apache.geode.distributed.DistributedMember;
@@ -77,6 +78,7 @@ public class CreateRegionCommand extends SingleGfshCommand {
       CliStrings.CREATE_REGION__STARTUPRECOVERYDDELAY,
       CliStrings.CREATE_REGION__TOTALMAXMEMORY,
       CliStrings.CREATE_REGION__TOTALNUMBUCKETS,
+      CliStrings.CREATE_REGION__PARTITION_LISTENER,
       CliStrings.CREATE_REGION__PARTITION_RESOLVER
   };
 
@@ -167,6 +169,9 @@ public class CreateRegionCommand extends SingleGfshCommand {
           help = CliStrings.CREATE_REGION__LOCALMAXMEMORY__HELP) Integer prLocalMaxMemory,
       @CliOption(key = CliStrings.CREATE_REGION__OFF_HEAP, specifiedDefaultValue = "true",
           help = CliStrings.CREATE_REGION__OFF_HEAP__HELP) Boolean offHeap,
+      @CliOption(key = CliStrings.CREATE_REGION__PARTITION_LISTENER,
+          optionContext = "splittingRegex=,(?![^{]*\\})",
+          help = CliStrings.CREATE_REGION__PARTITION_LISTENER__HELP) ClassName[] partitionListener,
       @CliOption(key = CliStrings.CREATE_REGION__PARTITION_RESOLVER,
           help = CliStrings.CREATE_REGION__PARTITION_RESOLVER__HELP) String partitionResolver,
       @CliOption(key = CliStrings.CREATE_REGION__REGIONEXPIRATIONIDLETIME,
@@ -188,7 +193,9 @@ public class CreateRegionCommand extends SingleGfshCommand {
       @CliOption(key = CliStrings.CREATE_REGION__TOTALNUMBUCKETS,
           help = CliStrings.CREATE_REGION__TOTALNUMBUCKETS__HELP) Integer prTotalNumBuckets,
       @CliOption(key = CliStrings.CREATE_REGION__VALUECONSTRAINT,
-          help = CliStrings.CREATE_REGION__VALUECONSTRAINT__HELP) String valueConstraint
+          help = CliStrings.CREATE_REGION__VALUECONSTRAINT__HELP) String valueConstraint,
+      @CliOption(key = CliStrings.CREATE_REGION__SCOPE,
+          help = CliStrings.CREATE_REGION__SCOPE__HELP) RegionAttributesScope scope
   // NOTICE: keep the region attributes params in alphabetical order
   ) {
     if (regionShortcut != null && templateRegion != null) {
@@ -227,6 +234,10 @@ public class CreateRegionCommand extends SingleGfshCommand {
       regionConfig.setType(regionShortcut.name());
       regionConfig.setRegionAttributes(
           new RegionConverter().createRegionAttributesByType(regionShortcut.name()));
+      RegionAttributesType regionAttributesType = regionConfig.getRegionAttributes();
+      if (scope != null && regionShortcut.isReplicate()) {
+        regionAttributesType.setScope(scope);
+      }
     }
     // get the attributes from the template region
     else {
@@ -281,10 +292,15 @@ public class CreateRegionCommand extends SingleGfshCommand {
 
     regionConfig.setName(regionPathData.getName());
 
+    List<String> partitionListeners = partitionListener == null ? Collections.emptyList()
+        : Arrays.stream(partitionListener)
+            .map(ClassName::getClassName).collect(Collectors.toList());
+
     // set partition attributes
     RegionAttributesType regionAttributes = regionConfig.getRegionAttributes();
     RegionAttributesType.PartitionAttributes delta =
-        RegionAttributesType.PartitionAttributes.generate(partitionResolver, null, prLocalMaxMemory,
+        RegionAttributesType.PartitionAttributes.generate(partitionResolver,
+            partitionListeners, prLocalMaxMemory,
             prRecoveryDelay, prRedundantCopies, prStartupRecoveryDelay, prTotalMaxMemory,
             prTotalNumBuckets, prColocatedWith);
 
@@ -608,8 +624,94 @@ public class CreateRegionCommand extends SingleGfshCommand {
     return false;
   }
 
+  RegionConfig findNonProxyRegionsInClusterConfigurationByName(String regionName,
+      InternalConfigurationPersistenceService persistenceService) {
+    RegionConfig regionConfig;
+    for (String group : persistenceService.getGroups()) {
+      CacheConfig config = persistenceService.getCacheConfig(group);
+      if (config != null) {
+        regionConfig =
+            config.getRegions().stream().filter(
+                region -> region.getName().equals(regionName) && !region.getType()
+                    .contains("PROXY"))
+                .findFirst().orElse(null);
+        if (regionConfig != null) {
+          return regionConfig;
+        }
+      }
+    }
+    return null;
+  }
+
+  boolean isRegionExistsInGroup(String regionName, String group,
+      InternalConfigurationPersistenceService persistenceService) {
+    CacheConfig config = persistenceService.getCacheConfig(group);
+    RegionConfig regionConfig = null;
+    if (config != null) {
+      regionConfig =
+          config.getRegions().stream().filter(region -> region.getName().equals(regionName))
+              .findFirst().orElse(null);
+    }
+    return regionConfig != null;
+  }
+
+  private void failIfRegionExistsInClusterConfiguration(String regionPathFull, String[] groups,
+      RegionShortcut regionShortcut) {
+    InternalConfigurationPersistenceService persistenceService =
+        getConfigurationPersistenceService();
+    if (persistenceService == null) {
+      return;
+    }
+
+    RegionPath regionPath = new RegionPath(regionPathFull);
+    RegionConfig regionConfig =
+        findNonProxyRegionsInClusterConfigurationByName(regionPath.getName(), persistenceService);
+    if (regionConfig == null) {
+      return;
+    }
+
+    String existingDataPolicy = regionConfig.getType();
+    boolean existingRegionIsNotProxy = !existingDataPolicy.contains("PROXY");
+    if (regionShortcut.isLocal() || existingDataPolicy.equals("NORMAL")
+        || (!regionShortcut.isProxy() && existingRegionIsNotProxy)) {
+      throw new EntityExistsException(
+          String.format("Region %s already exists on the cluster.", regionPath.getRegionPath()));
+    }
+
+    if (regionShortcut.isPartition() && !existingDataPolicy.contains("PARTITION")) {
+      LogService.getLogger().info("Create region command: got EntityExists exception");
+      throw new EntityExistsException("The existing region is not a partitioned region");
+    }
+
+    if (regionShortcut.isReplicate() && !existingDataPolicy.equals("EMPTY")
+        && !existingDataPolicy.contains("REPLICATE") && !existingDataPolicy.contains("PRELOADED")) {
+      throw new EntityExistsException("The existing region is not a replicate region");
+    }
+
+    if (groups == null) {
+      if (isRegionExistsInGroup(regionPath.getName(), null, persistenceService)) {
+        throw new EntityExistsException(
+            String.format("Region %s already exists on the cluster.", regionPath.getRegionPath()));
+      }
+    } else {
+      List<String> groupsExists = new ArrayList<>();
+      for (String group : groups) {
+        if (isRegionExistsInGroup(regionPath.getName(), group, persistenceService)) {
+          groupsExists.add(group);
+        }
+      }
+      if (!groupsExists.isEmpty()) {
+        throw new EntityExistsException(
+            String.format("Region %s already exists in groups: %s.", regionPath.getRegionPath(),
+                StringUtils.join(groupsExists, ",")));
+      }
+    }
+  }
+
   private void failIfRegionAlreadyExists(String regionPath, RegionShortcut regionShortcut,
       String[] groups) throws EntityExistsException {
+
+    failIfRegionExistsInClusterConfiguration(regionPath, groups, regionShortcut);
     /*
      * Adding name collision check for regions created with regionShortcut only.
      * Regions can be categories as Proxy(replicate/partition), replicate/partition, and local
@@ -694,6 +796,7 @@ public class CreateRegionCommand extends SingleGfshCommand {
               "PartitionAttributes localMaxMemory must not be negative.");
         }
       }
+
       Long totalMaxMemory =
           (Long) parseResult.getParamValue(CliStrings.CREATE_REGION__TOTALMAXMEMORY);
       if (totalMaxMemory != null) {
@@ -827,7 +930,18 @@ public class CreateRegionCommand extends SingleGfshCommand {
           && EvictionAction.parseAction(evictionAction) == EvictionAction.NONE) {
         return ResultModel.createError(CliStrings.CREATE_REGION__MSG__INVALID_EVICTION_ACTION);
       }
-
+      RegionAttributesScope scope =
+          (RegionAttributesScope) parseResult.getParamValue(CliStrings.CREATE_REGION__SCOPE);
+      RegionShortcut regionShortcut =
+          (RegionShortcut) parseResult.getParamValue(CliStrings.CREATE_REGION__REGIONSHORTCUT);
+      if (scope != null && regionShortcut == null) {
+        return ResultModel
+            .createError(CliStrings.CREATE_REGION__SCOPE__SCOPE_CANNOT_BE_SET_IF_TYPE_NOT_SET);
+      } else if (scope != null && !regionShortcut.isReplicate()) {
+        return ResultModel
+            .createError(
+                CliStrings.CREATE_REGION__MSG__SCOPE_CANNOT_BE_SET_ON_NON_REPLICATED_REGION);
+      }
       return ResultModel.createInfo("");
     }
   }
