@@ -16,7 +16,6 @@
 package org.apache.geode.management.internal.cli.commands;
 
 import java.util.List;
-import java.util.Map;
 import java.util.Set;
 
 import org.springframework.shell.core.annotation.CliCommand;
@@ -28,6 +27,7 @@ import org.apache.geode.management.cli.GfshCommand;
 import org.apache.geode.management.internal.cli.functions.ListDeployedFunction;
 import org.apache.geode.management.internal.cli.result.model.ResultModel;
 import org.apache.geode.management.internal.cli.result.model.TabularResultModel;
+import org.apache.geode.management.internal.cli.util.DeploymentInfoTableUtil;
 import org.apache.geode.management.internal.functions.CliFunctionResult;
 import org.apache.geode.management.internal.i18n.CliStrings;
 import org.apache.geode.management.internal.security.ResourceOperation;
@@ -57,21 +57,12 @@ public class ListDeployedCommand extends GfshCommand {
     ResultModel result = new ResultModel();
     TabularResultModel tabularData = result.addTable("jars");
 
-    List<CliFunctionResult> functionResults = executeAndGetFunctionResult(this.listDeployedFunction,
+    List<CliFunctionResult> functionResults = executeAndGetFunctionResult(listDeployedFunction,
         null, targetMembers);
 
-    for (CliFunctionResult cliResult : functionResults) {
-      @SuppressWarnings("unchecked")
-      Map<String, String> strings = (Map<String, String>) cliResult.getResultObject();
-      if (strings == null) {
-        continue;
-      }
-      for (Map.Entry<String, String> jar : strings.entrySet()) {
-        tabularData.accumulate("Member", cliResult.getMemberIdOrName());
-        tabularData.accumulate("JAR", jar.getKey());
-        tabularData.accumulate("JAR Location", jar.getValue());
-      }
-    }
+    DeploymentInfoTableUtil.writeDeploymentInfoToTable(
+        new String[] {"Member", "JAR", "JAR Location"}, tabularData,
+        DeploymentInfoTableUtil.getDeploymentInfoFromFunctionResults(functionResults));
 
     if (tabularData.getRowSize() == 0) {
       return ResultModel.createInfo(CliStrings.LIST_DEPLOYED__NO_JARS_FOUND_MESSAGE);
