@@ -15,9 +15,11 @@
 
 package org.apache.geode.management.internal.cli.commands;
 
+import static java.lang.System.lineSeparator;
+import static org.apache.geode.management.internal.cli.commands.StartMemberUtils.resolveWorkingDirectory;
+
 import java.io.File;
 import java.io.IOException;
-import java.net.InetAddress;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
@@ -127,12 +129,12 @@ public class StartLocatorCommand extends OfflineGfshCommand {
       memberName = StartMemberUtils.getNameGenerator().generate('-');
     }
 
-    workingDirectory = StartMemberUtils.resolveWorkingDir(
-        workingDirectory == null ? null : new File(workingDirectory), new File(memberName));
+    String resolvedWorkingDirectory = resolveWorkingDirectory(workingDirectory, memberName);
 
     return doStartLocator(memberName, bindAddress, classpath, force, group, hostnameForClients,
         jmxManagerHostnameForClients, includeSystemClasspath, locators, logLevel, mcastBindAddress,
-        mcastPort, port, workingDirectory, gemfirePropertiesFile, gemfireSecurityPropertiesFile,
+        mcastPort, port, resolvedWorkingDirectory, gemfirePropertiesFile,
+        gemfireSecurityPropertiesFile,
         initialHeap, maxHeap, jvmArgsOpts, connect, enableSharedConfiguration,
         loadSharedConfigurationFromDirectory, clusterConfigDir, httpServicePort,
         httpServiceBindAddress, redirectOutput);
@@ -228,11 +230,11 @@ public class StartLocatorCommand extends OfflineGfshCommand {
     final ProcessStreamReader.ReadingMode readingMode = SystemUtils.isWindows()
         ? ProcessStreamReader.ReadingMode.NON_BLOCKING : ProcessStreamReader.ReadingMode.BLOCKING;
 
-    final StringBuffer message = new StringBuffer(); // need thread-safe StringBuffer
+    final StringBuilder message = new StringBuilder(); // need thread-safe StringBuilder
     ProcessStreamReader.InputListener inputListener = line -> {
       message.append(line);
       if (readingMode == ProcessStreamReader.ReadingMode.BLOCKING) {
-        message.append(SystemUtils.getLineSeparator());
+        message.append(lineSeparator());
       }
     };
 
@@ -269,7 +271,7 @@ public class StartLocatorCommand extends OfflineGfshCommand {
           if (locatorState.isStartingOrNotResponding()
               && !(StringUtils.isBlank(currentLocatorStatusMessage)
                   || currentLocatorStatusMessage.equalsIgnoreCase(previousLocatorStatusMessage)
-                  || currentLocatorStatusMessage.trim().toLowerCase().equals("null"))) {
+                  || currentLocatorStatusMessage.trim().equalsIgnoreCase("null"))) {
             Gfsh.println();
             Gfsh.println(currentLocatorStatusMessage);
             previousLocatorStatusMessage = currentLocatorStatusMessage;
@@ -279,7 +281,7 @@ public class StartLocatorCommand extends OfflineGfshCommand {
 
           return ResultModel.createError(
               String.format(CliStrings.START_LOCATOR__PROCESS_TERMINATED_ABNORMALLY_ERROR_MESSAGE,
-                  exitValue, locatorLauncher.getWorkingDirectory(), message.toString()));
+                  exitValue, locatorLauncher.getWorkingDirectory(), message));
         }
       } while (!(registeredLocatorSignalListener && locatorSignalListener.isSignaled())
           && locatorState.isStartingOrNotResponding());
@@ -314,9 +316,9 @@ public class StartLocatorCommand extends OfflineGfshCommand {
 
     infoResult.addLine(locatorState.toString());
     String locatorHostName;
-    InetAddress bindAddr = locatorLauncher.getBindAddress();
+    String bindAddr = locatorLauncher.getBindAddressString();
     if (bindAddr != null) {
-      locatorHostName = bindAddr.getCanonicalHostName();
+      locatorHostName = bindAddr;
     } else {
       locatorHostName = StringUtils.defaultIfBlank(locatorLauncher.getHostnameForClients(),
           HostUtils.getLocalHost());
@@ -456,6 +458,7 @@ public class StartLocatorCommand extends OfflineGfshCommand {
     commandLine.add("-classpath");
     commandLine
         .add(getLocatorClasspath(Boolean.TRUE.equals(includeSystemClasspath), userClasspath));
+    commandLine.addAll(MemberJvmOptions.getMemberJvmOptions());
 
     StartMemberUtils.addCurrentLocators(this, commandLine, gemfireProperties);
     StartMemberUtils.addGemFirePropertyFile(commandLine, gemfirePropertiesFile);
@@ -481,8 +484,8 @@ public class StartLocatorCommand extends OfflineGfshCommand {
       commandLine.add(launcher.getMemberName());
     }
 
-    if (launcher.getBindAddress() != null) {
-      commandLine.add("--bind-address=" + launcher.getBindAddress().getHostAddress());
+    if (launcher.getBindAddressString() != null) {
+      commandLine.add("--bind-address=" + launcher.getBindAddressString());
     }
 
     if (launcher.isDebugging() || isDebugging()) {
