@@ -39,7 +39,13 @@ public class ChangeLogLevelFunction implements InternalFunction<Object[]> {
   private static final Logger logger = LogService.getLogger();
   private static final long serialVersionUID = 1L;
 
-  public static final String ID = ChangeLogLevelFunction.class.getName();
+  private static final String ID =
+      "org.apache.geode.management.internal.cli.functions.ChangeLogLevelFunction";
+
+  @Override
+  public String getId() {
+    return ID;
+  }
 
   @Override
   public void execute(FunctionContext<Object[]> context) {
@@ -68,11 +74,6 @@ public class ChangeLogLevelFunction implements InternalFunction<Object[]> {
     }
   }
 
-  @Override
-  public String getId() {
-    return ID;
-  }
-
   @Override
   public boolean hasResult() {
     return true;
