@@ -26,15 +26,21 @@ import org.apache.geode.cache.configuration.JndiBindingsType.JndiBinding;
 import org.apache.geode.cache.execute.FunctionContext;
 import org.apache.geode.internal.datasource.ConfigProperty;
 import org.apache.geode.internal.jndi.JNDIInvoker;
-import org.apache.geode.internal.util.DriverJarUtil;
+import org.apache.geode.internal.util.DriverJarUtils;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.management.cli.CliFunction;
 import org.apache.geode.management.internal.functions.CliFunctionResult;
 import org.apache.geode.management.internal.functions.CliFunctionResult.StatusState;
 
 public class CreateJndiBindingFunction extends CliFunction<Object[]> {
-
   private static final Logger logger = LogService.getLogger();
+  private static final String ID =
+      "org.apache.geode.management.internal.cli.functions.CreateJndiBindingFunction";
+
+  @Override
+  public String getId() {
+    return ID;
+  }
 
   @Override
   public CliFunctionResult executeFunction(FunctionContext<Object[]> context) {
@@ -84,8 +90,8 @@ public class CreateJndiBindingFunction extends CliFunction<Object[]> {
     return params;
   }
 
-  DriverJarUtil getDriverJarUtil() {
-    return new DriverJarUtil();
+  DriverJarUtils getDriverJarUtil() {
+    return new DriverJarUtils();
   }
 
   static List<ConfigProperty> convert(
