@@ -14,6 +14,8 @@
  */
 package org.apache.geode.management.internal.cli.functions;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
+
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -44,11 +46,11 @@ import org.apache.geode.cache.query.internal.IndexTrackingQueryObserver;
 import org.apache.geode.cache.query.internal.QueryObserver;
 import org.apache.geode.cache.query.internal.QueryObserverHolder;
 import org.apache.geode.distributed.DistributedMember;
-import org.apache.geode.internal.ClassPathLoader;
 import org.apache.geode.internal.NanoTimer;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.PartitionedRegion;
 import org.apache.geode.internal.cache.execute.InternalFunction;
+import org.apache.geode.internal.classloader.ClassPathLoader;
 import org.apache.geode.internal.security.SecurityService;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.management.internal.cli.domain.DataCommandRequest;
@@ -70,9 +72,12 @@ public class DataCommandFunction implements InternalFunction<DataCommandRequest>
 
   private boolean optimizeForWrite = false;
 
+  private static final String ID =
+      "org.apache.geode.management.internal.cli.functions.DataCommandFunction";
+
   @Override
   public String getId() {
-    return DataCommandFunction.class.getName();
+    return ID;
   }
 
   @Override
@@ -418,7 +423,7 @@ public class DataCommandFunction implements InternalFunction<DataCommandRequest>
       // Recursively find the keys starting from the specified region path.
       List<String> regionPaths = getAllRegionPaths(cache, true);
       for (String path : regionPaths) {
-        if (path.startsWith(regionPath) || path.startsWith(Region.SEPARATOR + regionPath)) {
+        if (path.startsWith(regionPath) || path.startsWith(SEPARATOR + regionPath)) {
           Region targetRegion = cache.getRegion(path);
           listOfRegionsStartingWithRegionPath.add(targetRegion);
         }
@@ -595,7 +600,6 @@ public class DataCommandFunction implements InternalFunction<DataCommandRequest>
 
   private Object[] getClassAndJson(Object obj) {
     Object[] array = new Object[2];
-
     if (obj == null) {
       array[0] = null;
       array[1] = null;
@@ -609,7 +613,7 @@ public class DataCommandFunction implements InternalFunction<DataCommandRequest>
       return array;
     }
 
-    ObjectMapper mapper = new ObjectMapper();
+    ObjectMapper mapper = GeodeJsonMapper.getMapperWithAlwaysInclusion();
     try {
       array[1] = mapper.writeValueAsString(obj);
     } catch (JsonProcessingException e) {
