@@ -15,6 +15,8 @@
 
 package org.apache.geode.management.internal.cli.functions;
 
+import static java.lang.System.lineSeparator;
+
 import java.io.PrintWriter;
 import java.io.StringWriter;
 import java.util.Map;
@@ -36,10 +38,16 @@ import org.apache.geode.management.internal.functions.CliFunctionResult;
 public class ExportConfigFunction implements InternalFunction<Object> {
   private static final Logger logger = LogService.getLogger();
 
-  public static final String ID = ExportConfigFunction.class.getName();
-
   private static final long serialVersionUID = 1L;
 
+  private static final String ID =
+      "org.apache.geode.management.internal.cli.functions.ExportConfigFunction";
+
+  @Override
+  public String getId() {
+    return ID;
+  }
+
   @Override
   @SuppressWarnings("deprecation")
   public void execute(FunctionContext<Object> context) {
@@ -67,7 +75,7 @@ public class ExportConfigFunction implements InternalFunction<Object> {
           (DistributionConfigImpl) ((InternalDistributedSystem) cache.getDistributedSystem())
               .getConfig();
       StringBuilder propStringBuf = new StringBuilder();
-      String lineSeparator = System.getProperty("line.separator");
+      String lineSeparator = lineSeparator();
       for (Map.Entry entry : config.getConfigPropsFromSource(ConfigSource.runtime()).entrySet()) {
         if (entry.getValue() != null && !entry.getValue().equals("")) {
           propStringBuf.append(entry.getKey()).append("=").append(entry.getValue())
@@ -115,11 +123,6 @@ public class ExportConfigFunction implements InternalFunction<Object> {
     }
   }
 
-  @Override
-  public String getId() {
-    return ID;
-  }
-
   @Override
   public boolean hasResult() {
     return true;
