@@ -29,7 +29,7 @@ import org.apache.geode.cache.wan.GatewaySenderFactory;
 import org.apache.geode.cache.wan.GatewayTransportFilter;
 import org.apache.geode.internal.cache.execute.InternalFunction;
 import org.apache.geode.logging.internal.log4j.api.LogService;
-import org.apache.geode.management.internal.cli.CliUtil;
+import org.apache.geode.management.internal.cli.CliUtils;
 import org.apache.geode.management.internal.functions.CliFunctionResult;
 import org.apache.geode.management.internal.i18n.CliStrings;
 import org.apache.geode.management.internal.util.ManagementUtils;
@@ -40,11 +40,16 @@ public class GatewaySenderCreateFunction implements InternalFunction<GatewaySend
 
   private static final long serialVersionUID = 8746830191680509335L;
 
-  private static final String ID = GatewaySenderCreateFunction.class.getName();
-
   @Immutable
   public static final GatewaySenderCreateFunction INSTANCE = new GatewaySenderCreateFunction();
 
+  private static final String ID =
+      "org.apache.geode.management.internal.cli.functions.GatewaySenderCreateFunction";
+
+  @Override
+  public String getId() {
+    return ID;
+  }
 
   @Override
   public void execute(FunctionContext<GatewaySenderFunctionArgs> context) {
@@ -132,8 +137,8 @@ public class GatewaySenderCreateFunction implements InternalFunction<GatewaySend
       gateway.setDispatcherThreads(dispatcherThreads);
     }
 
-    if (dispatcherThreads != null && dispatcherThreads > 1) {
-      String orderPolicy = gatewaySenderCreateArgs.getOrderPolicy();
+    String orderPolicy = gatewaySenderCreateArgs.getOrderPolicy();
+    if (orderPolicy != null && dispatcherThreads != null && dispatcherThreads > 1) {
       gateway.setOrderPolicy(OrderPolicy.valueOf(orderPolicy));
     }
 
@@ -159,7 +164,7 @@ public class GatewaySenderCreateFunction implements InternalFunction<GatewaySend
             ManagementUtils.forName(gatewayEventFilter,
                 CliStrings.CREATE_GATEWAYSENDER__GATEWAYEVENTFILTER);
         gateway.addGatewayEventFilter(
-            (GatewayEventFilter) CliUtil.newInstance(gatewayEventFilterKlass,
+            (GatewayEventFilter) CliUtils.newInstance(gatewayEventFilterKlass,
                 CliStrings.CREATE_GATEWAYSENDER__GATEWAYEVENTFILTER));
       }
     }
@@ -169,7 +174,7 @@ public class GatewaySenderCreateFunction implements InternalFunction<GatewaySend
       for (String gatewayTransportFilter : gatewayTransportFilters) {
         Class<?> gatewayTransportFilterKlass = ManagementUtils.forName(gatewayTransportFilter,
             CliStrings.CREATE_GATEWAYSENDER__GATEWAYTRANSPORTFILTER);
-        gateway.addGatewayTransportFilter((GatewayTransportFilter) CliUtil.newInstance(
+        gateway.addGatewayTransportFilter((GatewayTransportFilter) CliUtils.newInstance(
             gatewayTransportFilterKlass, CliStrings.CREATE_GATEWAYSENDER__GATEWAYTRANSPORTFILTER));
       }
     }
@@ -183,10 +188,4 @@ public class GatewaySenderCreateFunction implements InternalFunction<GatewaySend
     return gateway.create(gatewaySenderCreateArgs.getId(),
         gatewaySenderCreateArgs.getRemoteDistributedSystemId());
   }
-
-  @Override
-  public String getId() {
-    return ID;
-  }
-
 }
