@@ -14,12 +14,15 @@
  */
 package org.apache.geode.management.internal.cli.functions;
 
+import java.util.function.BooleanSupplier;
+
 import org.apache.commons.lang3.exception.ExceptionUtils;
 import org.apache.logging.log4j.Logger;
 
 import org.apache.geode.annotations.Immutable;
 import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.cache.RegionExistsException;
+import org.apache.geode.cache.TimeoutException;
 import org.apache.geode.cache.execute.FunctionContext;
 import org.apache.geode.cache.execute.ResultSender;
 import org.apache.geode.internal.cache.InternalCache;
@@ -44,14 +47,20 @@ public class RegionCreateFunction implements InternalFunction {
 
   private static final long serialVersionUID = 8746830191680509335L;
 
-  private static final String ID = RegionCreateFunction.class.getName();
-
   @Immutable
   public static final RegionCreateFunction INSTANCE = new RegionCreateFunction();
 
   @Immutable
   private static final RegionConfigRealizer realizer = new RegionConfigRealizer();
 
+  private static final String ID =
+      "org.apache.geode.management.internal.cli.functions.RegionCreateFunction";
+
+  @Override
+  public String getId() {
+    return ID;
+  }
+
   @Override
   public boolean isHA() {
     return false;
@@ -64,8 +73,9 @@ public class RegionCreateFunction implements InternalFunction {
 
     InternalCache cache =
         ((InternalCache) context.getCache()).getCacheForProcessingClientRequests();
-    String memberNameOrId = context.getMemberName();
+    waitUntilConditionIsMet(() -> cache.getPdxRegistry() != null, 2000);
 
+    String memberNameOrId = context.getMemberName();
     CreateRegionFunctionArgs regionCreateArgs = (CreateRegionFunctionArgs) context.getArguments();
 
     try {
@@ -123,9 +133,14 @@ public class RegionCreateFunction implements InternalFunction {
     return new CliFunctionResult(memberNameOrId, CliFunctionResult.StatusState.ERROR);
   }
 
-  @Override
-  public String getId() {
-    return ID;
+  private void waitUntilConditionIsMet(BooleanSupplier awaitedCondition, int timeoutInMs) {
+    long startTime = System.currentTimeMillis();
+    while (!awaitedCondition.getAsBoolean()) {
+      if (System.currentTimeMillis() - startTime > timeoutInMs) {
+        throw new TimeoutException(
+            String.format("The pdxRegistry is not created within %s ms", timeoutInMs));
+      }
+    }
   }
 
   @VisibleForTesting
